@font-face {
    font-family: Inter var;
    font-weight: 100 900;
    font-display: swap;
    font-style: normal;
    font-named-instance:"Regular";src: url(/assets/inter-roman-cyrillic.CMhn1ESj.woff2) format("woff2");
    unicode-range: U+0301,U+0400-045F,U+0490-0491,U+04B0-04B1,U+2116
}

@font-face {
    font-family: Inter var;
    font-weight: 100 900;
    font-display: swap;
    font-style: normal;
    font-named-instance:"Regular";src: url(/assets/inter-roman-cyrillic-ext.DxP3Awbn.woff2) format("woff2");
    unicode-range: U+0460-052F,U+1C80-1C88,U+20B4,U+2DE0-2DFF,U+A640-A69F,U+FE2E-FE2F
}

@font-face {
    font-family: Inter var;
    font-weight: 100 900;
    font-display: swap;
    font-style: normal;
    font-named-instance:"Regular";src: url(/assets/inter-roman-greek.JvnBZ4YD.woff2) format("woff2");
    unicode-range: U+0370-03FF
}

@font-face {
    font-family: Inter var;
    font-weight: 100 900;
    font-display: swap;
    font-style: normal;
    font-named-instance:"Regular";src: url(/assets/inter-roman-greek-ext.D0mI3NpI.woff2) format("woff2");
    unicode-range: U+1F00-1FFF
}

@font-face {
    font-family: Inter var;
    font-weight: 100 900;
    font-display: swap;
    font-style: normal;
    font-named-instance:"Regular";src: url(/assets/inter-roman-latin.Bu8hRsVA.woff2) format("woff2");
    unicode-range: U+0000-00FF,U+0131,U+0152-0153,U+02BB-02BC,U+02C6,U+02DA,U+02DC,U+2000-206F,U+2074,U+20AC,U+2122,U+2191,U+2193,U+2212,U+2215,U+FEFF,U+FFFD
}

@font-face {
    font-family: Inter var;
    font-weight: 100 900;
    font-display: swap;
    font-style: normal;
    font-named-instance:"Regular";src: url(/assets/inter-roman-latin-ext.ZlYT4o7i.woff2) format("woff2");
    unicode-range: U+0100-024F,U+0259,U+1E00-1EFF,U+2020,U+20A0-20AB,U+20AD-20CF,U+2113,U+2C60-2C7F,U+A720-A7FF
}

@font-face {
    font-family: Inter var;
    font-weight: 100 900;
    font-display: swap;
    font-style: normal;
    font-named-instance:"Regular";src: url(/assets/inter-roman-vietnamese.ClpjcLMQ.woff2) format("woff2");
    unicode-range: U+0102-0103,U+0110-0111,U+0128-0129,U+0168-0169,U+01A0-01A1,U+01AF-01B0,U+1EA0-1EF9,U+20AB
}

@font-face {
    font-family: Inter var;
    font-weight: 100 900;
    font-display: swap;
    font-style: italic;
    font-named-instance:"Italic";src: url(/assets/inter-italic-cyrillic.D6csxwjC.woff2) format("woff2");
    unicode-range: U+0301,U+0400-045F,U+0490-0491,U+04B0-04B1,U+2116
}

@font-face {
    font-family: Inter var;
    font-weight: 100 900;
    font-display: swap;
    font-style: italic;
    font-named-instance:"Italic";src: url(/assets/inter-italic-cyrillic-ext.5XJwZIOp.woff2) format("woff2");
    unicode-range: U+0460-052F,U+1C80-1C88,U+20B4,U+2DE0-2DFF,U+A640-A69F,U+FE2E-FE2F
}

@font-face {
    font-family: Inter var;
    font-weight: 100 900;
    font-display: swap;
    font-style: italic;
    font-named-instance:"Italic";src: url(/assets/inter-italic-greek.9J96vYpw.woff2) format("woff2");
    unicode-range: U+0370-03FF
}

@font-face {
    font-family: Inter var;
    font-weight: 100 900;
    font-display: swap;
    font-style: italic;
    font-named-instance:"Italic";src: url(/assets/inter-italic-greek-ext.CHOfFY1k.woff2) format("woff2");
    unicode-range: U+1F00-1FFF
}

@font-face {
    font-family: Inter var;
    font-weight: 100 900;
    font-display: swap;
    font-style: italic;
    font-named-instance:"Italic";src: url(/assets/inter-italic-latin.DbsTr1gm.woff2) format("woff2");
    unicode-range: U+0000-00FF,U+0131,U+0152-0153,U+02BB-02BC,U+02C6,U+02DA,U+02DC,U+2000-206F,U+2074,U+20AC,U+2122,U+2191,U+2193,U+2212,U+2215,U+FEFF,U+FFFD
}

@font-face {
    font-family: Inter var;
    font-weight: 100 900;
    font-display: swap;
    font-style: italic;
    font-named-instance:"Italic";src: url(/assets/inter-italic-latin-ext.BGcWXLrn.woff2) format("woff2");
    unicode-range: U+0100-024F,U+0259,U+1E00-1EFF,U+2020,U+20A0-20AB,U+20AD-20CF,U+2113,U+2C60-2C7F,U+A720-A7FF
}

@font-face {
    font-family: Inter var;
    font-weight: 100 900;
    font-display: swap;
    font-style: italic;
    font-named-instance:"Italic";src: url(/assets/inter-italic-vietnamese.DHNAd7Wr.woff2) format("woff2");
    unicode-range: U+0102-0103,U+0110-0111,U+0128-0129,U+0168-0169,U+01A0-01A1,U+01AF-01B0,U+1EA0-1EF9,U+20AB
}

@font-face {
    font-family: Chinese Quotes;
    src: local("PingFang SC Regular"),local("PingFang SC"),local("SimHei"),local("Source Han Sans SC");
    unicode-range: U+2018,U+2019,U+201C,U+201D
}

:root {
    --vp-c-white: #ffffff;
    --vp-c-black: #000000;
    --vp-c-neutral: var(--vp-c-black);
    --vp-c-neutral-inverse: var(--vp-c-white)
}

.dark {
    --vp-c-neutral: var(--vp-c-white);
    --vp-c-neutral-inverse: var(--vp-c-black)
}

:root {
    --vp-c-gray-1: #dddde3;
    --vp-c-gray-2: #e4e4e9;
    --vp-c-gray-3: #ebebef;
    --vp-c-gray-soft: rgba(142, 150, 170, .14);
    --vp-c-indigo-1: #3451b2;
    --vp-c-indigo-2: #3a5ccc;
    --vp-c-indigo-3: #5672cd;
    --vp-c-indigo-soft: rgba(100, 108, 255, .14);
    --vp-c-green-1: #18794e;
    --vp-c-green-2: #299764;
    --vp-c-green-3: #30a46c;
    --vp-c-green-soft: rgba(16, 185, 129, .14);
    --vp-c-yellow-1: #915930;
    --vp-c-yellow-2: #946300;
    --vp-c-yellow-3: #9f6a00;
    --vp-c-yellow-soft: rgba(234, 179, 8, .14);
    --vp-c-red-1: #b8272c;
    --vp-c-red-2: #d5393e;
    --vp-c-red-3: #e0575b;
    --vp-c-red-soft: rgba(244, 63, 94, .14);
    --vp-c-sponsor: #db2777
}

.dark {
    --vp-c-gray-1: #515c67;
    --vp-c-gray-2: #414853;
    --vp-c-gray-3: #32363f;
    --vp-c-gray-soft: rgba(101, 117, 133, .16);
    --vp-c-indigo-1: #a8b1ff;
    --vp-c-indigo-2: #5c73e7;
    --vp-c-indigo-3: #3e63dd;
    --vp-c-indigo-soft: rgba(100, 108, 255, .16);
    --vp-c-green-1: #3dd68c;
    --vp-c-green-2: #30a46c;
    --vp-c-green-3: #298459;
    --vp-c-green-soft: rgba(16, 185, 129, .16);
    --vp-c-yellow-1: #f9b44e;
    --vp-c-yellow-2: #da8b17;
    --vp-c-yellow-3: #a46a0a;
    --vp-c-yellow-soft: rgba(234, 179, 8, .16);
    --vp-c-red-1: #f66f81;
    --vp-c-red-2: #f14158;
    --vp-c-red-3: #b62a3c;
    --vp-c-red-soft: rgba(244, 63, 94, .16)
}

:root {
    --vp-c-bg: #ffffff;
    --vp-c-bg-alt: #f6f6f7;
    --vp-c-bg-elv: #ffffff;
    --vp-c-bg-soft: #f6f6f7
}

.dark {
    --vp-c-bg: #1b1b1f;
    --vp-c-bg-alt: #161618;
    --vp-c-bg-elv: #202127;
    --vp-c-bg-soft: #202127
}

:root {
    --vp-c-border: #c2c2c4;
    --vp-c-divider: #e2e2e3;
    --vp-c-gutter: #e2e2e3
}

.dark {
    --vp-c-border: #3c3f44;
    --vp-c-divider: #2e2e32;
    --vp-c-gutter: #000000
}

:root {
    --vp-c-text-1: rgba(60, 60, 67);
    --vp-c-text-2: rgba(60, 60, 67, .78);
    --vp-c-text-3: rgba(60, 60, 67, .56)
}

.dark {
    --vp-c-text-1: rgba(255, 255, 245, .86);
    --vp-c-text-2: rgba(235, 235, 245, .6);
    --vp-c-text-3: rgba(235, 235, 245, .38)
}

:root {
    --vp-c-default-1: var(--vp-c-gray-1);
    --vp-c-default-2: var(--vp-c-gray-2);
    --vp-c-default-3: var(--vp-c-gray-3);
    --vp-c-default-soft: var(--vp-c-gray-soft);
    --vp-c-brand-1: var(--vp-c-indigo-1);
    --vp-c-brand-2: var(--vp-c-indigo-2);
    --vp-c-brand-3: var(--vp-c-indigo-3);
    --vp-c-brand-soft: var(--vp-c-indigo-soft);
    --vp-c-brand: var(--vp-c-brand-1);
    --vp-c-tip-1: var(--vp-c-brand-1);
    --vp-c-tip-2: var(--vp-c-brand-2);
    --vp-c-tip-3: var(--vp-c-brand-3);
    --vp-c-tip-soft: var(--vp-c-brand-soft);
    --vp-c-warning-1: var(--vp-c-yellow-1);
    --vp-c-warning-2: var(--vp-c-yellow-2);
    --vp-c-warning-3: var(--vp-c-yellow-3);
    --vp-c-warning-soft: var(--vp-c-yellow-soft);
    --vp-c-danger-1: var(--vp-c-red-1);
    --vp-c-danger-2: var(--vp-c-red-2);
    --vp-c-danger-3: var(--vp-c-red-3);
    --vp-c-danger-soft: var(--vp-c-red-soft)
}

:root {
    --vp-font-family-base: "Chinese Quotes", "Inter var", "Inter", ui-sans-serif, system-ui, -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, "Helvetica Neue", Helvetica, Arial, "Noto Sans", sans-serif, "Apple Color Emoji", "Segoe UI Emoji", "Segoe UI Symbol", "Noto Color Emoji";
    --vp-font-family-mono: ui-monospace, SFMono-Regular, "SF Mono", Menlo, Monaco, Consolas, "Liberation Mono", "Courier New", monospace
}

:root {
    --vp-shadow-1: 0 1px 2px rgba(0, 0, 0, .04), 0 1px 2px rgba(0, 0, 0, .06);
    --vp-shadow-2: 0 3px 12px rgba(0, 0, 0, .07), 0 1px 4px rgba(0, 0, 0, .07);
    --vp-shadow-3: 0 12px 32px rgba(0, 0, 0, .1), 0 2px 6px rgba(0, 0, 0, .08);
    --vp-shadow-4: 0 14px 44px rgba(0, 0, 0, .12), 0 3px 9px rgba(0, 0, 0, .12);
    --vp-shadow-5: 0 18px 56px rgba(0, 0, 0, .16), 0 4px 12px rgba(0, 0, 0, .16)
}

:root {
    --vp-z-index-footer: 10;
    --vp-z-index-local-nav: 20;
    --vp-z-index-nav: 30;
    --vp-z-index-layout-top: 40;
    --vp-z-index-backdrop: 50;
    --vp-z-index-sidebar: 60
}

:root {
    --vp-icon-copy: url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' fill='none' height='20' width='20' stroke='rgba(128,128,128,1)' stroke-width='2' viewBox='0 0 24 24'%3E%3Cpath stroke-linecap='round' stroke-linejoin='round' d='M9 5H7a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h10a2 2 0 0 0 2-2V7a2 2 0 0 0-2-2h-2M9 5a2 2 0 0 0 2 2h2a2 2 0 0 0 2-2M9 5a2 2 0 0 1 2-2h2a2 2 0 0 1 2 2'/%3E%3C/svg%3E");
    --vp-icon-copied: url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' fill='none' height='20' width='20' stroke='rgba(128,128,128,1)' stroke-width='2' viewBox='0 0 24 24'%3E%3Cpath stroke-linecap='round' stroke-linejoin='round' d='M9 5H7a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h10a2 2 0 0 0 2-2V7a2 2 0 0 0-2-2h-2M9 5a2 2 0 0 0 2 2h2a2 2 0 0 0 2-2M9 5a2 2 0 0 1 2-2h2a2 2 0 0 1 2 2m-6 9 2 2 4-4'/%3E%3C/svg%3E")
}

:root {
    --vp-layout-max-width: 1440px
}

:root {
    --vp-header-anchor-symbol: "#"
}

:root {
    --vp-code-line-height: 1.7;
    --vp-code-font-size: .875em;
    --vp-code-color: var(--vp-c-brand-1);
    --vp-code-link-color: var(--vp-c-brand-1);
    --vp-code-link-hover-color: var(--vp-c-brand-2);
    --vp-code-bg: var(--vp-c-default-soft);
    --vp-code-block-color: var(--vp-c-text-2);
    --vp-code-block-bg: var(--vp-c-bg-alt);
    --vp-code-block-divider-color: var(--vp-c-gutter);
    --vp-code-lang-color: var(--vp-c-text-3);
    --vp-code-line-highlight-color: var(--vp-c-default-soft);
    --vp-code-line-number-color: var(--vp-c-text-3);
    --vp-code-line-diff-add-color: var(--vp-c-green-soft);
    --vp-code-line-diff-add-symbol-color: var(--vp-c-green-1);
    --vp-code-line-diff-remove-color: var(--vp-c-red-soft);
    --vp-code-line-diff-remove-symbol-color: var(--vp-c-red-1);
    --vp-code-line-warning-color: var(--vp-c-yellow-soft);
    --vp-code-line-error-color: var(--vp-c-red-soft);
    --vp-code-copy-code-border-color: var(--vp-c-divider);
    --vp-code-copy-code-bg: var(--vp-c-bg-soft);
    --vp-code-copy-code-hover-border-color: var(--vp-c-divider);
    --vp-code-copy-code-hover-bg: var(--vp-c-bg);
    --vp-code-copy-code-active-text: var(--vp-c-text-2);
    --vp-code-copy-copied-text-content: "Copied";
    --vp-code-tab-divider: var(--vp-code-block-divider-color);
    --vp-code-tab-text-color: var(--vp-c-text-2);
    --vp-code-tab-bg: var(--vp-code-block-bg);
    --vp-code-tab-hover-text-color: var(--vp-c-text-1);
    --vp-code-tab-active-text-color: var(--vp-c-text-1);
    --vp-code-tab-active-bar-color: var(--vp-c-brand-1)
}

:root {
    --vp-button-brand-border: transparent;
    --vp-button-brand-text: var(--vp-c-white);
    --vp-button-brand-bg: var(--vp-c-brand-3);
    --vp-button-brand-hover-border: transparent;
    --vp-button-brand-hover-text: var(--vp-c-white);
    --vp-button-brand-hover-bg: var(--vp-c-brand-2);
    --vp-button-brand-active-border: transparent;
    --vp-button-brand-active-text: var(--vp-c-white);
    --vp-button-brand-active-bg: var(--vp-c-brand-1);
    --vp-button-alt-border: transparent;
    --vp-button-alt-text: var(--vp-c-text-1);
    --vp-button-alt-bg: var(--vp-c-default-3);
    --vp-button-alt-hover-border: transparent;
    --vp-button-alt-hover-text: var(--vp-c-text-1);
    --vp-button-alt-hover-bg: var(--vp-c-default-2);
    --vp-button-alt-active-border: transparent;
    --vp-button-alt-active-text: var(--vp-c-text-1);
    --vp-button-alt-active-bg: var(--vp-c-default-1);
    --vp-button-sponsor-border: var(--vp-c-text-2);
    --vp-button-sponsor-text: var(--vp-c-text-2);
    --vp-button-sponsor-bg: transparent;
    --vp-button-sponsor-hover-border: var(--vp-c-sponsor);
    --vp-button-sponsor-hover-text: var(--vp-c-sponsor);
    --vp-button-sponsor-hover-bg: transparent;
    --vp-button-sponsor-active-border: var(--vp-c-sponsor);
    --vp-button-sponsor-active-text: var(--vp-c-sponsor);
    --vp-button-sponsor-active-bg: transparent
}

:root {
    --vp-custom-block-font-size: 14px;
    --vp-custom-block-code-font-size: 13px;
    --vp-custom-block-info-border: transparent;
    --vp-custom-block-info-text: var(--vp-c-text-1);
    --vp-custom-block-info-bg: var(--vp-c-default-soft);
    --vp-custom-block-info-code-bg: var(--vp-c-default-soft);
    --vp-custom-block-tip-border: transparent;
    --vp-custom-block-tip-text: var(--vp-c-text-1);
    --vp-custom-block-tip-bg: var(--vp-c-brand-soft);
    --vp-custom-block-tip-code-bg: var(--vp-c-brand-soft);
    --vp-custom-block-warning-border: transparent;
    --vp-custom-block-warning-text: var(--vp-c-text-1);
    --vp-custom-block-warning-bg: var(--vp-c-warning-soft);
    --vp-custom-block-warning-code-bg: var(--vp-c-warning-soft);
    --vp-custom-block-danger-border: transparent;
    --vp-custom-block-danger-text: var(--vp-c-text-1);
    --vp-custom-block-danger-bg: var(--vp-c-danger-soft);
    --vp-custom-block-danger-code-bg: var(--vp-c-danger-soft);
    --vp-custom-block-details-border: var(--vp-custom-block-info-border);
    --vp-custom-block-details-text: var(--vp-custom-block-info-text);
    --vp-custom-block-details-bg: var(--vp-custom-block-info-bg);
    --vp-custom-block-details-code-bg: var(--vp-custom-block-info-code-bg)
}

:root {
    --vp-input-border-color: var(--vp-c-border);
    --vp-input-bg-color: var(--vp-c-bg-alt);
    --vp-input-switch-bg-color: var(--vp-c-gray-soft)
}

:root {
    --vp-nav-height: 64px;
    --vp-nav-bg-color: var(--vp-c-bg);
    --vp-nav-screen-bg-color: var(--vp-c-bg);
    --vp-nav-logo-height: 24px
}

.hide-nav {
    --vp-nav-height: 0px
}

.hide-nav .VPSidebar {
    --vp-nav-height: 22px
}

:root {
    --vp-local-nav-bg-color: var(--vp-c-bg)
}

:root {
    --vp-sidebar-width: 272px;
    --vp-sidebar-bg-color: var(--vp-c-bg-alt)
}

:root {
    --vp-backdrop-bg-color: rgba(0, 0, 0, .6)
}

:root {
    --vp-home-hero-name-color: var(--vp-c-brand-1);
    --vp-home-hero-name-background: transparent;
    --vp-home-hero-image-background-image: none;
    --vp-home-hero-image-filter: none
}

:root {
    --vp-badge-info-border: transparent;
    --vp-badge-info-text: var(--vp-c-text-2);
    --vp-badge-info-bg: var(--vp-c-default-soft);
    --vp-badge-tip-border: transparent;
    --vp-badge-tip-text: var(--vp-c-brand-1);
    --vp-badge-tip-bg: var(--vp-c-brand-soft);
    --vp-badge-warning-border: transparent;
    --vp-badge-warning-text: var(--vp-c-warning-1);
    --vp-badge-warning-bg: var(--vp-c-warning-soft);
    --vp-badge-danger-border: transparent;
    --vp-badge-danger-text: var(--vp-c-danger-1);
    --vp-badge-danger-bg: var(--vp-c-danger-soft)
}

:root {
    --vp-carbon-ads-text-color: var(--vp-c-text-1);
    --vp-carbon-ads-poweredby-color: var(--vp-c-text-2);
    --vp-carbon-ads-bg-color: var(--vp-c-bg-soft);
    --vp-carbon-ads-hover-text-color: var(--vp-c-brand-1);
    --vp-carbon-ads-hover-poweredby-color: var(--vp-c-text-1)
}

:root {
    --vp-local-search-bg: var(--vp-c-bg);
    --vp-local-search-result-bg: var(--vp-c-bg);
    --vp-local-search-result-border: var(--vp-c-divider);
    --vp-local-search-result-selected-bg: var(--vp-c-bg);
    --vp-local-search-result-selected-border: var(--vp-c-brand-1);
    --vp-local-search-highlight-bg: var(--vp-c-brand-1);
    --vp-local-search-highlight-text: var(--vp-c-neutral-inverse)
}

@media (prefers-reduced-motion: reduce) {
    *,:before,:after {
        animation-delay: -1ms!important;
        animation-duration: 1ms!important;
        animation-iteration-count: 1!important;
        background-attachment: initial!important;
        scroll-behavior: auto!important;
        transition-duration: 0s!important;
        transition-delay: 0s!important
    }
}

*,:before,:after {
    box-sizing: border-box
}

html {
    line-height: 1.4;
    font-size: 16px;
    -webkit-text-size-adjust: 100%
}

html.dark {
    color-scheme: dark
}

body {
    margin: 0;
    width: 100%;
    min-width: 320px;
    min-height: 100vh;
    line-height: 24px;
    font-family: var(--vp-font-family-base);
    font-size: 16px;
    font-weight: 400;
    color: var(--vp-c-text-1);
    background-color: var(--vp-c-bg);
    direction: ltr;
    font-synthesis: style;
    text-rendering: optimizeLegibility;
    -webkit-font-smoothing: antialiased;
    -moz-osx-font-smoothing: grayscale
}

main {
    display: block
}

h1,h2,h3,h4,h5,h6 {
    margin: 0;
    line-height: 24px;
    font-size: 16px;
    font-weight: 400
}

p {
    margin: 0
}

strong,b {
    font-weight: 600
}

a,area,button,[role=button],input,label,select,summary,textarea {
    touch-action: manipulation
}

a {
    color: inherit;
    text-decoration: inherit
}

ol,ul {
    list-style: none;
    margin: 0;
    padding: 0
}

blockquote {
    margin: 0
}

pre,code,kbd,samp {
    font-family: var(--vp-font-family-mono)
}

img,svg,video,canvas,audio,iframe,embed,object {
    display: block
}

figure {
    margin: 0
}

img,video {
    max-width: 100%;
    height: auto
}

button,input,optgroup,select,textarea {
    border: 0;
    padding: 0;
    line-height: inherit;
    color: inherit
}

button {
    padding: 0;
    font-family: inherit;
    background-color: transparent;
    background-image: none
}

button:enabled,[role=button]:enabled {
    cursor: pointer
}

button:focus,button:focus-visible {
    outline: 1px dotted;
    outline: 4px auto -webkit-focus-ring-color
}

button:focus:not(:focus-visible) {
    outline: none!important
}

input:focus,textarea:focus,select:focus {
    outline: none
}

table {
    border-collapse: collapse
}

input {
    background-color: transparent
}

input:-ms-input-placeholder,textarea:-ms-input-placeholder {
    color: var(--vp-c-text-3)
}

input::-ms-input-placeholder,textarea::-ms-input-placeholder {
    color: var(--vp-c-text-3)
}

input::placeholder,textarea::placeholder {
    color: var(--vp-c-text-3)
}

input::-webkit-outer-spin-button,input::-webkit-inner-spin-button {
    -webkit-appearance: none;
    margin: 0
}

input[type=number] {
    -moz-appearance: textfield
}

textarea {
    resize: vertical
}

select {
    -webkit-appearance: none
}

fieldset {
    margin: 0;
    padding: 0
}

h1,h2,h3,h4,h5,h6,li,p {
    overflow-wrap: break-word
}

vite-error-overlay {
    z-index: 9999
}

mjx-container {
    display: inline-block;
    margin: auto 2px -2px
}

mjx-container>svg {
    margin: auto
}

.visually-hidden {
    position: absolute;
    width: 1px;
    height: 1px;
    white-space: nowrap;
    clip: rect(0 0 0 0);
    clip-path: inset(50%);
    overflow: hidden
}

.custom-block {
    border: 1px solid transparent;
    border-radius: 8px;
    padding: 16px 16px 8px;
    line-height: 24px;
    font-size: var(--vp-custom-block-font-size);
    color: var(--vp-c-text-2)
}

.custom-block.info {
    border-color: var(--vp-custom-block-info-border);
    color: var(--vp-custom-block-info-text);
    background-color: var(--vp-custom-block-info-bg)
}

.custom-block.info a,.custom-block.info code {
    color: var(--vp-c-brand-1)
}

.custom-block.info a:hover {
    color: var(--vp-c-brand-2)
}

.custom-block.info code {
    background-color: var(--vp-custom-block-info-code-bg)
}

.custom-block.tip {
    border-color: var(--vp-custom-block-tip-border);
    color: var(--vp-custom-block-tip-text);
    background-color: var(--vp-custom-block-tip-bg)
}

.custom-block.tip a,.custom-block.tip code {
    color: var(--vp-c-brand-1)
}

.custom-block.tip a:hover {
    color: var(--vp-c-brand-2)
}

.custom-block.tip code {
    background-color: var(--vp-custom-block-tip-code-bg)
}

.custom-block.warning {
    border-color: var(--vp-custom-block-warning-border);
    color: var(--vp-custom-block-warning-text);
    background-color: var(--vp-custom-block-warning-bg)
}

.custom-block.warning a,.custom-block.warning code {
    color: var(--vp-c-warning-1)
}

.custom-block.warning a:hover {
    color: var(--vp-c-warning-2)
}

.custom-block.warning code {
    background-color: var(--vp-custom-block-warning-code-bg)
}

.custom-block.danger {
    border-color: var(--vp-custom-block-danger-border);
    color: var(--vp-custom-block-danger-text);
    background-color: var(--vp-custom-block-danger-bg)
}

.custom-block.danger a,.custom-block.danger code {
    color: var(--vp-c-danger-1)
}

.custom-block.danger a:hover {
    color: var(--vp-c-danger-2)
}

.custom-block.danger code {
    background-color: var(--vp-custom-block-danger-code-bg)
}

.custom-block.details {
    border-color: var(--vp-custom-block-details-border);
    color: var(--vp-custom-block-details-text);
    background-color: var(--vp-custom-block-details-bg)
}

.custom-block.details a {
    color: var(--vp-c-brand-1)
}

.custom-block.details a:hover {
    color: var(--vp-c-brand-2)
}

.custom-block.details code {
    background-color: var(--vp-custom-block-details-code-bg)
}

.custom-block-title {
    font-weight: 600
}

.custom-block p+p {
    margin: 8px 0
}

.custom-block.details summary {
    margin: 0 0 8px;
    font-weight: 700;
    cursor: pointer
}

.custom-block.details summary+p {
    margin: 8px 0
}

.custom-block a {
    color: inherit;
    font-weight: 600;
    text-decoration: underline;
    text-underline-offset: 2px;
    transition: opacity .25s
}

.custom-block a:hover {
    opacity: .75
}

.custom-block code {
    font-size: var(--vp-custom-block-code-font-size)
}

.custom-block.custom-block th,.custom-block.custom-block blockquote>p {
    font-size: var(--vp-custom-block-font-size);
    color: inherit
}

.dark .vp-code span {
    color: var(--shiki-dark, inherit)
}

html:not(.dark) .vp-code span {
    color: var(--shiki-light, inherit)
}

.vp-code-group {
    margin-top: 16px
}

.vp-code-group .tabs {
    position: relative;
    display: flex;
    margin-right: -24px;
    margin-left: -24px;
    padding: 0 12px;
    background-color: var(--vp-code-tab-bg);
    overflow-x: auto;
    overflow-y: hidden;
    box-shadow: inset 0 -1px var(--vp-code-tab-divider)
}

@media (min-width: 640px) {
    .vp-code-group .tabs {
        margin-right:0;
        margin-left: 0;
        border-radius: 8px 8px 0 0
    }
}

.vp-code-group .tabs input {
    position: fixed;
    opacity: 0;
    pointer-events: none
}

.vp-code-group .tabs label {
    position: relative;
    display: inline-block;
    border-bottom: 1px solid transparent;
    padding: 0 12px;
    line-height: 48px;
    font-size: 14px;
    font-weight: 500;
    color: var(--vp-code-tab-text-color);
    white-space: nowrap;
    cursor: pointer;
    transition: color .25s
}

.vp-code-group .tabs label:after {
    position: absolute;
    right: 8px;
    bottom: -1px;
    left: 8px;
    z-index: 1;
    height: 2px;
    border-radius: 2px;
    content: "";
    background-color: transparent;
    transition: background-color .25s
}

.vp-code-group label:hover {
    color: var(--vp-code-tab-hover-text-color)
}

.vp-code-group input:checked+label {
    color: var(--vp-code-tab-active-text-color)
}

.vp-code-group input:checked+label:after {
    background-color: var(--vp-code-tab-active-bar-color)
}

.vp-code-group div[class*=language-],.vp-block {
    display: none;
    margin-top: 0!important;
    border-top-left-radius: 0!important;
    border-top-right-radius: 0!important
}

.vp-code-group div[class*=language-].active,.vp-block.active {
    display: block
}

.vp-block {
    padding: 20px 24px
}

.vp-doc h1,.vp-doc h2,.vp-doc h3,.vp-doc h4,.vp-doc h5,.vp-doc h6 {
    position: relative;
    font-weight: 600;
    outline: none
}

.vp-doc h1 {
    letter-spacing: -.02em;
    line-height: 40px;
    font-size: 28px
}

.vp-doc h2 {
    margin: 48px 0 16px;
    border-top: 1px solid var(--vp-c-divider);
    padding-top: 24px;
    letter-spacing: -.02em;
    line-height: 32px;
    font-size: 24px
}

.vp-doc h3 {
    margin: 32px 0 0;
    letter-spacing: -.01em;
    line-height: 28px;
    font-size: 20px
}

.vp-doc .header-anchor {
    position: absolute;
    top: 0;
    left: 0;
    margin-left: -.87em;
    font-weight: 500;
    -webkit-user-select: none;
    user-select: none;
    opacity: 0;
    text-decoration: none;
    transition: color .25s,opacity .25s
}

.vp-doc .header-anchor:before {
    content: var(--vp-header-anchor-symbol)
}

.vp-doc h1:hover .header-anchor,.vp-doc h1 .header-anchor:focus,.vp-doc h2:hover .header-anchor,.vp-doc h2 .header-anchor:focus,.vp-doc h3:hover .header-anchor,.vp-doc h3 .header-anchor:focus,.vp-doc h4:hover .header-anchor,.vp-doc h4 .header-anchor:focus,.vp-doc h5:hover .header-anchor,.vp-doc h5 .header-anchor:focus,.vp-doc h6:hover .header-anchor,.vp-doc h6 .header-anchor:focus {
    opacity: 1
}

@media (min-width: 768px) {
    .vp-doc h1 {
        letter-spacing:-.02em;
        line-height: 40px;
        font-size: 32px
    }
}

.vp-doc h2 .header-anchor {
    top: 24px
}

.vp-doc p,.vp-doc summary {
    margin: 16px 0
}

.vp-doc p {
    line-height: 28px
}

.vp-doc blockquote {
    margin: 16px 0;
    border-left: 2px solid var(--vp-c-divider);
    padding-left: 16px;
    transition: border-color .5s
}

.vp-doc blockquote>p {
    margin: 0;
    font-size: 16px;
    color: var(--vp-c-text-2);
    transition: color .5s
}

.vp-doc a {
    font-weight: 500;
    color: var(--vp-c-brand-1);
    text-decoration: underline;
    text-underline-offset: 2px;
    transition: color .25s,opacity .25s
}

.vp-doc a:hover {
    color: var(--vp-c-brand-2)
}

.vp-doc strong {
    font-weight: 600
}

.vp-doc ul,.vp-doc ol {
    padding-left: 1.25rem;
    margin: 16px 0
}

.vp-doc ul {
    list-style: disc
}

.vp-doc ol {
    list-style: decimal
}

.vp-doc li+li {
    margin-top: 8px
}

.vp-doc li>ol,.vp-doc li>ul {
    margin: 8px 0 0
}

.vp-doc table {
    display: block;
    border-collapse: collapse;
    margin: 20px 0;
    overflow-x: auto
}

.vp-doc tr {
    background-color: var(--vp-c-bg);
    border-top: 1px solid var(--vp-c-divider);
    transition: background-color .5s
}

.vp-doc tr:nth-child(2n) {
    background-color: var(--vp-c-bg-soft)
}

.vp-doc th,.vp-doc td {
    border: 1px solid var(--vp-c-divider);
    padding: 8px 16px
}

.vp-doc th {
    text-align: left;
    font-size: 14px;
    font-weight: 600;
    color: var(--vp-c-text-2);
    background-color: var(--vp-c-bg-soft)
}

.vp-doc td {
    font-size: 14px
}

.vp-doc hr {
    margin: 16px 0;
    border: none;
    border-top: 1px solid var(--vp-c-divider)
}

.vp-doc .custom-block {
    margin: 16px 0
}

.vp-doc .custom-block p {
    margin: 8px 0;
    line-height: 24px
}

.vp-doc .custom-block p:first-child {
    margin: 0
}

.vp-doc .custom-block div[class*=language-] {
    margin: 8px 0;
    border-radius: 8px
}

.vp-doc .custom-block div[class*=language-] code {
    font-weight: 400;
    background-color: transparent
}

.vp-doc .custom-block .vp-code-group .tabs {
    margin: 0;
    border-radius: 8px 8px 0 0
}

.vp-doc :not(pre,h1,h2,h3,h4,h5,h6)>code {
    font-size: var(--vp-code-font-size);
    color: var(--vp-code-color)
}

.vp-doc :not(pre)>code {
    border-radius: 4px;
    padding: 3px 6px;
    background-color: var(--vp-code-bg);
    transition: color .25s,background-color .5s
}

.vp-doc a>code {
    color: var(--vp-code-link-color)
}

.vp-doc a:hover>code {
    color: var(--vp-code-link-hover-color)
}

.vp-doc h1>code,.vp-doc h2>code,.vp-doc h3>code {
    font-size: .9em
}

.vp-doc div[class*=language-],.vp-block {
    position: relative;
    margin: 16px -24px;
    background-color: var(--vp-code-block-bg);
    overflow-x: auto;
    transition: background-color .5s
}

@media (min-width: 640px) {
    .vp-doc div[class*=language-],.vp-block {
        border-radius:8px;
        margin: 16px 0
    }
}

@media (max-width: 639px) {
    .vp-doc li div[class*=language-] {
        border-radius:8px 0 0 8px
    }
}

.vp-doc div[class*=language-]+div[class*=language-],.vp-doc div[class$=-api]+div[class*=language-],.vp-doc div[class*=language-]+div[class$=-api]>div[class*=language-] {
    margin-top: -8px
}

.vp-doc [class*=language-] pre,.vp-doc [class*=language-] code {
    direction: ltr;
    text-align: left;
    white-space: pre;
    word-spacing: normal;
    word-break: normal;
    word-wrap: normal;
    -moz-tab-size: 4;
    -o-tab-size: 4;
    tab-size: 4;
    -webkit-hyphens: none;
    -moz-hyphens: none;
    -ms-hyphens: none;
    hyphens: none
}

.vp-doc [class*=language-] pre {
    position: relative;
    z-index: 1;
    margin: 0;
    padding: 20px 0;
    background: transparent;
    overflow-x: auto
}

.vp-doc [class*=language-] code {
    display: block;
    padding: 0 24px;
    width: fit-content;
    min-width: 100%;
    line-height: var(--vp-code-line-height);
    font-size: var(--vp-code-font-size);
    color: var(--vp-code-block-color);
    transition: color .5s
}

.vp-doc [class*=language-] code .highlighted {
    background-color: var(--vp-code-line-highlight-color);
    transition: background-color .5s;
    margin: 0 -24px;
    padding: 0 24px;
    width: calc(100% + 48px);
    display: inline-block
}

.vp-doc [class*=language-] code .highlighted.error {
    background-color: var(--vp-code-line-error-color)
}

.vp-doc [class*=language-] code .highlighted.warning {
    background-color: var(--vp-code-line-warning-color)
}

.vp-doc [class*=language-] code .diff {
    transition: background-color .5s;
    margin: 0 -24px;
    padding: 0 24px;
    width: calc(100% + 48px);
    display: inline-block
}

.vp-doc [class*=language-] code .diff:before {
    position: absolute;
    left: 10px
}

.vp-doc [class*=language-] .has-focused-lines .line:not(.has-focus) {
    filter: blur(.095rem);
    opacity: .4;
    transition: filter .35s,opacity .35s
}

.vp-doc [class*=language-] .has-focused-lines .line:not(.has-focus) {
    opacity: .7;
    transition: filter .35s,opacity .35s
}

.vp-doc [class*=language-]:hover .has-focused-lines .line:not(.has-focus) {
    filter: blur(0);
    opacity: 1
}

.vp-doc [class*=language-] code .diff.remove {
    background-color: var(--vp-code-line-diff-remove-color);
    opacity: .7
}

.vp-doc [class*=language-] code .diff.remove:before {
    content: "-";
    color: var(--vp-code-line-diff-remove-symbol-color)
}

.vp-doc [class*=language-] code .diff.add {
    background-color: var(--vp-code-line-diff-add-color)
}

.vp-doc [class*=language-] code .diff.add:before {
    content: "+";
    color: var(--vp-code-line-diff-add-symbol-color)
}

.vp-doc div[class*=language-].line-numbers-mode {
    padding-left: 32px
}

.vp-doc .line-numbers-wrapper {
    position: absolute;
    top: 0;
    bottom: 0;
    left: 0;
    z-index: 3;
    border-right: 1px solid var(--vp-code-block-divider-color);
    padding-top: 20px;
    width: 32px;
    text-align: center;
    font-family: var(--vp-font-family-mono);
    line-height: var(--vp-code-line-height);
    font-size: var(--vp-code-font-size);
    color: var(--vp-code-line-number-color);
    transition: border-color .5s,color .5s
}

.vp-doc [class*=language-]>button.copy {
    direction: ltr;
    position: absolute;
    top: 12px;
    right: 12px;
    z-index: 3;
    border: 1px solid var(--vp-code-copy-code-border-color);
    border-radius: 4px;
    width: 40px;
    height: 40px;
    background-color: var(--vp-code-copy-code-bg);
    opacity: 0;
    cursor: pointer;
    background-image: var(--vp-icon-copy);
    background-position: 50%;
    background-size: 20px;
    background-repeat: no-repeat;
    transition: border-color .25s,background-color .25s,opacity .25s
}

.vp-doc [class*=language-]:hover>button.copy,.vp-doc [class*=language-]>button.copy:focus {
    opacity: 1
}

.vp-doc [class*=language-]>button.copy:hover,.vp-doc [class*=language-]>button.copy.copied {
    border-color: var(--vp-code-copy-code-hover-border-color);
    background-color: var(--vp-code-copy-code-hover-bg)
}

.vp-doc [class*=language-]>button.copy.copied,.vp-doc [class*=language-]>button.copy:hover.copied {
    border-radius: 0 4px 4px 0;
    background-color: var(--vp-code-copy-code-hover-bg);
    background-image: var(--vp-icon-copied)
}

.vp-doc [class*=language-]>button.copy.copied:before,.vp-doc [class*=language-]>button.copy:hover.copied:before {
    position: relative;
    top: -1px;
    transform: translate(calc(-100% - 1px));
    display: flex;
    justify-content: center;
    align-items: center;
    border: 1px solid var(--vp-code-copy-code-hover-border-color);
    border-right: 0;
    border-radius: 4px 0 0 4px;
    padding: 0 10px;
    width: fit-content;
    height: 40px;
    text-align: center;
    font-size: 12px;
    font-weight: 500;
    color: var(--vp-code-copy-code-active-text);
    background-color: var(--vp-code-copy-code-hover-bg);
    white-space: nowrap;
    content: var(--vp-code-copy-copied-text-content)
}

.vp-doc [class*=language-]>span.lang {
    position: absolute;
    top: 2px;
    right: 8px;
    z-index: 2;
    font-size: 12px;
    font-weight: 500;
    color: var(--vp-code-lang-color);
    transition: color .4s,opacity .4s
}

.vp-doc [class*=language-]:hover>button.copy+span.lang,.vp-doc [class*=language-]>button.copy:focus+span.lang {
    opacity: 0
}

.vp-doc .VPTeamMembers {
    margin-top: 24px
}

.vp-doc .VPTeamMembers.small.count-1 .container {
    margin: 0!important;
    max-width: calc((100% - 24px)/2)!important
}

.vp-doc .VPTeamMembers.small.count-2 .container,.vp-doc .VPTeamMembers.small.count-3 .container {
    max-width: 100%!important
}

.vp-doc .VPTeamMembers.medium.count-1 .container {
    margin: 0!important;
    max-width: calc((100% - 24px)/2)!important
}

:is(.vp-external-link-icon,.vp-doc a[href*="://"],.vp-doc a[target=_blank]):not(.no-icon):after {
    display: inline-block;
    margin-top: -1px;
    margin-left: 4px;
    width: 11px;
    height: 11px;
    background: currentColor;
    color: var(--vp-c-text-3);
    flex-shrink: 0;
    --icon: url("data:image/svg+xml, %3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 24 24' %3E%3Cpath d='M0 0h24v24H0V0z' fill='none' /%3E%3Cpath d='M9 5v2h6.59L4 18.59 5.41 20 17 8.41V15h2V5H9z' /%3E%3C/svg%3E");
    -webkit-mask-image: var(--icon);
    mask-image: var(--icon)
}

.vp-external-link-icon:after {
    content: ""
}

.vp-sponsor {
    border-radius: 16px;
    overflow: hidden
}

.vp-sponsor.aside {
    border-radius: 12px
}

.vp-sponsor-section+.vp-sponsor-section {
    margin-top: 4px
}

.vp-sponsor-tier {
    margin-bottom: 4px;
    text-align: center;
    letter-spacing: 1px;
    line-height: 24px;
    width: 100%;
    font-weight: 600;
    color: var(--vp-c-text-2);
    background-color: var(--vp-c-bg-soft)
}

.vp-sponsor.normal .vp-sponsor-tier {
    padding: 13px 0 11px;
    font-size: 14px
}

.vp-sponsor.aside .vp-sponsor-tier {
    padding: 9px 0 7px;
    font-size: 12px
}

.vp-sponsor-grid+.vp-sponsor-tier {
    margin-top: 4px
}

.vp-sponsor-grid {
    display: flex;
    flex-wrap: wrap;
    gap: 4px
}

.vp-sponsor-grid.xmini .vp-sponsor-grid-link {
    height: 64px
}

.vp-sponsor-grid.xmini .vp-sponsor-grid-image {
    max-width: 64px;
    max-height: 22px
}

.vp-sponsor-grid.mini .vp-sponsor-grid-link {
    height: 72px
}

.vp-sponsor-grid.mini .vp-sponsor-grid-image {
    max-width: 96px;
    max-height: 24px
}

.vp-sponsor-grid.small .vp-sponsor-grid-link {
    height: 96px
}

.vp-sponsor-grid.small .vp-sponsor-grid-image {
    max-width: 96px;
    max-height: 24px
}

.vp-sponsor-grid.medium .vp-sponsor-grid-link {
    height: 112px
}

.vp-sponsor-grid.medium .vp-sponsor-grid-image {
    max-width: 120px;
    max-height: 36px
}

.vp-sponsor-grid.big .vp-sponsor-grid-link {
    height: 184px
}

.vp-sponsor-grid.big .vp-sponsor-grid-image {
    max-width: 192px;
    max-height: 56px
}

.vp-sponsor-grid[data-vp-grid="2"] .vp-sponsor-grid-item {
    width: calc((100% - 4px)/2)
}

.vp-sponsor-grid[data-vp-grid="3"] .vp-sponsor-grid-item {
    width: calc((100% - 4px * 2) / 3)
}

.vp-sponsor-grid[data-vp-grid="4"] .vp-sponsor-grid-item {
    width: calc((100% - 12px)/4)
}

.vp-sponsor-grid[data-vp-grid="5"] .vp-sponsor-grid-item {
    width: calc((100% - 16px)/5)
}

.vp-sponsor-grid[data-vp-grid="6"] .vp-sponsor-grid-item {
    width: calc((100% - 4px * 5) / 6)
}

.vp-sponsor-grid-item {
    flex-shrink: 0;
    width: 100%;
    background-color: var(--vp-c-bg-soft);
    transition: background-color .25s
}

.vp-sponsor-grid-item:hover {
    background-color: var(--vp-c-default-soft)
}

.vp-sponsor-grid-item:hover .vp-sponsor-grid-image {
    filter: grayscale(0) invert(0)
}

.vp-sponsor-grid-item.empty:hover {
    background-color: var(--vp-c-bg-soft)
}

.dark .vp-sponsor-grid-item:hover {
    background-color: var(--vp-c-white)
}

.dark .vp-sponsor-grid-item.empty:hover {
    background-color: var(--vp-c-bg-soft)
}

.vp-sponsor-grid-link {
    display: flex
}

.vp-sponsor-grid-box {
    display: flex;
    justify-content: center;
    align-items: center;
    width: 100%
}

.vp-sponsor-grid-image {
    max-width: 100%;
    filter: grayscale(1);
    transition: filter .25s
}

.dark .vp-sponsor-grid-image {
    filter: grayscale(1) invert(1)
}

.VPBadge[data-v-4dd1c1c3] {
    display: inline-block;
    margin-left: 2px;
    border: 1px solid transparent;
    border-radius: 12px;
    padding: 0 10px;
    line-height: 22px;
    font-size: 12px;
    font-weight: 500;
    transform: translateY(-2px)
}

.vp-doc h1>.VPBadge[data-v-4dd1c1c3] {
    margin-top: 4px;
    vertical-align: top
}

.vp-doc h2>.VPBadge[data-v-4dd1c1c3] {
    margin-top: 3px;
    padding: 0 8px;
    vertical-align: top
}

.vp-doc h3>.VPBadge[data-v-4dd1c1c3] {
    vertical-align: middle
}

.vp-doc h4>.VPBadge[data-v-4dd1c1c3],.vp-doc h5>.VPBadge[data-v-4dd1c1c3],.vp-doc h6>.VPBadge[data-v-4dd1c1c3] {
    vertical-align: middle;
    line-height: 18px
}

.VPBadge.info[data-v-4dd1c1c3] {
    border-color: var(--vp-badge-info-border);
    color: var(--vp-badge-info-text);
    background-color: var(--vp-badge-info-bg)
}

.VPBadge.tip[data-v-4dd1c1c3] {
    border-color: var(--vp-badge-tip-border);
    color: var(--vp-badge-tip-text);
    background-color: var(--vp-badge-tip-bg)
}

.VPBadge.warning[data-v-4dd1c1c3] {
    border-color: var(--vp-badge-warning-border);
    color: var(--vp-badge-warning-text);
    background-color: var(--vp-badge-warning-bg)
}

.VPBadge.danger[data-v-4dd1c1c3] {
    border-color: var(--vp-badge-danger-border);
    color: var(--vp-badge-danger-text);
    background-color: var(--vp-badge-danger-bg)
}

.VPBackdrop[data-v-99f666bb] {
    position: fixed;
    top: 0;
    right: 0;
    bottom: 0;
    left: 0;
    z-index: var(--vp-z-index-backdrop);
    background: var(--vp-backdrop-bg-color);
    transition: opacity .5s
}

.VPBackdrop.fade-enter-from[data-v-99f666bb],.VPBackdrop.fade-leave-to[data-v-99f666bb] {
    opacity: 0
}

.VPBackdrop.fade-leave-active[data-v-99f666bb] {
    transition-duration: .25s
}

@media (min-width: 1280px) {
    .VPBackdrop[data-v-99f666bb] {
        display:none
    }
}

.NotFound[data-v-be45c269] {
    padding: 64px 24px 96px;
    text-align: center
}

@media (min-width: 768px) {
    .NotFound[data-v-be45c269] {
        padding:96px 32px 168px
    }
}

.code[data-v-be45c269] {
    line-height: 64px;
    font-size: 64px;
    font-weight: 600
}

.title[data-v-be45c269] {
    padding-top: 12px;
    letter-spacing: 2px;
    line-height: 20px;
    font-size: 20px;
    font-weight: 700
}

.divider[data-v-be45c269] {
    margin: 24px auto 18px;
    width: 64px;
    height: 1px;
    background-color: var(--vp-c-divider)
}

.quote[data-v-be45c269] {
    margin: 0 auto;
    max-width: 256px;
    font-size: 14px;
    font-weight: 500;
    color: var(--vp-c-text-2)
}

.action[data-v-be45c269] {
    padding-top: 20px
}

.link[data-v-be45c269] {
    display: inline-block;
    border: 1px solid var(--vp-c-brand-1);
    border-radius: 16px;
    padding: 3px 16px;
    font-size: 14px;
    font-weight: 500;
    color: var(--vp-c-brand-1);
    transition: border-color .25s,color .25s
}

.link[data-v-be45c269]:hover {
    border-color: var(--vp-c-brand-2);
    color: var(--vp-c-brand-2)
}

.root[data-v-29296ca0] {
    position: relative;
    z-index: 1
}

.nested[data-v-29296ca0] {
    padding-left: 16px
}

.outline-link[data-v-29296ca0] {
    display: block;
    line-height: 28px;
    color: var(--vp-c-text-2);
    white-space: nowrap;
    overflow: hidden;
    text-overflow: ellipsis;
    transition: color .5s;
    font-weight: 400
}

.outline-link[data-v-29296ca0]:hover,.outline-link.active[data-v-29296ca0] {
    color: var(--vp-c-text-1);
    transition: color .25s
}

.outline-link.nested[data-v-29296ca0] {
    padding-left: 13px
}

.VPDocAsideOutline[data-v-40d4bba3] {
    display: none
}

.VPDocAsideOutline.has-outline[data-v-40d4bba3] {
    display: block
}

.content[data-v-40d4bba3] {
    position: relative;
    border-left: 1px solid var(--vp-c-divider);
    padding-left: 16px;
    font-size: 13px;
    font-weight: 500
}

.outline-marker[data-v-40d4bba3] {
    position: absolute;
    top: 32px;
    left: -1px;
    z-index: 0;
    opacity: 0;
    width: 2px;
    border-radius: 2px;
    height: 18px;
    background-color: var(--vp-c-brand-1);
    transition: top .25s cubic-bezier(0,1,.5,1),background-color .5s,opacity .25s
}

.outline-title[data-v-40d4bba3] {
    letter-spacing: .4px;
    line-height: 28px;
    font-size: 13px;
    font-weight: 600
}

.VPDocAside[data-v-25a9628d] {
    display: flex;
    flex-direction: column;
    flex-grow: 1
}

.spacer[data-v-25a9628d] {
    flex-grow: 1
}

.VPDocAside[data-v-25a9628d] .spacer+.VPDocAsideSponsors,.VPDocAside[data-v-25a9628d] .spacer+.VPDocAsideCarbonAds {
    margin-top: 24px
}

.VPDocAside[data-v-25a9628d] .VPDocAsideSponsors+.VPDocAsideCarbonAds {
    margin-top: 16px
}

.VPLastUpdated[data-v-81f0f08a] {
    line-height: 24px;
    font-size: 14px;
    font-weight: 500;
    color: var(--vp-c-text-2)
}

@media (min-width: 640px) {
    .VPLastUpdated[data-v-81f0f08a] {
        line-height:32px;
        font-size: 14px;
        font-weight: 500
    }
}

.VPDocFooter[data-v-47dd2cd2] {
    margin-top: 64px
}

.edit-info[data-v-47dd2cd2] {
    padding-bottom: 18px
}

@media (min-width: 640px) {
    .edit-info[data-v-47dd2cd2] {
        display:flex;
        justify-content: space-between;
        align-items: center;
        padding-bottom: 14px
    }
}

.edit-link-button[data-v-47dd2cd2] {
    display: flex;
    align-items: center;
    border: 0;
    line-height: 32px;
    font-size: 14px;
    font-weight: 500;
    color: var(--vp-c-brand-1);
    transition: color .25s
}

.edit-link-button[data-v-47dd2cd2]:hover {
    color: var(--vp-c-brand-2)
}

.edit-link-icon[data-v-47dd2cd2] {
    margin-right: 8px;
    width: 14px;
    height: 14px;
    fill: currentColor
}

.prev-next[data-v-47dd2cd2] {
    border-top: 1px solid var(--vp-c-divider);
    padding-top: 24px;
    display: grid;
    grid-row-gap: 8px
}

@media (min-width: 640px) {
    .prev-next[data-v-47dd2cd2] {
        grid-template-columns:repeat(2,1fr);
        grid-column-gap: 16px
    }
}

.pager-link[data-v-47dd2cd2] {
    display: block;
    border: 1px solid var(--vp-c-divider);
    border-radius: 8px;
    padding: 11px 16px 13px;
    width: 100%;
    height: 100%;
    transition: border-color .25s
}

.pager-link[data-v-47dd2cd2]:hover {
    border-color: var(--vp-c-brand-1)
}

.pager-link.next[data-v-47dd2cd2] {
    margin-left: auto;
    text-align: right
}

.desc[data-v-47dd2cd2] {
    display: block;
    line-height: 20px;
    font-size: 12px;
    font-weight: 500;
    color: var(--vp-c-text-2)
}

.title[data-v-47dd2cd2] {
    display: block;
    line-height: 20px;
    font-size: 14px;
    font-weight: 500;
    color: var(--vp-c-brand-1);
    transition: color .25s
}

.VPDocOutlineDropdown[data-v-98ae2f6c] {
    margin-bottom: 48px
}

.VPDocOutlineDropdown button[data-v-98ae2f6c] {
    display: block;
    font-size: 14px;
    font-weight: 500;
    line-height: 24px;
    border: 1px solid var(--vp-c-border);
    padding: 4px 12px;
    color: var(--vp-c-text-2);
    background-color: var(--vp-c-default-soft);
    border-radius: 8px;
    transition: color .5s
}

.VPDocOutlineDropdown button[data-v-98ae2f6c]:hover {
    color: var(--vp-c-text-1);
    transition: color .25s
}

.VPDocOutlineDropdown button.open[data-v-98ae2f6c] {
    color: var(--vp-c-text-1)
}

.icon[data-v-98ae2f6c] {
    display: inline-block;
    vertical-align: middle;
    width: 16px;
    height: 16px;
    fill: currentColor
}

[data-v-98ae2f6c] .outline-link {
    font-size: 14px;
    font-weight: 400
}

.open>.icon[data-v-98ae2f6c] {
    transform: rotate(90deg)
}

.items[data-v-98ae2f6c] {
    margin-top: 12px;
    border-left: 1px solid var(--vp-c-divider)
}

.VPDoc[data-v-0af56b89] {
    padding: 32px 24px 96px;
    width: 100%
}

.VPDoc .VPDocOutlineDropdown[data-v-0af56b89] {
    display: none
}

@media (min-width: 960px) and (max-width: 1279px) {
    .VPDoc .VPDocOutlineDropdown[data-v-0af56b89] {
        display:block
    }
}

@media (min-width: 768px) {
    .VPDoc[data-v-0af56b89] {
        padding:48px 32px 128px
    }
}

@media (min-width: 960px) {
    .VPDoc[data-v-0af56b89] {
        padding:32px 32px 0
    }

    .VPDoc:not(.has-sidebar) .container[data-v-0af56b89] {
        display: flex;
        justify-content: center;
        max-width: 992px
    }

    .VPDoc:not(.has-sidebar) .content[data-v-0af56b89] {
        max-width: 752px
    }
}

@media (min-width: 1280px) {
    .VPDoc .container[data-v-0af56b89] {
        display:flex;
        justify-content: center
    }

    .VPDoc .aside[data-v-0af56b89] {
        display: block
    }
}

@media (min-width: 1440px) {
    .VPDoc:not(.has-sidebar) .content[data-v-0af56b89] {
        max-width:784px
    }

    .VPDoc:not(.has-sidebar) .container[data-v-0af56b89] {
        max-width: 1104px
    }
}

.container[data-v-0af56b89] {
    margin: 0 auto;
    width: 100%
}

.aside[data-v-0af56b89] {
    position: relative;
    display: none;
    order: 2;
    flex-grow: 1;
    padding-left: 32px;
    width: 100%;
    max-width: 256px
}

.left-aside[data-v-0af56b89] {
    order: 1;
    padding-left: unset;
    padding-right: 32px
}

.aside-container[data-v-0af56b89] {
    position: fixed;
    top: 0;
    padding-top: calc(var(--vp-nav-height) + var(--vp-layout-top-height, 0px) + var(--vp-doc-top-height, 0px) + 32px);
    width: 224px;
    height: 100vh;
    overflow-x: hidden;
    overflow-y: auto;
    scrollbar-width: none
}

.aside-container[data-v-0af56b89]::-webkit-scrollbar {
    display: none
}

.aside-curtain[data-v-0af56b89] {
    position: fixed;
    bottom: 0;
    z-index: 10;
    width: 224px;
    height: 32px;
    background: linear-gradient(transparent,var(--vp-c-bg) 70%)
}

.aside-content[data-v-0af56b89] {
    display: flex;
    flex-direction: column;
    min-height: calc(100vh - (var(--vp-nav-height) + var(--vp-layout-top-height, 0px) + 32px));
    padding-bottom: 32px
}

.content[data-v-0af56b89] {
    position: relative;
    margin: 0 auto;
    width: 100%
}

@media (min-width: 960px) {
    .content[data-v-0af56b89] {
        padding:0 32px 128px
    }
}

@media (min-width: 1280px) {
    .content[data-v-0af56b89] {
        order:1;
        margin: 0;
        min-width: 640px
    }
}

.content-container[data-v-0af56b89] {
    margin: 0 auto
}

.VPDoc.has-aside .content-container[data-v-0af56b89] {
    max-width: 688px
}

.external-link-icon-enabled :is(.vp-doc a[href*="://"][data-v-0af56b89],.vp-doc a[target=_blank][data-v-0af56b89]):after {
    content: "";
    color: currentColor
}

.VPButton[data-v-51e0e2bc] {
    display: inline-block;
    border: 1px solid transparent;
    text-align: center;
    font-weight: 600;
    white-space: nowrap;
    transition: color .25s,border-color .25s,background-color .25s
}

.VPButton[data-v-51e0e2bc]:active {
    transition: color .1s,border-color .1s,background-color .1s
}

.VPButton.medium[data-v-51e0e2bc] {
    border-radius: 20px;
    padding: 0 20px;
    line-height: 38px;
    font-size: 14px
}

.VPButton.big[data-v-51e0e2bc] {
    border-radius: 24px;
    padding: 0 24px;
    line-height: 46px;
    font-size: 16px
}

.VPButton.brand[data-v-51e0e2bc] {
    border-color: var(--vp-button-brand-border);
    color: var(--vp-button-brand-text);
    background-color: var(--vp-button-brand-bg)
}

.VPButton.brand[data-v-51e0e2bc]:hover {
    border-color: var(--vp-button-brand-hover-border);
    color: var(--vp-button-brand-hover-text);
    background-color: var(--vp-button-brand-hover-bg)
}

.VPButton.brand[data-v-51e0e2bc]:active {
    border-color: var(--vp-button-brand-active-border);
    color: var(--vp-button-brand-active-text);
    background-color: var(--vp-button-brand-active-bg)
}

.VPButton.alt[data-v-51e0e2bc] {
    border-color: var(--vp-button-alt-border);
    color: var(--vp-button-alt-text);
    background-color: var(--vp-button-alt-bg)
}

.VPButton.alt[data-v-51e0e2bc]:hover {
    border-color: var(--vp-button-alt-hover-border);
    color: var(--vp-button-alt-hover-text);
    background-color: var(--vp-button-alt-hover-bg)
}

.VPButton.alt[data-v-51e0e2bc]:active {
    border-color: var(--vp-button-alt-active-border);
    color: var(--vp-button-alt-active-text);
    background-color: var(--vp-button-alt-active-bg)
}

.VPButton.sponsor[data-v-51e0e2bc] {
    border-color: var(--vp-button-sponsor-border);
    color: var(--vp-button-sponsor-text);
    background-color: var(--vp-button-sponsor-bg)
}

.VPButton.sponsor[data-v-51e0e2bc]:hover {
    border-color: var(--vp-button-sponsor-hover-border);
    color: var(--vp-button-sponsor-hover-text);
    background-color: var(--vp-button-sponsor-hover-bg)
}

.VPButton.sponsor[data-v-51e0e2bc]:active {
    border-color: var(--vp-button-sponsor-active-border);
    color: var(--vp-button-sponsor-active-text);
    background-color: var(--vp-button-sponsor-active-bg)
}

html:not(.dark) .VPImage.dark[data-v-abb5b1fc] {
    display: none
}

.dark .VPImage.light[data-v-abb5b1fc] {
    display: none
}

.VPHero[data-v-ee3c89da] {
    margin-top: calc((var(--vp-nav-height) + var(--vp-layout-top-height, 0px)) * -1);
    padding: calc(var(--vp-nav-height) + var(--vp-layout-top-height, 0px) + 48px) 24px 48px
}

@media (min-width: 640px) {
    .VPHero[data-v-ee3c89da] {
        padding:calc(var(--vp-nav-height) + var(--vp-layout-top-height, 0px) + 80px) 48px 64px
    }
}

@media (min-width: 960px) {
    .VPHero[data-v-ee3c89da] {
        padding:calc(var(--vp-nav-height) + var(--vp-layout-top-height, 0px) + 80px) 64px 64px
    }
}

.container[data-v-ee3c89da] {
    display: flex;
    flex-direction: column;
    margin: 0 auto;
    max-width: 1152px
}

@media (min-width: 960px) {
    .container[data-v-ee3c89da] {
        flex-direction:row
    }
}

.main[data-v-ee3c89da] {
    position: relative;
    z-index: 10;
    order: 2;
    flex-grow: 1;
    flex-shrink: 0
}

.VPHero.has-image .container[data-v-ee3c89da] {
    text-align: center
}

@media (min-width: 960px) {
    .VPHero.has-image .container[data-v-ee3c89da] {
        text-align:left
    }
}

@media (min-width: 960px) {
    .main[data-v-ee3c89da] {
        order:1;
        width: calc((100% / 3) * 2)
    }

    .VPHero.has-image .main[data-v-ee3c89da] {
        max-width: 592px
    }
}

.name[data-v-ee3c89da],.text[data-v-ee3c89da] {
    max-width: 392px;
    letter-spacing: -.4px;
    line-height: 40px;
    font-size: 32px;
    font-weight: 700;
    white-space: pre-wrap
}

.VPHero.has-image .name[data-v-ee3c89da],.VPHero.has-image .text[data-v-ee3c89da] {
    margin: 0 auto
}

.name[data-v-ee3c89da] {
    color: var(--vp-home-hero-name-color)
}

.clip[data-v-ee3c89da] {
    background: var(--vp-home-hero-name-background);
    -webkit-background-clip: text;
    background-clip: text;
    -webkit-text-fill-color: var(--vp-home-hero-name-color)
}

@media (min-width: 640px) {
    .name[data-v-ee3c89da],.text[data-v-ee3c89da] {
        max-width:576px;
        line-height: 56px;
        font-size: 48px
    }
}

@media (min-width: 960px) {
    .name[data-v-ee3c89da],.text[data-v-ee3c89da] {
        line-height:64px;
        font-size: 56px
    }

    .VPHero.has-image .name[data-v-ee3c89da],.VPHero.has-image .text[data-v-ee3c89da] {
        margin: 0
    }
}

.tagline[data-v-ee3c89da] {
    padding-top: 8px;
    max-width: 392px;
    line-height: 28px;
    font-size: 18px;
    font-weight: 500;
    white-space: pre-wrap;
    color: var(--vp-c-text-2)
}

.VPHero.has-image .tagline[data-v-ee3c89da] {
    margin: 0 auto
}

@media (min-width: 640px) {
    .tagline[data-v-ee3c89da] {
        padding-top:12px;
        max-width: 576px;
        line-height: 32px;
        font-size: 20px
    }
}

@media (min-width: 960px) {
    .tagline[data-v-ee3c89da] {
        line-height:36px;
        font-size: 24px
    }

    .VPHero.has-image .tagline[data-v-ee3c89da] {
        margin: 0
    }
}

.actions[data-v-ee3c89da] {
    display: flex;
    flex-wrap: wrap;
    margin: -6px;
    padding-top: 24px
}

.VPHero.has-image .actions[data-v-ee3c89da] {
    justify-content: center
}

@media (min-width: 640px) {
    .actions[data-v-ee3c89da] {
        padding-top:32px
    }
}

@media (min-width: 960px) {
    .VPHero.has-image .actions[data-v-ee3c89da] {
        justify-content:flex-start
    }
}

.action[data-v-ee3c89da] {
    flex-shrink: 0;
    padding: 6px
}

.image[data-v-ee3c89da] {
    order: 1;
    margin: -76px -24px -48px
}

@media (min-width: 640px) {
    .image[data-v-ee3c89da] {
        margin:-108px -24px -48px
    }
}

@media (min-width: 960px) {
    .image[data-v-ee3c89da] {
        flex-grow:1;
        order: 2;
        margin: 0;
        min-height: 100%
    }
}

.image-container[data-v-ee3c89da] {
    position: relative;
    margin: 0 auto;
    width: 320px;
    height: 320px
}

@media (min-width: 640px) {
    .image-container[data-v-ee3c89da] {
        width:392px;
        height: 392px
    }
}

@media (min-width: 960px) {
    .image-container[data-v-ee3c89da] {
        display:flex;
        justify-content: center;
        align-items: center;
        width: 100%;
        height: 100%;
        transform: translate(-32px,-32px)
    }
}

.image-bg[data-v-ee3c89da] {
    position: absolute;
    top: 50%;
    left: 50%;
    border-radius: 50%;
    width: 192px;
    height: 192px;
    background-image: var(--vp-home-hero-image-background-image);
    filter: var(--vp-home-hero-image-filter);
    transform: translate(-50%,-50%)
}

@media (min-width: 640px) {
    .image-bg[data-v-ee3c89da] {
        width:256px;
        height: 256px
    }
}

@media (min-width: 960px) {
    .image-bg[data-v-ee3c89da] {
        width:320px;
        height: 320px
    }
}

[data-v-ee3c89da] .image-src {
    position: absolute;
    top: 50%;
    left: 50%;
    max-width: 192px;
    max-height: 192px;
    transform: translate(-50%,-50%)
}

@media (min-width: 640px) {
    [data-v-ee3c89da] .image-src {
        max-width:256px;
        max-height: 256px
    }
}

@media (min-width: 960px) {
    [data-v-ee3c89da] .image-src {
        max-width:320px;
        max-height: 320px
    }
}

.VPFeature[data-v-3db7ad26] {
    display: block;
    border: 1px solid var(--vp-c-bg-soft);
    border-radius: 12px;
    height: 100%;
    background-color: var(--vp-c-bg-soft);
    transition: border-color .25s,background-color .25s
}

.VPFeature.link[data-v-3db7ad26]:hover {
    border-color: var(--vp-c-brand-1)
}

.box[data-v-3db7ad26] {
    display: flex;
    flex-direction: column;
    padding: 24px;
    height: 100%
}

.box[data-v-3db7ad26]>.VPImage {
    margin-bottom: 20px
}

.icon[data-v-3db7ad26] {
    display: flex;
    justify-content: center;
    align-items: center;
    margin-bottom: 20px;
    border-radius: 6px;
    background-color: var(--vp-c-default-soft);
    width: 48px;
    height: 48px;
    font-size: 24px;
    transition: background-color .25s
}

.title[data-v-3db7ad26] {
    line-height: 24px;
    font-size: 16px;
    font-weight: 600
}

.details[data-v-3db7ad26] {
    flex-grow: 1;
    padding-top: 8px;
    line-height: 24px;
    font-size: 14px;
    font-weight: 500;
    color: var(--vp-c-text-2)
}

.link-text[data-v-3db7ad26] {
    padding-top: 8px
}

.link-text-value[data-v-3db7ad26] {
    display: flex;
    align-items: center;
    font-size: 14px;
    font-weight: 500;
    color: var(--vp-c-brand-1)
}

.link-text-icon[data-v-3db7ad26] {
    display: inline-block;
    margin-left: 6px;
    width: 14px;
    height: 14px;
    fill: currentColor
}

.VPFeatures[data-v-dd16d523] {
    position: relative;
    padding: 0 24px
}

@media (min-width: 640px) {
    .VPFeatures[data-v-dd16d523] {
        padding:0 48px
    }
}

@media (min-width: 960px) {
    .VPFeatures[data-v-dd16d523] {
        padding:0 64px
    }
}

.container[data-v-dd16d523] {
    margin: 0 auto;
    max-width: 1152px
}

.items[data-v-dd16d523] {
    display: flex;
    flex-wrap: wrap;
    margin: -8px
}

.item[data-v-dd16d523] {
    padding: 8px;
    width: 100%
}

@media (min-width: 640px) {
    .item.grid-2[data-v-dd16d523],.item.grid-4[data-v-dd16d523],.item.grid-6[data-v-dd16d523] {
        width:50%
    }
}

@media (min-width: 768px) {
    .item.grid-2[data-v-dd16d523],.item.grid-4[data-v-dd16d523] {
        width:50%
    }

    .item.grid-3[data-v-dd16d523],.item.grid-6[data-v-dd16d523] {
        width: calc(100% / 3)
    }
}

@media (min-width: 960px) {
    .item.grid-4[data-v-dd16d523] {
        width:25%
    }
}

.VPHome[data-v-053989f2] {
    padding-bottom: 96px
}

.VPHome[data-v-053989f2] .VPHomeSponsors {
    margin-top: 112px;
    margin-bottom: -128px
}

@media (min-width: 768px) {
    .VPHome[data-v-053989f2] {
        padding-bottom:128px
    }
}

.VPContent[data-v-f0cf549d] {
    flex-grow: 1;
    flex-shrink: 0;
    margin: var(--vp-layout-top-height, 0px) auto 0;
    width: 100%
}

.VPContent.is-home[data-v-f0cf549d] {
    width: 100%;
    max-width: 100%
}

.VPContent.has-sidebar[data-v-f0cf549d] {
    margin: 0
}

@media (min-width: 960px) {
    .VPContent[data-v-f0cf549d] {
        padding-top:var(--vp-nav-height)
    }

    .VPContent.has-sidebar[data-v-f0cf549d] {
        margin: var(--vp-layout-top-height, 0px) 0 0;
        padding-left: var(--vp-sidebar-width)
    }
}

@media (min-width: 1440px) {
    .VPContent.has-sidebar[data-v-f0cf549d] {
        padding-right:calc((100vw - var(--vp-layout-max-width)) / 2);
        padding-left: calc((100vw - var(--vp-layout-max-width)) / 2 + var(--vp-sidebar-width))
    }
}

.VPFooter[data-v-d2e29cfc] {
    position: relative;
    z-index: var(--vp-z-index-footer);
    border-top: 1px solid var(--vp-c-gutter);
    padding: 32px 24px;
    background-color: var(--vp-c-bg)
}

.VPFooter.has-sidebar[data-v-d2e29cfc] {
    display: none
}

.VPFooter[data-v-d2e29cfc] a {
    text-decoration-line: underline;
    text-underline-offset: 2px;
    transition: color .25s
}

.VPFooter[data-v-d2e29cfc] a:hover {
    color: var(--vp-c-text-1)
}

@media (min-width: 768px) {
    .VPFooter[data-v-d2e29cfc] {
        padding:32px
    }
}

.container[data-v-d2e29cfc] {
    margin: 0 auto;
    max-width: var(--vp-layout-max-width);
    text-align: center
}

.message[data-v-d2e29cfc],.copyright[data-v-d2e29cfc] {
    line-height: 24px;
    font-size: 14px;
    font-weight: 500;
    color: var(--vp-c-text-2)
}

.VPLocalNavOutlineDropdown[data-v-7a90ff68] {
    padding: 12px 20px 11px
}

.VPLocalNavOutlineDropdown button[data-v-7a90ff68] {
    display: block;
    font-size: 12px;
    font-weight: 500;
    line-height: 24px;
    color: var(--vp-c-text-2);
    transition: color .5s;
    position: relative
}

.VPLocalNavOutlineDropdown button[data-v-7a90ff68]:hover {
    color: var(--vp-c-text-1);
    transition: color .25s
}

.VPLocalNavOutlineDropdown button.open[data-v-7a90ff68] {
    color: var(--vp-c-text-1)
}

.icon[data-v-7a90ff68] {
    display: inline-block;
    vertical-align: middle;
    margin-left: 2px;
    width: 14px;
    height: 14px;
    fill: currentColor
}

[data-v-7a90ff68] .outline-link {
    font-size: 14px;
    padding: 2px 0
}

.open>.icon[data-v-7a90ff68] {
    transform: rotate(90deg)
}

.items[data-v-7a90ff68] {
    position: absolute;
    top: 64px;
    right: 16px;
    left: 16px;
    display: grid;
    gap: 1px;
    border: 1px solid var(--vp-c-border);
    border-radius: 8px;
    background-color: var(--vp-c-gutter);
    max-height: calc(var(--vp-vh, 100vh) - 86px);
    overflow: hidden auto;
    box-shadow: var(--vp-shadow-3)
}

.header[data-v-7a90ff68] {
    background-color: var(--vp-c-bg-soft)
}

.top-link[data-v-7a90ff68] {
    display: block;
    padding: 0 16px;
    line-height: 48px;
    font-size: 14px;
    font-weight: 500;
    color: var(--vp-c-brand-1)
}

.outline[data-v-7a90ff68] {
    padding: 8px 0;
    background-color: var(--vp-c-bg-soft)
}

.flyout-enter-active[data-v-7a90ff68] {
    transition: all .2s ease-out
}

.flyout-leave-active[data-v-7a90ff68] {
    transition: all .15s ease-in
}

.flyout-enter-from[data-v-7a90ff68],.flyout-leave-to[data-v-7a90ff68] {
    opacity: 0;
    transform: translateY(-16px)
}

.VPLocalNav[data-v-307eb646] {
    position: sticky;
    top: 0;
    left: 0;
    z-index: var(--vp-z-index-local-nav);
    display: flex;
    justify-content: space-between;
    align-items: center;
    border-top: 1px solid var(--vp-c-gutter);
    border-bottom: 1px solid var(--vp-c-gutter);
    padding-top: var(--vp-layout-top-height, 0px);
    width: 100%;
    background-color: var(--vp-local-nav-bg-color)
}

.VPLocalNav.fixed[data-v-307eb646] {
    position: fixed
}

.VPLocalNav.reached-top[data-v-307eb646] {
    border-top-color: transparent
}

@media (min-width: 960px) {
    .VPLocalNav[data-v-307eb646] {
        display:none
    }
}

.menu[data-v-307eb646] {
    display: flex;
    align-items: center;
    padding: 12px 24px 11px;
    line-height: 24px;
    font-size: 12px;
    font-weight: 500;
    color: var(--vp-c-text-2);
    transition: color .5s
}

.menu[data-v-307eb646]:hover {
    color: var(--vp-c-text-1);
    transition: color .25s
}

@media (min-width: 768px) {
    .menu[data-v-307eb646] {
        padding:0 32px
    }
}

.menu-icon[data-v-307eb646] {
    margin-right: 8px;
    width: 16px;
    height: 16px;
    fill: currentColor
}

.VPOutlineDropdown[data-v-307eb646] {
    padding: 12px 24px 11px
}

@media (min-width: 768px) {
    .VPOutlineDropdown[data-v-307eb646] {
        padding:12px 32px 11px
    }
}

.VPSwitch[data-v-58975ce1] {
    position: relative;
    border-radius: 11px;
    display: block;
    width: 40px;
    height: 22px;
    flex-shrink: 0;
    border: 1px solid var(--vp-input-border-color);
    background-color: var(--vp-input-switch-bg-color);
    transition: border-color .25s!important
}

.VPSwitch[data-v-58975ce1]:hover {
    border-color: var(--vp-c-brand-1)
}

.check[data-v-58975ce1] {
    position: absolute;
    top: 1px;
    left: 1px;
    width: 18px;
    height: 18px;
    border-radius: 50%;
    background-color: var(--vp-c-neutral-inverse);
    box-shadow: var(--vp-shadow-1);
    transition: transform .25s!important
}

.icon[data-v-58975ce1] {
    position: relative;
    display: block;
    width: 18px;
    height: 18px;
    border-radius: 50%;
    overflow: hidden
}

.icon[data-v-58975ce1] svg {
    position: absolute;
    top: 3px;
    left: 3px;
    width: 12px;
    height: 12px;
    fill: var(--vp-c-text-2)
}

.dark .icon[data-v-58975ce1] svg {
    fill: var(--vp-c-text-1);
    transition: opacity .25s!important
}

.sun[data-v-e8eb5b99] {
    opacity: 1
}

.moon[data-v-e8eb5b99],.dark .sun[data-v-e8eb5b99] {
    opacity: 0
}

.dark .moon[data-v-e8eb5b99] {
    opacity: 1
}

.dark .VPSwitchAppearance[data-v-e8eb5b99] .check {
    transform: translate(18px)
}

.VPNavBarAppearance[data-v-6420035c] {
    display: none
}

@media (min-width: 1280px) {
    .VPNavBarAppearance[data-v-6420035c] {
        display:flex;
        align-items: center
    }
}

.VPMenuGroup+.VPMenuLink[data-v-25844c5b] {
    margin: 12px -12px 0;
    border-top: 1px solid var(--vp-c-divider);
    padding: 12px 12px 0
}

.link[data-v-25844c5b] {
    display: block;
    border-radius: 6px;
    padding: 0 12px;
    line-height: 32px;
    font-size: 14px;
    font-weight: 500;
    color: var(--vp-c-text-1);
    white-space: nowrap;
    transition: background-color .25s,color .25s
}

.link[data-v-25844c5b]:hover {
    color: var(--vp-c-brand-1);
    background-color: var(--vp-c-default-soft)
}

.link.active[data-v-25844c5b] {
    color: var(--vp-c-brand-1)
}

.VPMenuGroup[data-v-7f66dfcf] {
    margin: 12px -12px 0;
    border-top: 1px solid var(--vp-c-divider);
    padding: 12px 12px 0
}

.VPMenuGroup[data-v-7f66dfcf]:first-child {
    margin-top: 0;
    border-top: 0;
    padding-top: 0
}

.VPMenuGroup+.VPMenuGroup[data-v-7f66dfcf] {
    margin-top: 12px;
    border-top: 1px solid var(--vp-c-divider)
}

.title[data-v-7f66dfcf] {
    padding: 0 12px;
    line-height: 32px;
    font-size: 14px;
    font-weight: 600;
    color: var(--vp-c-text-2);
    white-space: nowrap;
    transition: color .25s
}

.VPMenu[data-v-cfaeffb0] {
    border-radius: 12px;
    padding: 12px;
    min-width: 128px;
    border: 1px solid var(--vp-c-divider);
    background-color: var(--vp-c-bg-elv);
    box-shadow: var(--vp-shadow-3);
    transition: background-color .5s;
    max-height: calc(100vh - var(--vp-nav-height));
    overflow-y: auto
}

.VPMenu[data-v-cfaeffb0] .group {
    margin: 0 -12px;
    padding: 0 12px 12px
}

.VPMenu[data-v-cfaeffb0] .group+.group {
    border-top: 1px solid var(--vp-c-divider);
    padding: 11px 12px 12px
}

.VPMenu[data-v-cfaeffb0] .group:last-child {
    padding-bottom: 0
}

.VPMenu[data-v-cfaeffb0] .group+.item {
    border-top: 1px solid var(--vp-c-divider);
    padding: 11px 16px 0
}

.VPMenu[data-v-cfaeffb0] .item {
    padding: 0 16px;
    white-space: nowrap
}

.VPMenu[data-v-cfaeffb0] .label {
    flex-grow: 1;
    line-height: 28px;
    font-size: 12px;
    font-weight: 500;
    color: var(--vp-c-text-2);
    transition: color .5s
}

.VPMenu[data-v-cfaeffb0] .action {
    padding-left: 24px
}

.VPFlyout[data-v-ba18c4e8] {
    position: relative
}

.VPFlyout[data-v-ba18c4e8]:hover {
    color: var(--vp-c-brand-1);
    transition: color .25s
}

.VPFlyout:hover .text[data-v-ba18c4e8] {
    color: var(--vp-c-text-2)
}

.VPFlyout:hover .icon[data-v-ba18c4e8] {
    fill: var(--vp-c-text-2)
}

.VPFlyout.active .text[data-v-ba18c4e8] {
    color: var(--vp-c-brand-1)
}

.VPFlyout.active:hover .text[data-v-ba18c4e8] {
    color: var(--vp-c-brand-2)
}

.VPFlyout:hover .menu[data-v-ba18c4e8],.button[aria-expanded=true]+.menu[data-v-ba18c4e8] {
    opacity: 1;
    visibility: visible;
    transform: translateY(0)
}

.button[aria-expanded=false]+.menu[data-v-ba18c4e8] {
    opacity: 0;
    visibility: hidden;
    transform: translateY(0)
}

.button[data-v-ba18c4e8] {
    display: flex;
    align-items: center;
    padding: 0 12px;
    height: var(--vp-nav-height);
    color: var(--vp-c-text-1);
    transition: color .5s
}

.text[data-v-ba18c4e8] {
    display: flex;
    align-items: center;
    line-height: var(--vp-nav-height);
    font-size: 14px;
    font-weight: 500;
    color: var(--vp-c-text-1);
    transition: color .25s
}

.option-icon[data-v-ba18c4e8] {
    margin-right: 0;
    width: 16px;
    height: 16px;
    fill: currentColor
}

.text-icon[data-v-ba18c4e8] {
    margin-left: 4px;
    width: 14px;
    height: 14px;
    fill: currentColor
}

.icon[data-v-ba18c4e8] {
    width: 20px;
    height: 20px;
    fill: currentColor;
    transition: fill .25s
}

.menu[data-v-ba18c4e8] {
    position: absolute;
    top: calc(var(--vp-nav-height) / 2 + 20px);
    right: 0;
    opacity: 0;
    visibility: hidden;
    transition: opacity .25s,visibility .25s,transform .25s
}

.VPSocialLink[data-v-b20eef4f] {
    display: flex;
    justify-content: center;
    align-items: center;
    width: 36px;
    height: 36px;
    color: var(--vp-c-text-2);
    transition: color .5s
}

.VPSocialLink[data-v-b20eef4f]:hover {
    color: var(--vp-c-text-1);
    transition: color .25s
}

.VPSocialLink[data-v-b20eef4f]>svg {
    width: 20px;
    height: 20px;
    fill: currentColor
}

.VPSocialLinks[data-v-45acb0d9] {
    display: flex;
    justify-content: center
}

.VPNavBarExtra[data-v-68cb40e4] {
    display: none;
    margin-right: -12px
}

@media (min-width: 768px) {
    .VPNavBarExtra[data-v-68cb40e4] {
        display:block
    }
}

@media (min-width: 1280px) {
    .VPNavBarExtra[data-v-68cb40e4] {
        display:none
    }
}

.trans-title[data-v-68cb40e4] {
    padding: 0 24px 0 12px;
    line-height: 32px;
    font-size: 14px;
    font-weight: 700;
    color: var(--vp-c-text-1)
}

.item.appearance[data-v-68cb40e4],.item.social-links[data-v-68cb40e4] {
    display: flex;
    align-items: center;
    padding: 0 12px
}

.item.appearance[data-v-68cb40e4] {
    min-width: 176px
}

.appearance-action[data-v-68cb40e4] {
    margin-right: -2px
}

.social-links-list[data-v-68cb40e4] {
    margin: -4px -8px
}

.VPNavBarHamburger[data-v-e69a284e] {
    display: flex;
    justify-content: center;
    align-items: center;
    width: 48px;
    height: var(--vp-nav-height)
}

@media (min-width: 768px) {
    .VPNavBarHamburger[data-v-e69a284e] {
        display:none
    }
}

.container[data-v-e69a284e] {
    position: relative;
    width: 16px;
    height: 14px;
    overflow: hidden
}

.VPNavBarHamburger:hover .top[data-v-e69a284e] {
    top: 0;
    left: 0;
    transform: translate(4px)
}

.VPNavBarHamburger:hover .middle[data-v-e69a284e] {
    top: 6px;
    left: 0;
    transform: translate(0)
}

.VPNavBarHamburger:hover .bottom[data-v-e69a284e] {
    top: 12px;
    left: 0;
    transform: translate(8px)
}

.VPNavBarHamburger.active .top[data-v-e69a284e] {
    top: 6px;
    transform: translate(0) rotate(225deg)
}

.VPNavBarHamburger.active .middle[data-v-e69a284e] {
    top: 6px;
    transform: translate(16px)
}

.VPNavBarHamburger.active .bottom[data-v-e69a284e] {
    top: 6px;
    transform: translate(0) rotate(135deg)
}

.VPNavBarHamburger.active:hover .top[data-v-e69a284e],.VPNavBarHamburger.active:hover .middle[data-v-e69a284e],.VPNavBarHamburger.active:hover .bottom[data-v-e69a284e] {
    background-color: var(--vp-c-text-2);
    transition: top .25s,background-color .25s,transform .25s
}

.top[data-v-e69a284e],.middle[data-v-e69a284e],.bottom[data-v-e69a284e] {
    position: absolute;
    width: 16px;
    height: 2px;
    background-color: var(--vp-c-text-1);
    transition: top .25s,background-color .5s,transform .25s
}

.top[data-v-e69a284e] {
    top: 0;
    left: 0;
    transform: translate(0)
}

.middle[data-v-e69a284e] {
    top: 6px;
    left: 0;
    transform: translate(8px)
}

.bottom[data-v-e69a284e] {
    top: 12px;
    left: 0;
    transform: translate(4px)
}

.VPNavBarMenuLink[data-v-61cca3df] {
    display: flex;
    align-items: center;
    padding: 0 12px;
    line-height: var(--vp-nav-height);
    font-size: 14px;
    font-weight: 500;
    color: var(--vp-c-text-1);
    transition: color .25s
}

.VPNavBarMenuLink.active[data-v-61cca3df],.VPNavBarMenuLink[data-v-61cca3df]:hover {
    color: var(--vp-c-brand-1)
}

.VPNavBarMenu[data-v-140c523e] {
    display: none
}

@media (min-width: 768px) {
    .VPNavBarMenu[data-v-140c523e] {
        display:flex
    }
}

/*! @docsearch/css 3.5.2 | MIT License | © Algolia, Inc. and contributors | https://docsearch.algolia.com */
:root {
    --docsearch-primary-color: #5468ff;
    --docsearch-text-color: #1c1e21;
    --docsearch-spacing: 12px;
    --docsearch-icon-stroke-width: 1.4;
    --docsearch-highlight-color: var(--docsearch-primary-color);
    --docsearch-muted-color: #969faf;
    --docsearch-container-background: rgba(101,108,133,.8);
    --docsearch-logo-color: #5468ff;
    --docsearch-modal-width: 560px;
    --docsearch-modal-height: 600px;
    --docsearch-modal-background: #f5f6f7;
    --docsearch-modal-shadow: inset 1px 1px 0 0 hsla(0,0%,100%,.5),0 3px 8px 0 #555a64;
    --docsearch-searchbox-height: 56px;
    --docsearch-searchbox-background: #ebedf0;
    --docsearch-searchbox-focus-background: #fff;
    --docsearch-searchbox-shadow: inset 0 0 0 2px var(--docsearch-primary-color);
    --docsearch-hit-height: 56px;
    --docsearch-hit-color: #444950;
    --docsearch-hit-active-color: #fff;
    --docsearch-hit-background: #fff;
    --docsearch-hit-shadow: 0 1px 3px 0 #d4d9e1;
    --docsearch-key-gradient: linear-gradient(-225deg,#d5dbe4,#f8f8f8);
    --docsearch-key-shadow: inset 0 -2px 0 0 #cdcde6,inset 0 0 1px 1px #fff,0 1px 2px 1px rgba(30,35,90,.4);
    --docsearch-footer-height: 44px;
    --docsearch-footer-background: #fff;
    --docsearch-footer-shadow: 0 -1px 0 0 #e0e3e8,0 -3px 6px 0 rgba(69,98,155,.12)
}

html[data-theme=dark] {
    --docsearch-text-color: #f5f6f7;
    --docsearch-container-background: rgba(9,10,17,.8);
    --docsearch-modal-background: #15172a;
    --docsearch-modal-shadow: inset 1px 1px 0 0 #2c2e40,0 3px 8px 0 #000309;
    --docsearch-searchbox-background: #090a11;
    --docsearch-searchbox-focus-background: #000;
    --docsearch-hit-color: #bec3c9;
    --docsearch-hit-shadow: none;
    --docsearch-hit-background: #090a11;
    --docsearch-key-gradient: linear-gradient(-26.5deg,#565872,#31355b);
    --docsearch-key-shadow: inset 0 -2px 0 0 #282d55,inset 0 0 1px 1px #51577d,0 2px 2px 0 rgba(3,4,9,.3);
    --docsearch-footer-background: #1e2136;
    --docsearch-footer-shadow: inset 0 1px 0 0 rgba(73,76,106,.5),0 -4px 8px 0 rgba(0,0,0,.2);
    --docsearch-logo-color: #fff;
    --docsearch-muted-color: #7f8497
}

.DocSearch-Button {
    align-items: center;
    background: var(--docsearch-searchbox-background);
    border: 0;
    border-radius: 40px;
    color: var(--docsearch-muted-color);
    cursor: pointer;
    display: flex;
    font-weight: 500;
    height: 36px;
    justify-content: space-between;
    margin: 0 0 0 16px;
    padding: 0 8px;
    -webkit-user-select: none;
    user-select: none
}

.DocSearch-Button:active,.DocSearch-Button:focus,.DocSearch-Button:hover {
    background: var(--docsearch-searchbox-focus-background);
    box-shadow: var(--docsearch-searchbox-shadow);
    color: var(--docsearch-text-color);
    outline: none
}

.DocSearch-Button-Container {
    align-items: center;
    display: flex
}

.DocSearch-Search-Icon {
    stroke-width: 1.6
}

.DocSearch-Button .DocSearch-Search-Icon {
    color: var(--docsearch-text-color)
}

.DocSearch-Button-Placeholder {
    font-size: 1rem;
    padding: 0 12px 0 6px
}

.DocSearch-Button-Keys {
    display: flex;
    min-width: calc(40px + .8em)
}

.DocSearch-Button-Key {
    align-items: center;
    background: var(--docsearch-key-gradient);
    border-radius: 3px;
    box-shadow: var(--docsearch-key-shadow);
    color: var(--docsearch-muted-color);
    display: flex;
    height: 18px;
    justify-content: center;
    margin-right: .4em;
    position: relative;
    padding: 0 0 2px;
    border: 0;
    top: -1px;
    width: 20px
}

@media (max-width: 768px) {
    .DocSearch-Button-Keys,.DocSearch-Button-Placeholder {
        display:none
    }
}

.DocSearch--active {
    overflow: hidden!important
}

.DocSearch-Container,.DocSearch-Container * {
    box-sizing: border-box
}

.DocSearch-Container {
    background-color: var(--docsearch-container-background);
    height: 100vh;
    left: 0;
    position: fixed;
    top: 0;
    width: 100vw;
    z-index: 200
}

.DocSearch-Container a {
    text-decoration: none
}

.DocSearch-Link {
    -webkit-appearance: none;
    -moz-appearance: none;
    appearance: none;
    background: none;
    border: 0;
    color: var(--docsearch-highlight-color);
    cursor: pointer;
    font: inherit;
    margin: 0;
    padding: 0
}

.DocSearch-Modal {
    background: var(--docsearch-modal-background);
    border-radius: 6px;
    box-shadow: var(--docsearch-modal-shadow);
    flex-direction: column;
    margin: 60px auto auto;
    max-width: var(--docsearch-modal-width);
    position: relative
}

.DocSearch-SearchBar {
    display: flex;
    padding: var(--docsearch-spacing) var(--docsearch-spacing) 0
}

.DocSearch-Form {
    align-items: center;
    background: var(--docsearch-searchbox-focus-background);
    border-radius: 4px;
    box-shadow: var(--docsearch-searchbox-shadow);
    display: flex;
    height: var(--docsearch-searchbox-height);
    margin: 0;
    padding: 0 var(--docsearch-spacing);
    position: relative;
    width: 100%
}

.DocSearch-Input {
    -webkit-appearance: none;
    -moz-appearance: none;
    appearance: none;
    background: transparent;
    border: 0;
    color: var(--docsearch-text-color);
    flex: 1;
    font: inherit;
    font-size: 1.2em;
    height: 100%;
    outline: none;
    padding: 0 0 0 8px;
    width: 80%
}

.DocSearch-Input::placeholder {
    color: var(--docsearch-muted-color);
    opacity: 1
}

.DocSearch-Input::-webkit-search-cancel-button,.DocSearch-Input::-webkit-search-decoration,.DocSearch-Input::-webkit-search-results-button,.DocSearch-Input::-webkit-search-results-decoration {
    display: none
}

.DocSearch-LoadingIndicator,.DocSearch-MagnifierLabel,.DocSearch-Reset {
    margin: 0;
    padding: 0
}

.DocSearch-MagnifierLabel,.DocSearch-Reset {
    align-items: center;
    color: var(--docsearch-highlight-color);
    display: flex;
    justify-content: center
}

.DocSearch-Container--Stalled .DocSearch-MagnifierLabel,.DocSearch-LoadingIndicator {
    display: none
}

.DocSearch-Container--Stalled .DocSearch-LoadingIndicator {
    align-items: center;
    color: var(--docsearch-highlight-color);
    display: flex;
    justify-content: center
}

@media screen and (prefers-reduced-motion:reduce) {
    .DocSearch-Reset {
        animation: none;
        -webkit-appearance: none;
        -moz-appearance: none;
        appearance: none;
        background: none;
        border: 0;
        border-radius: 50%;
        color: var(--docsearch-icon-color);
        cursor: pointer;
        right: 0;
        stroke-width: var(--docsearch-icon-stroke-width)
    }
}

.DocSearch-Reset {
    animation: fade-in .1s ease-in forwards;
    -webkit-appearance: none;
    -moz-appearance: none;
    appearance: none;
    background: none;
    border: 0;
    border-radius: 50%;
    color: var(--docsearch-icon-color);
    cursor: pointer;
    padding: 2px;
    right: 0;
    stroke-width: var(--docsearch-icon-stroke-width)
}

.DocSearch-Reset[hidden] {
    display: none
}

.DocSearch-Reset:hover {
    color: var(--docsearch-highlight-color)
}

.DocSearch-LoadingIndicator svg,.DocSearch-MagnifierLabel svg {
    height: 24px;
    width: 24px
}

.DocSearch-Cancel {
    display: none
}

.DocSearch-Dropdown {
    max-height: calc(var(--docsearch-modal-height) - var(--docsearch-searchbox-height) - var(--docsearch-spacing) - var(--docsearch-footer-height));
    min-height: var(--docsearch-spacing);
    overflow-y: auto;
    overflow-y: overlay;
    padding: 0 var(--docsearch-spacing);
    scrollbar-color: var(--docsearch-muted-color) var(--docsearch-modal-background);
    scrollbar-width: thin
}

.DocSearch-Dropdown::-webkit-scrollbar {
    width: 12px
}

.DocSearch-Dropdown::-webkit-scrollbar-track {
    background: transparent
}

.DocSearch-Dropdown::-webkit-scrollbar-thumb {
    background-color: var(--docsearch-muted-color);
    border: 3px solid var(--docsearch-modal-background);
    border-radius: 20px
}

.DocSearch-Dropdown ul {
    list-style: none;
    margin: 0;
    padding: 0
}

.DocSearch-Label {
    font-size: .75em;
    line-height: 1.6em
}

.DocSearch-Help,.DocSearch-Label {
    color: var(--docsearch-muted-color)
}

.DocSearch-Help {
    font-size: .9em;
    margin: 0;
    -webkit-user-select: none;
    user-select: none
}

.DocSearch-Title {
    font-size: 1.2em
}

.DocSearch-Logo a {
    display: flex
}

.DocSearch-Logo svg {
    color: var(--docsearch-logo-color);
    margin-left: 8px
}

.DocSearch-Hits:last-of-type {
    margin-bottom: 24px
}

.DocSearch-Hits mark {
    background: none;
    color: var(--docsearch-highlight-color)
}

.DocSearch-HitsFooter {
    color: var(--docsearch-muted-color);
    display: flex;
    font-size: .85em;
    justify-content: center;
    margin-bottom: var(--docsearch-spacing);
    padding: var(--docsearch-spacing)
}

.DocSearch-HitsFooter a {
    border-bottom: 1px solid;
    color: inherit
}

.DocSearch-Hit {
    border-radius: 4px;
    display: flex;
    padding-bottom: 4px;
    position: relative
}

@media screen and (prefers-reduced-motion:reduce) {
    .DocSearch-Hit--deleting {
        transition: none
    }
}

.DocSearch-Hit--deleting {
    opacity: 0;
    transition: all .25s linear
}

@media screen and (prefers-reduced-motion:reduce) {
    .DocSearch-Hit--favoriting {
        transition: none
    }
}

.DocSearch-Hit--favoriting {
    transform: scale(0);
    transform-origin: top center;
    transition: all .25s linear;
    transition-delay: .25s
}

.DocSearch-Hit a {
    background: var(--docsearch-hit-background);
    border-radius: 4px;
    box-shadow: var(--docsearch-hit-shadow);
    display: block;
    padding-left: var(--docsearch-spacing);
    width: 100%
}

.DocSearch-Hit-source {
    background: var(--docsearch-modal-background);
    color: var(--docsearch-highlight-color);
    font-size: .85em;
    font-weight: 600;
    line-height: 32px;
    margin: 0 -4px;
    padding: 8px 4px 0;
    position: sticky;
    top: 0;
    z-index: 10
}

.DocSearch-Hit-Tree {
    color: var(--docsearch-muted-color);
    height: var(--docsearch-hit-height);
    opacity: .5;
    stroke-width: var(--docsearch-icon-stroke-width);
    width: 24px
}

.DocSearch-Hit[aria-selected=true] a {
    background-color: var(--docsearch-highlight-color)
}

.DocSearch-Hit[aria-selected=true] mark {
    text-decoration: underline
}

.DocSearch-Hit-Container {
    align-items: center;
    color: var(--docsearch-hit-color);
    display: flex;
    flex-direction: row;
    height: var(--docsearch-hit-height);
    padding: 0 var(--docsearch-spacing) 0 0
}

.DocSearch-Hit-icon {
    height: 20px;
    width: 20px
}

.DocSearch-Hit-action,.DocSearch-Hit-icon {
    color: var(--docsearch-muted-color);
    stroke-width: var(--docsearch-icon-stroke-width)
}

.DocSearch-Hit-action {
    align-items: center;
    display: flex;
    height: 22px;
    width: 22px
}

.DocSearch-Hit-action svg {
    display: block;
    height: 18px;
    width: 18px
}

.DocSearch-Hit-action+.DocSearch-Hit-action {
    margin-left: 6px
}

.DocSearch-Hit-action-button {
    -webkit-appearance: none;
    -moz-appearance: none;
    appearance: none;
    background: none;
    border: 0;
    border-radius: 50%;
    color: inherit;
    cursor: pointer;
    padding: 2px
}

svg.DocSearch-Hit-Select-Icon {
    display: none
}

.DocSearch-Hit[aria-selected=true] .DocSearch-Hit-Select-Icon {
    display: block
}

.DocSearch-Hit-action-button:focus,.DocSearch-Hit-action-button:hover {
    background: #0003;
    transition: background-color .1s ease-in
}

@media screen and (prefers-reduced-motion:reduce) {
    .DocSearch-Hit-action-button:focus,.DocSearch-Hit-action-button:hover {
        transition: none
    }
}

.DocSearch-Hit-action-button:focus path,.DocSearch-Hit-action-button:hover path {
    fill: #fff
}

.DocSearch-Hit-content-wrapper {
    display: flex;
    flex: 1 1 auto;
    flex-direction: column;
    font-weight: 500;
    justify-content: center;
    line-height: 1.2em;
    margin: 0 8px;
    overflow-x: hidden;
    position: relative;
    text-overflow: ellipsis;
    white-space: nowrap;
    width: 80%
}

.DocSearch-Hit-title {
    font-size: .9em
}

.DocSearch-Hit-path {
    color: var(--docsearch-muted-color);
    font-size: .75em
}

.DocSearch-Hit[aria-selected=true] .DocSearch-Hit-action,.DocSearch-Hit[aria-selected=true] .DocSearch-Hit-icon,.DocSearch-Hit[aria-selected=true] .DocSearch-Hit-path,.DocSearch-Hit[aria-selected=true] .DocSearch-Hit-text,.DocSearch-Hit[aria-selected=true] .DocSearch-Hit-title,.DocSearch-Hit[aria-selected=true] .DocSearch-Hit-Tree,.DocSearch-Hit[aria-selected=true] mark {
    color: var(--docsearch-hit-active-color)!important
}

@media screen and (prefers-reduced-motion:reduce) {
    .DocSearch-Hit-action-button:focus,.DocSearch-Hit-action-button:hover {
        background: #0003;
        transition: none
    }
}

.DocSearch-ErrorScreen,.DocSearch-NoResults,.DocSearch-StartScreen {
    font-size: .9em;
    margin: 0 auto;
    padding: 36px 0;
    text-align: center;
    width: 80%
}

.DocSearch-Screen-Icon {
    color: var(--docsearch-muted-color);
    padding-bottom: 12px
}

.DocSearch-NoResults-Prefill-List {
    display: inline-block;
    padding-bottom: 24px;
    text-align: left
}

.DocSearch-NoResults-Prefill-List ul {
    display: inline-block;
    padding: 8px 0 0
}

.DocSearch-NoResults-Prefill-List li {
    list-style-position: inside;
    list-style-type: "» "
}

.DocSearch-Prefill {
    -webkit-appearance: none;
    -moz-appearance: none;
    appearance: none;
    background: none;
    border: 0;
    border-radius: 1em;
    color: var(--docsearch-highlight-color);
    cursor: pointer;
    display: inline-block;
    font-size: 1em;
    font-weight: 700;
    padding: 0
}

.DocSearch-Prefill:focus,.DocSearch-Prefill:hover {
    outline: none;
    text-decoration: underline
}

.DocSearch-Footer {
    align-items: center;
    background: var(--docsearch-footer-background);
    border-radius: 0 0 8px 8px;
    box-shadow: var(--docsearch-footer-shadow);
    display: flex;
    flex-direction: row-reverse;
    flex-shrink: 0;
    height: var(--docsearch-footer-height);
    justify-content: space-between;
    padding: 0 var(--docsearch-spacing);
    position: relative;
    -webkit-user-select: none;
    user-select: none;
    width: 100%;
    z-index: 300
}

.DocSearch-Commands {
    color: var(--docsearch-muted-color);
    display: flex;
    list-style: none;
    margin: 0;
    padding: 0
}

.DocSearch-Commands li {
    align-items: center;
    display: flex
}

.DocSearch-Commands li:not(:last-of-type) {
    margin-right: .8em
}

.DocSearch-Commands-Key {
    align-items: center;
    background: var(--docsearch-key-gradient);
    border-radius: 2px;
    box-shadow: var(--docsearch-key-shadow);
    display: flex;
    height: 18px;
    justify-content: center;
    margin-right: .4em;
    padding: 0 0 1px;
    color: var(--docsearch-muted-color);
    border: 0;
    width: 20px
}

@media (max-width: 768px) {
    :root {
        --docsearch-spacing:10px;
        --docsearch-footer-height: 40px
    }

    .DocSearch-Dropdown {
        height: 100%
    }

    .DocSearch-Container {
        height: 100vh;
        height: -webkit-fill-available;
        height: calc(var(--docsearch-vh, 1vh)*100);
        position: absolute
    }

    .DocSearch-Footer {
        border-radius: 0;
        bottom: 0;
        position: absolute
    }

    .DocSearch-Hit-content-wrapper {
        display: flex;
        position: relative;
        width: 80%
    }

    .DocSearch-Modal {
        border-radius: 0;
        box-shadow: none;
        height: 100vh;
        height: -webkit-fill-available;
        height: calc(var(--docsearch-vh, 1vh)*100);
        margin: 0;
        max-width: 100%;
        width: 100%
    }

    .DocSearch-Dropdown {
        max-height: calc(var(--docsearch-vh, 1vh)*100 - var(--docsearch-searchbox-height) - var(--docsearch-spacing) - var(--docsearch-footer-height))
    }

    .DocSearch-Cancel {
        -webkit-appearance: none;
        -moz-appearance: none;
        appearance: none;
        background: none;
        border: 0;
        color: var(--docsearch-highlight-color);
        cursor: pointer;
        display: inline-block;
        flex: none;
        font: inherit;
        font-size: 1em;
        font-weight: 500;
        margin-left: var(--docsearch-spacing);
        outline: none;
        overflow: hidden;
        padding: 0;
        -webkit-user-select: none;
        user-select: none;
        white-space: nowrap
    }

    .DocSearch-Commands,.DocSearch-Hit-Tree {
        display: none
    }
}

@keyframes fade-in {
    0% {
        opacity: 0
    }

    to {
        opacity: 1
    }
}

[class*=DocSearch] {
    --docsearch-primary-color: var(--vp-c-brand-1);
    --docsearch-highlight-color: var(--docsearch-primary-color);
    --docsearch-text-color: var(--vp-c-text-1);
    --docsearch-muted-color: var(--vp-c-text-2);
    --docsearch-searchbox-shadow: none;
    --docsearch-searchbox-background: transparent;
    --docsearch-searchbox-focus-background: transparent;
    --docsearch-key-gradient: transparent;
    --docsearch-key-shadow: none;
    --docsearch-modal-background: var(--vp-c-bg-soft);
    --docsearch-footer-background: var(--vp-c-bg)
}

.dark [class*=DocSearch] {
    --docsearch-modal-shadow: none;
    --docsearch-footer-shadow: none;
    --docsearch-logo-color: var(--vp-c-text-2);
    --docsearch-hit-background: var(--vp-c-default-soft);
    --docsearch-hit-color: var(--vp-c-text-2);
    --docsearch-hit-shadow: none
}

.DocSearch-Button {
    display: flex;
    justify-content: center;
    align-items: center;
    margin: 0;
    padding: 0;
    width: 48px;
    height: 55px;
    background: transparent;
    transition: border-color .25s
}

.DocSearch-Button:hover {
    background: transparent
}

.DocSearch-Button:focus {
    outline: 1px dotted;
    outline: 5px auto -webkit-focus-ring-color
}

.DocSearch-Button:focus:not(:focus-visible) {
    outline: none!important
}

@media (min-width: 768px) {
    .DocSearch-Button {
        justify-content:flex-start;
        border: 1px solid transparent;
        border-radius: 8px;
        padding: 0 10px 0 12px;
        width: 100%;
        height: 40px;
        background-color: var(--vp-c-bg-alt)
    }

    .DocSearch-Button:hover {
        border-color: var(--vp-c-brand-1);
        background: var(--vp-c-bg-alt)
    }
}

.DocSearch-Button .DocSearch-Button-Container {
    display: flex;
    align-items: center
}

.DocSearch-Button .DocSearch-Search-Icon {
    position: relative;
    width: 16px;
    height: 16px;
    color: var(--vp-c-text-1);
    fill: currentColor;
    transition: color .5s
}

.DocSearch-Button:hover .DocSearch-Search-Icon {
    color: var(--vp-c-text-1)
}

@media (min-width: 768px) {
    .DocSearch-Button .DocSearch-Search-Icon {
        top:1px;
        margin-right: 8px;
        width: 14px;
        height: 14px;
        color: var(--vp-c-text-2)
    }
}

.DocSearch-Button .DocSearch-Button-Placeholder {
    display: none;
    margin-top: 2px;
    padding: 0 16px 0 0;
    font-size: 13px;
    font-weight: 500;
    color: var(--vp-c-text-2);
    transition: color .5s
}

.DocSearch-Button:hover .DocSearch-Button-Placeholder {
    color: var(--vp-c-text-1)
}

@media (min-width: 768px) {
    .DocSearch-Button .DocSearch-Button-Placeholder {
        display:inline-block
    }
}

.DocSearch-Button .DocSearch-Button-Keys {
    direction: ltr;
    display: none;
    min-width: auto
}

@media (min-width: 768px) {
    .DocSearch-Button .DocSearch-Button-Keys {
        display:flex;
        align-items: center
    }
}

.DocSearch-Button .DocSearch-Button-Key {
    display: block;
    margin: 2px 0 0;
    border: 1px solid var(--vp-c-divider);
    border-right: none;
    border-radius: 4px 0 0 4px;
    padding-left: 6px;
    min-width: 0;
    width: auto;
    height: 22px;
    line-height: 22px;
    font-family: var(--vp-font-family-base);
    font-size: 12px;
    font-weight: 500;
    transition: color .5s,border-color .5s
}

.DocSearch-Button .DocSearch-Button-Key+.DocSearch-Button-Key {
    border-right: 1px solid var(--vp-c-divider);
    border-left: none;
    border-radius: 0 4px 4px 0;
    padding-left: 2px;
    padding-right: 6px
}

.DocSearch-Button .DocSearch-Button-Key:first-child {
    font-size: 0!important
}

.DocSearch-Button .DocSearch-Button-Key:first-child:after {
    content: "Ctrl";
    font-size: 12px;
    letter-spacing: normal;
    color: var(--docsearch-muted-color)
}

.mac .DocSearch-Button .DocSearch-Button-Key:first-child:after {
    content: "⌘"
}

.DocSearch-Button .DocSearch-Button-Key:first-child>* {
    display: none
}

.VPNavBarSearch {
    display: flex;
    align-items: center
}

@media (min-width: 768px) {
    .VPNavBarSearch {
        flex-grow:1;
        padding-left: 24px
    }
}

@media (min-width: 960px) {
    .VPNavBarSearch {
        padding-left:32px
    }
}

.dark .DocSearch-Footer {
    border-top: 1px solid var(--vp-c-divider)
}

.DocSearch-Form {
    border: 1px solid var(--vp-c-brand-1);
    background-color: var(--vp-c-white)
}

.dark .DocSearch-Form {
    background-color: var(--vp-c-default-soft)
}

.DocSearch-Screen-Icon>svg {
    margin: auto
}

.VPNavBarSocialLinks[data-v-465b39a4] {
    display: none
}

@media (min-width: 1280px) {
    .VPNavBarSocialLinks[data-v-465b39a4] {
        display:flex;
        align-items: center
    }
}

.title[data-v-66f5bc03] {
    display: flex;
    align-items: center;
    border-bottom: 1px solid transparent;
    width: 100%;
    height: var(--vp-nav-height);
    font-size: 16px;
    font-weight: 600;
    color: var(--vp-c-text-1);
    transition: opacity .25s
}

@media (min-width: 960px) {
    .title[data-v-66f5bc03] {
        flex-shrink:0
    }

    .VPNavBarTitle.has-sidebar .title[data-v-66f5bc03] {
        border-bottom-color: var(--vp-c-divider)
    }
}

[data-v-66f5bc03] .logo {
    margin-right: 8px;
    height: var(--vp-nav-logo-height)
}

.VPNavBarTranslations[data-v-87eed331] {
    display: none
}

@media (min-width: 1280px) {
    .VPNavBarTranslations[data-v-87eed331] {
        display:flex;
        align-items: center
    }
}

.title[data-v-87eed331] {
    padding: 0 24px 0 12px;
    line-height: 32px;
    font-size: 14px;
    font-weight: 700;
    color: var(--vp-c-text-1)
}

.VPNavBar[data-v-db553777] {
    position: relative;
    border-bottom: 1px solid transparent;
    padding: 0 8px 0 24px;
    height: var(--vp-nav-height);
    pointer-events: none;
    white-space: nowrap
}

@media (min-width: 768px) {
    .VPNavBar[data-v-db553777] {
        padding:0 32px
    }
}

@media (min-width: 960px) {
    .VPNavBar.has-sidebar[data-v-db553777] {
        padding:0
    }

    .VPNavBar[data-v-db553777]:not(.has-sidebar):not(.top) {
        border-bottom-color: var(--vp-c-gutter);
        background-color: var(--vp-nav-bg-color)
    }
}

.container[data-v-db553777] {
    display: flex;
    justify-content: space-between;
    margin: 0 auto;
    max-width: calc(var(--vp-layout-max-width) - 64px);
    height: var(--vp-nav-height);
    pointer-events: none
}

.container>.title[data-v-db553777],.container>.content[data-v-db553777] {
    pointer-events: none
}

.container[data-v-db553777] * {
    pointer-events: auto
}

@media (min-width: 960px) {
    .VPNavBar.has-sidebar .container[data-v-db553777] {
        max-width:100%
    }
}

.title[data-v-db553777] {
    flex-shrink: 0;
    height: calc(var(--vp-nav-height) - 1px);
    transition: background-color .5s
}

@media (min-width: 960px) {
    .VPNavBar.has-sidebar .title[data-v-db553777] {
        position:absolute;
        top: 0;
        left: 0;
        z-index: 2;
        padding: 0 32px;
        width: var(--vp-sidebar-width);
        height: var(--vp-nav-height);
        background-color: transparent
    }
}

@media (min-width: 1440px) {
    .VPNavBar.has-sidebar .title[data-v-db553777] {
        padding-left:max(32px,calc((100% - (var(--vp-layout-max-width) - 64px)) / 2));
        width: calc((100% - (var(--vp-layout-max-width) - 64px)) / 2 + var(--vp-sidebar-width) - 32px)
    }
}

.content[data-v-db553777] {
    flex-grow: 1
}

@media (min-width: 960px) {
    .VPNavBar.has-sidebar .content[data-v-db553777] {
        position:relative;
        z-index: 1;
        padding-right: 32px;
        padding-left: var(--vp-sidebar-width)
    }
}

@media (min-width: 1440px) {
    .VPNavBar.has-sidebar .content[data-v-db553777] {
        padding-right:calc((100vw - var(--vp-layout-max-width)) / 2 + 32px);
        padding-left: calc((100vw - var(--vp-layout-max-width)) / 2 + var(--vp-sidebar-width))
    }
}

.content-body[data-v-db553777] {
    display: flex;
    justify-content: flex-end;
    align-items: center;
    height: calc(var(--vp-nav-height) - 1px);
    transition: background-color .5s
}

@media (min-width: 960px) {
    .VPNavBar:not(.top) .content-body[data-v-db553777] {
        position:relative;
        background-color: var(--vp-nav-bg-color)
    }
}

@media (max-width: 767px) {
    .content-body[data-v-db553777] {
        column-gap:.5rem
    }
}

.menu+.translations[data-v-db553777]:before,.menu+.appearance[data-v-db553777]:before,.menu+.social-links[data-v-db553777]:before,.translations+.appearance[data-v-db553777]:before,.appearance+.social-links[data-v-db553777]:before {
    margin-right: 8px;
    margin-left: 8px;
    width: 1px;
    height: 24px;
    background-color: var(--vp-c-divider);
    content: ""
}

.menu+.appearance[data-v-db553777]:before,.translations+.appearance[data-v-db553777]:before {
    margin-right: 16px
}

.appearance+.social-links[data-v-db553777]:before {
    margin-left: 16px
}

.social-links[data-v-db553777] {
    margin-right: -8px
}

@media (min-width: 960px) {
    .VPNavBar.has-sidebar .curtain[data-v-db553777] {
        position:absolute;
        right: 0;
        bottom: -31px;
        width: calc(100% - var(--vp-sidebar-width));
        height: 32px
    }

    .VPNavBar.has-sidebar .curtain[data-v-db553777]:before {
        display: block;
        width: 100%;
        height: 32px;
        background: linear-gradient(var(--vp-c-bg),transparent 70%);
        content: ""
    }
}

@media (min-width: 1440px) {
    .VPNavBar.has-sidebar .curtain[data-v-db553777] {
        width:calc(100% - ((100vw - var(--vp-layout-max-width)) / 2 + var(--vp-sidebar-width)))
    }
}

.VPNavScreenAppearance[data-v-62083633] {
    display: flex;
    justify-content: space-between;
    align-items: center;
    border-radius: 8px;
    padding: 12px 14px 12px 16px;
    background-color: var(--vp-c-bg-soft)
}

.text[data-v-62083633] {
    line-height: 24px;
    font-size: 12px;
    font-weight: 500;
    color: var(--vp-c-text-2)
}

.VPNavScreenMenuLink[data-v-170e3acf] {
    display: block;
    border-bottom: 1px solid var(--vp-c-divider);
    padding: 12px 0 11px;
    line-height: 24px;
    font-size: 14px;
    font-weight: 500;
    color: var(--vp-c-text-1);
    transition: border-color .25s,color .25s
}

.VPNavScreenMenuLink[data-v-170e3acf]:hover {
    color: var(--vp-c-brand-1)
}

.VPNavScreenMenuGroupLink[data-v-b0fed5ab] {
    display: block;
    margin-left: 12px;
    line-height: 32px;
    font-size: 14px;
    font-weight: 400;
    color: var(--vp-c-text-1);
    transition: color .25s
}

.VPNavScreenMenuGroupLink[data-v-b0fed5ab]:hover {
    color: var(--vp-c-brand-1)
}

.VPNavScreenMenuGroupSection[data-v-d22e95cb] {
    display: block
}

.title[data-v-d22e95cb] {
    line-height: 32px;
    font-size: 13px;
    font-weight: 700;
    color: var(--vp-c-text-2);
    transition: color .25s
}

.VPNavScreenMenuGroup[data-v-d3f9e607] {
    border-bottom: 1px solid var(--vp-c-divider);
    height: 48px;
    overflow: hidden;
    transition: border-color .5s
}

.VPNavScreenMenuGroup .items[data-v-d3f9e607] {
    visibility: hidden
}

.VPNavScreenMenuGroup.open .items[data-v-d3f9e607] {
    visibility: visible
}

.VPNavScreenMenuGroup.open[data-v-d3f9e607] {
    padding-bottom: 10px;
    height: auto
}

.VPNavScreenMenuGroup.open .button[data-v-d3f9e607] {
    padding-bottom: 6px;
    color: var(--vp-c-brand-1)
}

.VPNavScreenMenuGroup.open .button-icon[data-v-d3f9e607] {
    transform: rotate(45deg)
}

.button[data-v-d3f9e607] {
    display: flex;
    justify-content: space-between;
    align-items: center;
    padding: 12px 4px 11px 0;
    width: 100%;
    line-height: 24px;
    font-size: 14px;
    font-weight: 500;
    color: var(--vp-c-text-1);
    transition: color .25s
}

.button[data-v-d3f9e607]:hover {
    color: var(--vp-c-brand-1)
}

.button-icon[data-v-d3f9e607] {
    width: 14px;
    height: 14px;
    fill: var(--vp-c-text-2);
    transition: fill .5s,transform .25s
}

.group[data-v-d3f9e607]:first-child {
    padding-top: 0
}

.group+.group[data-v-d3f9e607],.group+.item[data-v-d3f9e607] {
    padding-top: 4px
}

.VPNavScreenTranslations[data-v-03936ac8] {
    height: 24px;
    overflow: hidden
}

.VPNavScreenTranslations.open[data-v-03936ac8] {
    height: auto
}

.title[data-v-03936ac8] {
    display: flex;
    align-items: center;
    font-size: 14px;
    font-weight: 500;
    color: var(--vp-c-text-1)
}

.icon[data-v-03936ac8] {
    width: 16px;
    height: 16px;
    fill: currentColor
}

.icon.lang[data-v-03936ac8] {
    margin-right: 8px
}

.icon.chevron[data-v-03936ac8] {
    margin-left: 4px
}

.list[data-v-03936ac8] {
    padding: 4px 0 0 24px
}

.link[data-v-03936ac8] {
    line-height: 32px;
    font-size: 13px;
    color: var(--vp-c-text-1)
}

.VPNavScreen[data-v-dd1703b5] {
    position: fixed;
    top: calc(var(--vp-nav-height) + var(--vp-layout-top-height, 0px) + 1px);
    right: 0;
    bottom: 0;
    left: 0;
    padding: 0 32px;
    width: 100%;
    background-color: var(--vp-nav-screen-bg-color);
    overflow-y: auto;
    transition: background-color .5s;
    pointer-events: auto
}

.VPNavScreen.fade-enter-active[data-v-dd1703b5],.VPNavScreen.fade-leave-active[data-v-dd1703b5] {
    transition: opacity .25s
}

.VPNavScreen.fade-enter-active .container[data-v-dd1703b5],.VPNavScreen.fade-leave-active .container[data-v-dd1703b5] {
    transition: transform .25s ease
}

.VPNavScreen.fade-enter-from[data-v-dd1703b5],.VPNavScreen.fade-leave-to[data-v-dd1703b5] {
    opacity: 0
}

.VPNavScreen.fade-enter-from .container[data-v-dd1703b5],.VPNavScreen.fade-leave-to .container[data-v-dd1703b5] {
    transform: translateY(-8px)
}

@media (min-width: 768px) {
    .VPNavScreen[data-v-dd1703b5] {
        display:none
    }
}

.container[data-v-dd1703b5] {
    margin: 0 auto;
    padding: 24px 0 96px;
    max-width: 288px
}

.menu+.translations[data-v-dd1703b5],.menu+.appearance[data-v-dd1703b5],.translations+.appearance[data-v-dd1703b5] {
    margin-top: 24px
}

.menu+.social-links[data-v-dd1703b5] {
    margin-top: 16px
}

.appearance+.social-links[data-v-dd1703b5] {
    margin-top: 16px
}

.VPNav[data-v-04baf407] {
    position: relative;
    top: var(--vp-layout-top-height, 0px);
    left: 0;
    z-index: var(--vp-z-index-nav);
    width: 100%;
    pointer-events: none;
    transition: background-color .5s
}

@media (min-width: 960px) {
    .VPNav[data-v-04baf407] {
        position:fixed
    }
}

.VPSidebarItem.level-0[data-v-591e9257] {
    padding-bottom: 24px
}

.VPSidebarItem.collapsed.level-0[data-v-591e9257] {
    padding-bottom: 10px
}

.item[data-v-591e9257] {
    position: relative;
    display: flex;
    width: 100%
}

.VPSidebarItem.collapsible>.item[data-v-591e9257] {
    cursor: pointer
}

.indicator[data-v-591e9257] {
    position: absolute;
    top: 6px;
    bottom: 6px;
    left: -17px;
    width: 2px;
    border-radius: 2px;
    transition: background-color .25s
}

.VPSidebarItem.level-2.is-active>.item>.indicator[data-v-591e9257],.VPSidebarItem.level-3.is-active>.item>.indicator[data-v-591e9257],.VPSidebarItem.level-4.is-active>.item>.indicator[data-v-591e9257],.VPSidebarItem.level-5.is-active>.item>.indicator[data-v-591e9257] {
    background-color: var(--vp-c-brand-1)
}

.link[data-v-591e9257] {
    display: flex;
    align-items: center;
    flex-grow: 1
}

.text[data-v-591e9257] {
    flex-grow: 1;
    padding: 4px 0;
    line-height: 24px;
    font-size: 14px;
    transition: color .25s
}

.VPSidebarItem.level-0 .text[data-v-591e9257] {
    font-weight: 700;
    color: var(--vp-c-text-1)
}

.VPSidebarItem.level-1 .text[data-v-591e9257],.VPSidebarItem.level-2 .text[data-v-591e9257],.VPSidebarItem.level-3 .text[data-v-591e9257],.VPSidebarItem.level-4 .text[data-v-591e9257],.VPSidebarItem.level-5 .text[data-v-591e9257] {
    font-weight: 500;
    color: var(--vp-c-text-2)
}

.VPSidebarItem.level-0.is-link>.item>.link:hover .text[data-v-591e9257],.VPSidebarItem.level-1.is-link>.item>.link:hover .text[data-v-591e9257],.VPSidebarItem.level-2.is-link>.item>.link:hover .text[data-v-591e9257],.VPSidebarItem.level-3.is-link>.item>.link:hover .text[data-v-591e9257],.VPSidebarItem.level-4.is-link>.item>.link:hover .text[data-v-591e9257],.VPSidebarItem.level-5.is-link>.item>.link:hover .text[data-v-591e9257] {
    color: var(--vp-c-brand-1)
}

.VPSidebarItem.level-0.has-active>.item>.text[data-v-591e9257],.VPSidebarItem.level-1.has-active>.item>.text[data-v-591e9257],.VPSidebarItem.level-2.has-active>.item>.text[data-v-591e9257],.VPSidebarItem.level-3.has-active>.item>.text[data-v-591e9257],.VPSidebarItem.level-4.has-active>.item>.text[data-v-591e9257],.VPSidebarItem.level-5.has-active>.item>.text[data-v-591e9257],.VPSidebarItem.level-0.has-active>.item>.link>.text[data-v-591e9257],.VPSidebarItem.level-1.has-active>.item>.link>.text[data-v-591e9257],.VPSidebarItem.level-2.has-active>.item>.link>.text[data-v-591e9257],.VPSidebarItem.level-3.has-active>.item>.link>.text[data-v-591e9257],.VPSidebarItem.level-4.has-active>.item>.link>.text[data-v-591e9257],.VPSidebarItem.level-5.has-active>.item>.link>.text[data-v-591e9257] {
    color: var(--vp-c-text-1)
}

.VPSidebarItem.level-0.is-active>.item .link>.text[data-v-591e9257],.VPSidebarItem.level-1.is-active>.item .link>.text[data-v-591e9257],.VPSidebarItem.level-2.is-active>.item .link>.text[data-v-591e9257],.VPSidebarItem.level-3.is-active>.item .link>.text[data-v-591e9257],.VPSidebarItem.level-4.is-active>.item .link>.text[data-v-591e9257],.VPSidebarItem.level-5.is-active>.item .link>.text[data-v-591e9257] {
    color: var(--vp-c-brand-1)
}

.caret[data-v-591e9257] {
    display: flex;
    justify-content: center;
    align-items: center;
    margin-right: -7px;
    width: 32px;
    height: 32px;
    color: var(--vp-c-text-3);
    cursor: pointer;
    transition: color .25s;
    flex-shrink: 0
}

.item:hover .caret[data-v-591e9257] {
    color: var(--vp-c-text-2)
}

.item:hover .caret[data-v-591e9257]:hover {
    color: var(--vp-c-text-1)
}

.caret-icon[data-v-591e9257] {
    width: 18px;
    height: 18px;
    fill: currentColor;
    transform: rotate(90deg);
    transition: transform .25s
}

.VPSidebarItem.collapsed .caret-icon[data-v-591e9257] {
    transform: rotate(0)
}

.VPSidebarItem.level-1 .items[data-v-591e9257],.VPSidebarItem.level-2 .items[data-v-591e9257],.VPSidebarItem.level-3 .items[data-v-591e9257],.VPSidebarItem.level-4 .items[data-v-591e9257],.VPSidebarItem.level-5 .items[data-v-591e9257] {
    border-left: 1px solid var(--vp-c-divider);
    padding-left: 16px
}

.VPSidebarItem.collapsed .items[data-v-591e9257] {
    display: none
}

.VPSidebar[data-v-f37c151b] {
    position: fixed;
    top: var(--vp-layout-top-height, 0px);
    bottom: 0;
    left: 0;
    z-index: var(--vp-z-index-sidebar);
    padding: 32px 32px 96px;
    width: calc(100vw - 64px);
    max-width: 320px;
    background-color: var(--vp-sidebar-bg-color);
    opacity: 0;
    box-shadow: var(--vp-c-shadow-3);
    overflow-x: hidden;
    overflow-y: auto;
    transform: translate(-100%);
    transition: opacity .5s,transform .25s ease;
    overscroll-behavior: contain
}

.VPSidebar.open[data-v-f37c151b] {
    opacity: 1;
    visibility: visible;
    transform: translate(0);
    transition: opacity .25s,transform .5s cubic-bezier(.19,1,.22,1)
}

.dark .VPSidebar[data-v-f37c151b] {
    box-shadow: var(--vp-shadow-1)
}

@media (min-width: 960px) {
    .VPSidebar[data-v-f37c151b] {
        z-index:1;
        padding-top: var(--vp-nav-height);
        width: var(--vp-sidebar-width);
        max-width: 100%;
        background-color: var(--vp-sidebar-bg-color);
        opacity: 1;
        visibility: visible;
        box-shadow: none;
        transform: translate(0)
    }
}

@media (min-width: 1440px) {
    .VPSidebar[data-v-f37c151b] {
        padding-left:max(32px,calc((100% - (var(--vp-layout-max-width) - 64px)) / 2));
        width: calc((100% - (var(--vp-layout-max-width) - 64px)) / 2 + var(--vp-sidebar-width) - 32px)
    }
}

@media (min-width: 960px) {
    .curtain[data-v-f37c151b] {
        position:sticky;
        top: -64px;
        left: 0;
        z-index: 1;
        margin-top: calc(var(--vp-nav-height) * -1);
        margin-right: -32px;
        margin-left: -32px;
        height: var(--vp-nav-height);
        background-color: var(--vp-sidebar-bg-color)
    }
}

.nav[data-v-f37c151b] {
    outline: 0
}

.group+.group[data-v-f37c151b] {
    border-top: 1px solid var(--vp-c-divider);
    padding-top: 10px
}

@media (min-width: 960px) {
    .group[data-v-f37c151b] {
        padding-top:10px;
        width: calc(var(--vp-sidebar-width) - 64px)
    }
}

.VPSkipLink[data-v-ce0cfd7a] {
    top: 8px;
    left: 8px;
    padding: 8px 16px;
    z-index: 999;
    border-radius: 8px;
    font-size: 12px;
    font-weight: 700;
    text-decoration: none;
    color: var(--vp-c-brand-1);
    box-shadow: var(--vp-shadow-3);
    background-color: var(--vp-c-bg)
}

.VPSkipLink[data-v-ce0cfd7a]:focus {
    height: auto;
    width: auto;
    clip: auto;
    clip-path: none
}

@media (min-width: 1280px) {
    .VPSkipLink[data-v-ce0cfd7a] {
        top:14px;
        left: 16px
    }
}

.Layout[data-v-e59d5fbf] {
    display: flex;
    flex-direction: column;
    min-height: 100vh
}

.VPHomeSponsors[data-v-fed054d8] {
    border-top: 1px solid var(--vp-c-gutter);
    padding: 88px 24px 96px;
    background-color: var(--vp-c-bg)
}

.container[data-v-fed054d8] {
    margin: 0 auto;
    max-width: 1152px
}

.love[data-v-fed054d8] {
    margin: 0 auto;
    width: 28px;
    height: 28px;
    color: var(--vp-c-text-3)
}

.icon[data-v-fed054d8] {
    width: 28px;
    height: 28px;
    fill: currentColor
}

.message[data-v-fed054d8] {
    margin: 0 auto;
    padding-top: 10px;
    max-width: 320px;
    text-align: center;
    line-height: 24px;
    font-size: 16px;
    font-weight: 500;
    color: var(--vp-c-text-2)
}

.sponsors[data-v-fed054d8] {
    padding-top: 32px
}

.action[data-v-fed054d8] {
    padding-top: 40px;
    text-align: center
}

.VPTeamPage[data-v-38af105b] {
    padding-bottom: 96px
}

@media (min-width: 768px) {
    .VPTeamPage[data-v-38af105b] {
        padding-bottom:128px
    }
}

.VPTeamPageSection+.VPTeamPageSection[data-v-38af105b-s],.VPTeamMembers+.VPTeamPageSection[data-v-38af105b-s] {
    margin-top: 64px
}

.VPTeamMembers+.VPTeamMembers[data-v-38af105b-s] {
    margin-top: 24px
}

@media (min-width: 768px) {
    .VPTeamPageTitle+.VPTeamPageSection[data-v-38af105b-s] {
        margin-top:16px
    }

    .VPTeamPageSection+.VPTeamPageSection[data-v-38af105b-s],.VPTeamMembers+.VPTeamPageSection[data-v-38af105b-s] {
        margin-top: 96px
    }
}

.VPTeamMembers[data-v-38af105b-s] {
    padding: 0 24px
}

@media (min-width: 768px) {
    .VPTeamMembers[data-v-38af105b-s] {
        padding:0 48px
    }
}

@media (min-width: 960px) {
    .VPTeamMembers[data-v-38af105b-s] {
        padding:0 64px
    }
}

.VPTeamPageTitle[data-v-21389afc] {
    padding: 48px 32px;
    text-align: center
}

@media (min-width: 768px) {
    .VPTeamPageTitle[data-v-21389afc] {
        padding:64px 48px 48px
    }
}

@media (min-width: 960px) {
    .VPTeamPageTitle[data-v-21389afc] {
        padding:80px 64px 48px
    }
}

.title[data-v-21389afc] {
    letter-spacing: 0;
    line-height: 44px;
    font-size: 36px;
    font-weight: 500
}

@media (min-width: 768px) {
    .title[data-v-21389afc] {
        letter-spacing:-.5px;
        line-height: 56px;
        font-size: 48px
    }
}

.lead[data-v-21389afc] {
    margin: 0 auto;
    max-width: 512px;
    padding-top: 12px;
    line-height: 24px;
    font-size: 16px;
    font-weight: 500;
    color: var(--vp-c-text-2)
}

@media (min-width: 768px) {
    .lead[data-v-21389afc] {
        max-width:592px;
        letter-spacing: .15px;
        line-height: 28px;
        font-size: 20px
    }
}

.VPTeamPageSection[data-v-7c501c57] {
    padding: 0 32px
}

@media (min-width: 768px) {
    .VPTeamPageSection[data-v-7c501c57] {
        padding:0 48px
    }
}

@media (min-width: 960px) {
    .VPTeamPageSection[data-v-7c501c57] {
        padding:0 64px
    }
}

.title[data-v-7c501c57] {
    position: relative;
    margin: 0 auto;
    max-width: 1152px;
    text-align: center;
    color: var(--vp-c-text-2)
}

.title-line[data-v-7c501c57] {
    position: absolute;
    top: 16px;
    left: 0;
    width: 100%;
    height: 1px;
    background-color: var(--vp-c-divider)
}

.title-text[data-v-7c501c57] {
    position: relative;
    display: inline-block;
    padding: 0 24px;
    letter-spacing: 0;
    line-height: 32px;
    font-size: 20px;
    font-weight: 500;
    background-color: var(--vp-c-bg)
}

.lead[data-v-7c501c57] {
    margin: 0 auto;
    max-width: 480px;
    padding-top: 12px;
    text-align: center;
    line-height: 24px;
    font-size: 16px;
    font-weight: 500;
    color: var(--vp-c-text-2)
}

.members[data-v-7c501c57] {
    padding-top: 40px
}

.VPTeamMembersItem[data-v-a7deb80b] {
    display: flex;
    flex-direction: column;
    gap: 2px;
    border-radius: 12px;
    width: 100%;
    height: 100%;
    overflow: hidden
}

.VPTeamMembersItem.small .profile[data-v-a7deb80b] {
    padding: 32px
}

.VPTeamMembersItem.small .data[data-v-a7deb80b] {
    padding-top: 20px
}

.VPTeamMembersItem.small .avatar[data-v-a7deb80b] {
    width: 64px;
    height: 64px
}

.VPTeamMembersItem.small .name[data-v-a7deb80b] {
    line-height: 24px;
    font-size: 16px
}

.VPTeamMembersItem.small .affiliation[data-v-a7deb80b] {
    padding-top: 4px;
    line-height: 20px;
    font-size: 14px
}

.VPTeamMembersItem.small .desc[data-v-a7deb80b] {
    padding-top: 12px;
    line-height: 20px;
    font-size: 14px
}

.VPTeamMembersItem.small .links[data-v-a7deb80b] {
    margin: 0 -16px -20px;
    padding: 10px 0 0
}

.VPTeamMembersItem.medium .profile[data-v-a7deb80b] {
    padding: 48px 32px
}

.VPTeamMembersItem.medium .data[data-v-a7deb80b] {
    padding-top: 24px;
    text-align: center
}

.VPTeamMembersItem.medium .avatar[data-v-a7deb80b] {
    width: 96px;
    height: 96px
}

.VPTeamMembersItem.medium .name[data-v-a7deb80b] {
    letter-spacing: .15px;
    line-height: 28px;
    font-size: 20px
}

.VPTeamMembersItem.medium .affiliation[data-v-a7deb80b] {
    padding-top: 4px;
    font-size: 16px
}

.VPTeamMembersItem.medium .desc[data-v-a7deb80b] {
    padding-top: 16px;
    max-width: 288px;
    font-size: 16px
}

.VPTeamMembersItem.medium .links[data-v-a7deb80b] {
    margin: 0 -16px -12px;
    padding: 16px 12px 0
}

.profile[data-v-a7deb80b] {
    flex-grow: 1;
    background-color: var(--vp-c-bg-soft)
}

.data[data-v-a7deb80b] {
    text-align: center
}

.avatar[data-v-a7deb80b] {
    position: relative;
    flex-shrink: 0;
    margin: 0 auto;
    border-radius: 50%;
    box-shadow: var(--vp-shadow-3)
}

.avatar-img[data-v-a7deb80b] {
    position: absolute;
    top: 0;
    right: 0;
    bottom: 0;
    left: 0;
    border-radius: 50%;
    object-fit: cover
}

.name[data-v-a7deb80b] {
    margin: 0;
    font-weight: 600
}

.affiliation[data-v-a7deb80b] {
    margin: 0;
    font-weight: 500;
    color: var(--vp-c-text-2)
}

.org.link[data-v-a7deb80b] {
    color: var(--vp-c-text-2);
    transition: color .25s
}

.org.link[data-v-a7deb80b]:hover {
    color: var(--vp-c-brand-1)
}

.desc[data-v-a7deb80b] {
    margin: 0 auto
}

.desc[data-v-a7deb80b] a {
    font-weight: 500;
    color: var(--vp-c-brand-1);
    text-decoration-style: dotted;
    transition: color .25s
}

.links[data-v-a7deb80b] {
    display: flex;
    justify-content: center;
    height: 56px
}

.sp-link[data-v-a7deb80b] {
    display: flex;
    justify-content: center;
    align-items: center;
    text-align: center;
    padding: 16px;
    font-size: 14px;
    font-weight: 500;
    color: var(--vp-c-sponsor);
    background-color: var(--vp-c-bg-soft);
    transition: color .25s,background-color .25s
}

.sp .sp-link.link[data-v-a7deb80b]:hover,.sp .sp-link.link[data-v-a7deb80b]:focus {
    outline: none;
    color: var(--vp-c-white);
    background-color: var(--vp-c-sponsor)
}

.sp-icon[data-v-a7deb80b] {
    margin-right: 8px;
    width: 16px;
    height: 16px;
    fill: currentColor
}

.VPTeamMembers.small .container[data-v-5c40eab9] {
    grid-template-columns: repeat(auto-fit,minmax(224px,1fr))
}

.VPTeamMembers.small.count-1 .container[data-v-5c40eab9] {
    max-width: 276px
}

.VPTeamMembers.small.count-2 .container[data-v-5c40eab9] {
    max-width: 576px
}

.VPTeamMembers.small.count-3 .container[data-v-5c40eab9] {
    max-width: 876px
}

.VPTeamMembers.medium .container[data-v-5c40eab9] {
    grid-template-columns: repeat(auto-fit,minmax(256px,1fr))
}

@media (min-width: 375px) {
    .VPTeamMembers.medium .container[data-v-5c40eab9] {
        grid-template-columns:repeat(auto-fit,minmax(288px,1fr))
    }
}

.VPTeamMembers.medium.count-1 .container[data-v-5c40eab9] {
    max-width: 368px
}

.VPTeamMembers.medium.count-2 .container[data-v-5c40eab9] {
    max-width: 760px
}

.container[data-v-5c40eab9] {
    display: grid;
    gap: 24px;
    margin: 0 auto;
    max-width: 1152px
}

pre code.hljs {
    display: block;
    overflow-x: auto;
    padding: 1em
}

code.hljs {
    padding: 3px 5px
}

.hljs {
    color: #383a42;
    background: #fafafa
}

.hljs-comment,.hljs-quote {
    color: #a0a1a7;
    font-style: italic
}

.hljs-doctag,.hljs-formula,.hljs-keyword {
    color: #a626a4
}

.hljs-deletion,.hljs-name,.hljs-section,.hljs-selector-tag,.hljs-subst {
    color: #e45649
}

.hljs-literal {
    color: #0184bb
}

.hljs-addition,.hljs-attribute,.hljs-meta .hljs-string,.hljs-regexp,.hljs-string {
    color: #50a14f
}

.hljs-attr,.hljs-number,.hljs-selector-attr,.hljs-selector-class,.hljs-selector-pseudo,.hljs-template-variable,.hljs-type,.hljs-variable {
    color: #986801
}

.hljs-bullet,.hljs-link,.hljs-meta,.hljs-selector-id,.hljs-symbol,.hljs-title {
    color: #4078f2
}

.hljs-built_in,.hljs-class .hljs-title,.hljs-title.class_ {
    color: #c18401
}

.hljs-emphasis {
    font-style: italic
}

.hljs-strong {
    font-weight: 700
}

.hljs-link {
    text-decoration: underline
}

.dark pre code.hljs {
    display: block;
    overflow-x: auto;
    padding: 1em
}

.dark code.hljs {
    padding: 3px 5px
}

.dark .hljs {
    color: #abb2bf;
    background: #282c34
}

.dark .hljs-comment,.dark .hljs-quote {
    color: #5c6370;
    font-style: italic
}

.hljs-doctag,.dark .hljs-formula,.dark .hljs-keyword {
    color: #c678dd
}

.dark .hljs-deletion,.dark .hljs-name,.dark .hljs-section,.dark .hljs-selector-tag,.dark .hljs-subst {
    color: #e06c75
}

.dark .hljs-literal {
    color: #56b6c2
}

.dark .hljs-addition,.dark .hljs-attribute,.dark .hljs-meta .dark .hljs-string,.dark .hljs-regexp,.dark .hljs-string {
    color: #98c379
}

.dark .hljs-attr,.dark .hljs-number,.dark .hljs-selector-attr,.dark .hljs-selector-class,.dark .hljs-selector-pseudo,.dark .hljs-template-variable,.dark .hljs-type,.dark .hljs-variable {
    color: #d19a66
}

.dark .hljs-bullet,.dark .hljs-link,.dark .hljs-meta,.dark .hljs-selector-id,.dark .hljs-symbol,.dark .hljs-title {
    color: #61aeee
}

.dark .hljs-built_in,.dark .hljs-class .dark .hljs-title,.dark .hljs-title.class_ {
    color: #e6c07b
}

.dark .hljs-emphasis {
    font-style: italic
}

.dark .hljs-strong {
    font-weight: 700
}

.dark .hljs-link {
    text-decoration: underline
}

.k-docs-code {
    width: 100%;
    font-size: 14px
}

.hljs {
    border-radius: 8px
}

.vp-doc .demo-link .k-link--default {
    color: var(--ikun-gray-500)
}

.vp-doc .demo-link .k-link--success {
    color: var(--ikun-green-400)
}

.vp-doc .demo-link .k-link--warning {
    color: var(--ikun-amber-400)
}

.vp-doc .demo-link .k-link--primary {
    color: var(--ikun-teal-400)
}

.vp-doc .demo-link .k-link--info {
    color: var(--ikun-gray-400)
}

.vp-doc .demo-link .k-link--error {
    color: var(--ikun-rose-400)
}

.vp-doc .demo-link .k-link--underline__none {
    text-decoration: none
}

.vp-doc .demo-empty p {
    margin: 0!important
}

.vp-doc .demon-dropdown .k-link--underline__none {
    text-decoration: none
}

.vp-doc .demon-dropdown .k-link--primary {
    color: var(--ikun-teal-400)
}

.vp-doc ul.k-skeleton-paragraph {
    padding: 0
}

.vp-doc li.k-timeline-item {
    margin-top: 0
}

.vp-doc ul.k-timeline {
    padding-right: 1.25rem
}

.vp-doc table.k-calendar-content {
    box-sizing: border-box;
    width: 100%;
    border-collapse: collapse;
    table-layout: fixed;
    display: table;
    margin: 0;
    overflow-x: visible
}

.vp-doc table.k-calendar-content tr {
    background-color: #0000;
    border-top-color: gray;
    border-top-left-radius: 0;
    border-top-right-radius: 0;
    border-top-style: none;
    border-top-width: 0px;
    transition-behavior: normal;
    transition-delay: 0s;
    transition-duration: 0s;
    transition-property: all;
    transition-timing-function: ease;
    view-transition-name: none
}

.vp-doc th.k-calendar-thead-card,.vp-doc th.k-calendar-thead {
    position: relative;
    box-sizing: border-box;
    min-width: 24px;
    border-radius: 18px;
    vertical-align: middle;
    font-weight: 400;
    border: none;
    padding: 0 12px 4px 0;
    background-color: transparent;
    text-align: right;
    font-size: 14px;
    color: #0a0a0a
}

.vp-doc td.k-calendar-cell {
    padding: 0;
    border: none
}

.vp-doc th.k-calendar-thead-card--dark,.vp-doc th.k-calendar-thead--dark {
    color: #fff
}

.logo-grey {
    width: 52px;
    height: 52px;
    position: relative;
    transform: rotate(135deg);
    margin: auto;
    animation: logo-grey var(--t) infinite cubic-bezier(.68,-.55,.265,1.55) var(--play-status);
    overflow: hidden
}

.logo-grey:before,.logo-grey:after {
    content: "";
    position: absolute;
    width: 52px;
    height: 26px;
    background-color: #999
}

.logo-grey:before {
    left: 0;
    transform-origin: 100% 0;
    transform: rotate(8deg);
    animation: mid-split-right var(--t) infinite cubic-bezier(.68,-.55,.265,1.55) var(--play-status)
}

.logo-grey:after {
    width: 26px;
    height: 52px;
    right: 0;
    transform-origin: 100% 0;
    transform: rotate(-8deg);
    animation: mid-split-left var(--t) infinite cubic-bezier(.68,-.55,.265,1.55) var(--play-status)
}

@keyframes logo-grey {
    0%,50%,to {
        transform: translateY(0) rotate(135deg)
    }

    25%,75% {
        transform: translateY(10%) rotate(135deg)
    }
}

@keyframes mid-split-left {
    0%,50%,to {
        transform: rotate(-8deg)
    }

    30%,80% {
        transform: rotate(1deg)
    }
}

@keyframes mid-split-right {
    0%,50%,to {
        transform: rotate(8deg)
    }

    30%,80% {
        transform: rotate(-1deg)
    }
}

.logo-black {
    width: 84px;
    height: 84px;
    background: #000;
    position: relative;
    transform: rotate(45deg);
    overflow: hidden;
    clip-path: polygon(33% 0,100% 0,100% 100%,0 100%,0 33%,33% 33%,33% 0);
    margin: -5px auto auto;
    animation: logo-black var(--t) infinite var(--play-status)
}

.logo-black:before,.logo-black:after {
    content: "";
    position: absolute;
    background-color: #fff;
    width: 6px;
    height: 100%
}

.logo-black:before {
    top: 25%;
    left: 10%;
    transform: rotate(-45deg)
}

.logo-black:after {
    top: -25%;
    right: 10%;
    transform: rotate(-45deg)
}

.logo-black span {
    position: absolute;
    top: 25%;
    left: 25%;
    width: 100%;
    height: 100%;
    background: linear-gradient(to bottom,#fff 50%,#000 50%) 50% 0 / 10% 20% repeat-y;
    transform: rotate(-45deg)
}

@keyframes logo-black {
    0%,10%,90%,to {
        transform: translateY(0) rotate(45deg)
    }

    35% {
        transform: translate(10px,-10px) rotate(45deg)
    }

    40% {
        transform: translate(0) rotate(45deg)
    }

    50% {
        transform: translate(10px,10px) rotate(45deg)
    }

    65% {
        transform: translate(0) rotate(45deg)
    }

    70% {
        transform: translate(10px,-10px) rotate(45deg)
    }

    75% {
        transform: translate(10px,10px) rotate(45deg)
    }

    20%,30%,80% {
        transform: translateY(5px) rotate(45deg)
    }
}

.logo-circle {
    width: 100%;
    height: 130px;
    position: absolute;
    top: 0;
    left: 0;
    animation: logo-circle var(--t) infinite var(--play-status)
}

.logo-circle:after {
    content: "";
    position: absolute;
    width: 30px;
    height: 30px;
    background-color: #f80;
    border-radius: 50%;
    bottom: 0;
    left: 0;
    animation: play 1s infinite
}

.shadow {
    position: absolute;
    bottom: -30px;
    left: 0;
    width: 30px;
    height: 10px;
    border-radius: 50%;
    background: radial-gradient(#666,transparent 50%);
    animation: play-shadow 1s infinite;
    transform: scale(.5)
}

.play .logo-circle:after {
    animation-play-state: paused
}

.play .shadow {
    display: none
}

@keyframes logo-circle {
    25% {
        transform: rotate(-60deg)
    }

    50% {
        transform: rotate(-90deg)
    }

    75% {
        transform: rotate(-30deg)
    }
}

@keyframes play {
    40% {
        transform: translateY(20px)
    }
}

@keyframes play-shadow {
    40% {
        transform: scale(1)
    }
}

@keyframes run-shadow {
    25% {
        left: 78px;
        transform: scale(1) translateY(10px)
    }

    50% {
        left: 118px;
        transform: scale(.5)
    }

    75% {
        left: 40px;
        transform: scale(1) translateY(10px)
    }
}

#home_logo {
    scale: 1.5;
    position: relative;
    width: 150px;
    margin: 20px auto;
    --t: 3s;
    --play-status: pause
}

#home_logo.play {
    --play-status: running
}

@media (max-width: 960px) {
    #home_logo {
        top:20%
    }
}

:root {
    --vp-c-brand: #ff7707;
    --vp-c-brand-light: #f68b32;
    --vp-c-brand-lighter: #f8a153;
    --vp-c-brand-1: #ff7707;
    --vp-c-brand-2: #f8a153;
    --vp-c-brand-lightest: #f6ad75;
    --vp-c-brand-dark: #ff7707;
    --vp-c-brand-darker: #f6a462;
    --vp-c-brand-dimm: rgba(255, 119, 7, .08)
}

:root {
    --vp-button-brand-border: var(--vp-c-brand-light);
    --vp-button-brand-text: var(--vp-c-white);
    --vp-button-brand-bg: var(--vp-c-brand);
    --vp-button-brand-hover-border: var(--vp-c-brand-light);
    --vp-button-brand-hover-text: var(--vp-c-white);
    --vp-button-brand-hover-bg: var(--vp-c-brand-light);
    --vp-button-brand-active-border: var(--vp-c-brand-light);
    --vp-button-brand-active-text: var(--vp-c-white);
    --vp-button-brand-active-bg: var(--vp-button-brand-bg)
}

:root {
    --vp-home-hero-name-color: transparent;
    --vp-home-hero-name-background: -webkit-linear-gradient(120deg, #ff7707 30%, #809aff);
    --vp-home-hero-image-background-image: linear-gradient(-45deg, #ff7707 50%, #809aff 50%);
    --vp-home-hero-image-filter: blur(40px)
}

@media (min-width: 640px) {
    :root {
        --vp-home-hero-image-filter: blur(56px)
    }
}

@media (min-width: 960px) {
    :root {
        --vp-home-hero-image-filter: blur(72px)
    }
}

:root {
    --vp-custom-block-tip-border: var(--vp-c-brand);
    --vp-custom-block-tip-text: var(--vp-c-brand-darker);
    --vp-custom-block-tip-bg: var(--vp-c-brand-dimm)
}

.dark {
    --vp-custom-block-tip-border: var(--vp-c-brand);
    --vp-custom-block-tip-text: var(--vp-c-brand-lightest);
    --vp-custom-block-tip-bg: var(--vp-c-brand-dimm)
}

.DocSearch {
    --docsearch-primary-color: var(--vp-c-brand) !important
}

html ::-webkit-scrollbar-track-piece {
    background: #ff3e000f
}

html ::-webkit-scrollbar {
    width: 8px;
    height: 8px
}

html ::-webkit-scrollbar-thumb {
    background: #ff3e0061;
    border-radius: 20px
}

*,:before,:after {
    --un-rotate: 0;
    --un-rotate-x: 0;
    --un-rotate-y: 0;
    --un-rotate-z: 0;
    --un-scale-x: 1;
    --un-scale-y: 1;
    --un-scale-z: 1;
    --un-skew-x: 0;
    --un-skew-y: 0;
    --un-translate-x: 0;
    --un-translate-y: 0;
    --un-translate-z: 0;
    --un-pan-x: ;
    --un-pan-y: ;
    --un-pinch-zoom: ;
    --un-scroll-snap-strictness: proximity;
    --un-ordinal: ;
    --un-slashed-zero: ;
    --un-numeric-figure: ;
    --un-numeric-spacing: ;
    --un-numeric-fraction: ;
    --un-border-spacing-x: 0;
    --un-border-spacing-y: 0;
    --un-ring-offset-shadow: 0 0 rgb(0 0 0 / 0);
    --un-ring-shadow: 0 0 rgb(0 0 0 / 0);
    --un-shadow-inset: ;
    --un-shadow: 0 0 rgb(0 0 0 / 0);
    --un-ring-inset: ;
    --un-ring-offset-width: 0px;
    --un-ring-offset-color: #fff;
    --un-ring-width: 0px;
    --un-ring-color: rgb(147 197 253 / .5);
    --un-blur: ;
    --un-brightness: ;
    --un-contrast: ;
    --un-drop-shadow: ;
    --un-grayscale: ;
    --un-hue-rotate: ;
    --un-invert: ;
    --un-saturate: ;
    --un-sepia: ;
    --un-backdrop-blur: ;
    --un-backdrop-brightness: ;
    --un-backdrop-contrast: ;
    --un-backdrop-grayscale: ;
    --un-backdrop-hue-rotate: ;
    --un-backdrop-invert: ;
    --un-backdrop-opacity: ;
    --un-backdrop-saturate: ;
    --un-backdrop-sepia:
}

::backdrop {
    --un-rotate: 0;
    --un-rotate-x: 0;
    --un-rotate-y: 0;
    --un-rotate-z: 0;
    --un-scale-x: 1;
    --un-scale-y: 1;
    --un-scale-z: 1;
    --un-skew-x: 0;
    --un-skew-y: 0;
    --un-translate-x: 0;
    --un-translate-y: 0;
    --un-translate-z: 0;
    --un-pan-x: ;
    --un-pan-y: ;
    --un-pinch-zoom: ;
    --un-scroll-snap-strictness: proximity;
    --un-ordinal: ;
    --un-slashed-zero: ;
    --un-numeric-figure: ;
    --un-numeric-spacing: ;
    --un-numeric-fraction: ;
    --un-border-spacing-x: 0;
    --un-border-spacing-y: 0;
    --un-ring-offset-shadow: 0 0 rgb(0 0 0 / 0);
    --un-ring-shadow: 0 0 rgb(0 0 0 / 0);
    --un-shadow-inset: ;
    --un-shadow: 0 0 rgb(0 0 0 / 0);
    --un-ring-inset: ;
    --un-ring-offset-width: 0px;
    --un-ring-offset-color: #fff;
    --un-ring-width: 0px;
    --un-ring-color: rgb(147 197 253 / .5);
    --un-blur: ;
    --un-brightness: ;
    --un-contrast: ;
    --un-drop-shadow: ;
    --un-grayscale: ;
    --un-hue-rotate: ;
    --un-invert: ;
    --un-saturate: ;
    --un-sepia: ;
    --un-backdrop-blur: ;
    --un-backdrop-brightness: ;
    --un-backdrop-contrast: ;
    --un-backdrop-grayscale: ;
    --un-backdrop-hue-rotate: ;
    --un-backdrop-invert: ;
    --un-backdrop-opacity: ;
    --un-backdrop-saturate: ;
    --un-backdrop-sepia:
}

.i-carbon-3d-cursor-alt {
    --un-icon: url("data:image/svg+xml;utf8,%3Csvg viewBox='0 0 32 32' display='inline-block' vertical-align='middle' width='1.2em' height='1.2em' xmlns='http://www.w3.org/2000/svg' %3E%3Cpath d='M16 30a14 14 0 1 1 14-14a14.016 14.016 0 0 1-14 14zm0-26a12 12 0 1 0 12 12A12.014 12.014 0 0 0 16 4z' fill='currentColor'/%3E%3Cpath d='M15 7h2v7h-2z' fill='currentColor'/%3E%3Cpath d='M7 15h7v2H7z' fill='currentColor'/%3E%3Cpath d='M15 18h2v7h-2z' fill='currentColor'/%3E%3Cpath d='M18 15h7v2h-7z' fill='currentColor'/%3E%3C/svg%3E");
    -webkit-mask: var(--un-icon) no-repeat;
    mask: var(--un-icon) no-repeat;
    -webkit-mask-size: 100% 100%;
    mask-size: 100% 100%;
    background-color: currentColor;
    color: inherit;
    display: inline-block;
    vertical-align: middle;
    width: 1.2em;
    height: 1.2em
}

.i-carbon-add {
    --un-icon: url("data:image/svg+xml;utf8,%3Csvg viewBox='0 0 32 32' display='inline-block' vertical-align='middle' width='1.2em' height='1.2em' xmlns='http://www.w3.org/2000/svg' %3E%3Cpath fill='currentColor' d='M17 15V8h-2v7H8v2h7v7h2v-7h7v-2z'/%3E%3C/svg%3E");
    -webkit-mask: var(--un-icon) no-repeat;
    mask: var(--un-icon) no-repeat;
    -webkit-mask-size: 100% 100%;
    mask-size: 100% 100%;
    background-color: currentColor;
    color: inherit;
    display: inline-block;
    vertical-align: middle;
    width: 1.2em;
    height: 1.2em
}

.i-carbon-aperture {
    --un-icon: url("data:image/svg+xml;utf8,%3Csvg viewBox='0 0 32 32' display='inline-block' vertical-align='middle' width='1.2em' height='1.2em' xmlns='http://www.w3.org/2000/svg' %3E%3Cpath fill='currentColor' d='M16 2a14 14 0 1 0 14 14A14 14 0 0 0 16 2m11.84 12.14L22 17.52V5.62a12 12 0 0 1 5.84 8.52M12 18.68v-5.36L16 11l4 2.31v5.36L16 21Zm8-14V11l-9.66-5.58A11.9 11.9 0 0 1 20 4.7Zm-11.52 2L14 9.85L4 15.62a12 12 0 0 1 4.48-8.96ZM4.16 17.85L10 14.47v11.91a12 12 0 0 1-5.84-8.53M12 27.3V21l9.67 5.58A11.92 11.92 0 0 1 16 28a12.05 12.05 0 0 1-4-.7m11.52-2L18 22.14l10-5.77a12 12 0 0 1-4.48 8.97Z'/%3E%3C/svg%3E");
    -webkit-mask: var(--un-icon) no-repeat;
    mask: var(--un-icon) no-repeat;
    -webkit-mask-size: 100% 100%;
    mask-size: 100% 100%;
    background-color: currentColor;
    color: inherit;
    display: inline-block;
    vertical-align: middle;
    width: 1.2em;
    height: 1.2em
}

.i-carbon-arrow-left {
    --un-icon: url("data:image/svg+xml;utf8,%3Csvg viewBox='0 0 32 32' display='inline-block' vertical-align='middle' width='1.2em' height='1.2em' xmlns='http://www.w3.org/2000/svg' %3E%3Cpath fill='currentColor' d='m14 26l1.41-1.41L7.83 17H28v-2H7.83l7.58-7.59L14 6L4 16z'/%3E%3C/svg%3E");
    -webkit-mask: var(--un-icon) no-repeat;
    mask: var(--un-icon) no-repeat;
    -webkit-mask-size: 100% 100%;
    mask-size: 100% 100%;
    background-color: currentColor;
    color: inherit;
    display: inline-block;
    vertical-align: middle;
    width: 1.2em;
    height: 1.2em
}

.i-carbon-arrow-up {
    --un-icon: url("data:image/svg+xml;utf8,%3Csvg viewBox='0 0 32 32' display='inline-block' vertical-align='middle' width='1.2em' height='1.2em' xmlns='http://www.w3.org/2000/svg' %3E%3Cpath fill='currentColor' d='M16 4L6 14l1.41 1.41L15 7.83V28h2V7.83l7.59 7.58L26 14z'/%3E%3C/svg%3E");
    -webkit-mask: var(--un-icon) no-repeat;
    mask: var(--un-icon) no-repeat;
    -webkit-mask-size: 100% 100%;
    mask-size: 100% 100%;
    background-color: currentColor;
    color: inherit;
    display: inline-block;
    vertical-align: middle;
    width: 1.2em;
    height: 1.2em
}

.i-carbon-arrows-horizontal {
    --un-icon: url("data:image/svg+xml;utf8,%3Csvg viewBox='0 0 32 32' display='inline-block' vertical-align='middle' width='1.2em' height='1.2em' xmlns='http://www.w3.org/2000/svg' %3E%3Cpath fill='currentColor' d='M11.41 26.59L7.83 23H28v-2H7.83l3.58-3.59L10 16l-6 6l6 6zM28 10l-6-6l-1.41 1.41L24.17 9H4v2h20.17l-3.58 3.59L22 16z'/%3E%3C/svg%3E");
    -webkit-mask: var(--un-icon) no-repeat;
    mask: var(--un-icon) no-repeat;
    -webkit-mask-size: 100% 100%;
    mask-size: 100% 100%;
    background-color: currentColor;
    color: inherit;
    display: inline-block;
    vertical-align: middle;
    width: 1.2em;
    height: 1.2em
}

.i-carbon-arrows-vertical {
    --un-icon: url("data:image/svg+xml;utf8,%3Csvg viewBox='0 0 32 32' display='inline-block' vertical-align='middle' width='1.2em' height='1.2em' xmlns='http://www.w3.org/2000/svg' %3E%3Cpath fill='currentColor' d='M27.6 20.6L24 24.2V4h-2v20.2l-3.6-3.6L17 22l6 6l6-6zM9 4l-6 6l1.4 1.4L8 7.8V28h2V7.8l3.6 3.6L15 10z'/%3E%3C/svg%3E");
    -webkit-mask: var(--un-icon) no-repeat;
    mask: var(--un-icon) no-repeat;
    -webkit-mask-size: 100% 100%;
    mask-size: 100% 100%;
    background-color: currentColor;
    color: inherit;
    display: inline-block;
    vertical-align: middle;
    width: 1.2em;
    height: 1.2em
}

.i-carbon-border-full {
    --un-icon: url("data:image/svg+xml;utf8,%3Csvg viewBox='0 0 32 32' display='inline-block' vertical-align='middle' width='1.2em' height='1.2em' xmlns='http://www.w3.org/2000/svg' %3E%3Cpath fill='currentColor' d='M8 10h10v2H8zm0 5h6v2H8z'/%3E%3Cpath fill='currentColor' d='M29 29H3V3h26ZM5 27h22V5H5Z'/%3E%3C/svg%3E");
    -webkit-mask: var(--un-icon) no-repeat;
    mask: var(--un-icon) no-repeat;
    -webkit-mask-size: 100% 100%;
    mask-size: 100% 100%;
    background-color: currentColor;
    color: inherit;
    display: inline-block;
    vertical-align: middle;
    width: 1.2em;
    height: 1.2em
}

.i-carbon-caret-down {
    --un-icon: url("data:image/svg+xml;utf8,%3Csvg viewBox='0 0 32 32' display='inline-block' vertical-align='middle' width='1.2em' height='1.2em' xmlns='http://www.w3.org/2000/svg' %3E%3Cpath fill='currentColor' d='m24 12l-8 10l-8-10z'/%3E%3C/svg%3E");
    -webkit-mask: var(--un-icon) no-repeat;
    mask: var(--un-icon) no-repeat;
    -webkit-mask-size: 100% 100%;
    mask-size: 100% 100%;
    background-color: currentColor;
    color: inherit;
    display: inline-block;
    vertical-align: middle;
    width: 1.2em;
    height: 1.2em
}

.i-carbon-chart-pie {
    --un-icon: url("data:image/svg+xml;utf8,%3Csvg viewBox='0 0 32 32' display='inline-block' vertical-align='middle' width='1.2em' height='1.2em' xmlns='http://www.w3.org/2000/svg' %3E%3Cpath fill='currentColor' d='M16 4a12 12 0 1 0 12 12A12 12 0 0 0 16 4m10 11h-9V6.05A10 10 0 0 1 26 15M15.42 26A10 10 0 0 1 15 6.05v9a2 2 0 0 0 2 2h9A10 10 0 0 1 15.42 26'/%3E%3C/svg%3E");
    -webkit-mask: var(--un-icon) no-repeat;
    mask: var(--un-icon) no-repeat;
    -webkit-mask-size: 100% 100%;
    mask-size: 100% 100%;
    background-color: currentColor;
    color: inherit;
    display: inline-block;
    vertical-align: middle;
    width: 1.2em;
    height: 1.2em
}

.i-carbon-chart-scatter {
    --un-icon: url("data:image/svg+xml;utf8,%3Csvg viewBox='0 0 32 32' display='inline-block' vertical-align='middle' width='1.2em' height='1.2em' xmlns='http://www.w3.org/2000/svg' %3E%3Cpath fill='currentColor' d='M30 30H4a2 2 0 0 1-2-2V2h2v26h26Z'/%3E%3Ccircle cx='10' cy='22' r='2' fill='currentColor'/%3E%3Ccircle cx='14' cy='15' r='2' fill='currentColor'/%3E%3Ccircle cx='22' cy='15' r='2' fill='currentColor'/%3E%3Ccircle cx='26' cy='6' r='2' fill='currentColor'/%3E%3Ccircle cx='14' cy='8' r='2' fill='currentColor'/%3E%3C/svg%3E");
    -webkit-mask: var(--un-icon) no-repeat;
    mask: var(--un-icon) no-repeat;
    -webkit-mask-size: 100% 100%;
    mask-size: 100% 100%;
    background-color: currentColor;
    color: inherit;
    display: inline-block;
    vertical-align: middle;
    width: 1.2em;
    height: 1.2em
}

.i-carbon-checkmark {
    --un-icon: url("data:image/svg+xml;utf8,%3Csvg viewBox='0 0 32 32' display='inline-block' vertical-align='middle' width='1.2em' height='1.2em' xmlns='http://www.w3.org/2000/svg' %3E%3Cpath fill='currentColor' d='m13 24l-9-9l1.414-1.414L13 21.171L26.586 7.586L28 9z'/%3E%3C/svg%3E");
    -webkit-mask: var(--un-icon) no-repeat;
    mask: var(--un-icon) no-repeat;
    -webkit-mask-size: 100% 100%;
    mask-size: 100% 100%;
    background-color: currentColor;
    color: inherit;
    display: inline-block;
    vertical-align: middle;
    width: 1.2em;
    height: 1.2em
}

.i-carbon-checkmark-filled {
    --un-icon: url("data:image/svg+xml;utf8,%3Csvg viewBox='0 0 32 32' display='inline-block' vertical-align='middle' width='1.2em' height='1.2em' xmlns='http://www.w3.org/2000/svg' %3E%3Cpath fill='currentColor' d='M16 2a14 14 0 1 0 14 14A14 14 0 0 0 16 2m-2 19.59l-5-5L10.59 15L14 18.41L21.41 11l1.596 1.586Z'/%3E%3Cpath fill='none' d='m14 21.591l-5-5L10.591 15L14 18.409L21.41 11l1.595 1.585z'/%3E%3C/svg%3E");
    -webkit-mask: var(--un-icon) no-repeat;
    mask: var(--un-icon) no-repeat;
    -webkit-mask-size: 100% 100%;
    mask-size: 100% 100%;
    background-color: currentColor;
    color: inherit;
    display: inline-block;
    vertical-align: middle;
    width: 1.2em;
    height: 1.2em
}

.i-carbon-chevron-down,[i-carbon-chevron-down=""] {
    --un-icon: url("data:image/svg+xml;utf8,%3Csvg viewBox='0 0 32 32' display='inline-block' vertical-align='middle' width='1.2em' height='1.2em' xmlns='http://www.w3.org/2000/svg' %3E%3Cpath fill='currentColor' d='M16 22L6 12l1.4-1.4l8.6 8.6l8.6-8.6L26 12z'/%3E%3C/svg%3E");
    -webkit-mask: var(--un-icon) no-repeat;
    mask: var(--un-icon) no-repeat;
    -webkit-mask-size: 100% 100%;
    mask-size: 100% 100%;
    background-color: currentColor;
    color: inherit;
    display: inline-block;
    vertical-align: middle;
    width: 1.2em;
    height: 1.2em
}

.i-carbon-chevron-left {
    --un-icon: url("data:image/svg+xml;utf8,%3Csvg viewBox='0 0 32 32' display='inline-block' vertical-align='middle' width='1.2em' height='1.2em' xmlns='http://www.w3.org/2000/svg' %3E%3Cpath fill='currentColor' d='M10 16L20 6l1.4 1.4l-8.6 8.6l8.6 8.6L20 26z'/%3E%3C/svg%3E");
    -webkit-mask: var(--un-icon) no-repeat;
    mask: var(--un-icon) no-repeat;
    -webkit-mask-size: 100% 100%;
    mask-size: 100% 100%;
    background-color: currentColor;
    color: inherit;
    display: inline-block;
    vertical-align: middle;
    width: 1.2em;
    height: 1.2em
}

.i-carbon-chevron-right {
    --un-icon: url("data:image/svg+xml;utf8,%3Csvg viewBox='0 0 32 32' display='inline-block' vertical-align='middle' width='1.2em' height='1.2em' xmlns='http://www.w3.org/2000/svg' %3E%3Cpath fill='currentColor' d='M22 16L12 26l-1.4-1.4l8.6-8.6l-8.6-8.6L12 6z'/%3E%3C/svg%3E");
    -webkit-mask: var(--un-icon) no-repeat;
    mask: var(--un-icon) no-repeat;
    -webkit-mask-size: 100% 100%;
    mask-size: 100% 100%;
    background-color: currentColor;
    color: inherit;
    display: inline-block;
    vertical-align: middle;
    width: 1.2em;
    height: 1.2em
}

.i-carbon-chevron-up {
    --un-icon: url("data:image/svg+xml;utf8,%3Csvg viewBox='0 0 32 32' display='inline-block' vertical-align='middle' width='1.2em' height='1.2em' xmlns='http://www.w3.org/2000/svg' %3E%3Cpath fill='currentColor' d='m16 10l10 10l-1.4 1.4l-8.6-8.6l-8.6 8.6L6 20z'/%3E%3C/svg%3E");
    -webkit-mask: var(--un-icon) no-repeat;
    mask: var(--un-icon) no-repeat;
    -webkit-mask-size: 100% 100%;
    mask-size: 100% 100%;
    background-color: currentColor;
    color: inherit;
    display: inline-block;
    vertical-align: middle;
    width: 1.2em;
    height: 1.2em
}

.i-carbon-circle-dash {
    --un-icon: url("data:image/svg+xml;utf8,%3Csvg viewBox='0 0 32 32' display='inline-block' vertical-align='middle' width='1.2em' height='1.2em' xmlns='http://www.w3.org/2000/svg' %3E%3Cpath fill='currentColor' d='M7.7 4.7a14.7 14.7 0 0 0-3 3.1L6.3 9a13.26 13.26 0 0 1 2.6-2.7zm-3.1 7.6l-1.9-.6A12.51 12.51 0 0 0 2 16h2a11.48 11.48 0 0 1 .6-3.7m-1.9 8.1a14.4 14.4 0 0 0 2 3.9l1.6-1.2a12.89 12.89 0 0 1-1.7-3.3zm5.1 6.9a14.4 14.4 0 0 0 3.9 2l.6-1.9A12.89 12.89 0 0 1 9 25.7zm3.9-24.6l.6 1.9A11.48 11.48 0 0 1 16 4V2a12.51 12.51 0 0 0-4.3.7m12.5 24.6a15.18 15.18 0 0 0 3.1-3.1L25.7 23a11.53 11.53 0 0 1-2.7 2.7zm3.2-7.6l1.9.6A15.47 15.47 0 0 0 30 16h-2a11.48 11.48 0 0 1-.6 3.7m1.8-8.1a14.4 14.4 0 0 0-2-3.9l-1.6 1.2a12.89 12.89 0 0 1 1.7 3.3zm-5.1-7a14.4 14.4 0 0 0-3.9-2l-.6 1.9a12.89 12.89 0 0 1 3.3 1.7zm-3.8 24.7l-.6-1.9a11.48 11.48 0 0 1-3.7.6v2a21.42 21.42 0 0 0 4.3-.7'/%3E%3C/svg%3E");
    -webkit-mask: var(--un-icon) no-repeat;
    mask: var(--un-icon) no-repeat;
    -webkit-mask-size: 100% 100%;
    mask-size: 100% 100%;
    background-color: currentColor;
    color: inherit;
    display: inline-block;
    vertical-align: middle;
    width: 1.2em;
    height: 1.2em
}

.i-carbon-close {
    --un-icon: url("data:image/svg+xml;utf8,%3Csvg viewBox='0 0 32 32' display='inline-block' vertical-align='middle' width='1.2em' height='1.2em' xmlns='http://www.w3.org/2000/svg' %3E%3Cpath fill='currentColor' d='M17.414 16L24 9.414L22.586 8L16 14.586L9.414 8L8 9.414L14.586 16L8 22.586L9.414 24L16 17.414L22.586 24L24 22.586z'/%3E%3C/svg%3E");
    -webkit-mask: var(--un-icon) no-repeat;
    mask: var(--un-icon) no-repeat;
    -webkit-mask-size: 100% 100%;
    mask-size: 100% 100%;
    background-color: currentColor;
    color: inherit;
    display: inline-block;
    vertical-align: middle;
    width: 1.2em;
    height: 1.2em
}

.i-carbon-close-outline,.i-carbon\:close-outline {
    --un-icon: url("data:image/svg+xml;utf8,%3Csvg viewBox='0 0 32 32' display='inline-block' vertical-align='middle' width='1.2em' height='1.2em' xmlns='http://www.w3.org/2000/svg' %3E%3Cpath fill='currentColor' d='M16 2C8.2 2 2 8.2 2 16s6.2 14 14 14s14-6.2 14-14S23.8 2 16 2m0 26C9.4 28 4 22.6 4 16S9.4 4 16 4s12 5.4 12 12s-5.4 12-12 12'/%3E%3Cpath fill='currentColor' d='M21.4 23L16 17.6L10.6 23L9 21.4l5.4-5.4L9 10.6L10.6 9l5.4 5.4L21.4 9l1.6 1.6l-5.4 5.4l5.4 5.4z'/%3E%3C/svg%3E");
    -webkit-mask: var(--un-icon) no-repeat;
    mask: var(--un-icon) no-repeat;
    -webkit-mask-size: 100% 100%;
    mask-size: 100% 100%;
    background-color: currentColor;
    color: inherit;
    display: inline-block;
    vertical-align: middle;
    width: 1.2em;
    height: 1.2em
}

.i-carbon-code {
    --un-icon: url("data:image/svg+xml;utf8,%3Csvg viewBox='0 0 32 32' display='inline-block' vertical-align='middle' width='1.2em' height='1.2em' xmlns='http://www.w3.org/2000/svg' %3E%3Cpath fill='currentColor' d='m31 16l-7 7l-1.41-1.41L28.17 16l-5.58-5.59L24 9zM1 16l7-7l1.41 1.41L3.83 16l5.58 5.59L8 23zm11.42 9.484L17.64 6l1.932.517L14.352 26z'/%3E%3C/svg%3E");
    -webkit-mask: var(--un-icon) no-repeat;
    mask: var(--un-icon) no-repeat;
    -webkit-mask-size: 100% 100%;
    mask-size: 100% 100%;
    background-color: currentColor;
    color: inherit;
    display: inline-block;
    vertical-align: middle;
    width: 1.2em;
    height: 1.2em
}

.i-carbon-collapse-categories {
    --un-icon: url("data:image/svg+xml;utf8,%3Csvg viewBox='0 0 32 32' display='inline-block' vertical-align='middle' width='1.2em' height='1.2em' xmlns='http://www.w3.org/2000/svg' %3E%3Cpath fill='currentColor' d='M14 25h14v2H14zm-6.83 1l-2.58 2.58L6 30l4-4l-4-4l-1.42 1.41zM14 15h14v2H14zm-6.83 1l-2.58 2.58L6 20l4-4l-4-4l-1.42 1.41zM14 5h14v2H14zM7.17 6L4.59 8.58L6 10l4-4l-4-4l-1.42 1.41z'/%3E%3C/svg%3E");
    -webkit-mask: var(--un-icon) no-repeat;
    mask: var(--un-icon) no-repeat;
    -webkit-mask-size: 100% 100%;
    mask-size: 100% 100%;
    background-color: currentColor;
    color: inherit;
    display: inline-block;
    vertical-align: middle;
    width: 1.2em;
    height: 1.2em
}

.i-carbon-copy-file {
    --un-icon: url("data:image/svg+xml;utf8,%3Csvg viewBox='0 0 32 32' display='inline-block' vertical-align='middle' width='1.2em' height='1.2em' xmlns='http://www.w3.org/2000/svg' %3E%3Cpath fill='currentColor' d='m27.4 14.7l-6.1-6.1C21 8.2 20.5 8 20 8h-8c-1.1 0-2 .9-2 2v18c0 1.1.9 2 2 2h14c1.1 0 2-.9 2-2V16.1c0-.5-.2-1-.6-1.4M20 10l5.9 6H20zm-8 18V10h6v6c0 1.1.9 2 2 2h6v10z'/%3E%3Cpath fill='currentColor' d='M6 18H4V4c0-1.1.9-2 2-2h14v2H6z'/%3E%3C/svg%3E");
    -webkit-mask: var(--un-icon) no-repeat;
    mask: var(--un-icon) no-repeat;
    -webkit-mask-size: 100% 100%;
    mask-size: 100% 100%;
    background-color: currentColor;
    color: inherit;
    display: inline-block;
    vertical-align: middle;
    width: 1.2em;
    height: 1.2em
}

.i-carbon-cube {
    --un-icon: url("data:image/svg+xml;utf8,%3Csvg viewBox='0 0 32 32' display='inline-block' vertical-align='middle' width='1.2em' height='1.2em' xmlns='http://www.w3.org/2000/svg' %3E%3Cpath fill='currentColor' d='m28.504 8.136l-12-7a1 1 0 0 0-1.008 0l-12 7A1 1 0 0 0 3 9v14a1 1 0 0 0 .496.864l12 7a1 1 0 0 0 1.008 0l12-7A1 1 0 0 0 29 23V9a1 1 0 0 0-.496-.864M16 3.158L26.016 9L16 14.842L5.984 9ZM5 10.74l10 5.833V28.26L5 22.426Zm12 17.52V16.574l10-5.833v11.685Z'/%3E%3C/svg%3E");
    -webkit-mask: var(--un-icon) no-repeat;
    mask: var(--un-icon) no-repeat;
    -webkit-mask-size: 100% 100%;
    mask-size: 100% 100%;
    background-color: currentColor;
    color: inherit;
    display: inline-block;
    vertical-align: middle;
    width: 1.2em;
    height: 1.2em
}

.i-carbon-document {
    --un-icon: url("data:image/svg+xml;utf8,%3Csvg viewBox='0 0 32 32' display='inline-block' vertical-align='middle' width='1.2em' height='1.2em' xmlns='http://www.w3.org/2000/svg' %3E%3Cpath fill='currentColor' d='m25.7 9.3l-7-7c-.2-.2-.4-.3-.7-.3H8c-1.1 0-2 .9-2 2v24c0 1.1.9 2 2 2h16c1.1 0 2-.9 2-2V10c0-.3-.1-.5-.3-.7M18 4.4l5.6 5.6H18zM24 28H8V4h8v6c0 1.1.9 2 2 2h6z'/%3E%3Cpath fill='currentColor' d='M10 22h12v2H10zm0-6h12v2H10z'/%3E%3C/svg%3E");
    -webkit-mask: var(--un-icon) no-repeat;
    mask: var(--un-icon) no-repeat;
    -webkit-mask-size: 100% 100%;
    mask-size: 100% 100%;
    background-color: currentColor;
    color: inherit;
    display: inline-block;
    vertical-align: middle;
    width: 1.2em;
    height: 1.2em
}

.i-carbon-download {
    --un-icon: url("data:image/svg+xml;utf8,%3Csvg viewBox='0 0 32 32' display='inline-block' vertical-align='middle' width='1.2em' height='1.2em' xmlns='http://www.w3.org/2000/svg' %3E%3Cpath fill='currentColor' d='M26 24v4H6v-4H4v4a2 2 0 0 0 2 2h20a2 2 0 0 0 2-2v-4zm0-10l-1.41-1.41L17 20.17V2h-2v18.17l-7.59-7.58L6 14l10 10z'/%3E%3C/svg%3E");
    -webkit-mask: var(--un-icon) no-repeat;
    mask: var(--un-icon) no-repeat;
    -webkit-mask-size: 100% 100%;
    mask-size: 100% 100%;
    background-color: currentColor;
    color: inherit;
    display: inline-block;
    vertical-align: middle;
    width: 1.2em;
    height: 1.2em
}

.i-carbon-error-filled {
    --un-icon: url("data:image/svg+xml;utf8,%3Csvg viewBox='0 0 32 32' display='inline-block' vertical-align='middle' width='1.2em' height='1.2em' xmlns='http://www.w3.org/2000/svg' %3E%3Cpath fill='none' d='M9 10.555L10.555 9L23 21.444L21.444 23z'/%3E%3Cpath fill='currentColor' d='M16 2A13.914 13.914 0 0 0 2 16a13.914 13.914 0 0 0 14 14a13.914 13.914 0 0 0 14-14A13.914 13.914 0 0 0 16 2m5.445 21L9 10.556L10.556 9L23 21.445Z'/%3E%3C/svg%3E");
    -webkit-mask: var(--un-icon) no-repeat;
    mask: var(--un-icon) no-repeat;
    -webkit-mask-size: 100% 100%;
    mask-size: 100% 100%;
    background-color: currentColor;
    color: inherit;
    display: inline-block;
    vertical-align: middle;
    width: 1.2em;
    height: 1.2em
}

.i-carbon-image {
    --un-icon: url("data:image/svg+xml;utf8,%3Csvg viewBox='0 0 32 32' display='inline-block' vertical-align='middle' width='1.2em' height='1.2em' xmlns='http://www.w3.org/2000/svg' %3E%3Cpath fill='currentColor' d='M19 14a3 3 0 1 0-3-3a3 3 0 0 0 3 3m0-4a1 1 0 1 1-1 1a1 1 0 0 1 1-1'/%3E%3Cpath fill='currentColor' d='M26 4H6a2 2 0 0 0-2 2v20a2 2 0 0 0 2 2h20a2 2 0 0 0 2-2V6a2 2 0 0 0-2-2m0 22H6v-6l5-5l5.59 5.59a2 2 0 0 0 2.82 0L21 19l5 5Zm0-4.83l-3.59-3.59a2 2 0 0 0-2.82 0L18 19.17l-5.59-5.59a2 2 0 0 0-2.82 0L6 17.17V6h20Z'/%3E%3C/svg%3E");
    -webkit-mask: var(--un-icon) no-repeat;
    mask: var(--un-icon) no-repeat;
    -webkit-mask-size: 100% 100%;
    mask-size: 100% 100%;
    background-color: currentColor;
    color: inherit;
    display: inline-block;
    vertical-align: middle;
    width: 1.2em;
    height: 1.2em
}

.i-carbon-information {
    --un-icon: url("data:image/svg+xml;utf8,%3Csvg viewBox='0 0 32 32' display='inline-block' vertical-align='middle' width='1.2em' height='1.2em' xmlns='http://www.w3.org/2000/svg' %3E%3Cpath fill='currentColor' d='M17 22v-8h-4v2h2v6h-3v2h8v-2zM16 8a1.5 1.5 0 1 0 1.5 1.5A1.5 1.5 0 0 0 16 8'/%3E%3Cpath fill='currentColor' d='M16 30a14 14 0 1 1 14-14a14 14 0 0 1-14 14m0-26a12 12 0 1 0 12 12A12 12 0 0 0 16 4'/%3E%3C/svg%3E");
    -webkit-mask: var(--un-icon) no-repeat;
    mask: var(--un-icon) no-repeat;
    -webkit-mask-size: 100% 100%;
    mask-size: 100% 100%;
    background-color: currentColor;
    color: inherit;
    display: inline-block;
    vertical-align: middle;
    width: 1.2em;
    height: 1.2em
}

.i-carbon-information-filled {
    --un-icon: url("data:image/svg+xml;utf8,%3Csvg viewBox='0 0 32 32' display='inline-block' vertical-align='middle' width='1.2em' height='1.2em' xmlns='http://www.w3.org/2000/svg' %3E%3Cpath fill='none' d='M16 8a1.5 1.5 0 1 1-1.5 1.5A1.5 1.5 0 0 1 16 8m4 13.875h-2.875v-8H13v2.25h1.875v5.75H12v2.25h8Z'/%3E%3Cpath fill='currentColor' d='M16 2a14 14 0 1 0 14 14A14 14 0 0 0 16 2m0 6a1.5 1.5 0 1 1-1.5 1.5A1.5 1.5 0 0 1 16 8m4 16.125h-8v-2.25h2.875v-5.75H13v-2.25h4.125v8H20Z'/%3E%3C/svg%3E");
    -webkit-mask: var(--un-icon) no-repeat;
    mask: var(--un-icon) no-repeat;
    -webkit-mask-size: 100% 100%;
    mask-size: 100% 100%;
    background-color: currentColor;
    color: inherit;
    display: inline-block;
    vertical-align: middle;
    width: 1.2em;
    height: 1.2em
}

.i-carbon-link {
    --un-icon: url("data:image/svg+xml;utf8,%3Csvg viewBox='0 0 32 32' display='inline-block' vertical-align='middle' width='1.2em' height='1.2em' xmlns='http://www.w3.org/2000/svg' %3E%3Cpath fill='currentColor' d='M29.25 6.76a6 6 0 0 0-8.5 0l1.42 1.42a4 4 0 1 1 5.67 5.67l-8 8a4 4 0 1 1-5.67-5.66l1.41-1.42l-1.41-1.42l-1.42 1.42a6 6 0 0 0 0 8.5A6 6 0 0 0 17 25a6 6 0 0 0 4.27-1.76l8-8a6 6 0 0 0-.02-8.48'/%3E%3Cpath fill='currentColor' d='M4.19 24.82a4 4 0 0 1 0-5.67l8-8a4 4 0 0 1 5.67 0A3.94 3.94 0 0 1 19 14a4 4 0 0 1-1.17 2.85L15.71 19l1.42 1.42l2.12-2.12a6 6 0 0 0-8.51-8.51l-8 8a6 6 0 0 0 0 8.51A6 6 0 0 0 7 28a6.07 6.07 0 0 0 4.28-1.76l-1.42-1.42a4 4 0 0 1-5.67 0'/%3E%3C/svg%3E");
    -webkit-mask: var(--un-icon) no-repeat;
    mask: var(--un-icon) no-repeat;
    -webkit-mask-size: 100% 100%;
    mask-size: 100% 100%;
    background-color: currentColor;
    color: inherit;
    display: inline-block;
    vertical-align: middle;
    width: 1.2em;
    height: 1.2em
}

.i-carbon-logo-github {
    --un-icon: url("data:image/svg+xml;utf8,%3Csvg viewBox='0 0 32 32' display='inline-block' vertical-align='middle' width='1.2em' height='1.2em' xmlns='http://www.w3.org/2000/svg' %3E%3Cpath fill='currentColor' fill-rule='evenodd' d='M16 2a14 14 0 0 0-4.43 27.28c.7.13 1-.3 1-.67v-2.38c-3.89.84-4.71-1.88-4.71-1.88a3.71 3.71 0 0 0-1.62-2.05c-1.27-.86.1-.85.1-.85a2.94 2.94 0 0 1 2.14 1.45a3 3 0 0 0 4.08 1.16a2.93 2.93 0 0 1 .88-1.87c-3.1-.36-6.37-1.56-6.37-6.92a5.4 5.4 0 0 1 1.44-3.76a5 5 0 0 1 .14-3.7s1.17-.38 3.85 1.43a13.3 13.3 0 0 1 7 0c2.67-1.81 3.84-1.43 3.84-1.43a5 5 0 0 1 .14 3.7a5.4 5.4 0 0 1 1.44 3.76c0 5.38-3.27 6.56-6.39 6.91a3.33 3.33 0 0 1 .95 2.59v3.84c0 .46.25.81 1 .67A14 14 0 0 0 16 2'/%3E%3C/svg%3E");
    -webkit-mask: var(--un-icon) no-repeat;
    mask: var(--un-icon) no-repeat;
    -webkit-mask-size: 100% 100%;
    mask-size: 100% 100%;
    background-color: currentColor;
    color: inherit;
    display: inline-block;
    vertical-align: middle;
    width: 1.2em;
    height: 1.2em
}

.i-carbon-logo-google {
    --un-icon: url("data:image/svg+xml;utf8,%3Csvg viewBox='0 0 32 32' display='inline-block' vertical-align='middle' width='1.2em' height='1.2em' xmlns='http://www.w3.org/2000/svg' %3E%3Cpath fill='currentColor' d='M27.39 13.82H16.21v4.63h6.44c-.6 2.95-3.11 4.64-6.44 4.64a7.09 7.09 0 0 1 0-14.18a7 7 0 0 1 4.42 1.58L24.12 7a12 12 0 1 0-7.91 21c6 0 11.45-4.36 11.45-12a9.56 9.56 0 0 0-.27-2.18Z'/%3E%3C/svg%3E");
    -webkit-mask: var(--un-icon) no-repeat;
    mask: var(--un-icon) no-repeat;
    -webkit-mask-size: 100% 100%;
    mask-size: 100% 100%;
    background-color: currentColor;
    color: inherit;
    display: inline-block;
    vertical-align: middle;
    width: 1.2em;
    height: 1.2em
}

.i-carbon-logo-react {
    --un-icon: url("data:image/svg+xml;utf8,%3Csvg viewBox='0 0 32 32' display='inline-block' vertical-align='middle' width='1.2em' height='1.2em' xmlns='http://www.w3.org/2000/svg' %3E%3Cpath fill='currentColor' d='m25 11.6l-.9-.3c0-.2.1-.4.1-.6c.7-3.3.2-6-1.3-6.9c-1.5-.8-3.9 0-6.3 2.1c-.2.2-.5.4-.7.6c-.2-.1-.3-.3-.5-.4C13 3.9 10.5 3 9 3.9c-1.5.8-1.9 3.4-1.3 6.5c.1.3.1.6.2.9c-.4.1-.7.2-1 .3c-3 1-4.9 2.7-4.9 4.3c0 1.7 2 3.5 5.1 4.5c.2.1.5.2.8.2c-.1.3-.2.7-.2 1c-.6 3.1-.1 5.5 1.3 6.4c1.5.9 4 0 6.5-2.2c.2-.2.4-.4.6-.5c.2.2.5.5.8.7c2.4 2.1 4.7 2.9 6.2 2c1.5-.9 2-3.5 1.4-6.7c0-.2-.1-.5-.2-.8c.2-.1.4-.1.5-.2c3.2-1.1 5.3-2.8 5.3-4.5c-.1-1.5-2.1-3.1-5.1-4.2m-7.5-4.7c2.1-1.8 4-2.5 4.9-2c.9.5 1.3 2.7.7 5.6c0 .2-.1.4-.1.6c-1.2-.3-2.5-.5-3.7-.6c-.7-1-1.5-2-2.4-3zm-7.2 10.5c.3.5.5 1 .8 1.5c.3.5.6 1 .9 1.4c-.9-.1-1.7-.2-2.6-.4c.2-.8.5-1.6.9-2.5m0-2.8c-.4-.8-.6-1.6-.9-2.4c.8-.2 1.7-.3 2.5-.4c-.3.5-.6.9-.9 1.4c-.2.4-.5.9-.7 1.4m.6 1.4c.4-.8.8-1.5 1.2-2.3c.4-.7.9-1.5 1.4-2.2c.8-.1 1.7-.1 2.6-.1c.9 0 1.7 0 2.6.1c.5.7.9 1.4 1.3 2.2c.4.7.8 1.5 1.2 2.3c-.4.8-.8 1.5-1.2 2.3c-.4.7-.9 1.5-1.3 2.2c-.8.1-1.7.1-2.6.1c-.9 0-1.7 0-2.5-.1c-.5-.7-.9-1.4-1.4-2.2c-.5-.8-.9-1.5-1.3-2.3m10 2.9c.3-.5.6-1 .8-1.5c.4.8.7 1.6.9 2.5c-.9.2-1.7.3-2.6.4c.4-.5.7-1 .9-1.4m.8-4.3c-.3-.5-.5-1-.8-1.5c-.3-.5-.6-.9-.8-1.4c.9.1 1.7.3 2.6.4c-.3.9-.6 1.7-1 2.5M16 8.3c.6.6 1.1 1.3 1.6 2c-1.1-.1-2.2-.1-3.3 0c.6-.7 1.2-1.4 1.7-2M9.6 4.9c.9-.5 3 .2 5.2 2.2l.4.4c-.9.9-1.7 1.9-2.4 3c-1.3.1-2.5.3-3.7.6c-.1-.3-.1-.6-.2-.9c-.6-2.7-.2-4.8.7-5.3M8.2 19.6c-.2-.1-.5-.1-.7-.2c-1.4-.5-2.5-1.1-3.3-1.7c-.7-.6-1-1.2-1-1.7c0-1 1.5-2.3 4.1-3.2c.3-.1.6-.2 1-.3c.3 1.2.7 2.4 1.3 3.5c-.6 1.2-1 2.4-1.4 3.6m6.5 5.5c-1.1 1-2.2 1.6-3.1 2c-.9.3-1.5.3-2 .1c-.9-.5-1.3-2.5-.8-5.1c.1-.4.2-.7.2-1.1c1.2.3 2.5.5 3.8.5c.7 1 1.5 2 2.4 3c-.2.2-.3.4-.5.6m1.3-1.4c-.6-.6-1.1-1.3-1.7-2h3.3c-.4.7-1 1.4-1.6 2m7.3 1.7c-.2.9-.5 1.5-.9 1.7c-.9.5-2.8-.2-4.8-1.9c-.2-.2-.5-.4-.7-.6c.8-.9 1.6-1.9 2.3-3c1.3-.1 2.5-.3 3.8-.6c.1.2.1.5.2.7c.3 1.4.3 2.7.1 3.7m1-6c-.2 0-.3.1-.5.1c-.4-1.2-.9-2.4-1.4-3.6c.5-1.1 1-2.3 1.4-3.5c.3.1.6.2.8.3c2.6.9 4.2 2.2 4.2 3.2c0 1.2-1.7 2.6-4.5 3.5'/%3E%3Cpath fill='currentColor' d='M16 18.5c.5 0 1-.1 1.4-.4c.4-.3.7-.7.9-1.1c.2-.5.2-1 .1-1.5s-.3-.9-.7-1.3c-.3-.4-.8-.6-1.3-.7c-.5-.1-1 0-1.5.1c-.5.2-.9.5-1.1.9c-.3.4-.4.9-.4 1.4c0 .3.1.7.2 1c.1.3.3.6.5.8c.2.2.5.4.8.5c.4.2.8.3 1.1.3'/%3E%3C/svg%3E");
    -webkit-mask: var(--un-icon) no-repeat;
    mask: var(--un-icon) no-repeat;
    -webkit-mask-size: 100% 100%;
    mask-size: 100% 100%;
    background-color: currentColor;
    color: inherit;
    display: inline-block;
    vertical-align: middle;
    width: 1.2em;
    height: 1.2em
}

.i-carbon-logo-svelte {
    --un-icon: url("data:image/svg+xml;utf8,%3Csvg viewBox='0 0 32 32' display='inline-block' vertical-align='middle' width='1.2em' height='1.2em' xmlns='http://www.w3.org/2000/svg' %3E%3Cpath fill='currentColor' d='M26.1 5.7C23.5 2 18.4.9 14.7 3.2L8.2 7.4c-1.8 1.1-3 2.9-3.4 5c-.3 1.7 0 3.5.8 5.1c-.6.8-.9 1.8-1.1 2.8c-.4 2.1.1 4.3 1.4 6c2.6 3.7 7.7 4.8 11.4 2.5l6.5-4.2c1.8-1.1 3-2.9 3.4-5c.3-1.7 0-3.5-.8-5.1c.6-.8.9-1.8 1.1-2.8c.4-2.1-.1-4.3-1.4-6M24.3 11c0 .2-.1.4-.2.6l-.1.4l-.3-.2c-.8-.6-1.6-1-2.6-1.3l-.2-.1v-.2c0-.3-.1-.7-.3-1c-.4-.5-1-.8-1.7-.6c-.1 0-.3.1-.4.2L12 12.9c-.3.2-.5.5-.6.9c-.1.4 0 .8.2 1.1c.4.5 1 .8 1.7.6c.1 0 .3-.1.4-.2l2.5-1.6c.4-.3.9-.5 1.3-.6c2.1-.5 4.3.3 5.6 2.1c.7 1 1 2.4.8 3.6c-.2 1.2-1 2.3-2 3L15.4 26c-.4.3-.9.5-1.3.6c-2.1.5-4.3-.3-5.6-2.1c-.7-1-1-2.4-.8-3.6c0-.2.1-.4.2-.6L8 20l.3.2c.8.6 1.6 1 2.6 1.3l.2.1v.2c0 .3.1.7.3 1c.4.5 1 .8 1.7.6c.1 0 .3-.1.4-.2L20 19c.3-.2.5-.5.6-.9c.1-.4 0-.8-.2-1.1c-.4-.5-1-.8-1.7-.6c-.1 0-.3.1-.4.2l-2.5 1.6c-.4.3-.9.5-1.3.6c-2.1.5-4.3-.3-5.6-2.1c-.8-1-1-2.4-.8-3.6c.2-1.2 1-2.3 2-3l6.5-4.2c.4-.3.9-.5 1.3-.6c2.1-.5 4.3.3 5.6 2.1c.7 1.1 1 2.4.8 3.6'/%3E%3C/svg%3E");
    -webkit-mask: var(--un-icon) no-repeat;
    mask: var(--un-icon) no-repeat;
    -webkit-mask-size: 100% 100%;
    mask-size: 100% 100%;
    background-color: currentColor;
    color: inherit;
    display: inline-block;
    vertical-align: middle;
    width: 1.2em;
    height: 1.2em
}

.i-carbon-logo-twitter {
    --un-icon: url("data:image/svg+xml;utf8,%3Csvg viewBox='0 0 32 32' display='inline-block' vertical-align='middle' width='1.2em' height='1.2em' xmlns='http://www.w3.org/2000/svg' %3E%3Cpath fill='currentColor' d='M11.548 25.752c9.056 0 14.01-7.503 14.01-14.01c0-.213 0-.425-.015-.636A10.017 10.017 0 0 0 28 8.556a9.827 9.827 0 0 1-2.828.776a4.942 4.942 0 0 0 2.164-2.724a9.866 9.866 0 0 1-3.126 1.195a4.929 4.929 0 0 0-8.392 4.491A13.98 13.98 0 0 1 5.67 7.15a4.928 4.928 0 0 0 1.525 6.573a4.887 4.887 0 0 1-2.235-.617v.063a4.926 4.926 0 0 0 3.95 4.827a4.917 4.917 0 0 1-2.223.084a4.93 4.93 0 0 0 4.6 3.42A9.88 9.88 0 0 1 4 23.54a13.94 13.94 0 0 0 7.547 2.209'/%3E%3C/svg%3E");
    -webkit-mask: var(--un-icon) no-repeat;
    mask: var(--un-icon) no-repeat;
    -webkit-mask-size: 100% 100%;
    mask-size: 100% 100%;
    background-color: currentColor;
    color: inherit;
    display: inline-block;
    vertical-align: middle;
    width: 1.2em;
    height: 1.2em
}

.i-carbon-logo-vue {
    --un-icon: url("data:image/svg+xml;utf8,%3Csvg viewBox='0 0 32 32' display='inline-block' vertical-align='middle' width='1.2em' height='1.2em' xmlns='http://www.w3.org/2000/svg' %3E%3Cpath fill='currentColor' d='M24.9 3.9L16 19.4L7.1 3.9H2l14 24.3L30 3.9z'/%3E%3Cpath fill='currentColor' d='m16 9.5l-3.2-5.6H8.1L16 17.5l7.9-13.6h-4.6z'/%3E%3C/svg%3E");
    -webkit-mask: var(--un-icon) no-repeat;
    mask: var(--un-icon) no-repeat;
    -webkit-mask-size: 100% 100%;
    mask-size: 100% 100%;
    background-color: currentColor;
    color: inherit;
    display: inline-block;
    vertical-align: middle;
    width: 1.2em;
    height: 1.2em
}

.i-carbon-logo-wechat {
    --un-icon: url("data:image/svg+xml;utf8,%3Csvg viewBox='0 0 32 32' display='inline-block' vertical-align='middle' width='1.2em' height='1.2em' xmlns='http://www.w3.org/2000/svg' %3E%3Cpath fill='currentColor' fill-rule='evenodd' d='M27.086 24.78A6.618 6.618 0 0 0 30 19.465c0-3.88-3.776-7.027-8.434-7.027s-8.434 3.147-8.434 7.027s3.777 7.028 8.434 7.028a9.955 9.955 0 0 0 2.754-.385l.247-.037a.892.892 0 0 1 .448.13l1.847 1.066l.162.053a.281.281 0 0 0 .281-.282l-.045-.205l-.38-1.417l-.03-.18a.56.56 0 0 1 .236-.458M12.12 4.68C6.53 4.68 2 8.455 2 13.114a7.939 7.939 0 0 0 3.497 6.374a.671.671 0 0 1 .283.55l-.035.215l-.456 1.701l-.055.246a.338.338 0 0 0 .337.338l.196-.063l2.216-1.28a1.058 1.058 0 0 1 .536-.155l.298.044a11.967 11.967 0 0 0 3.304.464l.555-.014a6.515 6.515 0 0 1-.34-2.067c0-4.247 4.133-7.691 9.23-7.691l.55.014c-.762-4.029-4.947-7.11-9.995-7.11m6.633 13.663a1.125 1.125 0 1 1 1.125-1.125a1.124 1.124 0 0 1-1.125 1.125m5.624 0a1.125 1.125 0 1 1 1.123-1.125a1.125 1.125 0 0 1-1.123 1.125m-15.631-6.58a1.35 1.35 0 1 1 1.35-1.348a1.349 1.349 0 0 1-1.35 1.349m6.747 0a1.35 1.35 0 1 1 1.35-1.348a1.349 1.349 0 0 1-1.35 1.349'/%3E%3C/svg%3E");
    -webkit-mask: var(--un-icon) no-repeat;
    mask: var(--un-icon) no-repeat;
    -webkit-mask-size: 100% 100%;
    mask-size: 100% 100%;
    background-color: currentColor;
    color: inherit;
    display: inline-block;
    vertical-align: middle;
    width: 1.2em;
    height: 1.2em
}

.i-carbon-overflow-menu-horizontal,[i-carbon-overflow-menu-horizontal=""] {
    --un-icon: url("data:image/svg+xml;utf8,%3Csvg viewBox='0 0 32 32' display='inline-block' vertical-align='middle' width='1.2em' height='1.2em' xmlns='http://www.w3.org/2000/svg' %3E%3Ccircle cx='8' cy='16' r='2' fill='currentColor'/%3E%3Ccircle cx='16' cy='16' r='2' fill='currentColor'/%3E%3Ccircle cx='24' cy='16' r='2' fill='currentColor'/%3E%3C/svg%3E");
    -webkit-mask: var(--un-icon) no-repeat;
    mask: var(--un-icon) no-repeat;
    -webkit-mask-size: 100% 100%;
    mask-size: 100% 100%;
    background-color: currentColor;
    color: inherit;
    display: inline-block;
    vertical-align: middle;
    width: 1.2em;
    height: 1.2em
}

.i-carbon-page-first {
    --un-icon: url("data:image/svg+xml;utf8,%3Csvg viewBox='0 0 32 32' display='inline-block' vertical-align='middle' width='1.2em' height='1.2em' xmlns='http://www.w3.org/2000/svg' %3E%3Cpath fill='currentColor' d='M14 16L24 6l1.4 1.4l-8.6 8.6l8.6 8.6L24 26zM8 4h2v24H8z'/%3E%3C/svg%3E");
    -webkit-mask: var(--un-icon) no-repeat;
    mask: var(--un-icon) no-repeat;
    -webkit-mask-size: 100% 100%;
    mask-size: 100% 100%;
    background-color: currentColor;
    color: inherit;
    display: inline-block;
    vertical-align: middle;
    width: 1.2em;
    height: 1.2em
}

.i-carbon-page-last {
    --un-icon: url("data:image/svg+xml;utf8,%3Csvg viewBox='0 0 32 32' display='inline-block' vertical-align='middle' width='1.2em' height='1.2em' xmlns='http://www.w3.org/2000/svg' %3E%3Cpath fill='currentColor' d='M18 16L8 26l-1.4-1.4l8.6-8.6l-8.6-8.6L8 6zm4-12h2v24h-2z'/%3E%3C/svg%3E");
    -webkit-mask: var(--un-icon) no-repeat;
    mask: var(--un-icon) no-repeat;
    -webkit-mask-size: 100% 100%;
    mask-size: 100% 100%;
    background-color: currentColor;
    color: inherit;
    display: inline-block;
    vertical-align: middle;
    width: 1.2em;
    height: 1.2em
}

.i-carbon-rotate-clockwise {
    --un-icon: url("data:image/svg+xml;utf8,%3Csvg viewBox='0 0 32 32' display='inline-block' vertical-align='middle' width='1.2em' height='1.2em' xmlns='http://www.w3.org/2000/svg' %3E%3Cpath fill='currentColor' d='M28 30H16a2.002 2.002 0 0 1-2-2V16a2.002 2.002 0 0 1 2-2h12a2.002 2.002 0 0 1 2 2v12a2.002 2.002 0 0 1-2 2M16 16v12h12.001L28 16zM15 2l-1.41 1.41L16.17 6H11a7.008 7.008 0 0 0-7 7v5h2v-5a5.006 5.006 0 0 1 5-5h5.17l-2.58 2.59L15 12l5-5z'/%3E%3C/svg%3E");
    -webkit-mask: var(--un-icon) no-repeat;
    mask: var(--un-icon) no-repeat;
    -webkit-mask-size: 100% 100%;
    mask-size: 100% 100%;
    background-color: currentColor;
    color: inherit;
    display: inline-block;
    vertical-align: middle;
    width: 1.2em;
    height: 1.2em
}

.i-carbon-rotate-counterclockwise {
    --un-icon: url("data:image/svg+xml;utf8,%3Csvg viewBox='0 0 32 32' display='inline-block' vertical-align='middle' width='1.2em' height='1.2em' xmlns='http://www.w3.org/2000/svg' %3E%3Cpath fill='currentColor' d='M2 28V16a2.002 2.002 0 0 1 2-2h12a2.002 2.002 0 0 1 2 2v12a2.002 2.002 0 0 1-2 2H4a2.002 2.002 0 0 1-2-2m2-12l-.001 12H16V16zM17 2l1.41 1.41L15.83 6H21a7.008 7.008 0 0 1 7 7v5h-2v-5a5.006 5.006 0 0 0-5-5h-5.17l2.58 2.59L17 12l-5-5z'/%3E%3C/svg%3E");
    -webkit-mask: var(--un-icon) no-repeat;
    mask: var(--un-icon) no-repeat;
    -webkit-mask-size: 100% 100%;
    mask-size: 100% 100%;
    background-color: currentColor;
    color: inherit;
    display: inline-block;
    vertical-align: middle;
    width: 1.2em;
    height: 1.2em
}

.i-carbon-search {
    --un-icon: url("data:image/svg+xml;utf8,%3Csvg viewBox='0 0 32 32' display='inline-block' vertical-align='middle' width='1.2em' height='1.2em' xmlns='http://www.w3.org/2000/svg' %3E%3Cpath fill='currentColor' d='m29 27.586l-7.552-7.552a11.018 11.018 0 1 0-1.414 1.414L27.586 29ZM4 13a9 9 0 1 1 9 9a9.01 9.01 0 0 1-9-9'/%3E%3C/svg%3E");
    -webkit-mask: var(--un-icon) no-repeat;
    mask: var(--un-icon) no-repeat;
    -webkit-mask-size: 100% 100%;
    mask-size: 100% 100%;
    background-color: currentColor;
    color: inherit;
    display: inline-block;
    vertical-align: middle;
    width: 1.2em;
    height: 1.2em
}

.i-carbon-settings {
    --un-icon: url("data:image/svg+xml;utf8,%3Csvg viewBox='0 0 32 32' display='inline-block' vertical-align='middle' width='1.2em' height='1.2em' xmlns='http://www.w3.org/2000/svg' %3E%3Cpath fill='currentColor' d='M27 16.76v-1.53l1.92-1.68A2 2 0 0 0 29.3 11l-2.36-4a2 2 0 0 0-1.73-1a2 2 0 0 0-.64.1l-2.43.82a11.35 11.35 0 0 0-1.31-.75l-.51-2.52a2 2 0 0 0-2-1.61h-4.68a2 2 0 0 0-2 1.61l-.51 2.52a11.48 11.48 0 0 0-1.32.75l-2.38-.86A2 2 0 0 0 6.79 6a2 2 0 0 0-1.73 1L2.7 11a2 2 0 0 0 .41 2.51L5 15.24v1.53l-1.89 1.68A2 2 0 0 0 2.7 21l2.36 4a2 2 0 0 0 1.73 1a2 2 0 0 0 .64-.1l2.43-.82a11.35 11.35 0 0 0 1.31.75l.51 2.52a2 2 0 0 0 2 1.61h4.72a2 2 0 0 0 2-1.61l.51-2.52a11.48 11.48 0 0 0 1.32-.75l2.42.82a2 2 0 0 0 .64.1a2 2 0 0 0 1.73-1l2.28-4a2 2 0 0 0-.41-2.51ZM25.21 24l-3.43-1.16a8.86 8.86 0 0 1-2.71 1.57L18.36 28h-4.72l-.71-3.55a9.36 9.36 0 0 1-2.7-1.57L6.79 24l-2.36-4l2.72-2.4a8.9 8.9 0 0 1 0-3.13L4.43 12l2.36-4l3.43 1.16a8.86 8.86 0 0 1 2.71-1.57L13.64 4h4.72l.71 3.55a9.36 9.36 0 0 1 2.7 1.57L25.21 8l2.36 4l-2.72 2.4a8.9 8.9 0 0 1 0 3.13L27.57 20Z'/%3E%3Cpath fill='currentColor' d='M16 22a6 6 0 1 1 6-6a5.94 5.94 0 0 1-6 6m0-10a3.91 3.91 0 0 0-4 4a3.91 3.91 0 0 0 4 4a3.91 3.91 0 0 0 4-4a3.91 3.91 0 0 0-4-4'/%3E%3C/svg%3E");
    -webkit-mask: var(--un-icon) no-repeat;
    mask: var(--un-icon) no-repeat;
    -webkit-mask-size: 100% 100%;
    mask-size: 100% 100%;
    background-color: currentColor;
    color: inherit;
    display: inline-block;
    vertical-align: middle;
    width: 1.2em;
    height: 1.2em
}

.i-carbon-star {
    --un-icon: url("data:image/svg+xml;utf8,%3Csvg viewBox='0 0 32 32' display='inline-block' vertical-align='middle' width='1.2em' height='1.2em' xmlns='http://www.w3.org/2000/svg' %3E%3Cpath fill='currentColor' d='m16 6.52l2.76 5.58l.46 1l1 .15l6.16.89l-4.38 4.3l-.75.73l.18 1l1.05 6.13l-5.51-2.89L16 23l-.93.49l-5.51 2.85l1-6.13l.18-1l-.74-.77l-4.42-4.35l6.16-.89l1-.15l.46-1zM16 2l-4.55 9.22l-10.17 1.47l7.36 7.18L6.9 30l9.1-4.78L25.1 30l-1.74-10.13l7.36-7.17l-10.17-1.48Z'/%3E%3C/svg%3E");
    -webkit-mask: var(--un-icon) no-repeat;
    mask: var(--un-icon) no-repeat;
    -webkit-mask-size: 100% 100%;
    mask-size: 100% 100%;
    background-color: currentColor;
    color: inherit;
    display: inline-block;
    vertical-align: middle;
    width: 1.2em;
    height: 1.2em
}

.i-carbon-star-filled {
    --un-icon: url("data:image/svg+xml;utf8,%3Csvg viewBox='0 0 32 32' display='inline-block' vertical-align='middle' width='1.2em' height='1.2em' xmlns='http://www.w3.org/2000/svg' %3E%3Cpath fill='currentColor' d='m16 2l-4.55 9.22l-10.17 1.47l7.36 7.18L6.9 30l9.1-4.78L25.1 30l-1.74-10.13l7.36-7.17l-10.17-1.48Z'/%3E%3C/svg%3E");
    -webkit-mask: var(--un-icon) no-repeat;
    mask: var(--un-icon) no-repeat;
    -webkit-mask-size: 100% 100%;
    mask-size: 100% 100%;
    background-color: currentColor;
    color: inherit;
    display: inline-block;
    vertical-align: middle;
    width: 1.2em;
    height: 1.2em
}

.i-carbon-subtract {
    --un-icon: url("data:image/svg+xml;utf8,%3Csvg viewBox='0 0 32 32' display='inline-block' vertical-align='middle' width='1.2em' height='1.2em' xmlns='http://www.w3.org/2000/svg' %3E%3Cpath fill='currentColor' d='M8 15h16v2H8z'/%3E%3C/svg%3E");
    -webkit-mask: var(--un-icon) no-repeat;
    mask: var(--un-icon) no-repeat;
    -webkit-mask-size: 100% 100%;
    mask-size: 100% 100%;
    background-color: currentColor;
    color: inherit;
    display: inline-block;
    vertical-align: middle;
    width: 1.2em;
    height: 1.2em
}

.i-carbon-view {
    --un-icon: url("data:image/svg+xml;utf8,%3Csvg viewBox='0 0 32 32' display='inline-block' vertical-align='middle' width='1.2em' height='1.2em' xmlns='http://www.w3.org/2000/svg' %3E%3Cpath fill='currentColor' d='M30.94 15.66A16.69 16.69 0 0 0 16 5A16.69 16.69 0 0 0 1.06 15.66a1 1 0 0 0 0 .68A16.69 16.69 0 0 0 16 27a16.69 16.69 0 0 0 14.94-10.66a1 1 0 0 0 0-.68M16 25c-5.3 0-10.9-3.93-12.93-9C5.1 10.93 10.7 7 16 7s10.9 3.93 12.93 9C26.9 21.07 21.3 25 16 25'/%3E%3Cpath fill='currentColor' d='M16 10a6 6 0 1 0 6 6a6 6 0 0 0-6-6m0 10a4 4 0 1 1 4-4a4 4 0 0 1-4 4'/%3E%3C/svg%3E");
    -webkit-mask: var(--un-icon) no-repeat;
    mask: var(--un-icon) no-repeat;
    -webkit-mask-size: 100% 100%;
    mask-size: 100% 100%;
    background-color: currentColor;
    color: inherit;
    display: inline-block;
    vertical-align: middle;
    width: 1.2em;
    height: 1.2em
}

.i-carbon-view-off {
    --un-icon: url("data:image/svg+xml;utf8,%3Csvg viewBox='0 0 32 32' display='inline-block' vertical-align='middle' width='1.2em' height='1.2em' xmlns='http://www.w3.org/2000/svg' %3E%3Cpath fill='currentColor' d='m5.24 22.51l1.43-1.42A14.06 14.06 0 0 1 3.07 16C5.1 10.93 10.7 7 16 7a12.38 12.38 0 0 1 4 .72l1.55-1.56A14.72 14.72 0 0 0 16 5A16.69 16.69 0 0 0 1.06 15.66a1 1 0 0 0 0 .68a16 16 0 0 0 4.18 6.17'/%3E%3Cpath fill='currentColor' d='M12 15.73a4 4 0 0 1 3.7-3.7l1.81-1.82a6 6 0 0 0-7.33 7.33zm18.94-.07a16.4 16.4 0 0 0-5.74-7.44L30 3.41L28.59 2L2 28.59L3.41 30l5.1-5.1A15.29 15.29 0 0 0 16 27a16.69 16.69 0 0 0 14.94-10.66a1 1 0 0 0 0-.68M20 16a4 4 0 0 1-6 3.44L19.44 14a4 4 0 0 1 .56 2m-4 9a13.05 13.05 0 0 1-6-1.58l2.54-2.54a6 6 0 0 0 8.35-8.35l2.87-2.87A14.54 14.54 0 0 1 28.93 16C26.9 21.07 21.3 25 16 25'/%3E%3C/svg%3E");
    -webkit-mask: var(--un-icon) no-repeat;
    mask: var(--un-icon) no-repeat;
    -webkit-mask-size: 100% 100%;
    mask-size: 100% 100%;
    background-color: currentColor;
    color: inherit;
    display: inline-block;
    vertical-align: middle;
    width: 1.2em;
    height: 1.2em
}

.i-carbon-warning-filled {
    --un-icon: url("data:image/svg+xml;utf8,%3Csvg viewBox='0 0 32 32' display='inline-block' vertical-align='middle' width='1.2em' height='1.2em' xmlns='http://www.w3.org/2000/svg' %3E%3Cpath fill='currentColor' d='M16 2C8.3 2 2 8.3 2 16s6.3 14 14 14s14-6.3 14-14S23.7 2 16 2m-1.1 6h2.2v11h-2.2zM16 25c-.8 0-1.5-.7-1.5-1.5S15.2 22 16 22s1.5.7 1.5 1.5S16.8 25 16 25'/%3E%3C/svg%3E");
    -webkit-mask: var(--un-icon) no-repeat;
    mask: var(--un-icon) no-repeat;
    -webkit-mask-size: 100% 100%;
    mask-size: 100% 100%;
    background-color: currentColor;
    color: inherit;
    display: inline-block;
    vertical-align: middle;
    width: 1.2em;
    height: 1.2em
}

.i-carbon-zoom-in {
    --un-icon: url("data:image/svg+xml;utf8,%3Csvg viewBox='0 0 32 32' display='inline-block' vertical-align='middle' width='1.2em' height='1.2em' xmlns='http://www.w3.org/2000/svg' %3E%3Cpath fill='currentColor' d='M18 12h-4V8h-2v4H8v2h4v4h2v-4h4z'/%3E%3Cpath fill='currentColor' d='M21.448 20A10.856 10.856 0 0 0 24 13a11 11 0 1 0-11 11a10.856 10.856 0 0 0 7-2.552L27.586 29L29 27.586ZM13 22a9 9 0 1 1 9-9a9.01 9.01 0 0 1-9 9'/%3E%3C/svg%3E");
    -webkit-mask: var(--un-icon) no-repeat;
    mask: var(--un-icon) no-repeat;
    -webkit-mask-size: 100% 100%;
    mask-size: 100% 100%;
    background-color: currentColor;
    color: inherit;
    display: inline-block;
    vertical-align: middle;
    width: 1.2em;
    height: 1.2em
}

.i-carbon-zoom-out {
    --un-icon: url("data:image/svg+xml;utf8,%3Csvg viewBox='0 0 32 32' display='inline-block' vertical-align='middle' width='1.2em' height='1.2em' xmlns='http://www.w3.org/2000/svg' %3E%3Cpath fill='currentColor' d='M8 12h10v2H8z'/%3E%3Cpath fill='currentColor' d='M21.448 20A10.856 10.856 0 0 0 24 13a11 11 0 1 0-11 11a10.856 10.856 0 0 0 7-2.552L27.586 29L29 27.586ZM13 22a9 9 0 1 1 9-9a9.01 9.01 0 0 1-9 9'/%3E%3C/svg%3E");
    -webkit-mask: var(--un-icon) no-repeat;
    mask: var(--un-icon) no-repeat;
    -webkit-mask-size: 100% 100%;
    mask-size: 100% 100%;
    background-color: currentColor;
    color: inherit;
    display: inline-block;
    vertical-align: middle;
    width: 1.2em;
    height: 1.2em
}

.i-carbon\:ai-status-in-progress {
    --un-icon: url("data:image/svg+xml;utf8,%3Csvg viewBox='0 0 32 32' display='inline-block' vertical-align='middle' width='1.2em' height='1.2em' xmlns='http://www.w3.org/2000/svg' %3E%3Cpath d='M11 24h10v2H11z' fill='currentColor'/%3E%3Cpath d='M13 28h6v2h-6z' fill='currentColor'/%3E%3Cpath d='M10.815 18.14A7.185 7.185 0 0 1 8 12a8.01 8.01 0 0 1 8-8V2A10.011 10.011 0 0 0 6 12a9.18 9.18 0 0 0 3.46 7.616C10.472 20.551 11 21.081 11 22h2c0-1.84-1.11-2.866-2.185-3.86z' fill='currentColor'/%3E%3Cpath d='M21.178 18.143C20.107 19.135 19 20.16 19 22h2c0-.92.526-1.45 1.535-2.386A9.193 9.193 0 0 0 26 12h-2a7.203 7.203 0 0 1-2.822 6.143z' fill='currentColor'/%3E%3Ccircle cx='18.5' cy='7.5' r='1.5' fill='currentColor'/%3E%3Ccircle cx='28.5' cy='7.5' r='1.5' fill='currentColor'/%3E%3Ccircle cx='23.5' cy='7.5' r='1.5' fill='currentColor'/%3E%3C/svg%3E");
    -webkit-mask: var(--un-icon) no-repeat;
    mask: var(--un-icon) no-repeat;
    -webkit-mask-size: 100% 100%;
    mask-size: 100% 100%;
    background-color: currentColor;
    color: inherit;
    display: inline-block;
    vertical-align: middle;
    width: 1.2em;
    height: 1.2em
}

.i-carbon\:ai-status-rejected {
    --un-icon: url("data:image/svg+xml;utf8,%3Csvg viewBox='0 0 32 32' display='inline-block' vertical-align='middle' width='1.2em' height='1.2em' xmlns='http://www.w3.org/2000/svg' %3E%3Cpath d='M11 24h10v2H11z' fill='currentColor'/%3E%3Cpath d='M13 28h6v2h-6z' fill='currentColor'/%3E%3Cpath d='M10.815 18.14A7.185 7.185 0 0 1 8 12a8.01 8.01 0 0 1 8-8V2A10.011 10.011 0 0 0 6 12a9.18 9.18 0 0 0 3.46 7.616C10.472 20.551 11 21.081 11 22h2c0-1.84-1.11-2.866-2.185-3.86z' fill='currentColor'/%3E%3Cpath d='M23.04 16a9.486 9.486 0 0 1-1.862 2.143C20.107 19.135 19 20.16 19 22h2c0-.92.526-1.45 1.535-2.386A9.984 9.984 0 0 0 25.275 16z' fill='currentColor'/%3E%3Cpath d='M30 8a6 6 0 1 0-6 6a6.007 6.007 0 0 0 6-6zm-2 0a3.952 3.952 0 0 1-.567 2.019l-5.452-5.452A3.953 3.953 0 0 1 24 4a4.005 4.005 0 0 1 4 4zm-8 0a3.952 3.952 0 0 1 .567-2.019l5.452 5.452A3.953 3.953 0 0 1 24 12a4.005 4.005 0 0 1-4-4z' fill='currentColor'/%3E%3C/svg%3E");
    -webkit-mask: var(--un-icon) no-repeat;
    mask: var(--un-icon) no-repeat;
    -webkit-mask-size: 100% 100%;
    mask-size: 100% 100%;
    background-color: currentColor;
    color: inherit;
    display: inline-block;
    vertical-align: middle;
    width: 1.2em;
    height: 1.2em
}

.i-carbon\:arrow-right {
    --un-icon: url("data:image/svg+xml;utf8,%3Csvg viewBox='0 0 32 32' display='inline-block' vertical-align='middle' width='1.2em' height='1.2em' xmlns='http://www.w3.org/2000/svg' %3E%3Cpath fill='currentColor' d='m18 6l-1.43 1.393L24.15 15H4v2h20.15l-7.58 7.573L18 26l10-10z'/%3E%3C/svg%3E");
    -webkit-mask: var(--un-icon) no-repeat;
    mask: var(--un-icon) no-repeat;
    -webkit-mask-size: 100% 100%;
    mask-size: 100% 100%;
    background-color: currentColor;
    color: inherit;
    display: inline-block;
    vertical-align: middle;
    width: 1.2em;
    height: 1.2em
}

.i-carbon\:edit {
    --un-icon: url("data:image/svg+xml;utf8,%3Csvg viewBox='0 0 32 32' display='inline-block' vertical-align='middle' width='1.2em' height='1.2em' xmlns='http://www.w3.org/2000/svg' %3E%3Cpath fill='currentColor' d='M2 26h28v2H2zM25.4 9c.8-.8.8-2 0-2.8l-3.6-3.6c-.8-.8-2-.8-2.8 0l-15 15V24h6.4zm-5-5L24 7.6l-3 3L17.4 7zM6 22v-3.6l10-10l3.6 3.6l-10 10z'/%3E%3C/svg%3E");
    -webkit-mask: var(--un-icon) no-repeat;
    mask: var(--un-icon) no-repeat;
    -webkit-mask-size: 100% 100%;
    mask-size: 100% 100%;
    background-color: currentColor;
    color: inherit;
    display: inline-block;
    vertical-align: middle;
    width: 1.2em;
    height: 1.2em
}

.i-carbon\:radio-button-checked {
    --un-icon: url("data:image/svg+xml;utf8,%3Csvg viewBox='0 0 32 32' display='inline-block' vertical-align='middle' width='1.2em' height='1.2em' xmlns='http://www.w3.org/2000/svg' %3E%3Cpath fill='currentColor' d='M16 2a14 14 0 1 0 14 14A14 14 0 0 0 16 2m0 26a12 12 0 1 1 12-12a12 12 0 0 1-12 12'/%3E%3Cpath fill='currentColor' d='M16 10a6 6 0 1 0 6 6a6 6 0 0 0-6-6'/%3E%3C/svg%3E");
    -webkit-mask: var(--un-icon) no-repeat;
    mask: var(--un-icon) no-repeat;
    -webkit-mask-size: 100% 100%;
    mask-size: 100% 100%;
    background-color: currentColor;
    color: inherit;
    display: inline-block;
    vertical-align: middle;
    width: 1.2em;
    height: 1.2em
}

.i-carbon\:share {
    --un-icon: url("data:image/svg+xml;utf8,%3Csvg viewBox='0 0 32 32' display='inline-block' vertical-align='middle' width='1.2em' height='1.2em' xmlns='http://www.w3.org/2000/svg' %3E%3Cpath fill='currentColor' d='M23 20a5 5 0 0 0-3.89 1.89l-7.31-4.57a4.46 4.46 0 0 0 0-2.64l7.31-4.57A5 5 0 1 0 18 7a4.79 4.79 0 0 0 .2 1.32l-7.31 4.57a5 5 0 1 0 0 6.22l7.31 4.57A4.79 4.79 0 0 0 18 25a5 5 0 1 0 5-5m0-16a3 3 0 1 1-3 3a3 3 0 0 1 3-3M7 19a3 3 0 1 1 3-3a3 3 0 0 1-3 3m16 9a3 3 0 1 1 3-3a3 3 0 0 1-3 3'/%3E%3C/svg%3E");
    -webkit-mask: var(--un-icon) no-repeat;
    mask: var(--un-icon) no-repeat;
    -webkit-mask-size: 100% 100%;
    mask-size: 100% 100%;
    background-color: currentColor;
    color: inherit;
    display: inline-block;
    vertical-align: middle;
    width: 1.2em;
    height: 1.2em
}

.i-carbon\:trash-can {
    --un-icon: url("data:image/svg+xml;utf8,%3Csvg viewBox='0 0 32 32' display='inline-block' vertical-align='middle' width='1.2em' height='1.2em' xmlns='http://www.w3.org/2000/svg' %3E%3Cpath fill='currentColor' d='M12 12h2v12h-2zm6 0h2v12h-2z'/%3E%3Cpath fill='currentColor' d='M4 6v2h2v20a2 2 0 0 0 2 2h16a2 2 0 0 0 2-2V8h2V6zm4 22V8h16v20zm4-26h8v2h-8z'/%3E%3C/svg%3E");
    -webkit-mask: var(--un-icon) no-repeat;
    mask: var(--un-icon) no-repeat;
    -webkit-mask-size: 100% 100%;
    mask-size: 100% 100%;
    background-color: currentColor;
    color: inherit;
    display: inline-block;
    vertical-align: middle;
    width: 1.2em;
    height: 1.2em
}

.k-alert--error__icon,.k-msg-box--icon--error,.k-notification--icon--error,.k-popconfirm--icon--error {
    --un-icon: url("data:image/svg+xml;utf8,%3Csvg viewBox='0 0 32 32' display='inline-block' vertical-align='middle' width='1.2em' height='1.2em' xmlns='http://www.w3.org/2000/svg' %3E%3Cpath fill='none' d='M9 10.555L10.555 9L23 21.444L21.444 23z'/%3E%3Cpath fill='currentColor' d='M16 2A13.914 13.914 0 0 0 2 16a13.914 13.914 0 0 0 14 14a13.914 13.914 0 0 0 14-14A13.914 13.914 0 0 0 16 2m5.445 21L9 10.556L10.556 9L23 21.445Z'/%3E%3C/svg%3E");
    -webkit-mask: var(--un-icon) no-repeat;
    mask: var(--un-icon) no-repeat;
    -webkit-mask-size: 100% 100%;
    mask-size: 100% 100%;
    background-color: currentColor;
    color: inherit;
    display: inline-block;
    vertical-align: middle;
    width: 1.2em;
    height: 1.2em
}

.k-alert--info__icon,.k-msg-box--icon--info,.k-notification--icon--info,.k-popconfirm--icon--info {
    --un-icon: url("data:image/svg+xml;utf8,%3Csvg viewBox='0 0 32 32' display='inline-block' vertical-align='middle' width='1.2em' height='1.2em' xmlns='http://www.w3.org/2000/svg' %3E%3Cpath fill='none' d='M16 8a1.5 1.5 0 1 1-1.5 1.5A1.5 1.5 0 0 1 16 8m4 13.875h-2.875v-8H13v2.25h1.875v5.75H12v2.25h8Z'/%3E%3Cpath fill='currentColor' d='M16 2a14 14 0 1 0 14 14A14 14 0 0 0 16 2m0 6a1.5 1.5 0 1 1-1.5 1.5A1.5 1.5 0 0 1 16 8m4 16.125h-8v-2.25h2.875v-5.75H13v-2.25h4.125v8H20Z'/%3E%3C/svg%3E");
    -webkit-mask: var(--un-icon) no-repeat;
    mask: var(--un-icon) no-repeat;
    -webkit-mask-size: 100% 100%;
    mask-size: 100% 100%;
    background-color: currentColor;
    color: inherit;
    display: inline-block;
    vertical-align: middle;
    width: 1.2em;
    height: 1.2em
}

.k-alert--success__icon,.k-msg-box--icon--success,.k-notification--icon--success,.k-popconfirm--icon--success {
    --un-icon: url("data:image/svg+xml;utf8,%3Csvg viewBox='0 0 32 32' display='inline-block' vertical-align='middle' width='1.2em' height='1.2em' xmlns='http://www.w3.org/2000/svg' %3E%3Cpath fill='currentColor' d='M16 2a14 14 0 1 0 14 14A14 14 0 0 0 16 2m-2 19.59l-5-5L10.59 15L14 18.41L21.41 11l1.596 1.586Z'/%3E%3Cpath fill='none' d='m14 21.591l-5-5L10.591 15L14 18.409L21.41 11l1.595 1.585z'/%3E%3C/svg%3E");
    -webkit-mask: var(--un-icon) no-repeat;
    mask: var(--un-icon) no-repeat;
    -webkit-mask-size: 100% 100%;
    mask-size: 100% 100%;
    background-color: currentColor;
    color: inherit;
    display: inline-block;
    vertical-align: middle;
    width: 1.2em;
    height: 1.2em
}

.k-alert--warning__icon,.k-msg-box--icon--warning,.k-notification--icon--warning,.k-popconfirm--icon--warning {
    --un-icon: url("data:image/svg+xml;utf8,%3Csvg viewBox='0 0 32 32' display='inline-block' vertical-align='middle' width='1.2em' height='1.2em' xmlns='http://www.w3.org/2000/svg' %3E%3Cpath fill='currentColor' d='M16 2C8.3 2 2 8.3 2 16s6.3 14 14 14s14-6.3 14-14S23.7 2 16 2m-1.1 6h2.2v11h-2.2zM16 25c-.8 0-1.5-.7-1.5-1.5S15.2 22 16 22s1.5.7 1.5 1.5S16.8 25 16 25'/%3E%3C/svg%3E");
    -webkit-mask: var(--un-icon) no-repeat;
    mask: var(--un-icon) no-repeat;
    -webkit-mask-size: 100% 100%;
    mask-size: 100% 100%;
    background-color: currentColor;
    color: inherit;
    display: inline-block;
    vertical-align: middle;
    width: 1.2em;
    height: 1.2em
}

.k-rate--active-icon,.k-rate--readonly-icon {
    --un-icon: url("data:image/svg+xml;utf8,%3Csvg viewBox='0 0 32 32' display='inline-block' vertical-align='middle' width='1.2em' height='1.2em' xmlns='http://www.w3.org/2000/svg' %3E%3Cpath fill='currentColor' d='m16 2l-4.55 9.22l-10.17 1.47l7.36 7.18L6.9 30l9.1-4.78L25.1 30l-1.74-10.13l7.36-7.17l-10.17-1.48Z'/%3E%3C/svg%3E");
    -webkit-mask: var(--un-icon) no-repeat;
    mask: var(--un-icon) no-repeat;
    -webkit-mask-size: 100% 100%;
    mask-size: 100% 100%;
    background-color: currentColor;
    color: inherit;
    display: inline-block;
    vertical-align: middle;
    width: 1.2em;
    height: 1.2em
}

.k-rate--void-icon {
    --un-icon: url("data:image/svg+xml;utf8,%3Csvg viewBox='0 0 32 32' display='inline-block' vertical-align='middle' width='1.2em' height='1.2em' xmlns='http://www.w3.org/2000/svg' %3E%3Cpath fill='currentColor' d='m16 6.52l2.76 5.58l.46 1l1 .15l6.16.89l-4.38 4.3l-.75.73l.18 1l1.05 6.13l-5.51-2.89L16 23l-.93.49l-5.51 2.85l1-6.13l.18-1l-.74-.77l-4.42-4.35l6.16-.89l1-.15l.46-1zM16 2l-4.55 9.22l-10.17 1.47l7.36 7.18L6.9 30l9.1-4.78L25.1 30l-1.74-10.13l7.36-7.17l-10.17-1.48Z'/%3E%3C/svg%3E");
    -webkit-mask: var(--un-icon) no-repeat;
    mask: var(--un-icon) no-repeat;
    -webkit-mask-size: 100% 100%;
    mask-size: 100% 100%;
    background-color: currentColor;
    color: inherit;
    display: inline-block;
    vertical-align: middle;
    width: 1.2em;
    height: 1.2em
}

.-container {
    width: -100%
}

.container,.k-msg-box--input,.k-tabs,[container=""] {
    width: 100%
}

.k-color-picker-slider--thumb {
    pointer-events: none;
    position: absolute;
    top: 50%;
    box-sizing: border-box;
    height: 14px;
    width: 14px;
    --un-translate-y: -50%;
    transform: translate(var(--un-translate-x)) translateY(var(--un-translate-y)) translateZ(var(--un-translate-z)) rotate(var(--un-rotate)) rotateX(var(--un-rotate-x)) rotateY(var(--un-rotate-y)) rotate(var(--un-rotate-z)) skew(var(--un-skew-x)) skewY(var(--un-skew-y)) scaleX(var(--un-scale-x)) scaleY(var(--un-scale-y)) scaleZ(var(--un-scale-z));
    --un-translate-x: -50%;
    border-top-width: 3px;
    border-left-width: 3px;
    border-bottom-width: 3px;
    border-right-width: 3px;
    --un-border-opacity: 1;
    border-color: rgb(255 255 255 / var(--un-border-opacity));
    border-radius: 9999px;
    border-style: solid;
    --un-shadow: var(--un-shadow-inset) 0 1px 3px 0 var(--un-shadow-color, rgb(0 0 0 / .1)),var(--un-shadow-inset) 0 1px 2px -1px var(--un-shadow-color, rgb(0 0 0 / .1));
    box-shadow: var(--un-ring-offset-shadow),var(--un-ring-shadow),var(--un-shadow)
}

.k-color-picker-slider--track {
    pointer-events: none;
    position: absolute;
    top: 50%;
    left: 0;
    right: 0;
    box-sizing: border-box;
    height: 8px;
    width: 100%;
    --un-translate-y: -50%;
    transform: translate(var(--un-translate-x)) translateY(var(--un-translate-y)) translateZ(var(--un-translate-z)) rotate(var(--un-rotate)) rotateX(var(--un-rotate-x)) rotateY(var(--un-rotate-y)) rotate(var(--un-rotate-z)) skew(var(--un-skew-x)) skewY(var(--un-skew-y)) scaleX(var(--un-scale-x)) scaleY(var(--un-scale-y)) scaleZ(var(--un-scale-z));
    border-radius: 8px;
    background: linear-gradient(to right,red,#ff0,#0f0,#0ff,#00f,#f0f,red)
}

.k-color-picker-slider--track_alpha {
    pointer-events: none;
    position: absolute;
    top: 50%;
    left: 0;
    right: 0;
    box-sizing: border-box;
    height: 8px;
    width: 100%;
    --un-translate-y: -50%;
    transform: translate(var(--un-translate-x)) translateY(var(--un-translate-y)) translateZ(var(--un-translate-z)) rotate(var(--un-rotate)) rotateX(var(--un-rotate-x)) rotateY(var(--un-rotate-y)) rotate(var(--un-rotate-z)) skew(var(--un-skew-x)) skewY(var(--un-skew-y)) scaleX(var(--un-scale-x)) scaleY(var(--un-scale-y)) scaleZ(var(--un-scale-z));
    border-radius: 8px
}

.k-affix.k-affix--affixed,.pf {
    position: fixed
}

.k-affix.k-affix--affixed.k-affix--absolute-positioned,.k-timeline-item-head--left,.pa {
    position: absolute
}

.k-alert {
    position: relative;
    margin: 0;
    box-sizing: border-box;
    width: 100%;
    display: flex;
    align-items: center;
    overflow: hidden;
    border-radius: 4px;
    padding: 8px 16px
}

.k-alert--close__has-description {
    position: absolute;
    top: 10px;
    right: 16px
}

.k-backtop--base {
    position: fixed;
    z-index: 100;
    width: 3rem;
    height: 3rem;
    display: flex;
    cursor: pointer;
    align-items: center;
    justify-content: center;
    border-radius: 9999px;
    background-color: var(--ikun-white);
    --un-shadow: var(--un-shadow-inset) 0 10px 15px -3px var(--un-shadow-color, rgb(0 0 0 / .1)),var(--un-shadow-inset) 0 4px 6px -4px var(--un-shadow-color, rgb(0 0 0 / .1));
    box-shadow: var(--un-ring-offset-shadow),var(--un-ring-shadow),var(--un-shadow);
    --un-shadow-opacity: 1;
    --un-shadow-color: rgb(248 161 83 / var(--un-shadow-opacity))
}

.k-badge--base {
    position: relative;
    display: inline-block;
    width: fit-content;
    vertical-align: middle
}

.k-badge--content-fixed {
    position: absolute;
    top: 0;
    right: 10px;
    z-index: 1;
    --un-translate-x: 100%;
    --un-translate-y: 100%;
    transform: translate(var(--un-translate-x)) translateY(var(--un-translate-y)) translateZ(var(--un-translate-z)) rotate(var(--un-rotate)) rotateX(var(--un-rotate-x)) rotateY(var(--un-rotate-y)) rotate(var(--un-rotate-z)) skew(var(--un-skew-x)) skewY(var(--un-skew-y)) scaleX(var(--un-scale-x)) scaleY(var(--un-scale-y)) scaleZ(var(--un-scale-z));
    --un-translate-y: -50%
}

.k-button-group>.k-button--base {
    position: relative;
    z-index: 0;
    float: left
}

.k-calendar-cell {
    position: relative;
    box-sizing: border-box;
    min-width: 24px;
    cursor: pointer;
    padding: 0;
    font-weight: 400
}

.k-calendar-cell-inner {
    position: relative;
    z-index: 2;
    box-sizing: border-box;
    min-width: 24px;
    line-height: 24px;
    transition: background .3s
}

.k-calendar-thead {
    position: relative;
    box-sizing: border-box;
    min-width: 24px;
    border-radius: 18px;
    padding-bottom: 4px;
    padding-right: 12px;
    vertical-align: middle;
    font-weight: 400
}

.k-calendar-thead-card {
    position: relative;
    min-width: 24px;
    border-radius: 18px;
    text-align: center;
    vertical-align: middle;
    font-weight: 400
}

.k-carousel,.pr {
    position: relative
}

.k-carousel-arrow {
    position: absolute;
    width: 100%;
    display: flex;
    justify-content: space-between;
    top: calc(50% - 16px)
}

.k-carousel-item-wrap {
    position: relative;
    display: flex
}

.k-carousel-wrap {
    position: relative;
    overflow: hidden
}

.k-color-picker-block-clear {
    position: relative;
    width: 28px;
    height: 28px;
    overflow: hidden;
    border-width: 1px;
    border-color: var(--ikun-zinc-300);
    border-radius: 4px;
    border-style: solid;
    background-size: 50% 50%;
    background-image: conic-gradient(rgba(0,0,0,.06) 0 25%,transparent 0 50%,rgba(0,0,0,.06) 0 75%,transparent 0)
}

.k-color-picker-clear {
    position: relative;
    margin-bottom: 12px;
    width: 18px;
    height: 18px;
    cursor: pointer;
    overflow: hidden;
    border-width: 1px;
    border-color: var(--ikun-zinc-300);
    border-radius: 4px;
    border-style: solid
}

.k-color-picker-palette {
    position: relative;
    left: 0;
    top: 0;
    width: 269px;
    height: 160px;
    overflow: hidden;
    border-radius: 4px;
    background-image: linear-gradient(0deg,rgb(0,0,0),transparent),linear-gradient(90deg,#fff,#fff0)
}

.k-color-picker-pointer {
    position: absolute;
    width: 14px;
    height: 14px;
    cursor: pointer;
    border-top-width: 3px;
    border-left-width: 3px;
    border-bottom-width: 3px;
    border-right-width: 3px;
    --un-border-opacity: 1;
    border-color: rgb(255 255 255 / var(--un-border-opacity));
    border-radius: 16px;
    border-style: solid
}

.k-color-picker-slider {
    position: relative;
    height: 8px;
    cursor: pointer;
    -webkit-user-select: none;
    user-select: none
}

.k-contextmenu--base,.k-contextmenu-sub-menu-item {
    position: fixed;
    margin: 0;
    list-style-type: none;
    border-radius: .25rem;
    --un-bg-opacity: 1;
    background-color: rgb(255 255 255 / var(--un-bg-opacity));
    padding-left: .5rem!important;
    padding-right: .5rem!important;
    --un-shadow: var(--un-shadow-inset) 0 10px 15px -3px var(--un-shadow-color, rgb(0 0 0 / .1)),var(--un-shadow-inset) 0 4px 6px -4px var(--un-shadow-color, rgb(0 0 0 / .1));
    box-shadow: var(--un-ring-offset-shadow),var(--un-ring-shadow),var(--un-shadow)
}

.k-drawer--base {
    position: fixed;
    top: 0;
    z-index: 1000;
    min-width: 33.3333333333%;
    height: 100%;
    background-color: var(--ikun-white);
    padding: .5rem
}

.k-form-item-content {
    position: relative;
    display: flex;
    flex: 1 1 0%;
    justify-content: flex-start
}

.k-form-item-msg_error {
    position: absolute;
    bottom: -16px;
    left: 0;
    font-size: 12px;
    color: var(--ikun-rose-400);
    line-height: 1
}

.k-image {
    position: relative;
    display: inline-block;
    overflow: hidden
}

.k-image__wrapper {
    position: absolute;
    top: 0;
    left: 0;
    width: 100%;
    height: 100%
}

.k-image-view--body {
    position: absolute;
    top: 0;
    right: 0;
    bottom: 0;
    left: 0;
    width: 100%;
    display: flex;
    align-items: center;
    justify-content: center
}

.k-image-view--body__img {
    position: absolute;
    max-width: 40%;
    cursor: grab;
    -webkit-user-select: none;
    user-select: none;
    -webkit-user-drag: none
}

.k-image-view--close {
    position: absolute;
    right: 32px;
    top: 32px;
    z-index: 2;
    height: 42px;
    width: 42px;
    display: flex;
    cursor: pointer;
    align-items: center;
    justify-content: center;
    border-radius: 9999px;
    color: var(--ikun-neutral-300);
    --ikun-context-background-color: rgba(0,0,0,.2);
    background-color: var(--ikun-context-background-color)
}

.k-image-view--footer__wrapper {
    position: absolute;
    right: 0;
    bottom: 32px;
    z-index: 2;
    width: 100%;
    display: flex;
    align-items: center;
    justify-content: center
}

.k-indicators {
    position: absolute;
    bottom: 12px;
    width: 100%;
    display: flex;
    justify-content: center
}

.k-input {
    position: relative;
    display: flex;
    align-items: center
}

.k-input--base {
    position: relative;
    box-sizing: border-box;
    width: 100%;
    display: flex;
    align-items: center;
    overflow: hidden;
    border-width: 1px;
    border-color: var(--ikun-zinc-300);
    border-style: solid
}

.k-mask--base {
    position: absolute;
    z-index: 999;
    --ikun-context-background-color: rgba(0,0,0,.5);
    background-color: var(--ikun-context-background-color)
}

.k-modal--base,.k-msg-box--base {
    position: fixed;
    left: 50%;
    top: 50%;
    min-width: 33.3333333333%;
    transform-origin: center;
    --un-translate-x: -50%;
    transform: translate(var(--un-translate-x)) translateY(var(--un-translate-y)) translateZ(var(--un-translate-z)) rotate(var(--un-rotate)) rotateX(var(--un-rotate-x)) rotateY(var(--un-rotate-y)) rotate(var(--un-rotate-z)) skew(var(--un-skew-x)) skewY(var(--un-skew-y)) scaleX(var(--un-scale-x)) scaleY(var(--un-scale-y)) scaleZ(var(--un-scale-z));
    --un-translate-y: -50%;
    border-radius: .25rem;
    background-color: var(--ikun-white);
    padding: .5rem;
    --un-shadow: var(--un-shadow-inset) 0 1px 3px 0 var(--un-shadow-color, rgb(0 0 0 / .1)),var(--un-shadow-inset) 0 1px 2px -1px var(--un-shadow-color, rgb(0 0 0 / .1));
    box-shadow: var(--un-ring-offset-shadow),var(--un-ring-shadow),var(--un-shadow)
}

.k-notification--base,[k-notification--base=""] {
    position: fixed;
    z-index: 1001;
    min-width: 240px;
    border-radius: .25rem;
    background-color: var(--ikun-white);
    padding: .5rem;
    --un-shadow: var(--un-shadow-inset) 0 1px 3px 0 var(--un-shadow-color, rgb(0 0 0 / .1)),var(--un-shadow-inset) 0 1px 2px -1px var(--un-shadow-color, rgb(0 0 0 / .1));
    box-shadow: var(--un-ring-offset-shadow),var(--un-ring-shadow),var(--un-shadow);
    transition: top .3s linear
}

.k-page-header__left {
    position: relative;
    margin-right: 40px;
    display: flex;
    align-items: center
}

.k-progress__cd {
    position: relative;
    display: inline-block
}

.k-progress--text__cd {
    position: absolute;
    left: 50%;
    top: 50%;
    --un-translate-x: -50%;
    --un-translate-y: -50%;
    transform: translate(var(--un-translate-x)) translateY(var(--un-translate-y)) translateZ(var(--un-translate-z)) rotate(var(--un-rotate)) rotateX(var(--un-rotate-x)) rotateY(var(--un-rotate-y)) rotate(var(--un-rotate-z)) skew(var(--un-skew-x)) skewY(var(--un-skew-y)) scaleX(var(--un-scale-x)) scaleY(var(--un-scale-y)) scaleZ(var(--un-scale-z))
}

.k-row--base {
    position: relative;
    box-sizing: border-box;
    display: flex;
    flex-wrap: wrap;
    text-align: center
}

.k-segmented-group {
    position: relative;
    width: 100%;
    display: flex;
    align-items: stretch;
    justify-content: flex-start
}

.k-segmented-item {
    position: relative;
    display: flex;
    align-items: center;
    justify-content: center;
    border-radius: .25rem;
    text-align: center
}

.k-segmented-item--active {
    position: absolute;
    height: 100%;
    width: 100%;
    border-radius: .25rem;
    --un-bg-opacity: 1;
    background-color: rgb(255 255 255 / var(--un-bg-opacity));
    --un-shadow: var(--un-shadow-inset) 0 1px 3px 0 var(--un-shadow-color, rgb(0 0 0 / .1)),var(--un-shadow-inset) 0 1px 2px -1px var(--un-shadow-color, rgb(0 0 0 / .1));
    box-shadow: var(--un-ring-offset-shadow),var(--un-ring-shadow),var(--un-shadow)
}

.k-segmented-item--disabled {
    position: relative;
    display: flex;
    cursor: not-allowed!important;
    align-items: center;
    justify-content: center;
    border-radius: .25rem;
    text-align: center;
    opacity: .5
}

.k-segmented-item--label {
    position: relative;
    z-index: 1;
    width: 100%;
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap;
    padding-left: 11px;
    padding-right: 11px
}

.k-slider--button-wrapper {
    position: absolute;
    top: 0;
    bottom: 0;
    margin-top: auto;
    margin-bottom: auto;
    display: flex;
    --un-translate-x: -50%;
    transform: translate(var(--un-translate-x)) translateY(var(--un-translate-y)) translateZ(var(--un-translate-z)) rotate(var(--un-rotate)) rotateX(var(--un-rotate-x)) rotateY(var(--un-rotate-y)) rotate(var(--un-rotate-z)) skew(var(--un-skew-x)) skewY(var(--un-skew-y)) scaleX(var(--un-scale-x)) scaleY(var(--un-scale-y)) scaleZ(var(--un-scale-z));
    cursor: pointer;
    -webkit-user-select: none;
    user-select: none;
    align-items: center;
    justify-content: center
}

.k-slider--button-wrapper__vertical {
    position: absolute;
    left: 50%;
    margin-left: auto;
    margin-right: auto;
    display: flex;
    --un-translate-x: -50%;
    transform: translate(var(--un-translate-x)) translateY(var(--un-translate-y)) translateZ(var(--un-translate-z)) rotate(var(--un-rotate)) rotateX(var(--un-rotate-x)) rotateY(var(--un-rotate-y)) rotate(var(--un-rotate-z)) skew(var(--un-skew-x)) skewY(var(--un-skew-y)) scaleX(var(--un-scale-x)) scaleY(var(--un-scale-y)) scaleZ(var(--un-scale-z));
    --un-translate-y: 50%;
    cursor: pointer;
    -webkit-user-select: none;
    user-select: none;
    align-items: center;
    justify-content: center
}

.k-slider--runway {
    position: relative;
    flex: 1 1 0%;
    cursor: pointer;
    border-radius: .1875rem;
    background-color: var(--ikun-light-900)
}

.k-slider--runway__vertical {
    position: relative;
    display: flex;
    flex-direction: column;
    cursor: pointer;
    justify-content: flex-end;
    border-radius: .1875rem;
    background-color: var(--ikun-light-900)
}

.k-slider--stop {
    position: absolute;
    top: 50%;
    display: inline-block;
    --un-translate-y: -50%;
    transform: translate(var(--un-translate-x)) translateY(var(--un-translate-y)) translateZ(var(--un-translate-z)) rotate(var(--un-rotate)) rotateX(var(--un-rotate-x)) rotateY(var(--un-rotate-y)) rotate(var(--un-rotate-z)) skew(var(--un-skew-x)) skewY(var(--un-skew-y)) scaleX(var(--un-scale-x)) scaleY(var(--un-scale-y)) scaleZ(var(--un-scale-z));
    border-radius: 50%;
    --un-bg-opacity: 1;
    background-color: rgb(248 161 83 / var(--un-bg-opacity))
}

.k-slider--stop__vertical {
    position: absolute;
    left: 50%;
    --un-translate-x: -50%;
    transform: translate(var(--un-translate-x)) translateY(var(--un-translate-y)) translateZ(var(--un-translate-z)) rotate(var(--un-rotate)) rotateX(var(--un-rotate-x)) rotateY(var(--un-rotate-y)) rotate(var(--un-rotate-z)) skew(var(--un-skew-x)) skewY(var(--un-skew-y)) scaleX(var(--un-scale-x)) scaleY(var(--un-scale-y)) scaleZ(var(--un-scale-z));
    border-radius: 50%;
    --un-bg-opacity: 1;
    background-color: rgb(248 161 83 / var(--un-bg-opacity))
}

.k-spin--spinner {
    position: absolute;
    top: 50%;
    left: 50%;
    --un-translate-x: -50%;
    transform: translate(var(--un-translate-x)) translateY(var(--un-translate-y)) translateZ(var(--un-translate-z)) rotate(var(--un-rotate)) rotateX(var(--un-rotate-x)) rotateY(var(--un-rotate-y)) rotate(var(--un-rotate-z)) skew(var(--un-skew-x)) skewY(var(--un-skew-y)) scaleX(var(--un-scale-x)) scaleY(var(--un-scale-y)) scaleZ(var(--un-scale-z));
    --un-translate-y: -50%;
    text-align: center;
    --un-text-opacity: 1;
    color: rgb(248 161 83 / var(--un-text-opacity))
}

.k-step-arrow-horizontal,.k-step-arrow-lb-vertical {
    position: absolute;
    top: 6px;
    right: 0;
    color: var(--ikun-zinc-400)
}

.k-step-arrow-vertical {
    position: absolute;
    bottom: -26px;
    left: 4px;
    color: var(--ikun-zinc-400)
}

.k-step-tail {
    position: absolute;
    inset-inline-start: 16px;
    top: 0;
    box-sizing: content-box;
    height: 100%;
    width: 1px;
    padding: 38px 0 6px
}

.k-step-tail-lb-horizontal--dot {
    position: absolute;
    inset-inline-start: 3px;
    top: 0;
    box-sizing: content-box;
    height: 100%;
    width: 2px;
    padding: 26px 0 6px
}

.k-step-tail-lb-vertical {
    position: absolute;
    inset-inline-start: 120px;
    top: 1px;
    left: 0;
    margin-left: 58px;
    box-sizing: border-box;
    height: 1px;
    width: 100%;
    padding: 0 32px
}

.k-step-title {
    position: relative;
    display: inline-block;
    padding-inline-end:16px;font-size: 16px;
    line-height: 32px
}

.k-step-vertical {
    position: relative;
    margin-top: 44px
}

.k-step-vertical--dot {
    position: relative;
    margin-top: 4px;
    margin-bottom: 20px
}

.k-steps-bar-horizontal,.k-steps-bar-lb-horizontal {
    position: absolute;
    bottom: 0;
    width: 100%;
    height: 2px;
    --un-bg-opacity: 1;
    background-color: rgb(248 161 83 / var(--un-bg-opacity))
}

.k-steps-bar-vertical {
    position: absolute;
    top: 0;
    right: 0;
    width: 2px;
    height: 100%;
    --un-bg-opacity: 1;
    background-color: rgb(248 161 83 / var(--un-bg-opacity))
}

.k-steps-container {
    position: relative;
    box-sizing: border-box;
    overflow: hidden;
    vertical-align: top
}

.k-switch {
    position: relative;
    display: inline-flex;
    align-items: center
}

.k-switch-circle {
    position: absolute;
    right: 2px;
    display: inline-flex;
    align-items: center;
    justify-content: center;
    border-radius: 9999px;
    background-color: var(--ikun-white);
    --un-shadow: var(--un-shadow-inset) 0 1px 3px 0 var(--un-shadow-color, rgb(0 0 0 / .1)),var(--un-shadow-inset) 0 1px 2px -1px var(--un-shadow-color, rgb(0 0 0 / .1));
    box-shadow: var(--un-ring-offset-shadow),var(--un-ring-shadow),var(--un-shadow);
    transition: right .1s linear
}

.k-tabs__bar {
    position: absolute;
    left: 0;
    bottom: 0;
    z-index: 1;
    height: 2px;
    width: 100%;
    --un-bg-opacity: 1;
    background-color: rgb(248 161 83 / var(--un-bg-opacity))
}

.k-tabs__header,.k-tabs__header--card {
    position: relative;
    display: flex;
    align-items: center;
    justify-content: space-between
}

.k-tabs__header--border {
    position: relative;
    display: flex;
    align-items: center;
    justify-content: space-between;
    background-color: var(--ikun-slate-50)
}

.k-tabs__nav {
    position: relative;
    z-index: 1;
    float: left;
    display: flex;
    white-space: nowrap;
    transition: transform .3s linear
}

.k-tabs__nav--wrap {
    position: relative;
    display: flex;
    align-items: center;
    justify-content: space-between;
    overflow: hidden
}

.k-tabs__nav-item {
    position: relative;
    box-sizing: border-box;
    height: 40px;
    display: flex;
    cursor: pointer;
    -webkit-user-select: none;
    user-select: none;
    align-items: center;
    justify-content: center;
    white-space: nowrap;
    padding: 0 16px;
    font-size: 1rem;
    line-height: 1.5rem;
    color: var(--ikun-slate-900);
    transition: padding .3s cubic-bezier(.645,.045,.355,1)
}

.k-tabs__next {
    position: absolute;
    right: 0;
    height: 100%;
    display: flex;
    cursor: pointer;
    align-items: center;
    justify-content: center
}

.k-tabs__prev {
    position: absolute;
    left: 0;
    height: 100%;
    display: flex;
    cursor: pointer;
    align-items: center;
    justify-content: center
}

.k-timeline-item {
    position: relative;
    margin: 0;
    list-style-type: none;
    padding-bottom: 20px;
    font-size: 14px
}

.k-timeline-item-content {
    position: relative;
    inset-block-start: -7px;
    margin-inline-end:0;margin-inline-start:26px;margin-block-start:0;margin-block-end:0;word-break: break-all
}

.k-timeline-item-head {
    position: absolute;
    box-sizing: border-box;
    width: 10px;
    height: 10px;
    border-top-width: 3px;
    border-left-width: 3px;
    border-bottom-width: 3px;
    border-right-width: 3px;
    --un-border-opacity: 1;
    border-color: rgb(248 161 83 / var(--un-border-opacity));
    border-radius: 9999px;
    border-style: solid;
    --un-bg-opacity: 1;
    background-color: rgb(255 255 255 / var(--un-bg-opacity));
    --un-text-opacity: 1;
    color: rgb(248 161 83 / var(--un-text-opacity))
}

.k-timeline-item-head--center {
    position: absolute;
    inset-inline-start: 50%;
    margin-inline-start:-4px}

.k-timeline-item-head--right {
    position: absolute;
    inset-inline-start: 100%;
    margin-inline-start:-4px}

.k-timeline-item-label {
    position: relative;
    position: absolute;
    inset-block-start: -7px;
    margin-inline-end:0;margin-inline-start:26px;margin-block-start:0;margin-block-end:0;word-break: break-all
}

.k-timeline-item-tail {
    position: absolute;
    inset-block-start: 10px;
    inset-inline-start: 4px;
    border-left-width: 2px;
    border-top-width: 0px;
    border-bottom-width: 0px;
    border-right-width: 0px;
    border-color: var(--ikun-zinc-300);
    border-style: solid
}

.k-tour {
    position: fixed;
    left: 0;
    top: 0;
    box-sizing: content-box
}

.k-tour-indicators {
    position: relative;
    width: 100%;
    height: 100%;
    display: flex;
    align-items: flex-end;
    justify-content: flex-start
}

.p-c {
    position: absolute;
    top: 50%;
    left: 50%;
    --un-translate-x: -50%;
    transform: translate(var(--un-translate-x)) translateY(var(--un-translate-y)) translateZ(var(--un-translate-z)) rotate(var(--un-rotate)) rotateX(var(--un-rotate-x)) rotateY(var(--un-rotate-y)) rotate(var(--un-rotate-z)) skew(var(--un-skew-x)) skewY(var(--un-skew-y)) scaleX(var(--un-scale-x)) scaleY(var(--un-scale-y)) scaleZ(var(--un-scale-z));
    --un-translate-y: -50%
}

.k-calendar-date-c:before {
    position: absolute;
    inset-inline-end: 0;
    inset-inline-start: 0;
    top: 0;
    bottom: 0;
    border-top-width: 1px;
    border-left-width: 1px;
    border-bottom-width: 1px;
    border-right-width: 1px;
    --un-border-opacity: 1;
    border-color: rgb(248 161 83 / var(--un-border-opacity));
    border-radius: .25rem;
    border-style: solid;
    content: ""
}

.k-color-picker-block-clear:after {
    position: absolute;
    right: 2px;
    top: 0;
    display: block;
    width: 50px;
    height: 2px;
    transform-origin: right;
    --un-rotate-x: 0;
    --un-rotate-y: 0;
    --un-rotate-z: 0;
    --un-rotate: -45deg;
    transform: translate(var(--un-translate-x)) translateY(var(--un-translate-y)) translateZ(var(--un-translate-z)) rotate(var(--un-rotate)) rotateX(var(--un-rotate-x)) rotateY(var(--un-rotate-y)) rotate(var(--un-rotate-z)) skew(var(--un-skew-x)) skewY(var(--un-skew-y)) scaleX(var(--un-scale-x)) scaleY(var(--un-scale-y)) scaleZ(var(--un-scale-z));
    background-color: var(--ikun-rose-400);
    content: ""
}

.k-color-picker-line:after {
    position: absolute;
    right: -2px;
    top: -2px;
    display: block;
    width: 50px;
    height: 2px;
    transform-origin: right;
    --un-rotate-x: 0;
    --un-rotate-y: 0;
    --un-rotate-z: 0;
    --un-rotate: -45deg;
    transform: translate(var(--un-translate-x)) translateY(var(--un-translate-y)) translateZ(var(--un-translate-z)) rotate(var(--un-rotate)) rotateX(var(--un-rotate-x)) rotateY(var(--un-rotate-y)) rotate(var(--un-rotate-z)) skew(var(--un-skew-x)) skewY(var(--un-skew-y)) scaleX(var(--un-scale-x)) scaleY(var(--un-scale-y)) scaleZ(var(--un-scale-z));
    background-color: var(--ikun-rose-400);
    content: ""
}

.k-step-tail-horizontal:after {
    position: absolute;
    inset-inline-start: 100%;
    top: 16px;
    display: block;
    width: 9999px;
    height: 1px;
    background-color: var(--ikun-neutral-200);
    content: "";
    transition: all .3s linear
}

.k-calendar-date-content {
    position: static;
    width: auto;
    height: 86px;
    overflow-y: auto;
    text-align: start;
    line-height: 1.5
}

.k-timeline-item-tail--center {
    inset-inline-start: 50%
}

.k-timeline-item-tail--right {
    inset-inline-start: 100%;
    margin-inline-start:-1px}

.k-badge--base>.k-badge--content-dot {
    right: 5px;
    width: 8px;
    height: 8px;
    border-radius: 50%;
    padding: 0
}

.k-step-tail-lb-vertical--dot {
    top: -11px;
    padding-left: 20px;
    padding-right: 20px
}

.k-popover--base {
    z-index: 999;
    box-sizing: border-box;
    border-radius: .25rem;
    background-color: var(--ikun-white);
    padding: 8px;
    color: var(--ikun-slate-900)
}

.k-button-group:hover>.k-button--base {
    z-index: 1
}

.k-button-group:focus>.k-button--base {
    z-index: 1
}

.k-button-group:active>.k-button--base {
    z-index: 1
}

.k-color-picker-preset--color {
    display: grid;
    grid-template-columns: repeat(11,minmax(0,1fr));
    margin-top: 12px;
    gap: 6px
}

.k-descriptions--body {
    display: grid
}

.k-breadcrumb-item {
    float: left;
    display: inline-flex;
    align-items: center
}

.k-breadcrumb:after {
    clear: both;
    display: table
}

.k-button-group:after {
    clear: both;
    display: table;
    content: ""
}

.k-alert--description {
    margin: 4px 0 0;
    text-align: justify;
    font-size: 12px
}

.k-calendar {
    margin: 0;
    box-sizing: border-box;
    list-style-type: none;
    --un-bg-opacity: 1;
    background-color: rgb(255 255 255 / var(--un-bg-opacity));
    padding: 0;
    font-size: 14px;
    line-height: 1.5
}

.k-calendar-header-card {
    margin: 0;
    box-sizing: border-box;
    display: block;
    align-items: center;
    justify-content: flex-end;
    border-left-width: 0px;
    border-top-width: 0px;
    border-bottom-width: 1px;
    border-right-width: 0px;
    border-color: var(--ikun-zinc-300);
    border-style: solid;
    padding: 12px 8px
}

.k-color-picker {
    margin: 4px
}

.k-empty__description__p {
    margin: 0;
    font-size: .875rem;
    line-height: 1.25rem;
    color: var(--ikun-zinc-400)
}

.k-pagination {
    margin: 0;
    display: flex;
    align-items: center;
    padding: 0
}

.k-segmented {
    margin: 0;
    box-sizing: border-box;
    display: inline-block;
    cursor: pointer;
    border-radius: .25rem;
    background-color: var(--ikun-neutral-100);
    padding: 2px;
    font-size: 14px;
    color: var(--ikun-slate-900)
}

.k-steps {
    margin: 0;
    box-sizing: border-box;
    width: 100%;
    padding: 0
}

.k-timeline {
    margin: 0;
    box-sizing: border-box;
    list-style-type: none;
    padding: 0;
    font-size: 1rem;
    line-height: 1.5rem;
    font-size: 14px;
    color: var(--ikun-slate-900)
}

.k-auto-complete--option {
    margin-left: .5rem;
    margin-right: .5rem;
    box-sizing: border-box;
    cursor: pointer;
    border-radius: .25rem;
    padding-top: .25rem;
    padding-bottom: .25rem;
    padding-left: .5rem;
    text-align: left;
    color: var(--ikun-slate-900)
}

.k-breadcrumb-item-separator {
    margin-left: 8px;
    margin-right: 8px;
    font-size: 10px;
    color: var(--ikun-stone-400)!important;
    font-weight: 700
}

.k-calendar-date {
    margin: 0 4px;
    box-sizing: border-box;
    display: block;
    width: auto;
    height: auto;
    border-width: 0px;
    border-top-width: 2px;
    border-color: var(--ikun-zinc-300);
    border-radius: 0;
    border-style: solid;
    padding-left: 8px;
    padding-right: 8px;
    padding-top: 4px
}

.k-calendar-date-card {
    margin: 0 auto;
    box-sizing: border-box;
    display: block;
    width: 24px;
    height: 24px;
    display: flex;
    align-items: center;
    justify-content: center;
    border-radius: 4px;
    padding: 0
}

.k-calendar-date-card-m {
    margin: 0 auto;
    box-sizing: border-box;
    display: block;
    width: 60px;
    height: 24px;
    display: flex;
    align-items: center;
    justify-content: center;
    border-radius: 4px;
    padding: 0
}

.k-calendar-header {
    margin: 12px 0;
    display: block;
    align-items: center;
    justify-content: flex-end
}

.k-calendar-header-select-m {
    margin-left: 0;
    margin-right: 0;
    display: block!important;
    width: 50%!important
}

.k-contextmenu-item {
    margin-top: .25rem;
    margin-bottom: .25rem;
    list-style-type: none;
    border-radius: .25rem;
    font-size: .875rem;
    line-height: 1.25rem
}

.k-contextmenu-item__divider,.k-dropdown-item__divider {
    margin-top: .25rem;
    margin-bottom: .25rem;
    border-top-width: 1px;
    border-left-width: 0px;
    border-right-width: 0px;
    border-bottom-width: 0px;
    border-color: var(--ikun-zinc-300);
    border-style: solid
}

.k-contextmenu-sub-menu--base {
    margin-top: .25rem;
    margin-bottom: .25rem;
    display: flex;
    cursor: pointer;
    list-style-type: none;
    align-items: center;
    justify-content: space-between;
    border-radius: .25rem;
    padding: .25rem;
    font-size: .875rem;
    line-height: 1.25rem;
    color: var(--ikun-slate-900)
}

.k-divider--horizontal {
    margin-top: 1rem;
    margin-bottom: 1rem;
    display: flex;
    align-items: center
}

.k-divider--vertical {
    margin-left: .25rem;
    margin-right: .25rem;
    width: 0;
    height: 1rem;
    display: inline-flex;
    --un-scale-x: .5;
    transform: translate(var(--un-translate-x)) translateY(var(--un-translate-y)) translateZ(var(--un-translate-z)) rotate(var(--un-rotate)) rotateX(var(--un-rotate-x)) rotateY(var(--un-rotate-y)) rotate(var(--un-rotate-z)) skew(var(--un-skew-x)) skewY(var(--un-skew-y)) scaleX(var(--un-scale-x)) scaleY(var(--un-scale-y)) scaleZ(var(--un-scale-z));
    align-items: center;
    border-width: 1px;
    vertical-align: middle
}

.k-drawer--footer--btn,.k-modal--footer--btn,.k-msg-box--footer--btn {
    margin-left: .5rem;
    margin-right: .5rem
}

.k-dropdown-item {
    margin-top: .25rem;
    margin-bottom: .25rem;
    border-radius: .25rem;
    font-size: .875rem;
    line-height: 1.25rem
}

.k-image-view--footer__icon {
    margin-left: 8px;
    margin-right: 8px;
    cursor: pointer;
    -webkit-user-select: none;
    user-select: none;
    color: var(--ikun-neutral-300)
}

.k-image-view--footer__icon__disabled {
    margin-left: 8px;
    margin-right: 8px;
    cursor: not-allowed!important;
    -webkit-user-select: none;
    user-select: none;
    color: var(--ikun-zinc-400)
}

.k-link--content,.k-pagination-sizes {
    margin-left: .25rem;
    margin-right: .25rem
}

.k-msg-box--header--title {
    margin-top: 0;
    margin-bottom: 0;
    height: 2rem;
    width: 100%;
    display: flex;
    align-items: center;
    font-size: 1.125rem;
    line-height: 1.75rem;
    color: var(--ikun-slate-900);
    font-weight: 700
}

.k-notification--title,[k-notification--title=""] {
    margin-top: 0;
    margin-bottom: 0;
    display: flex;
    align-items: center;
    justify-content: center;
    font-size: 1.125rem;
    line-height: 1.75rem;
    color: var(--ikun-slate-900)
}

.k-page-header__left>[data-divider=k-divider] {
    margin-left: 16px;
    margin-right: 16px
}

.k-pagination-jumper {
    margin-left: .25rem;
    margin-right: .25rem;
    display: flex;
    align-items: center;
    color: var(--ikun-slate-900)
}

.k-pagination-pager {
    margin-left: .25rem;
    margin-right: .25rem;
    margin-top: 0!important;
    box-sizing: border-box;
    display: flex;
    cursor: pointer;
    -webkit-user-select: none;
    user-select: none;
    list-style-type: none;
    align-items: center;
    justify-content: center;
    border-radius: .25rem;
    padding-left: .25rem;
    padding-right: .25rem;
    color: var(--ikun-slate-900)
}

.k-pagination-total {
    margin-left: .25rem;
    margin-right: .25rem;
    color: var(--ikun-slate-900)
}

.k-popconfirm--content {
    margin: 1rem .5rem
}

.k-select--option {
    margin-left: .5rem;
    margin-right: .5rem;
    box-sizing: border-box;
    cursor: pointer;
    border-radius: .25rem;
    padding-top: .25rem;
    padding-bottom: .25rem;
    padding-left: .5rem;
    color: var(--ikun-slate-900)
}

.k-select--suffix {
    margin-left: .4em;
    margin-right: .4em;
    font-size: 1em;
    opacity: .5
}

.k-slider--runway--lg {
    margin-left: 12px;
    margin-right: 12px;
    height: 5px
}

.k-slider--runway--lg__vertical {
    margin-top: 12px;
    margin-bottom: 12px;
    width: 5px
}

.k-slider--runway--md {
    margin-left: 10px;
    margin-right: 10px;
    height: 4px
}

.k-slider--runway--md__vertical {
    margin-top: 10px;
    margin-bottom: 10px;
    width: 4px
}

.k-slider--runway--sm {
    margin-left: 8px;
    margin-right: 8px;
    height: 3px
}

.k-slider--runway--sm__vertical {
    margin-top: 8px;
    margin-bottom: 8px;
    width: 3px
}

.k-spin--text {
    margin-top: 1rem;
    margin-bottom: 1rem;
    animation: bounce 1s linear infinite;
    font-size: 1rem
}

.k-tag--base,[k-tag--base=""] {
    margin-left: .125rem;
    margin-right: .125rem;
    width: fit-content;
    display: inline-flex;
    -webkit-user-select: none;
    user-select: none;
    align-items: center;
    justify-content: center;
    white-space: nowrap;
    border-radius: .25rem;
    padding: .125rem .375rem;
    font-size: .75rem;
    line-height: 1rem;
    color: var(--ikun-slate-900)
}

.k-timeline-item-content--right {
    margin-left: 0;
    margin-right: 0;
    margin-inline-end:26px;margin-inline-start:0;text-align: right
}

.k-tour-body {
    margin-top: 12px;
    margin-bottom: 12px
}

.k-alert--close {
    margin-left: 8px;
    display: inline-flex;
    cursor: pointer;
    font-size: 12px
}

.k-alert--description__no-title,.k-steps-container:first-child>[data-k-step] {
    margin-top: 0
}

.k-alert--icon {
    margin-right: 8px
}

.k-button-group>.k-button--base:not(:last-child) {
    margin-right: 2px
}

.k-button-group>.k-button--base+.k-button-group>.k-button--base {
    margin-left: 0
}

.k-calendar-header-btn-group {
    margin-top: 8px;
    display: flex!important
}

.k-calendar-header-select-y {
    margin-right: 8px;
    display: block!important
}

.k-carousel-arrow-next,.k-msg-box--icon,.k-notification--type--icon,.k-popconfirm--icon,.k-tag--icon__has-slot {
    margin-right: .5rem
}

.k-carousel-arrow-prev {
    margin-left: .5rem
}

.k-collapse--content,.k-msg-box--input__prompt {
    margin-top: 1rem
}

.k-collapse--line {
    margin-bottom: 1rem;
    border-top-width: 1px;
    border-left-width: 0px;
    border-bottom-width: 0px;
    border-right-width: 0px;
    border-color: var(--ikun-zinc-300);
    border-style: solid
}

.k-color-picker--alpha {
    margin-top: 12px
}

.k-color-picker--hs {
    margin-right: 12px;
    width: 100%
}

.k-color-picker--hsb {
    margin-top: 12px;
    width: 100%;
    display: flex;
    align-items: center;
    justify-content: center
}

.k-color-picker-format {
    margin-top: 12px;
    display: flex;
    align-items: center;
    justify-content: flex-start
}

.k-color-picker-format--input {
    margin-left: 6px
}

.k-color-picker-format--input-num {
    margin-left: 6px;
    width: 50px
}

.k-color-picker-preset--container {
    margin-top: 12px;
    cursor: pointer
}

.k-color-picker-preset--label {
    margin-left: 4px;
    font-size: 12px
}

.k-color-picker-title,.k-descriptions--header--lg {
    margin-bottom: 12px
}

.k-color-picker-txt,.k-switch-tx__checked--lg {
    margin-left: 4px
}

.k-descriptions--header--md {
    margin-bottom: 10px
}

.k-descriptions--header--sm {
    margin-bottom: 8px
}

.k-drawer--content {
    margin-top: .5rem;
    overflow-y: auto
}

.k-empty__bottom,.k-empty__description {
    margin-top: 16px
}

.k-form-item {
    margin-bottom: 1.5rem
}

.k-form-item-label__ml {
    margin-right: .75rem
}

.k-form-item-label__vertical {
    margin-bottom: .5rem
}

.k-indicators-item {
    margin-right: 8px;
    height: 6px;
    width: 6px;
    cursor: pointer;
    border-radius: 9999px;
    background-color: var(--ikun-slate-300);
    transition: all .3s cubic-bezier(.645,.045,.355,1)
}

.k-input--prefix-icon {
    margin-right: .375rem
}

.k-input--suffix-icon {
    margin-left: .375rem
}

.k-msg-box--form {
    margin-top: .5rem;
    margin-bottom: 0!important;
    width: 100%
}

.k-notification--content {
    margin-top: .5rem;
    padding: .5rem
}

.k-page-header__breadcrumb {
    margin-bottom: 16px
}

.k-page-header__icon {
    margin-right: 10px;
    display: flex;
    align-items: center;
    font-size: 16px
}

.k-page-header--contentful>[data-pager-header=main] {
    margin-top: 16px;
    border-top-width: 1px;
    border-left-width: 0px;
    border-bottom-width: 0px;
    border-right-width: 0px;
    border-color: var(--ikun-zinc-300);
    border-style: solid
}

.k-rate--text {
    margin-left: 6px;
    font-size: 10px;
    line-height: 1
}

.k-select--prefix {
    margin-right: .4em;
    font-size: 1em;
    opacity: .5
}

.k-skeleton-avatar-container--sm {
    margin-top: 4px;
    height: 48px
}

.k-skeleton-avatar-sk {
    margin-right: 16px
}

.k-skeleton-paragraph--item {
    margin-top: 16px;
    list-style-type: none;
    border-radius: 4px;
    background-color: var(--ikun-light-700)
}

.k-statistic__head {
    margin-bottom: 4px;
    font-size: 1rem;
    line-height: 1.5rem;
    font-size: 12px;
    color: var(--ikun-zinc-400);
    line-height: 20px
}

.k-statistic__prefix {
    margin-right: 4px;
    display: inline-block;
    vertical-align: middle
}

.k-statistic__suffix {
    margin-left: 4px;
    display: inline-block;
    vertical-align: middle
}

.k-step-content-vertical {
    margin-left: 8px
}

.k-step-sub-title {
    margin-inline-start:8px;display: inline;
    font-size: 14px;
    color: var(--ikun-zinc-400);
    font-weight: 400
}

.k-step-sub-title-lb-vertical {
    margin-inline-start:0;margin-bottom: 4px;
    display: block;
    line-height: 22px
}

.k-step-title-lb-vertical {
    margin-top: 6px;
    display: block;
    padding-inline-end:0}

.k-switch-tx__checked--md {
    margin-left: 3px
}

.k-switch-tx__checked--sm {
    margin-left: 2px
}

.k-switch-tx__unchecked--lg {
    margin-left: 28px
}

.k-switch-tx__unchecked--md {
    margin-left: 22px
}

.k-switch-tx__unchecked--sm {
    margin-left: 16px
}

.k-tabs__add {
    margin-left: 4px;
    cursor: pointer;
    border-width: 1px;
    border-color: var(--ikun-zinc-300);
    border-radius: .25rem;
    border-style: solid
}

.k-tabs__add--border {
    margin-right: 10px
}

.k-tabs__close {
    margin-left: 4px;
    display: flex;
    align-items: center;
    justify-content: center;
    transition: all .3s cubic-bezier(.645,.045,.355,1)
}

.k-tag--close-icon {
    margin-left: .5rem;
    cursor: pointer
}

.k-timeline-item-content--cl,.k-timeline-item-label--cl {
    margin-inline-end:26px;margin-inline-start:0;text-align: right;
    width: calc(50% - 12px)
}

.k-aside--base {
    box-sizing: border-box;
    flex-shrink: 0;
    overflow: auto
}

.k-avatar {
    box-sizing: border-box;
    display: inline-flex;
    align-items: center;
    justify-content: center;
    overflow: hidden;
    background-color: var(--ikun-light-700);
    text-align: center;
    vertical-align: middle;
    font-size: 14px;
    color: var(--ikun-slate-900)
}

.k-calendar-body {
    box-sizing: border-box;
    padding: 8px 0
}

.k-calendar-content {
    box-sizing: border-box;
    width: 100%;
    border-collapse: collapse;
    table-layout: fixed
}

.k-calendar-date-value {
    box-sizing: border-box;
    line-height: 24px
}

.k-calendar-panel {
    box-sizing: border-box;
    display: block;
    width: 100%;
    border-width: 0px;
    border-radius: 0;
    background-color: var(--ikun-white);
    text-align: end;
    outline: 2px solid transparent;
    outline-offset: 2px
}

.k-calendar-panel-card {
    box-sizing: border-box;
    display: block;
    width: 100%;
    border-width: 0px;
    border-radius: 8px;
    background-color: var(--ikun-white);
    text-align: end;
    outline: 2px solid transparent;
    outline-offset: 2px
}

.k-col--base {
    box-sizing: border-box
}

.k-color-picker-block-w {
    box-sizing: border-box;
    display: flex;
    cursor: pointer;
    align-items: center;
    justify-content: center;
    border-width: 1px;
    border-color: var(--ikun-zinc-300);
    border-radius: 4px;
    border-style: solid;
    padding: 4px
}

.k-container--base {
    box-sizing: border-box;
    min-width: 0;
    display: flex;
    flex-shrink: 1;
    flex-grow: 1;
    flex-basis: auto;
    flex-direction: row
}

.k-descriptions-item--content {
    box-sizing: border-box;
    flex: 1 1 0%;
    word-break: break-all
}

.k-descriptions-item--label {
    box-sizing: border-box;
    flex-shrink: 0;
    word-break: break-all;
    font-weight: 600
}

.k-empty {
    box-sizing: border-box;
    display: flex;
    flex-direction: column;
    align-items: center;
    justify-content: center;
    padding: 40px 0;
    text-align: center
}

.k-empty__nd {
    box-sizing: border-box;
    padding-left: 1rem;
    padding-right: 1rem
}

.k-footer--base,.k-header--base {
    box-sizing: border-box;
    flex-shrink: 0;
    padding-left: 1rem;
    padding-right: 1rem
}

.k-image-view--footer {
    box-sizing: border-box;
    height: 42px;
    width: min-content;
    display: flex;
    -webkit-user-select: none;
    user-select: none;
    align-items: center;
    justify-content: center;
    border-radius: 21px;
    padding-left: 10px;
    padding-right: 10px;
    --ikun-context-background-color: rgba(0,0,0,.2);
    background-color: var(--ikun-context-background-color)
}

.k-main--base {
    box-sizing: border-box;
    display: block;
    flex-shrink: 1;
    flex-grow: 1;
    flex-basis: auto;
    padding: 1rem
}

.k-select--base {
    box-sizing: border-box;
    display: flex;
    cursor: pointer;
    align-items: center;
    border-width: 1px;
    border-color: var(--ikun-zinc-300);
    border-radius: .25rem;
    border-style: solid;
    padding: .25rem .5rem
}

.k-skeleton-content--lg,.k-skeleton-content--md,.k-skeleton-content--sm {
    box-sizing: border-box;
    width: 100%
}

.k-skeleton-input {
    box-sizing: border-box;
    border-width: 0px;
    border-radius: 4px;
    background-color: var(--ikun-light-700);
    padding: 0;
    outline-width: 0px
}

.k-step-content {
    box-sizing: border-box;
    display: inline-block;
    white-space: nowrap;
    vertical-align: top
}

.k-tabs__content {
    box-sizing: border-box;
    padding: 10px
}

.k-tabs__pad {
    box-sizing: border-box;
    padding: 0 20px
}

.k-tour-close {
    box-sizing: border-box;
    cursor: pointer;
    border-radius: .25rem;
    padding: 2px
}

.k-avatar>img {
    display: block;
    max-width: 100%;
    width: 100%;
    height: 100%;
    border-style: none
}

.k-col__guttered {
    display: block;
    min-height: 1px
}

.k-input__focus:focus-within>.k-input--clear-icon,.k-input__hover:hover>.k-input--clear-icon,.k-step-content-lb-vertical,.k-step-icon-lb-vertical,.k-steps-container-vertical {
    display: block
}

.k-divider--horizontal:before {
    display: block;
    width: 50%;
    height: 0;
    --un-scale-y: .5;
    transform: translate(var(--un-translate-x)) translateY(var(--un-translate-y)) translateZ(var(--un-translate-z)) rotate(var(--un-rotate)) rotateX(var(--un-rotate-x)) rotateY(var(--un-rotate-y)) rotate(var(--un-rotate-z)) skew(var(--un-skew-x)) skewY(var(--un-skew-y)) scaleX(var(--un-scale-x)) scaleY(var(--un-scale-y)) scaleZ(var(--un-scale-z));
    border-width: 1px;
    border-color: inherit
}

.k-divider--horizontal:after {
    display: block;
    width: 50%;
    height: 0;
    --un-scale-y: .5;
    transform: translate(var(--un-translate-x)) translateY(var(--un-translate-y)) translateZ(var(--un-translate-z)) rotate(var(--un-rotate)) rotateX(var(--un-rotate-x)) rotateY(var(--un-rotate-y)) rotate(var(--un-rotate-z)) skew(var(--un-skew-x)) skewY(var(--un-skew-y)) scaleX(var(--un-scale-x)) scaleY(var(--un-scale-y)) scaleZ(var(--un-scale-z));
    border-width: 1px;
    border-color: inherit
}

.k-button-group {
    display: inline-block;
    vertical-align: middle
}

.k-statistic__value,.k-step-icon-lb-horizontal {
    display: inline-block
}

.k-steps-container-horizontal {
    display: inline-block;
    flex: 1 1 0%;
    padding-inline-start:16px}

.k-step-tail-lb-vertical:after {
    display: inline-block;
    width: 100%;
    height: 1px;
    background-color: var(--ikun-neutral-200);
    content: "";
    transition: all .3s linear
}

.k-step-tail-vertical:after {
    display: inline-block;
    width: 1px;
    height: 100%;
    background-color: var(--ikun-neutral-200);
    content: "";
    transition: all .3s linear
}

.k-breadcrumb-item:last-child>.k-breadcrumb-item-separator,.k-col__guttered__none,.k-input--clear-icon {
    display: none
}

.k-badge--content {
    height: 18px;
    display: inline-flex;
    align-items: center;
    justify-content: center;
    white-space: nowrap;
    border-width: 1px;
    border-color: var(--ikun-white);
    border-radius: 10px;
    border-style: solid;
    padding: 0 6px;
    font-size: 12px;
    color: var(--ikun-white)
}

.k-button--base {
    height: 32px;
    width: fit-content;
    display: flex;
    cursor: pointer;
    align-items: center;
    justify-content: center;
    border-width: 1px;
    border-radius: .25rem;
    border-style: solid;
    padding: .25rem .5rem;
    line-height: 1
}

.k-button--circle {
    height: 32px;
    width: 32px;
    border-radius: 9999px!important;
    padding: .5rem
}

.k-button--circle--lg {
    height: 40px;
    width: 40px;
    border-radius: 9999px!important;
    padding: 0!important
}

.k-button--circle--sm {
    height: 24px;
    width: 24px;
    border-radius: 9999px!important;
    padding: 0!important
}

.k-button--lg {
    height: 40px;
    padding: .5rem .75rem
}

.k-button--sm {
    height: 24px;
    padding: .2rem .375rem
}

.k-calendar-card {
    width: 300px;
    border-top-width: 1px;
    border-left-width: 1px;
    border-bottom-width: 1px;
    border-right-width: 1px;
    border-color: var(--ikun-zinc-300);
    border-radius: 8px;
    border-style: solid
}

.k-calendar-cell-card {
    width: 42px;
    height: 39px;
    padding-top: 4px;
    padding-bottom: 4px
}

.k-calendar-date-panel {
    width: auto;
    display: flex;
    flex-direction: column
}

.k-calendar-header-btn {
    width: 50%
}

.k-calendar-header-select-y-full {
    width: 100%!important
}

.k-calendar-header-select-y-half {
    width: 50%!important
}

.k-carousel-arrow-icon {
    height: 32px;
    width: 32px;
    display: inline-flex;
    cursor: pointer;
    align-items: center;
    justify-content: center;
    border-radius: 9999px;
    border-style: none;
    --un-bg-opacity: 1;
    background-color: rgb(255 255 255 / var(--un-bg-opacity));
    --un-shadow: var(--un-shadow-inset) 0 1px 3px 0 var(--un-shadow-color, rgb(0 0 0 / .1)),var(--un-shadow-inset) 0 1px 2px -1px var(--un-shadow-color, rgb(0 0 0 / .1));
    box-shadow: var(--un-ring-offset-shadow),var(--un-ring-shadow),var(--un-shadow);
    outline: 2px solid transparent;
    outline-offset: 2px
}

.k-checkbox--box {
    width: 1em;
    height: 1em;
    display: flex;
    align-items: center;
    justify-content: center;
    overflow: hidden;
    border-width: 1px;
    border-color: var(--ikun-zinc-300);
    border-radius: .25rem;
    border-style: solid
}

.k-checkbox--lg,.k-radio--lg {
    height: 40px;
    font-size: 16px
}

.k-checkbox--md,.k-radio--md {
    height: 32px;
    font-size: 14px
}

.k-checkbox--sm,.k-radio--sm {
    height: 24px;
    font-size: 12px
}

.k-color-picker-block {
    width: 28px;
    height: 28px;
    border-radius: 4px;
    background-size: 50% 50%;
    background-image: conic-gradient(rgba(0,0,0,.06) 0 25%,transparent 0 50%,rgba(0,0,0,.06) 0 75%,transparent 0)
}

.k-color-picker-block--lg {
    width: 32px;
    height: 32px
}

.k-color-picker-block--md {
    width: 24px;
    height: 24px
}

.k-color-picker-block--sm,.k-slider--button--md {
    width: 16px;
    height: 16px
}

.k-color-picker-block-content {
    width: 28px;
    height: 28px;
    border-radius: 4px
}

.k-color-picker-block-content--lg {
    width: 32px;
    height: 32px;
    border-radius: 4px
}

.k-color-picker-block-content--md {
    width: 24px;
    height: 24px;
    border-radius: 4px
}

.k-color-picker-block-content--sm {
    width: 16px;
    height: 16px;
    border-radius: 4px
}

.k-color-picker-block-w--lg {
    min-width: 40px;
    height: 40px
}

.k-color-picker-block-w--md {
    min-width: 32px;
    height: 32px
}

.k-color-picker-block-w--sm {
    min-width: 24px;
    height: 24px
}

.k-color-picker-preset--checkbox {
    width: 18px;
    height: 18px;
    border-radius: 4px
}

.k-descriptions-item--content__horizontal {
    height: 100%;
    border-top-style: none!important
}

.k-descriptions-item--label__horizontal {
    height: 100%
}

.k-drawer--op,.k-progress,.k-slider--base {
    width: 100%;
    display: flex;
    align-items: center
}

.k-empty__image {
    width: 160px
}

.k-empty__img {
    width: 100%;
    height: 100%;
    -webkit-user-select: none;
    user-select: none;
    object-fit: contain;
    vertical-align: top
}

.k-eyedropper--base,.k-progress--runway {
    width: 100%;
    height: 100%
}

.k-image__error {
    width: 100%;
    height: 100%;
    display: flex;
    align-items: center;
    justify-content: center;
    background-color: var(--ikun-gray-100);
    vertical-align: middle;
    font-size: 14px;
    color: var(--ikun-zinc-400);
    color: var(--ikun-gray-400)
}

.k-image__inner {
    width: 100%;
    height: 100%;
    vertical-align: top;
    opacity: 1
}

.k-image__placeholder {
    width: 100%;
    height: 100%;
    background-color: var(--ikun-gray-100)
}

.k-indicators-item--active {
    width: 24px;
    --un-bg-opacity: 1;
    background-color: rgb(248 161 83 / var(--un-bg-opacity));
    transition: all .3s cubic-bezier(.645,.045,.355,1)
}

.k-input__lg {
    height: 38px;
    padding-left: .625rem;
    padding-right: .625rem;
    font-size: 16px
}

.k-input__md {
    height: 30px;
    padding-left: .625rem;
    padding-right: .625rem;
    font-size: 14px
}

.k-input__sm {
    height: 22px;
    padding-left: .375rem;
    padding-right: .375rem;
    font-size: 12px
}

.k-input--append__lg,.k-input--prepend__lg,.k-select__lg {
    height: 38px
}

.k-input--append__md,.k-input--prepend__md,.k-select__md {
    height: 30px
}

.k-input--append__sm,.k-input--prepend__sm {
    height: 22px
}

.k-input--icon__lg,.k-select--icon__lg {
    width: 20px!important;
    height: 20px!important
}

.k-input--icon__md,.k-select--icon__md {
    width: 16px!important;
    height: 16px!important
}

.k-input--icon__sm,.k-select--icon__sm {
    width: 12px!important;
    height: 12px!important
}

.k-input--inner {
    width: 100%;
    flex: 1 1 auto;
    border-style: none;
    background-color: transparent;
    font-size: inherit;
    outline: 2px solid transparent;
    outline-offset: 2px
}

.k-input-number__lg {
    height: 38px;
    padding-left: .625rem;
    font-size: 16px
}

.k-input-number__md {
    height: 30px;
    padding-left: .625rem;
    font-size: 14px
}

.k-input-number__sm {
    height: 22px;
    padding-left: .375rem;
    font-size: 12px
}

.k-input-number--controls {
    width: 30px;
    border-left-width: 1px;
    border-top-width: 0px;
    border-bottom-width: 0px;
    border-right-width: 0px;
    border-color: var(--ikun-zinc-300);
    border-style: solid
}

.k-modal--header {
    height: 2rem;
    width: 100%;
    display: flex;
    align-items: center;
    justify-content: space-between
}

.k-notification--body,.k-tour-header {
    width: 100%;
    display: flex;
    align-items: center;
    justify-content: space-between
}

.k-pagination-pager__lg {
    min-width: 38px;
    height: 38px;
    font-size: 1.125rem;
    line-height: 1.75rem;
    line-height: 38px
}

.k-pagination-pager__md {
    min-width: 32px;
    height: 32px;
    line-height: 32px
}

.k-pagination-pager__sm {
    min-width: 26px;
    height: 26px;
    font-size: .875rem;
    line-height: 1.25rem;
    line-height: 26px
}

.k-pagination-total__lg {
    height: 38px;
    font-size: 1.125rem;
    line-height: 1.75rem;
    line-height: 38px
}

.k-pagination-total__md {
    height: 32px;
    line-height: 32px
}

.k-pagination-total__sm {
    height: 26px;
    font-size: .875rem;
    line-height: 1.25rem;
    line-height: 26px
}

.k-progress--bar {
    height: 100%;
    display: flex;
    align-items: center;
    justify-content: flex-end;
    transition: width .28s linear
}

.k-progress--base {
    width: 100%;
    height: 1.5rem;
    display: flex;
    border-radius: 1rem;
    background-color: var(--ikun-light-500)
}

.k-radio--box {
    width: 1em;
    height: 1em;
    display: flex;
    align-items: center;
    justify-content: center;
    overflow: hidden;
    border-width: 1px;
    border-color: var(--ikun-zinc-300);
    border-radius: 50%;
    border-style: solid
}

.k-rate--item--lg,.k-switch-circle--lg {
    width: 22px;
    height: 22px
}

.k-rate--item--md,.k-switch-circle--md {
    width: 18px;
    height: 18px
}

.k-rate--item--sm,.k-switch-circle--sm {
    width: 14px;
    height: 14px
}

.k-rate--lg,.k-segmented-item--lg,.k-skeleton-paragraph--lg,.k-skeleton-title--lg,.k-slider--lg {
    height: 40px
}

.k-rate--md,.k-segmented-item--md,.k-skeleton-paragraph--md,.k-skeleton-title--md,.k-slider--md {
    height: 32px
}

.k-rate--sm,.k-segmented-item--sm,.k-select__sm,.k-skeleton-paragraph--sm,.k-skeleton-title--sm,.k-slider--sm {
    height: 24px
}

.k-segmented-item--block {
    min-width: 0;
    flex: 1 1 0%
}

.k-select--inner {
    width: 100%;
    height: 100%;
    flex: 1 1 auto;
    border-color: transparent;
    background-color: transparent;
    outline: 2px solid transparent!important;
    outline-offset: 2px!important
}

.k-select--tx__empty {
    width: 100%;
    text-align: center;
    color: var(--ikun-zinc-400)
}

.k-skeleton-avatar--lg {
    height: 40px;
    width: 40px
}

.k-skeleton-avatar--md {
    height: 32px;
    width: 32px
}

.k-skeleton-avatar--sm {
    height: 24px;
    width: 24px
}

.k-skeleton-avatar-container--lg {
    height: 80px
}

.k-skeleton-avatar-container--md {
    height: 62px
}

.k-skeleton-avatar-sk--lg {
    height: 80px;
    width: 80px
}

.k-skeleton-avatar-sk--md {
    height: 62px;
    width: 62px
}

.k-skeleton-avatar-sk--sm {
    height: 48px;
    width: 48px
}

.k-skeleton-button--block--lg,.k-skeleton-input--block--lg {
    height: 40px;
    width: 100%
}

.k-skeleton-button--block--md,.k-skeleton-input--block--md {
    height: 32px;
    width: 100%
}

.k-skeleton-button--block--sm,.k-skeleton-input--block--sm {
    height: 24px;
    width: 100%
}

.k-skeleton-button--circle--lg {
    height: 40px;
    width: 40px;
    border-radius: 9999px
}

.k-skeleton-button--circle--md {
    height: 32px;
    width: 32px;
    border-radius: 9999px
}

.k-skeleton-button--circle--sm {
    height: 24px;
    width: 24px;
    border-radius: 9999px
}

.k-skeleton-button--lg,.k-skeleton-input--lg {
    height: 40px;
    width: 80px
}

.k-skeleton-button--md,.k-skeleton-input--md {
    height: 32px;
    width: 64px
}

.k-skeleton-button--sm,.k-skeleton-input--sm {
    height: 24px;
    width: 48px
}

.k-skeleton-header {
    width: 100%;
    display: flex;
    align-items: center;
    justify-content: flex-start
}

.k-skeleton-image {
    height: 96px;
    width: 96px;
    display: flex;
    align-items: center;
    justify-content: center;
    border-radius: 4px
}

.k-slider--bar {
    height: 100%;
    border-radius: .1875rem;
    --un-bg-opacity: 1;
    background-color: rgb(248 161 83 / var(--un-bg-opacity))
}

.k-slider--bar__vertical {
    width: 100%;
    border-radius: .1875rem;
    --un-bg-opacity: 1;
    background-color: rgb(248 161 83 / var(--un-bg-opacity))
}

.k-slider--base__vertical {
    height: 100%;
    display: flex;
    justify-content: center
}

.k-slider--button--lg {
    width: 20px;
    height: 20px
}

.k-slider--button--sm {
    width: 12px;
    height: 12px
}

.k-slider--lg__vertical {
    width: 40px
}

.k-slider--md__vertical {
    width: 32px
}

.k-slider--sm__vertical {
    width: 24px
}

.k-slider--stop--lg {
    width: 5px;
    height: 5px
}

.k-slider--stop--md {
    width: 4px;
    height: 4px
}

.k-slider--stop--sm {
    width: 3px;
    height: 3px
}

.k-step-icon {
    height: 32px;
    width: 32px;
    border-top-width: 1px;
    border-left-width: 1px;
    border-bottom-width: 1px;
    border-right-width: 1px;
    border-color: transparent;
    border-radius: 9999px;
    border-style: solid;
    transition: all .3s linear
}

.k-step-icon--dot {
    height: 8px;
    width: 8px;
    vertical-align: sub
}

.k-step-icon--inner {
    height: 100%;
    width: 100%;
    display: flex;
    align-items: center;
    justify-content: center
}

.k-step-lb-vertical {
    width: 120px;
    display: flex;
    flex-direction: column;
    align-items: center;
    justify-content: center;
    text-align: center
}

.k-switch--lg {
    height: 24px;
    min-width: 50px;
    font-size: 16px
}

.k-switch--md {
    height: 20px;
    min-width: 40px;
    font-size: 14px
}

.k-switch--sm {
    height: 16px;
    min-width: 30px;
    font-size: 12px
}

.k-tabs__add--wrap {
    height: 40px;
    display: flex;
    flex: 1 1 0%;
    align-items: center;
    justify-content: flex-end
}

.k-tour-content {
    width: 520px
}

.k-tour-footer {
    height: 32px;
    display: flex;
    align-items: center;
    justify-content: space-between
}

.k-divider--content-center:before {
    width: 50%
}

.k-divider--content-left:before {
    width: 20px
}

.k-divider--content-right:before {
    width: 100%
}

.k-divider--content-center:after {
    width: 50%
}

.k-divider--content-left:after {
    width: 100%
}

.k-divider--content-right:after {
    width: 20px
}

.k-step-tail-horizontal--dot:after {
    height: 2px
}

.k-step-tail-vertical--dot:after {
    width: 2px
}

.f-c,.fcc,.k-calendar-header-select-group,.k-icon--base {
    display: flex;
    align-items: center;
    justify-content: center
}

.f-c-c {
    display: flex;
    flex-direction: column;
    align-items: center;
    justify-content: center
}

.fa {
    display: flex;
    justify-content: space-around
}

.fac {
    display: flex;
    align-items: center;
    justify-content: space-around
}

.fb {
    display: flex;
    justify-content: space-between
}

.fbc,.k-descriptions--header {
    display: flex;
    align-items: center;
    justify-content: space-between
}

.fc {
    display: flex;
    justify-content: center
}

.fe {
    display: flex;
    justify-content: flex-end
}

.fec,.k-popconfirm--footer {
    display: flex;
    align-items: center;
    justify-content: flex-end
}

.fi,.k-descriptions-item__horizontal,.k-form-item__horizontal,.k-pagination-container,[fi=""] {
    display: flex;
    align-items: center
}

.fs {
    display: flex;
    justify-content: flex-start
}

.fsc,.k-color-picker-preset--head,.k-rate {
    display: flex;
    align-items: center;
    justify-content: flex-start
}

.fse,.k-tour-btn {
    display: flex;
    align-items: flex-end;
    justify-content: flex-start
}

.fss {
    display: flex;
    align-items: flex-start;
    justify-content: flex-start
}

.fssc {
    display: flex;
    align-items: stretch;
    justify-content: flex-start
}

.fw {
    display: flex;
    flex-wrap: wrap
}

.fwr {
    display: flex;
    flex-wrap: wrap-reverse
}

.k-breadcrumb {
    display: flex;
    font-size: 14px
}

.k-collapse--title {
    display: flex;
    cursor: pointer;
    justify-content: space-between;
    color: var(--ikun-slate-900);
    font-weight: 700
}

.k-color-picker-format--val,.k-input-number--down {
    display: flex;
    cursor: pointer;
    align-items: center;
    justify-content: center
}

.k-color-picker-header {
    display: flex;
    align-items: center;
    justify-content: space-between;
    font-size: 1rem;
    line-height: 1.5rem
}

.k-descriptions-item__vertical,.k-form-item__vertical {
    display: flex;
    flex-direction: column
}

.k-drawer--footer,.k-modal--footer,.k-msg-box--footer {
    display: flex;
    align-items: center;
    padding: .5rem
}

.k-flex,.k-segmented-block,.k-steps-horizontal {
    display: flex
}

.k-input-number--up {
    display: flex;
    cursor: pointer;
    align-items: center;
    justify-content: center;
    border-left-width: 0px;
    border-top-width: 0px;
    border-bottom-width: 1px;
    border-right-width: 0px;
    border-color: var(--ikun-zinc-300);
    border-style: solid
}

.k-page-header__back {
    display: flex;
    cursor: pointer;
    align-items: center
}

.k-page-header__head {
    display: flex;
    align-items: center;
    justify-content: space-between;
    line-height: 24px
}

.k-popconfirm--title {
    display: flex;
    align-items: center;
    font-weight: 700
}

.k-slider--button {
    display: flex;
    align-items: center;
    justify-content: center;
    border-width: 2px;
    --un-border-opacity: 1;
    border-color: rgb(248 161 83 / var(--un-border-opacity));
    border-radius: 50%;
    border-style: solid;
    background-color: var(--ikun-white);
    line-height: 1
}

.k-spin--spinner__rotating {
    display: flex;
    animation: spin 1s linear infinite;
    animation-duration: 3s;
    align-items: center;
    justify-content: center
}

.k-steps-container-horizontal--nav {
    display: flex;
    flex: 1 1 0%;
    align-items: center;
    justify-content: center;
    padding-bottom: 12px
}

.k-tabs__nav--scroll {
    display: flex;
    align-items: center;
    overflow: hidden
}

.k-virtual-list--base,.k-virtual-list--wrapper {
    display: flex;
    flex-direction: row
}

.infcc,.k-link--base,.k-rate--item {
    display: inline-flex;
    align-items: center;
    justify-content: center
}

.infi {
    display: inline-flex;
    align-items: center
}

.infsc {
    display: inline-flex;
    align-items: center;
    justify-content: flex-start
}

.k-checkbox--base,.k-radio--base {
    display: inline-flex;
    cursor: pointer;
    align-items: center;
    justify-content: flex-start;
    gap: .5rem;
    color: var(--ikun-slate-900)
}

.k-segmented-item--icon {
    display: inline-flex!important;
    vertical-align: middle
}

.k-tag--icon {
    display: inline-flex
}

.k-alert--content {
    flex: 1 1 0%;
    font-size: 14px
}

.k-carousel-wrap>[data-carousel-container]>* {
    flex: 1 1 0%
}

.k-progress--content__textOutside {
    flex: 1 1 0%;
    padding-left: .5rem;
    padding-right: .5rem
}

.k-steps-container-horizontal:last-child {
    flex: none
}

.k-flex--row {
    flex-direction: row
}

.k-container--base__vertical,.k-flex--col {
    flex-direction: column
}

.k-flex--wrap-wrap {
    flex-wrap: wrap
}

.k-flex--wrap-wrap-reverse {
    flex-wrap: wrap-reverse
}

.k-flex--wrap-nowrap {
    flex-wrap: nowrap
}

.k-breadcrumb:before {
    display: table
}

.k-button-group:before {
    display: table;
    content: ""
}

.k-alert--error__animate,.k-button--error__animate {
    animation: ikun-clicking--error .3s linear 1
}

.k-alert--info__animate,.k-button--info__animate {
    animation: ikun-clicking--info .3s linear 1
}

.k-alert--success__animate,.k-button--success__animate {
    animation: ikun-clicking--success .3s linear 1
}

.k-alert--warning__animate,.k-button--warning__animate {
    animation: ikun-clicking--warning .3s linear 1
}

.k-button--main__animate,.k-select--clear__animate {
    animation: ikun-checking-main .3s linear 1
}

.k-button--primary__animate {
    animation: ikun-clicking--primary .3s linear 1
}

.k-skeleton--active {
    animation: ikun-skeleton-loading 1.4s ease infinite;
    background: linear-gradient(90deg,#0000000f 25%,#00000026 37%,#0000000f 63%);
    background-size: 400% 100%
}

.k-switch-loading {
    animation: spin 1s linear infinite
}

.k-switch-tra {
    animation: ikun-switching .3s linear 1
}

.k-timeline-item-head--pending {
    animation: spin 1s linear infinite;
    border-left-width: 0px;
    border-top-width: 2px;
    border-bottom-width: 0px;
    border-right-width: 2px;
    border-style: dashed
}

.k-rate--readonly {
    cursor: auto
}

.k-contextmenu-item--base,.k-dropdown-item--base {
    cursor: pointer;
    padding: .25rem;
    color: var(--ikun-slate-900)
}

.k-icon--role-button,.k-image__preview\ ,.k-rate--item__not-readonly,.k-step--click {
    cursor: pointer
}

.k-switch--base {
    cursor: pointer;
    border-radius: 9999px
}

.k-breadcrumb-item-link:hover {
    cursor: pointer;
    color: var(--ikun-teal-400)
}

.k-cur-loading {
    cursor: wait
}

.k-calendar-date-disabled {
    cursor: not-allowed!important;
    background-color: var(--ikun-gray-100);
    color: var(--ikun-zinc-400)
}

.k-color-picker-block-w--disabled,.k-cur-disabled,.k-input-number--icon__disabled,.k-rate--item__disabled,.k-slider--runway__disabled,.k-switch__disabled,[k-cur-disabled=""] {
    cursor: not-allowed!important
}

.k-color-picker-trigger--disabled,.k-input__disabled,.k-select--base__disabled {
    cursor: not-allowed!important;
    background-color: var(--ikun-zinc-100)
}

.k-contextmenu-item__disabled,.k-contextmenu-sub-menu__disabled,.k-dropdown-item__disabled {
    cursor: not-allowed!important;
    background-color: var(--ikun-zinc-100);
    padding: .25rem;
    color: var(--ikun-gray-400)
}

.k-form-item-label__disabled,.k-pagination-jumper__disabled,.k-pagination-pager__disabled,.k-pagination-sizes__disabled,.k-pagination-total__disabled {
    cursor: not-allowed!important;
    color: var(--ikun-zinc-400)
}

.k-rate--disabled {
    cursor: not-allowed!important;
    opacity: .6
}

.k-tabs__nav-item--disabled {
    cursor: not-allowed!important;
    opacity: .5
}

.k-input-number--icon {
    -webkit-user-select: none;
    user-select: none;
    opacity: .5
}

.k-flex--align-start,.k-row__align__top {
    align-items: flex-start
}

.k-flex--align-end,.k-row__align__bottom {
    align-items: flex-end
}

.k-flex--align-center,.k-row__align__middle {
    align-items: center
}

.k-flex--align-baseline {
    align-items: baseline
}

.k-flex--align-stretch {
    align-items: stretch
}

.k-flex--justify-start,.k-row__justify__start {
    justify-content: flex-start
}

.k-flex--justify-end,.k-row__justify__end {
    justify-content: flex-end
}

.k-flex--justify-center,.k-row__justify__center {
    justify-content: center
}

.k-flex--justify-between,.k-row__justify__between {
    justify-content: space-between
}

.k-flex--justify-around,.k-row__justify__around {
    justify-content: space-around
}

.k-flex--justify-evenly,.k-row__justify__evenly {
    justify-content: space-evenly
}

.k-flex--justify-stretch {
    justify-content: stretch
}

.k-descriptions--body--lg {
    gap: 10px
}

.k-descriptions--body--md {
    gap: 8px
}

.k-descriptions--body--sm {
    gap: 6px
}

.k-auto-complete--option__fit,.k-select--option__fit {
    overflow: hidden;
    text-overflow: ellipsis
}

.k-card {
    overflow: hidden;
    border-width: 1px;
    border-color: var(--ikun-zinc-300);
    border-radius: .25rem;
    border-style: solid;
    background-color: var(--ikun-white);
    color: var(--ikun-slate-900)
}

.k-scrollbar {
    overflow: auto
}

.k-steps-label-container-vertical {
    overflow: visible;
    padding-inline-start:0}

.k-dropdown-item-container {
    overflow-y: auto;
    padding-left: .5rem!important;
    padding-right: .5rem!important
}

.k-step {
    white-space: nowrap
}

.k-step-description {
    white-space: normal;
    font-size: 14px
}

.k-form-item-label {
    word-break: break-all;
    font-size: .875rem;
    line-height: 1.25rem;
    color: var(--ikun-slate-900)
}

.k-border {
    border-width: 1px;
    border-style: solid
}

.k-collapse--base {
    border-width: 1px;
    border-color: var(--ikun-zinc-300);
    border-radius: .25rem;
    border-style: solid;
    padding: 1rem
}

.k-collapse-wrapper--base {
    border-width: 1px;
    border-color: var(--ikun-zinc-300);
    border-radius: .25rem;
    border-style: solid
}

.k-dropdown {
    border-width: 0px;
    background-color: transparent;
    padding: 0;
    line-height: 1
}

.k-skeleton-button {
    border-width: 0px;
    outline: 2px solid transparent;
    outline-offset: 2px
}

.k-tag--error__border {
    border-width: 1px;
    border-color: var(--ikun-rose-400);
    border-style: solid
}

.k-tag--info__border {
    border-width: 1px;
    border-color: var(--ikun-gray-400);
    border-style: solid
}

.k-tag--primary__border {
    border-width: 1px;
    border-color: var(--ikun-teal-400);
    border-style: solid
}

.k-tag--success__border {
    border-width: 1px;
    border-color: var(--ikun-green-400);
    border-style: solid
}

.k-tag--warning__border {
    border-width: 1px;
    border-color: var(--ikun-amber-400);
    border-style: solid
}

.k-collapse--base--wrapper {
    border-left-width: 0px;
    border-right-width: 0px;
    border-bottom-width: 1px;
    border-top-width: 0px;
    border-color: var(--ikun-zinc-300);
    border-style: solid;
    padding: 1rem
}

.bd-1 {
    border-top-width: 1px;
    border-left-width: 1px;
    border-bottom-width: 1px;
    border-right-width: 1px
}

.bd-2 {
    border-top-width: 2px;
    border-left-width: 2px;
    border-bottom-width: 2px;
    border-right-width: 2px
}

.bd-3 {
    border-top-width: 3px;
    border-left-width: 3px;
    border-bottom-width: 3px;
    border-right-width: 3px
}

.bdb-1 {
    border-left-width: 0px;
    border-top-width: 0px;
    border-bottom-width: 1px;
    border-right-width: 0px
}

.bdl-1 {
    border-left-width: 1px;
    border-top-width: 0px;
    border-bottom-width: 0px;
    border-right-width: 0px
}

.bdl-2 {
    border-left-width: 2px;
    border-top-width: 0px;
    border-bottom-width: 0px;
    border-right-width: 0px
}

.bdlb-1 {
    border-left-width: 1px;
    border-top-width: 0px;
    border-bottom-width: 1px;
    border-right-width: 0px
}

.bdt-1 {
    border-top-width: 1px;
    border-left-width: 0px;
    border-bottom-width: 0px;
    border-right-width: 0px
}

.bdtb-1 {
    border-left-width: 0px;
    border-top-width: 1px;
    border-bottom-width: 1px;
    border-right-width: 0px
}

.bdtr-1 {
    border-left-width: 0px;
    border-top-width: 1px;
    border-bottom-width: 0px;
    border-right-width: 1px
}

.bdtr-2 {
    border-left-width: 0px;
    border-top-width: 2px;
    border-bottom-width: 0px;
    border-right-width: 2px
}

.k-card--header {
    border-bottom-width: 1px;
    border-bottom-color: inherit;
    border-bottom-style: solid;
    padding: 1rem
}

.k-descriptions--body--border {
    border-bottom-width: 1px;
    border-right-width: 1px;
    border-bottom-color: var(--ikun-zinc-300);
    border-right-color: var(--ikun-zinc-300);
    border-bottom-style: solid;
    border-right-style: solid
}

.k-descriptions-item--border {
    border-top-width: 1px;
    border-left-width: 1px;
    border-top-color: var(--ikun-zinc-300);
    border-left-color: var(--ikun-zinc-300);
    border-top-style: solid;
    border-left-style: solid
}

.k-descriptions-item--content--lg--border {
    border-top-width: 1px;
    border-top-color: var(--ikun-zinc-300);
    border-top-style: solid;
    padding: 12px 15px!important
}

.k-descriptions-item--content--md--border {
    border-top-width: 1px;
    border-top-color: var(--ikun-zinc-300);
    border-top-style: solid;
    padding: 8px 11px!important
}

.k-descriptions-item--content--sm--border {
    border-top-width: 1px;
    border-top-color: var(--ikun-zinc-300);
    border-top-style: solid;
    padding: 4px 7px!important
}

.k-descriptions-item--label--lg--border {
    border-right-width: 1px;
    border-right-color: var(--ikun-zinc-300);
    border-right-style: solid;
    background-color: var(--ikun-light-700);
    padding: 12px 15px!important
}

.k-descriptions-item--label--md--border {
    border-right-width: 1px;
    border-right-color: var(--ikun-zinc-300);
    border-right-style: solid;
    background-color: var(--ikun-light-700);
    padding: 8px 11px!important
}

.k-descriptions-item--label--sm--border {
    border-right-width: 1px;
    border-right-color: var(--ikun-zinc-300);
    border-right-style: solid;
    background-color: var(--ikun-light-700);
    padding: 4px 7px!important
}

.k-tabs__add--wrap--border {
    border-left-width: 0px;
    border-top-width: 1px;
    border-bottom-width: 0px;
    border-right-width: 1px;
    border-color: var(--ikun-zinc-300);
    border-top-right-radius: .25rem;
    border-style: solid
}

.k-tabs__content--border {
    border-left-width: 1px;
    border-top-width: 0px;
    border-bottom-width: 1px;
    border-right-width: 1px;
    border-color: var(--ikun-zinc-300);
    border-bottom-left-radius: .25rem;
    border-bottom-right-radius: .25rem;
    border-style: solid
}

.k-tabs__nav--wrap--border {
    border-left-width: 1px;
    border-top-width: 1px;
    border-bottom-width: 0px;
    border-right-width: 1px;
    border-color: var(--ikun-zinc-300);
    border-top-left-radius: .25rem;
    border-style: solid
}

.k-tabs__nav--wrap--card {
    border-left-width: 1px;
    border-top-width: 1px;
    border-bottom-width: 0px;
    border-right-width: 1px;
    border-color: var(--ikun-zinc-300);
    border-top-left-radius: .25rem;
    border-top-right-radius: .25rem;
    border-style: solid
}

.k-tabs__nav-item--card {
    border-left-width: 1px;
    border-top-width: 0px;
    border-bottom-width: 0px;
    border-right-width: 0px;
    border-color: var(--ikun-zinc-300);
    border-style: solid
}

.n-bdb-1 {
    border-left-width: 1px;
    border-top-width: 1px;
    border-bottom-width: 0px;
    border-right-width: 1px
}

.n-bdl-1 {
    border-left-width: 0px;
    border-top-width: 1px;
    border-bottom-width: 1px;
    border-right-width: 1px
}

.n-bdt-1 {
    border-left-width: 1px;
    border-top-width: 0px;
    border-bottom-width: 1px;
    border-right-width: 1px
}

.dark .k-badge--content__dark {
    border-color: var(--ikun-dark-50)
}

.k-button--error {
    border-color: var(--ikun-rose-100);
    background-color: var(--ikun-rose-100);
    color: var(--ikun-rose-400)
}

.k-button--error__border {
    border-color: var(--ikun-rose-400)
}

.k-button--error__fill {
    border-color: var(--ikun-rose-400);
    background-color: var(--ikun-rose-400);
    color: var(--ikun-rose-100)
}

.k-button--info {
    border-color: var(--ikun-gray-100);
    background-color: var(--ikun-gray-100);
    color: var(--ikun-gray-400)
}

.k-button--info__border {
    border-color: var(--ikun-gray-400)
}

.k-button--info__fill {
    border-color: var(--ikun-gray-400);
    background-color: var(--ikun-gray-400);
    color: var(--ikun-gray-100)
}

.k-button--info__ghost {
    border-color: var(--ikun-zinc-300);
    --un-bg-opacity: 1;
    background-color: rgb(255 255 255 / var(--un-bg-opacity));
    color: var(--ikun-slate-900)
}

.dark .k-button--info__ghost--dark {
    border-color: var(--ikun-zinc-300);
    background-color: transparent;
    color: var(--ikun-zinc-300)
}

.k-button--main__border,.k-calendar-date-v {
    --un-border-opacity: 1;
    border-color: rgb(248 161 83 / var(--un-border-opacity))
}

.k-button--primary {
    border-color: var(--ikun-teal-100);
    background-color: var(--ikun-teal-100);
    color: var(--ikun-teal-400)
}

.k-button--primary__border {
    border-color: var(--ikun-teal-400)
}

.k-button--primary__fill {
    border-color: var(--ikun-teal-400);
    background-color: var(--ikun-teal-400);
    color: var(--ikun-teal-100)
}

.k-button--success {
    border-color: var(--ikun-green-100);
    background-color: var(--ikun-green-100);
    color: var(--ikun-green-400)
}

.k-button--success__border {
    border-color: var(--ikun-green-400)
}

.k-button--success__fill {
    border-color: var(--ikun-green-400);
    background-color: var(--ikun-green-400);
    color: var(--ikun-green-100)
}

.k-button--warning {
    border-color: var(--ikun-amber-100);
    background-color: var(--ikun-amber-100);
    color: var(--ikun-amber-400)
}

.k-button--warning__border {
    border-color: var(--ikun-amber-400)
}

.k-button--warning__fill {
    border-color: var(--ikun-amber-400);
    background-color: var(--ikun-amber-400);
    color: var(--ikun-amber-100)
}

.dark .k-card__dark {
    border-color: var(--ikun-dark-50);
    background-color: var(--ikun-dark-300);
    color: var(--ikun-white)
}

.k-color-picker-block-w--error,.k-input__error,.k-select__error {
    border-color: var(--ikun-rose-400);
    box-shadow: 0 0 0 2px #fb718580
}

.k-color-picker-block-w--focus {
    --un-border-opacity: 1;
    border-color: rgb(248 161 83 / var(--un-border-opacity));
    box-shadow: 0 0 0 2px #ff787542
}

.k-radio__selected {
    --un-border-opacity: 1;
    border-color: rgb(248 161 83 / var(--un-border-opacity));
    --un-bg-opacity: 1;
    background-color: rgb(248 161 83 / var(--un-bg-opacity))
}

.k-step-icon--click {
    --un-border-opacity: 1;
    border-color: rgb(248 161 83 / var(--un-border-opacity));
    --un-text-opacity: 1;
    color: rgb(248 161 83 / var(--un-text-opacity))
}

.k-input__focus:focus-within {
    --un-border-opacity: 1;
    border-color: rgb(248 161 83 / var(--un-border-opacity));
    box-shadow: 0 0 0 2px #f8a1534d
}

.k-select__focus:focus-within {
    --un-border-opacity: 1;
    border-color: rgb(248 161 83 / var(--un-border-opacity));
    box-shadow: 0 0 0 2px #f8a1534d
}

.k-button--error__hover:hover {
    border-color: var(--ikun-rose-400)
}

.k-button--error__hover__fill:hover {
    border-color: var(--ikun-rose-500);
    background-color: var(--ikun-rose-500)
}

.k-button--info__hover:hover {
    border-color: var(--ikun-gray-400)
}

.k-button--info__hover__fill:hover {
    border-color: var(--ikun-gray-500);
    background-color: var(--ikun-gray-500)
}

.k-button--main__hover:hover {
    --un-border-opacity: 1;
    border-color: rgb(248 161 83 / var(--un-border-opacity))
}

.k-button--primary__hover:hover {
    border-color: var(--ikun-teal-400)
}

.k-button--primary__hover__fill:hover {
    border-color: var(--ikun-teal-500);
    background-color: var(--ikun-teal-500)
}

.k-button--success__hover:hover {
    border-color: var(--ikun-green-400)
}

.k-button--success__hover__fill:hover {
    border-color: var(--ikun-green-500);
    background-color: var(--ikun-green-500)
}

.k-button--warning__hover:hover {
    border-color: var(--ikun-amber-400)
}

.k-button--warning__hover__fill:hover {
    border-color: var(--ikun-amber-500);
    background-color: var(--ikun-amber-500)
}

.k-color-picker-block-w:hover,.k-input__hover:hover,.k-select__hover:hover {
    --un-border-opacity: 1;
    border-color: rgb(248 161 83 / var(--un-border-opacity))
}

.k-button--error__focus:focus-visible {
    border-color: var(--ikun-rose-400);
    box-shadow: 0 0 0 2px #fb718580
}

.k-button--info__focus:focus-visible {
    border-color: var(--ikun-gray-400);
    box-shadow: 0 0 0 2px #94a3b880
}

.k-button--main__focus:focus-visible {
    --un-border-opacity: 1;
    border-color: rgb(248 161 83 / var(--un-border-opacity));
    box-shadow: 0 0 0 2px #f8a15380
}

.k-button--primary__focus:focus-visible {
    border-color: var(--ikun-teal-400);
    box-shadow: 0 0 0 2px #2dd4bf80
}

.k-button--success__focus:focus-visible {
    border-color: var(--ikun-green-400);
    box-shadow: 0 0 0 2px #4ade8080
}

.k-button--warning__focus:focus-visible {
    border-color: var(--ikun-amber-400);
    box-shadow: 0 0 0 2px #fbbf2480
}

.k-alert--error__close-icon:active {
    border-color: var(--ikun-rose-400);
    box-shadow: 0 0 0 2px #fb718580
}

.k-alert--info__close-icon:active {
    border-color: var(--ikun-gray-500);
    box-shadow: 0 0 0 2px #94a3b880
}

.k-alert--success__close-icon:active {
    border-color: var(--ikun-green-400);
    box-shadow: 0 0 0 2px #4ade8080
}

.k-alert--warning__close-icon:active {
    border-color: var(--ikun-amber-400);
    box-shadow: 0 0 0 2px #fbbf2480
}

.k-button--error__active:active {
    border-color: var(--ikun-rose-400);
    box-shadow: 0 0 0 2px #fb718580
}

.k-button--info__active:active {
    border-color: var(--ikun-gray-400);
    box-shadow: 0 0 0 2px #94a3b880
}

.k-button--main__active:active {
    --un-border-opacity: 1;
    border-color: rgb(248 161 83 / var(--un-border-opacity));
    box-shadow: 0 0 0 2px #f8a15380
}

.k-button--primary__active:active {
    border-color: var(--ikun-teal-400);
    box-shadow: 0 0 0 2px #2dd4bf80
}

.k-button--success__active:active {
    border-color: var(--ikun-green-400);
    box-shadow: 0 0 0 2px #4ade8080
}

.k-button--warning__active:active {
    border-color: var(--ikun-amber-400);
    box-shadow: 0 0 0 2px #fbbf2480
}

.k-tag--error__close-icon:active {
    border-color: var(--ikun-rose-400);
    box-shadow: 0 0 0 2px #fb718580
}

.k-tag--info__close-icon:active {
    border-color: var(--ikun-gray-400);
    box-shadow: 0 0 0 2px #94a3b880
}

.k-tag--primary__close-icon:active {
    border-color: var(--ikun-teal-400);
    box-shadow: 0 0 0 2px #2dd4bf80
}

.k-tag--success__close-icon:active {
    border-color: var(--ikun-green-400);
    box-shadow: 0 0 0 2px #4ade8080
}

.k-tag--warning__close-icon:active {
    border-color: var(--ikun-amber-400);
    box-shadow: 0 0 0 2px #fbbf2480
}

.k-button-group>.k-button--base:not(:first-child):not(:last-child) {
    border-radius: 0!important
}

.k-input__rounded {
    border-radius: .25rem
}

.k-input--inner__textarea {
    border-radius: .25rem;
    background-color: transparent;
    padding: .5rem
}

.k-skeleton-avatar--circle,.k-skeleton-paragraph--round,.k-skeleton-title--round {
    border-radius: 9999px
}

.k-skeleton-avatar--round,.k-skeleton-button--round,.k-skeleton-title {
    border-radius: 4px
}

.k-skeleton-avatar--square,.k-skeleton-button--square {
    border-radius: 0
}

.k-alert--error__close-icon:hover {
    border-radius: 50%;
    background-color: var(--ikun-rose-400);
    color: var(--ikun-white)
}

.k-alert--info__close-icon:hover {
    border-radius: 50%;
    background-color: var(--ikun-gray-500);
    color: var(--ikun-white)
}

.k-alert--success__close-icon:hover {
    border-radius: 50%;
    background-color: var(--ikun-green-400);
    color: var(--ikun-white)
}

.k-alert--warning__close-icon:hover {
    border-radius: 50%;
    background-color: var(--ikun-amber-400);
    color: var(--ikun-white)
}

.k-tabs__close--hover:hover {
    border-radius: 9999px;
    --un-bg-opacity: 1;
    background-color: rgb(248 161 83 / var(--un-bg-opacity));
    --un-text-opacity: 1;
    color: rgb(255 255 255 / var(--un-text-opacity))
}

.k-tag--error__close-icon:hover {
    border-radius: 50%;
    background-color: var(--ikun-rose-400)
}

.k-tag--info__close-icon:hover {
    border-radius: 50%;
    background-color: var(--ikun-gray-400)
}

.k-tag--primary__close-icon:hover {
    border-radius: 50%;
    background-color: var(--ikun-teal-400)
}

.k-tag--success__close-icon:hover {
    border-radius: 50%;
    background-color: var(--ikun-green-400)
}

.k-tag--warning__close-icon:hover {
    border-radius: 50%;
    background-color: var(--ikun-amber-400)
}

.k-button-group>.k-button--base:first-child {
    border-top-right-radius: 0!important;
    border-bottom-right-radius: 0!important
}

.k-button-group>.k-button--base:last-child {
    border-top-left-radius: 0!important;
    border-bottom-left-radius: 0!important
}

.k-input__rounded__left {
    border-top-left-radius: .25rem;
    border-bottom-left-radius: .25rem
}

.k-input__rounded__right {
    border-top-right-radius: .25rem;
    border-bottom-right-radius: .25rem
}

.k-input--append {
    border-top-right-radius: .25rem!important;
    border-bottom-right-radius: .25rem!important;
    border-top-left-radius: 0!important;
    border-bottom-left-radius: 0!important
}

.k-input--prepend {
    border-top-left-radius: .25rem!important;
    border-bottom-left-radius: .25rem!important;
    border-top-right-radius: 0!important;
    border-bottom-right-radius: 0!important
}

.k-divider--vertical__dashed,.k-timeline-item-tail--pending {
    border-style: dashed
}

.k-divider--vertical__dotted {
    border-style: dotted
}

.k-divider--vertical__double {
    border-style: double
}

.k-divider--vertical__groove {
    border-style: groove
}

.k-divider--vertical__inset {
    border-style: inset
}

.k-divider--vertical__outset {
    border-style: outset
}

.k-divider--vertical__ridge {
    border-style: ridge
}

.k-divider--vertical__solid {
    border-style: solid
}

.k-tour-mask {
    border-style: solid;
    --ikun-context-border-color: rgba(0,0,0,.5);
    border-color: var(--ikun-context-border-color)
}

.k-divider--horizontal__dashed:before {
    border-style: dashed
}

.k-divider--horizontal__dotted:before {
    border-style: dotted
}

.k-divider--horizontal__double:before {
    border-style: double
}

.k-divider--horizontal__groove:before {
    border-style: groove
}

.k-divider--horizontal__inset:before {
    border-style: inset
}

.k-divider--horizontal__outset:before {
    border-style: outset
}

.k-divider--horizontal__ridge:before {
    border-style: ridge
}

.k-divider--horizontal__solid:before {
    border-style: solid
}

.k-divider--horizontal__dashed:after {
    border-style: dashed
}

.k-divider--horizontal__dotted:after {
    border-style: dotted
}

.k-divider--horizontal__double:after {
    border-style: double
}

.k-divider--horizontal__groove:after {
    border-style: groove
}

.k-divider--horizontal__inset:after {
    border-style: inset
}

.k-divider--horizontal__outset:after {
    border-style: outset
}

.k-divider--horizontal__ridge:after {
    border-style: ridge
}

.k-divider--horizontal__solid:after {
    border-style: solid
}

.k-descriptions-item--label__vertical {
    border-right-style: none
}

.k-alert--error,.k-tag--error {
    background-color: var(--ikun-rose-100);
    color: var(--ikun-rose-400)
}

.k-alert--info,.k-tag--info {
    background-color: var(--ikun-gray-100);
    color: var(--ikun-gray-400)
}

.k-alert--success,.k-tag--success {
    background-color: var(--ikun-green-100);
    color: var(--ikun-green-400)
}

.k-alert--warning,.k-tag--warning {
    background-color: var(--ikun-amber-100);
    color: var(--ikun-amber-400)
}

.dark .k-avatar__dark,.k-skeleton-avatar,.k-skeleton-button-un--active,.k-skeleton-image-un--active,.k-skeleton-title-un--active {
    background-color: var(--ikun-light-700)
}

.dark .k-backtop__dark,.dark .k-contextmenu--base__dark,.dark .k-contextmenu-sub-menu-item__dark,.dark .k-drawer--base__dark,.dark .k-input__dark,.dark .k-pagination-pager__disabled__bg__dark,.dark .k-progress--base__dark,.dark .k-select--base__dark,.dark .k-skeleton-avatar__dark,.dark .k-skeleton-button-un--active__dark,.dark .k-skeleton-image-un--active__dark,.dark .k-skeleton-input__dark,.dark .k-skeleton-paragraph--item__dark,.dark .k-skeleton-title-un--active__dark,.dark .k-tabs__header--border--dark,.dark [k-skeleton-avatar__dark=""],.dark [k-skeleton-button-un--active__dark=""],.dark [k-skeleton-image-un--active__dark=""],.dark [k-skeleton-input__dark=""] {
    background-color: var(--ikun-dark-300)
}

.k-badge--content-error {
    background-color: var(--ikun-rose-400)
}

.k-badge--content-info {
    background-color: var(--ikun-gray-400)
}

.k-badge--content-primary {
    background-color: var(--ikun-teal-400)
}

.k-badge--content-success {
    background-color: var(--ikun-green-400)
}

.k-badge--content-warning {
    background-color: var(--ikun-amber-400)
}

.k-bg-disabled,.k-checkbox--box__disabled,.k-pagination-pager__disabled__bg,.k-radio--box__disabled,.k-slider--disabled {
    background-color: var(--ikun-zinc-100)
}

.k-button--error__ghost {
    --un-bg-opacity: 1;
    background-color: rgb(255 255 255 / var(--un-bg-opacity));
    color: var(--ikun-rose-400)
}

.k-button--main__ghost,.k-tabs__nav-item--active {
    --un-bg-opacity: 1;
    background-color: rgb(255 255 255 / var(--un-bg-opacity));
    --un-text-opacity: 1;
    color: rgb(248 161 83 / var(--un-text-opacity))
}

.dark .k-button--main__ghost--dark,.dark .k-calendar--dark,.dark .k-calendar-panel--dark {
    background-color: transparent
}

.k-button--primary__ghost {
    --un-bg-opacity: 1;
    background-color: rgb(255 255 255 / var(--un-bg-opacity));
    color: var(--ikun-teal-400)
}

.k-button--success__ghost {
    --un-bg-opacity: 1;
    background-color: rgb(255 255 255 / var(--un-bg-opacity));
    color: var(--ikun-green-400)
}

.k-button--warning__ghost {
    --un-bg-opacity: 1;
    background-color: rgb(255 255 255 / var(--un-bg-opacity));
    color: var(--ikun-amber-400)
}

.k-calendar-date-s-card {
    --un-bg-opacity: 1;
    background-color: rgb(248 161 83 / var(--un-bg-opacity));
    color: var(--ikun-white)
}

.dark .k-descriptions-item--label--lg--border,.dark .k-descriptions-item--label--md--border,.dark .k-descriptions-item--label--sm--border {
    background-color: var(--ikun-dark-100)
}

.k-dropdown-item-container__dark {
    --un-bg-opacity: 1;
    background-color: rgb(255 255 255 / var(--un-bg-opacity));
    padding-left: .5rem!important;
    padding-right: .5rem!important
}

.dark .k-input__disabled__dark,.dark .k-select--base__disabled__dark,.dark .k-select--inner__disabled__dark {
    background-color: var(--ikun-dark-50);
    color: var(--ikun-white)
}

.dark .k-input--inner__dark,.dark .k-pagination-pager__bg__dark,.dark .k-popover--base__dark,.dark .k-select--inner__dark {
    background-color: var(--ikun-dark-300);
    color: var(--ikun-white)
}

.dark .k-modal--base__dark,.dark .k-msg-box--base__dark {
    background-color: var(--ikun-dark-300);
    --un-shadow: var(--un-shadow-inset) 0 1px 3px 0 var(--un-shadow-color, rgb(0 0 0 / .1)),var(--un-shadow-inset) 0 1px 2px -1px var(--un-shadow-color, rgb(0 0 0 / .1));
    box-shadow: var(--un-ring-offset-shadow),var(--un-ring-shadow),var(--un-shadow);
    --un-shadow-opacity: 1;
    --un-shadow-color: rgb(248 161 83 / var(--un-shadow-opacity))
}

.dark .k-notification--base__dark,.dark [k-notification--base__dark=""] {
    background-color: var(--ikun-dark-300);
    --un-shadow-opacity: 1;
    --un-shadow-color: rgb(248 161 83 / var(--un-shadow-opacity))
}

.k-pagination-pager__bg {
    background-color: var(--ikun-slate-100)
}

.k-pagination-pager__bg__active,.k-step-icon--process {
    --un-bg-opacity: 1;
    background-color: rgb(248 161 83 / var(--un-bg-opacity));
    --un-text-opacity: 1;
    color: rgb(255 255 255 / var(--un-text-opacity))
}

.k-progress--error {
    background-color: var(--ikun-rose-400);
    color: var(--ikun-rose-100)
}

.k-progress--info {
    background-color: var(--ikun-gray-400);
    color: var(--ikun-gray-100)
}

.k-progress--primary {
    background-color: var(--ikun-teal-400);
    color: var(--ikun-teal-100)
}

.k-progress--success {
    background-color: var(--ikun-green-400);
    color: var(--ikun-green-100)
}

.k-progress--warning {
    background-color: var(--ikun-amber-400);
    color: var(--ikun-amber-100)
}

.dark .k-segmented__dark {
    background-color: var(--ikun-dark-50);
    --un-text-opacity: 1;
    color: rgb(255 255 255 / var(--un-text-opacity))
}

.dark .k-segmented-item--active__dark {
    background-color: var(--ikun-dark-400)
}

.dark .k-skeleton-image--icon__dark {
    background-color: var(--ikun-stone-400)
}

.k-step-icon--error {
    background-color: var(--ikun-rose-400);
    --un-text-opacity: 1;
    color: rgb(255 255 255 / var(--un-text-opacity))
}

.k-step-icon--wait-bg {
    background-color: var(--ikun-neutral-200)
}

.k-switch__checked {
    --un-bg-opacity: 1;
    background-color: rgb(248 161 83 / var(--un-bg-opacity))
}

.dark .k-tabs__content--border--dark,.dark .k-tabs__nav-item--border--active--dark {
    background-color: var(--ikun-dark-500)
}

.dark .k-tabs__nav-item--active--dark {
    background-color: transparent;
    --un-text-opacity: 1;
    color: rgb(248 161 83 / var(--un-text-opacity))
}

.k-tag--primary {
    background-color: var(--ikun-teal-100);
    color: var(--ikun-teal-400)
}

.k-button--main__hover__fill:hover {
    --un-bg-opacity: 1;
    background-color: rgb(248 161 83 / var(--un-bg-opacity))
}

.k-calendar-date-hover:hover {
    background-color: var(--ikun-gray-100)
}

.dark .k-calendar-date-hover--dark:hover {
    background-color: var(--ikun-dark-300)
}

.k-contextmenu-item--base:hover {
    --un-bg-opacity: 1;
    background-color: rgb(248 161 83 / var(--un-bg-opacity));
    --un-text-opacity: 1;
    color: rgb(255 255 255 / var(--un-text-opacity))
}

.k-contextmenu-sub-menu__disabled:hover {
    background-color: var(--ikun-zinc-100)!important;
    color: var(--ikun-gray-400)!important
}

.k-contextmenu-sub-menu--base:hover,.k-dropdown-item--base:hover {
    --un-bg-opacity: 1;
    background-color: rgb(248 161 83 / var(--un-bg-opacity));
    --un-text-opacity: 1;
    color: rgb(255 255 255 / var(--un-text-opacity))
}

.k-segmented-item:hover {
    background-color: var(--ikun-neutral-200)
}

.dark .k-segmented-item__dark:hover {
    background-color: var(--ikun-dark-200)
}

.k-segmented-item--active:hover {
    --un-bg-opacity: 1;
    background-color: rgb(255 255 255 / var(--un-bg-opacity))
}

.dark .k-segmented-item--active__dark:hover {
    background-color: var(--ikun-dark-400)
}

.k-tour-close:hover {
    background-color: var(--ikun-slate-100)
}

.k-segmented-item:active {
    background-color: var(--ikun-neutral-300)
}

.dark .k-segmented-item__dark:active {
    background-color: var(--ikun-dark-300)
}

.k-segmented-item--active:active {
    --un-bg-opacity: 1;
    background-color: rgb(255 255 255 / var(--un-bg-opacity))
}

.dark .k-segmented-item--active__dark:active {
    background-color: var(--ikun-dark-400)
}

.k-step-tail--finish:after {
    --un-bg-opacity: 1;
    background-color: rgb(248 161 83 / var(--un-bg-opacity))
}

.k-step-tail--none:after {
    background-color: transparent
}

.k-empty__nd--border {
    fill: var(--ikun-slate-900)
}

.dark .k-empty__nd--border__dark,.dark .k-empty__nd--content__dark,.dark .k-empty__nd--point__dark {
    fill: var(--ikun-dark-50)
}

.k-empty__nd--color,.k-empty__nd--color__dark {
    --un-fill-opacity: 1;
    fill: rgb(248 161 83 / var(--un-fill-opacity))
}

.k-empty__nd--content {
    fill: var(--ikun-stone-200)
}

.k-empty__nd--point {
    --un-fill-opacity: 1;
    fill: rgb(255 255 255 / var(--un-fill-opacity))
}

.k-progress--stroke--error {
    stroke: var(--ikun-rose-400)
}

.k-progress--stroke--info {
    stroke: var(--ikun-gray-400)
}

.k-progress--stroke--primary {
    stroke: var(--ikun-teal-400)
}

.k-progress--stroke--runway {
    stroke: var(--ikun-light-500)
}

.dark .k-progress--stroke--runway__dark {
    stroke: var(--ikun-dark-300)
}

.k-progress--stroke--success {
    stroke: var(--ikun-green-400)
}

.k-progress--stroke--warning {
    stroke: var(--ikun-amber-400)
}

.k-card--body {
    padding: 1rem
}

.k-modal--body,.k-msg-box--body,[k-modal--body=""] {
    padding: .5rem
}

.k-divider--content {
    padding-left: 1rem;
    padding-right: 1rem;
    text-wrap: nowrap;
    font-size: 14px;
    font-weight: 500
}

.k-progress--content__textInside {
    padding-left: .5rem;
    padding-right: .5rem;
    text-align: right
}

.k-descriptions-item--label__horizontal--lg {
    padding-right: 12px
}

.k-descriptions-item--label__horizontal--md {
    padding-right: 10px
}

.k-descriptions-item--label__horizontal--sm {
    padding-right: 8px
}

.k-descriptions-item--label__vertical--lg {
    padding-bottom: 12px
}

.k-descriptions-item--label__vertical--md {
    padding-bottom: 10px
}

.k-descriptions-item--label__vertical--sm {
    padding-bottom: 8px
}

.k-skeleton-paragraph {
    padding-left: 0
}

.k-skeleton-pd--lg {
    padding-left: 96px
}

.k-skeleton-pd--md {
    padding-left: 78px
}

.k-skeleton-pd--sm {
    padding-left: 64px
}

.k-steps-container-horizontal:first-child {
    padding-inline-start:0}

.k-form-item-label__center {
    text-align: center
}

.k-form-item-label__left,.k-timeline-item-c__left {
    text-align: left
}

.k-timeline-item-content--cr,.k-timeline-item-label--cr {
    text-align: left;
    inset-inline-start: calc(50% - 12px);
    width: calc(50% - 12px)
}

.k-form-item-label__right,.k-timeline-item-c__right {
    text-align: right
}

.k-checkbox--label,.k-radio--label {
    font-size: 1rem;
    line-height: 1.5rem
}

.k-descriptions--lg,.k-descriptions-item--lg,.k-form-item-label__lg,.k-select--inner__lg {
    font-size: 16px
}

.k-descriptions--md,.k-descriptions-item--md,.k-form-item-label__md,.k-select--inner__md {
    font-size: 14px
}

.k-descriptions--sm,.k-descriptions-item--sm,.k-form-item-label__sm,.k-select--inner__sm {
    font-size: 12px
}

.k-divider {
    font-size: 0
}

.k-modal--header--title {
    font-size: 1.125rem;
    line-height: 1.75rem;
    color: var(--ikun-slate-900);
    font-weight: 700
}

.k-page-header__content {
    font-size: 18px;
    color: var(--ikun-slate-900)
}

.k-page-header__title {
    font-size: 14px;
    font-weight: 500
}

.k-statistic__content {
    font-size: 1rem;
    line-height: 1.5rem;
    color: var(--ikun-slate-900)
}

.k-divider:before {
    font-size: 0;
    content: ""
}

.k-divider:after {
    font-size: 0;
    content: ""
}

.k-alert--error__icon-color,.k-button--error__icon,.k-link--error,.k-msg-box--error,.k-notification--error,.k-popconfirm--error,.k-step-description--error,.k-step-title--error,.k-tag--error__icon {
    color: var(--ikun-rose-400)
}

.k-alert--info__icon-color,.k-button--info__icon,.k-link--info,.k-msg-box--info,.k-notification--info,.k-popconfirm--info,.k-tag--info__icon {
    color: var(--ikun-gray-400)
}

.k-alert--success__icon-color,.k-button--success__icon,.k-link--success,.k-msg-box--success,.k-notification--success,.k-popconfirm--success,.k-tag--success__icon {
    color: var(--ikun-green-400)
}

.k-alert--warning__icon-color,.k-button--warning__icon,.k-link--warning,.k-msg-box--warning,.k-notification--warning,.k-popconfirm--warning,.k-tag--warning__icon {
    color: var(--ikun-amber-400)
}

.dark .k-carousel-arrow-icon--dark>span:hover,.dark .k-tabs__add--dark>span:hover,.dark .k-tabs__close--dark>span,.dark .k-tabs__next--dark>span:hover,.dark .k-tabs__prev--dark>span:hover,.k-auto-complete--option__active,.k-button--main__icon,.k-collapse--title__active,.k-pagination-pager__active,.k-select--option__active,.k-step-description--click,.k-step-title--click {
    --un-text-opacity: 1;
    color: rgb(248 161 83 / var(--un-text-opacity))
}

.dark .k-auto-complete--option__dark,.dark .k-calendar-thead--dark,.dark .k-calendar-thead-card--dark,.dark .k-checkbox--base__dark,.dark .k-collapse--title__dark,.dark .k-color-picker-format--val__dark,.dark .k-color-picker-txt__dark,.dark .k-contextmenu-item--base__dark,.dark .k-contextmenu-sub-menu--base__dark,.dark .k-descriptions__dark,.dark .k-descriptions-item__dark,.dark .k-dropdown-item--base__dark,.dark .k-form-item-label__dark,.dark .k-icon--base__dark,.dark .k-modal--header--title__dark,.dark .k-msg-box--header--title__dark,.dark .k-notification--title__dark,.dark .k-pagination-jumper__dark,.dark .k-pagination-pager__dark,.dark .k-pagination-total__dark,.dark .k-radio--base__dark,.dark .k-select--option__dark,.dark .k-tabs__nav-item--dark,.dark .k-timeline-item-content--dark,.dark .k-timeline-item-label--dark {
    color: var(--ikun-white)
}

.k-button--error__icon__fill {
    color: var(--ikun-rose-100)
}

.k-button--info__icon__fill {
    color: var(--ikun-gray-100)
}

.k-button--main {
    --un-text-opacity: 1;
    color: rgb(248 161 83 / var(--un-text-opacity));
    --ikun-context-background-color: rgba(248,161,83,.4);
    background-color: var(--ikun-context-background-color);
    --ikun-context-border-color: rgba(248,161,83,.4);
    border-color: var(--ikun-context-border-color)
}

.k-button--main__fill {
    --un-text-opacity: 1;
    color: rgb(255 255 255 / var(--un-text-opacity));
    --ikun-context-background-color: rgba(248,161,83,.9);
    background-color: var(--ikun-context-background-color);
    --ikun-context-border-color: rgba(248,161,83,.9);
    border-color: var(--ikun-context-border-color)
}

.dark .k-tabs__close--hover--dark:hover>span,.k-button--main__icon__fill {
    --un-text-opacity: 1;
    color: rgb(255 255 255 / var(--un-text-opacity))
}

.k-button--primary__icon,.k-link--primary,.k-tag--primary__icon {
    color: var(--ikun-teal-400)
}

.k-button--primary__icon__fill {
    color: var(--ikun-teal-100)
}

.k-button--success__icon__fill {
    color: var(--ikun-green-100)
}

.k-button--warning__icon__fill {
    color: var(--ikun-amber-100)
}

.dark .k-pagination-pager__disabled__dark>span,.k-calendar-date-not,.k-step-description--no-process,.k-step-icon--wait,.k-step-title--wait {
    color: var(--ikun-zinc-400)
}

.k-calendar-date-s,.k-step-icon--finish {
    --un-text-opacity: 1;
    color: rgb(248 161 83 / var(--un-text-opacity));
    --ikun-context-background-color: rgba(248,161,83,.2);
    background-color: var(--ikun-context-background-color)
}

.dark .k-carousel-arrow-icon--dark>span {
    --un-text-opacity: 1;
    color: rgb(0 0 0 / var(--un-text-opacity))
}

.k-descriptions--extra {
    color: var(--ikun-dark-200)
}

.k-form-item-star {
    color: var(--ikun-rose-400);
    line-height: 1;
    line-height: .25rem
}

.dark .k-input-number--controls__dark:hover>span {
    --un-text-opacity: 1;
    color: rgb(248 161 83 / var(--un-text-opacity));
    opacity: 1
}

.k-link--default {
    color: var(--ikun-gray-500)
}

.k-alert--close__icon-color,.k-skeleton-image--icon {
    color: var(--ikun-stone-400)
}

.dark .k-switch-loading__dark {
    color: var(--ikun-slate-900)
}

.k-auto-complete--option__hover:hover {
    --un-text-opacity: 1;
    color: rgb(255 255 255 / var(--un-text-opacity));
    --ikun-context-background-color: rgba(248,161,83,.8);
    background-color: var(--ikun-context-background-color)
}

.k-carousel-arrow-icon:hover,.k-drawer--header--icon__hover:hover {
    --un-text-opacity: 1;
    color: rgb(248 161 83 / var(--un-text-opacity))
}

.k-image-view--close:hover,.k-image-view--footer__icon:hover {
    --un-text-opacity: 1;
    color: rgb(255 255 255 / var(--un-text-opacity))
}

.k-input-number--down:hover,.k-input-number--up:hover {
    --un-text-opacity: 1;
    color: rgb(248 161 83 / var(--un-text-opacity));
    opacity: 1
}

.k-link--default__hover:hover {
    --un-text-opacity: 1;
    color: rgb(248 161 83 / var(--un-text-opacity))
}

.k-link--error__hover:hover {
    color: var(--ikun-rose-500)
}

.k-link--info__hover:hover {
    color: var(--ikun-gray-500)
}

.k-link--primary__hover:hover {
    color: var(--ikun-teal-500)
}

.k-link--success__hover:hover {
    color: var(--ikun-green-500)
}

.k-link--warning__hover:hover {
    color: var(--ikun-amber-500)
}

.k-modal--header--icon__hover:hover,.k-notification--close--icon:hover,.dark .k-pagination-pager__dark__hover:hover {
    --un-text-opacity: 1;
    color: rgb(248 161 83 / var(--un-text-opacity))
}

.dark .k-pagination-pager__dark__hover>span:hover {
    --un-text-opacity: 1;
    color: rgb(248 161 83 / var(--un-text-opacity))
}

.k-pagination-pager__hover:hover {
    --un-text-opacity: 1;
    color: rgb(248 161 83 / var(--un-text-opacity))
}

.k-select--option__hover:hover {
    --un-text-opacity: 1;
    color: rgb(255 255 255 / var(--un-text-opacity));
    --ikun-context-background-color: rgba(248,161,83,.8);
    background-color: var(--ikun-context-background-color)
}

.k-tabs__add:hover,.k-tabs__nav-item--hover:hover,.k-tabs__next:hover,.k-tabs__prev:hover {
    --un-text-opacity: 1;
    color: rgb(248 161 83 / var(--un-text-opacity))
}

.k-tag--error__close-icon>div:hover {
    color: var(--ikun-white)
}

.k-tag--info__close-icon>div:hover {
    color: var(--ikun-white)
}

.k-tag--primary__close-icon>div:hover {
    color: var(--ikun-white)
}

.k-tag--success__close-icon>div:hover {
    color: var(--ikun-white)
}

.k-tag--warning__close-icon>div:hover {
    color: var(--ikun-white)
}

.k-breadcrumb-item-content {
    color: var(--ikun-dark-400)
}

.dark .k-breadcrumb-item-content__dark {
    color: var(--ikun-light-400)
}

.dark .k-breadcrumb-item-separator__dark {
    color: var(--ikun-light-950)!important
}

.k-alert--title {
    font-weight: 600
}

.k-descriptions--title {
    font-weight: 700
}

.k-switch-tx__checked,.k-switch-tx__unchecked {
    line-height: .25rem
}

.k-link--underline:hover {
    text-decoration-line: underline;
    text-underline-offset: 4px
}

.k-breadcrumb-item-content,.k-breadcrumb-item-content:link,.k-breadcrumb-item-content:visited,.k-breadcrumb-item-content:hover,.k-breadcrumb-item-content:active,.k-breadcrumb-item-content:focus {
    text-decoration: none!important
}

.k-link--underline,.k-link--underline__none {
    text-decoration: none
}

.k-button--disabled,.k-input--icon,.k-link--disabled {
    opacity: .5
}

.k-color-picker-preset--icon,.k-select--icon {
    opacity: .5;
    transition: all .3s linear
}

.k-image__loading {
    opacity: 0
}

.k-input-number--icon:hover {
    opacity: 1
}

.k-card--shadow__always,.k-card--shadow__hover:hover {
    box-shadow: 0 0 12px #0000001f
}

.k-card--shadow__hover:focus {
    box-shadow: 0 0 12px #0000001f
}

.k-card--transition {
    transition: all .3s linear
}

.k-progress--bar__cd {
    transition: stroke-dasharray .28s linear
}

.k-popover--base__bottom,.k-popover--base__left,.k-popover--base__right,.k-popover--base__top {
    box-shadow: 0 0 10px #00000040
}

.dark .k-skeleton--active {
    background: linear-gradient(90deg,#ffffff0f 25%,#ffffff26 37%,#ffffff0f 63%);
    background-size: 400% 100%
}

.k-color-picker-slider_alpha {
    background-size: 8px 8px;
    background-image: conic-gradient(rgba(0,0,0,.06) 0 25%,transparent 0 50%,rgba(0,0,0,.06) 0 75%,transparent 0)
}

.dark .k-color-picker-block,.dark .k-color-picker-block-clear,.dark .k-color-picker-slider_alpha {
    background-image: conic-gradient(rgba(255,255,255,.3) 0 25%,transparent 0 50%,rgba(255,255,255,.3) 0 75%,transparent 0)
}

.dark .k-popover--base__bottom__dark,.dark .k-popover--base__left__dark,.dark .k-popover--base__right__dark,.dark .k-popover--base__top__dark {
    box-shadow: 0 0 10px #f8a153cc
}

.dark .k-card--shadow__always__dark,.dark .k-card--shadow__hover__dark:hover {
    box-shadow: 0 0 12px #f8a15380
}

.dark .k-card--shadow__hover__dark:focus {
    box-shadow: 0 0 12px #f8a15380
}

.dark .k-contextmenu-item__disabled__dark,.dark .k-contextmenu-sub-menu__disable__dark,.dark .k-dropdown-item__disabled__dark,.k-pagination-pager__disabled__bg__active,.k-switch__unchecked {
    --ikun-context-background-color: rgba(248,161,83,.4);
    background-color: var(--ikun-context-background-color)
}

@media (min-width: 640px) {
    .-container {
        max-width:-640px
    }

    .container,[container=""] {
        max-width: 640px
    }

    .k-calendar-header-btn-group {
        margin-top: 0
    }

    .k-calendar-header-select-m {
        margin-right: 8px;
        width: 80px!important
    }

    .k-calendar-header-select-y {
        width: 90px!important
    }

    .k-calendar-header,.k-calendar-header-card {
        display: flex
    }
}

@media (min-width: 768px) {
    .-container {
        max-width:-768px
    }

    .container,[container=""] {
        max-width: 768px
    }

    [md~=k-cur-disabled] {
        cursor: not-allowed!important
    }
}

@media (min-width: 1024px) {
    .-container {
        max-width:-1024px
    }

    .container,[container=""] {
        max-width: 1024px
    }
}

@media (min-width: 1280px) {
    .-container {
        max-width:-1280px
    }

    .container,[container=""] {
        max-width: 1280px
    }
}

@media (min-width: 1536px) {
    .-container {
        max-width:-1536px
    }

    .container,[container=""] {
        max-width: 1536px
    }
}

:root {
    --ikun-inherit: inherit;
    --ikun-current: currentColor;
    --ikun-transparent: transparent;
    --ikun-black: #000;
    --ikun-white: #fff;
    --ikun-rose-50: #fff1f2;
    --ikun-rose-100: #ffe4e6;
    --ikun-rose-200: #fecdd3;
    --ikun-rose-300: #fda4af;
    --ikun-rose-400: #fb7185;
    --ikun-rose-500: #f43f5e;
    --ikun-rose-600: #e11d48;
    --ikun-rose-700: #be123c;
    --ikun-rose-800: #9f1239;
    --ikun-rose-900: #881337;
    --ikun-rose-950: #4c0519;
    --ikun-pink-50: #fdf2f8;
    --ikun-pink-100: #fce7f3;
    --ikun-pink-200: #fbcfe8;
    --ikun-pink-300: #f9a8d4;
    --ikun-pink-400: #f472b6;
    --ikun-pink-500: #ec4899;
    --ikun-pink-600: #db2777;
    --ikun-pink-700: #be185d;
    --ikun-pink-800: #9d174d;
    --ikun-pink-900: #831843;
    --ikun-pink-950: #500724;
    --ikun-fuchsia-50: #fdf4ff;
    --ikun-fuchsia-100: #fae8ff;
    --ikun-fuchsia-200: #f5d0fe;
    --ikun-fuchsia-300: #f0abfc;
    --ikun-fuchsia-400: #e879f9;
    --ikun-fuchsia-500: #d946ef;
    --ikun-fuchsia-600: #c026d3;
    --ikun-fuchsia-700: #a21caf;
    --ikun-fuchsia-800: #86198f;
    --ikun-fuchsia-900: #701a75;
    --ikun-fuchsia-950: #4a044e;
    --ikun-purple-50: #faf5ff;
    --ikun-purple-100: #f3e8ff;
    --ikun-purple-200: #e9d5ff;
    --ikun-purple-300: #d8b4fe;
    --ikun-purple-400: #c084fc;
    --ikun-purple-500: #a855f7;
    --ikun-purple-600: #9333ea;
    --ikun-purple-700: #7e22ce;
    --ikun-purple-800: #6b21a8;
    --ikun-purple-900: #581c87;
    --ikun-purple-950: #3b0764;
    --ikun-violet-50: #f5f3ff;
    --ikun-violet-100: #ede9fe;
    --ikun-violet-200: #ddd6fe;
    --ikun-violet-300: #c4b5fd;
    --ikun-violet-400: #a78bfa;
    --ikun-violet-500: #8b5cf6;
    --ikun-violet-600: #7c3aed;
    --ikun-violet-700: #6d28d9;
    --ikun-violet-800: #5b21b6;
    --ikun-violet-900: #4c1d95;
    --ikun-violet-950: #2e1065;
    --ikun-indigo-50: #eef2ff;
    --ikun-indigo-100: #e0e7ff;
    --ikun-indigo-200: #c7d2fe;
    --ikun-indigo-300: #a5b4fc;
    --ikun-indigo-400: #818cf8;
    --ikun-indigo-500: #6366f1;
    --ikun-indigo-600: #4f46e5;
    --ikun-indigo-700: #4338ca;
    --ikun-indigo-800: #3730a3;
    --ikun-indigo-900: #312e81;
    --ikun-indigo-950: #1e1b4b;
    --ikun-blue-50: #eff6ff;
    --ikun-blue-100: #dbeafe;
    --ikun-blue-200: #bfdbfe;
    --ikun-blue-300: #93c5fd;
    --ikun-blue-400: #60a5fa;
    --ikun-blue-500: #3b82f6;
    --ikun-blue-600: #2563eb;
    --ikun-blue-700: #1d4ed8;
    --ikun-blue-800: #1e40af;
    --ikun-blue-900: #1e3a8a;
    --ikun-blue-950: #172554;
    --ikun-sky-50: #f0f9ff;
    --ikun-sky-100: #e0f2fe;
    --ikun-sky-200: #bae6fd;
    --ikun-sky-300: #7dd3fc;
    --ikun-sky-400: #38bdf8;
    --ikun-sky-500: #0ea5e9;
    --ikun-sky-600: #0284c7;
    --ikun-sky-700: #0369a1;
    --ikun-sky-800: #075985;
    --ikun-sky-900: #0c4a6e;
    --ikun-sky-950: #082f49;
    --ikun-cyan-50: #ecfeff;
    --ikun-cyan-100: #cffafe;
    --ikun-cyan-200: #a5f3fc;
    --ikun-cyan-300: #67e8f9;
    --ikun-cyan-400: #22d3ee;
    --ikun-cyan-500: #06b6d4;
    --ikun-cyan-600: #0891b2;
    --ikun-cyan-700: #0e7490;
    --ikun-cyan-800: #155e75;
    --ikun-cyan-900: #164e63;
    --ikun-cyan-950: #083344;
    --ikun-teal-50: #f0fdfa;
    --ikun-teal-100: #ccfbf1;
    --ikun-teal-200: #99f6e4;
    --ikun-teal-300: #5eead4;
    --ikun-teal-400: #2dd4bf;
    --ikun-teal-500: #14b8a6;
    --ikun-teal-600: #0d9488;
    --ikun-teal-700: #0f766e;
    --ikun-teal-800: #115e59;
    --ikun-teal-900: #134e4a;
    --ikun-teal-950: #042f2e;
    --ikun-emerald-50: #ecfdf5;
    --ikun-emerald-100: #d1fae5;
    --ikun-emerald-200: #a7f3d0;
    --ikun-emerald-300: #6ee7b7;
    --ikun-emerald-400: #34d399;
    --ikun-emerald-500: #10b981;
    --ikun-emerald-600: #059669;
    --ikun-emerald-700: #047857;
    --ikun-emerald-800: #065f46;
    --ikun-emerald-900: #064e3b;
    --ikun-emerald-950: #022c22;
    --ikun-green-50: #f0fdf4;
    --ikun-green-100: #dcfce7;
    --ikun-green-200: #bbf7d0;
    --ikun-green-300: #86efac;
    --ikun-green-400: #4ade80;
    --ikun-green-500: #22c55e;
    --ikun-green-600: #16a34a;
    --ikun-green-700: #15803d;
    --ikun-green-800: #166534;
    --ikun-green-900: #14532d;
    --ikun-green-950: #052e16;
    --ikun-lime-50: #f7fee7;
    --ikun-lime-100: #ecfccb;
    --ikun-lime-200: #d9f99d;
    --ikun-lime-300: #bef264;
    --ikun-lime-400: #a3e635;
    --ikun-lime-500: #84cc16;
    --ikun-lime-600: #65a30d;
    --ikun-lime-700: #4d7c0f;
    --ikun-lime-800: #3f6212;
    --ikun-lime-900: #365314;
    --ikun-lime-950: #1a2e05;
    --ikun-yellow-50: #fefce8;
    --ikun-yellow-100: #fef9c3;
    --ikun-yellow-200: #fef08a;
    --ikun-yellow-300: #fde047;
    --ikun-yellow-400: #facc15;
    --ikun-yellow-500: #eab308;
    --ikun-yellow-600: #ca8a04;
    --ikun-yellow-700: #a16207;
    --ikun-yellow-800: #854d0e;
    --ikun-yellow-900: #713f12;
    --ikun-yellow-950: #422006;
    --ikun-amber-50: #fffbeb;
    --ikun-amber-100: #fef3c7;
    --ikun-amber-200: #fde68a;
    --ikun-amber-300: #fcd34d;
    --ikun-amber-400: #fbbf24;
    --ikun-amber-500: #f59e0b;
    --ikun-amber-600: #d97706;
    --ikun-amber-700: #b45309;
    --ikun-amber-800: #92400e;
    --ikun-amber-900: #78350f;
    --ikun-amber-950: #451a03;
    --ikun-orange-50: #fff7ed;
    --ikun-orange-100: #ffedd5;
    --ikun-orange-200: #fed7aa;
    --ikun-orange-300: #fdba74;
    --ikun-orange-400: #fb923c;
    --ikun-orange-500: #f97316;
    --ikun-orange-600: #ea580c;
    --ikun-orange-700: #c2410c;
    --ikun-orange-800: #9a3412;
    --ikun-orange-900: #7c2d12;
    --ikun-orange-950: #431407;
    --ikun-red-50: #fef2f2;
    --ikun-red-100: #fee2e2;
    --ikun-red-200: #fecaca;
    --ikun-red-300: #fca5a5;
    --ikun-red-400: #f87171;
    --ikun-red-500: #ef4444;
    --ikun-red-600: #dc2626;
    --ikun-red-700: #b91c1c;
    --ikun-red-800: #991b1b;
    --ikun-red-900: #7f1d1d;
    --ikun-red-950: #450a0a;
    --ikun-gray-50: #f9fafb;
    --ikun-gray-100: #f3f4f6;
    --ikun-gray-200: #e5e7eb;
    --ikun-gray-300: #d1d5db;
    --ikun-gray-400: #9ca3af;
    --ikun-gray-500: #6b7280;
    --ikun-gray-600: #4b5563;
    --ikun-gray-700: #374151;
    --ikun-gray-800: #1f2937;
    --ikun-gray-900: #111827;
    --ikun-gray-950: #030712;
    --ikun-slate-50: #f8fafc;
    --ikun-slate-100: #f1f5f9;
    --ikun-slate-200: #e2e8f0;
    --ikun-slate-300: #cbd5e1;
    --ikun-slate-400: #94a3b8;
    --ikun-slate-500: #64748b;
    --ikun-slate-600: #475569;
    --ikun-slate-700: #334155;
    --ikun-slate-800: #1e293b;
    --ikun-slate-900: #0f172a;
    --ikun-slate-950: #020617;
    --ikun-zinc-50: #fafafa;
    --ikun-zinc-100: #f4f4f5;
    --ikun-zinc-200: #e4e4e7;
    --ikun-zinc-300: #d4d4d8;
    --ikun-zinc-400: #a1a1aa;
    --ikun-zinc-500: #71717a;
    --ikun-zinc-600: #52525b;
    --ikun-zinc-700: #3f3f46;
    --ikun-zinc-800: #27272a;
    --ikun-zinc-900: #18181b;
    --ikun-zinc-950: #09090b;
    --ikun-neutral-50: #fafafa;
    --ikun-neutral-100: #f5f5f5;
    --ikun-neutral-200: #e5e5e5;
    --ikun-neutral-300: #d4d4d4;
    --ikun-neutral-400: #a3a3a3;
    --ikun-neutral-500: #737373;
    --ikun-neutral-600: #525252;
    --ikun-neutral-700: #404040;
    --ikun-neutral-800: #262626;
    --ikun-neutral-900: #171717;
    --ikun-neutral-950: #0a0a0a;
    --ikun-stone-50: #fafaf9;
    --ikun-stone-100: #f5f5f4;
    --ikun-stone-200: #e7e5e4;
    --ikun-stone-300: #d6d3d1;
    --ikun-stone-400: #a8a29e;
    --ikun-stone-500: #78716c;
    --ikun-stone-600: #57534e;
    --ikun-stone-700: #44403c;
    --ikun-stone-800: #292524;
    --ikun-stone-900: #1c1917;
    --ikun-stone-950: #0c0a09;
    --ikun-light-50: #fdfdfd;
    --ikun-light-100: #fcfcfc;
    --ikun-light-200: #fafafa;
    --ikun-light-300: #f8f9fa;
    --ikun-light-400: #f6f6f6;
    --ikun-light-500: #f2f2f2;
    --ikun-light-600: #f1f3f5;
    --ikun-light-700: #e9ecef;
    --ikun-light-800: #dee2e6;
    --ikun-light-900: #dde1e3;
    --ikun-light-950: #d8dcdf;
    --ikun-dark-50: #4a4a4a;
    --ikun-dark-100: #3c3c3c;
    --ikun-dark-200: #323232;
    --ikun-dark-300: #2d2d2d;
    --ikun-dark-400: #222222;
    --ikun-dark-500: #1f1f1f;
    --ikun-dark-600: #1c1c1e;
    --ikun-dark-700: #1b1b1b;
    --ikun-dark-800: #181818;
    --ikun-dark-900: #0f0f0f;
    --ikun-dark-950: #080808
}

:root.dark {
    --ikun-inherit: inherit;
    --ikun-current: currentColor;
    --ikun-transparent: transparent;
    --ikun-black: #000;
    --ikun-white: #fff;
    --ikun-rose-50: #fff1f2;
    --ikun-rose-100: #ffe4e6;
    --ikun-rose-200: #fecdd3;
    --ikun-rose-300: #fda4af;
    --ikun-rose-400: #fb7185;
    --ikun-rose-500: #f43f5e;
    --ikun-rose-600: #e11d48;
    --ikun-rose-700: #be123c;
    --ikun-rose-800: #9f1239;
    --ikun-rose-900: #881337;
    --ikun-rose-950: #4c0519;
    --ikun-pink-50: #fdf2f8;
    --ikun-pink-100: #fce7f3;
    --ikun-pink-200: #fbcfe8;
    --ikun-pink-300: #f9a8d4;
    --ikun-pink-400: #f472b6;
    --ikun-pink-500: #ec4899;
    --ikun-pink-600: #db2777;
    --ikun-pink-700: #be185d;
    --ikun-pink-800: #9d174d;
    --ikun-pink-900: #831843;
    --ikun-pink-950: #500724;
    --ikun-fuchsia-50: #fdf4ff;
    --ikun-fuchsia-100: #fae8ff;
    --ikun-fuchsia-200: #f5d0fe;
    --ikun-fuchsia-300: #f0abfc;
    --ikun-fuchsia-400: #e879f9;
    --ikun-fuchsia-500: #d946ef;
    --ikun-fuchsia-600: #c026d3;
    --ikun-fuchsia-700: #a21caf;
    --ikun-fuchsia-800: #86198f;
    --ikun-fuchsia-900: #701a75;
    --ikun-fuchsia-950: #4a044e;
    --ikun-purple-50: #faf5ff;
    --ikun-purple-100: #f3e8ff;
    --ikun-purple-200: #e9d5ff;
    --ikun-purple-300: #d8b4fe;
    --ikun-purple-400: #c084fc;
    --ikun-purple-500: #a855f7;
    --ikun-purple-600: #9333ea;
    --ikun-purple-700: #7e22ce;
    --ikun-purple-800: #6b21a8;
    --ikun-purple-900: #581c87;
    --ikun-purple-950: #3b0764;
    --ikun-violet-50: #f5f3ff;
    --ikun-violet-100: #ede9fe;
    --ikun-violet-200: #ddd6fe;
    --ikun-violet-300: #c4b5fd;
    --ikun-violet-400: #a78bfa;
    --ikun-violet-500: #8b5cf6;
    --ikun-violet-600: #7c3aed;
    --ikun-violet-700: #6d28d9;
    --ikun-violet-800: #5b21b6;
    --ikun-violet-900: #4c1d95;
    --ikun-violet-950: #2e1065;
    --ikun-indigo-50: #eef2ff;
    --ikun-indigo-100: #e0e7ff;
    --ikun-indigo-200: #c7d2fe;
    --ikun-indigo-300: #a5b4fc;
    --ikun-indigo-400: #818cf8;
    --ikun-indigo-500: #6366f1;
    --ikun-indigo-600: #4f46e5;
    --ikun-indigo-700: #4338ca;
    --ikun-indigo-800: #3730a3;
    --ikun-indigo-900: #312e81;
    --ikun-indigo-950: #1e1b4b;
    --ikun-blue-50: #eff6ff;
    --ikun-blue-100: #dbeafe;
    --ikun-blue-200: #bfdbfe;
    --ikun-blue-300: #93c5fd;
    --ikun-blue-400: #60a5fa;
    --ikun-blue-500: #3b82f6;
    --ikun-blue-600: #2563eb;
    --ikun-blue-700: #1d4ed8;
    --ikun-blue-800: #1e40af;
    --ikun-blue-900: #1e3a8a;
    --ikun-blue-950: #172554;
    --ikun-sky-50: #f0f9ff;
    --ikun-sky-100: #e0f2fe;
    --ikun-sky-200: #bae6fd;
    --ikun-sky-300: #7dd3fc;
    --ikun-sky-400: #38bdf8;
    --ikun-sky-500: #0ea5e9;
    --ikun-sky-600: #0284c7;
    --ikun-sky-700: #0369a1;
    --ikun-sky-800: #075985;
    --ikun-sky-900: #0c4a6e;
    --ikun-sky-950: #082f49;
    --ikun-cyan-50: #ecfeff;
    --ikun-cyan-100: #cffafe;
    --ikun-cyan-200: #a5f3fc;
    --ikun-cyan-300: #67e8f9;
    --ikun-cyan-400: #22d3ee;
    --ikun-cyan-500: #06b6d4;
    --ikun-cyan-600: #0891b2;
    --ikun-cyan-700: #0e7490;
    --ikun-cyan-800: #155e75;
    --ikun-cyan-900: #164e63;
    --ikun-cyan-950: #083344;
    --ikun-teal-50: #f0fdfa;
    --ikun-teal-100: #ccfbf1;
    --ikun-teal-200: #99f6e4;
    --ikun-teal-300: #5eead4;
    --ikun-teal-400: #2dd4bf;
    --ikun-teal-500: #14b8a6;
    --ikun-teal-600: #0d9488;
    --ikun-teal-700: #0f766e;
    --ikun-teal-800: #115e59;
    --ikun-teal-900: #134e4a;
    --ikun-teal-950: #042f2e;
    --ikun-emerald-50: #ecfdf5;
    --ikun-emerald-100: #d1fae5;
    --ikun-emerald-200: #a7f3d0;
    --ikun-emerald-300: #6ee7b7;
    --ikun-emerald-400: #34d399;
    --ikun-emerald-500: #10b981;
    --ikun-emerald-600: #059669;
    --ikun-emerald-700: #047857;
    --ikun-emerald-800: #065f46;
    --ikun-emerald-900: #064e3b;
    --ikun-emerald-950: #022c22;
    --ikun-green-50: #f0fdf4;
    --ikun-green-100: #dcfce7;
    --ikun-green-200: #bbf7d0;
    --ikun-green-300: #86efac;
    --ikun-green-400: #4ade80;
    --ikun-green-500: #22c55e;
    --ikun-green-600: #16a34a;
    --ikun-green-700: #15803d;
    --ikun-green-800: #166534;
    --ikun-green-900: #14532d;
    --ikun-green-950: #052e16;
    --ikun-lime-50: #f7fee7;
    --ikun-lime-100: #ecfccb;
    --ikun-lime-200: #d9f99d;
    --ikun-lime-300: #bef264;
    --ikun-lime-400: #a3e635;
    --ikun-lime-500: #84cc16;
    --ikun-lime-600: #65a30d;
    --ikun-lime-700: #4d7c0f;
    --ikun-lime-800: #3f6212;
    --ikun-lime-900: #365314;
    --ikun-lime-950: #1a2e05;
    --ikun-yellow-50: #fefce8;
    --ikun-yellow-100: #fef9c3;
    --ikun-yellow-200: #fef08a;
    --ikun-yellow-300: #fde047;
    --ikun-yellow-400: #facc15;
    --ikun-yellow-500: #eab308;
    --ikun-yellow-600: #ca8a04;
    --ikun-yellow-700: #a16207;
    --ikun-yellow-800: #854d0e;
    --ikun-yellow-900: #713f12;
    --ikun-yellow-950: #422006;
    --ikun-amber-50: #fffbeb;
    --ikun-amber-100: #fef3c7;
    --ikun-amber-200: #fde68a;
    --ikun-amber-300: #fcd34d;
    --ikun-amber-400: #fbbf24;
    --ikun-amber-500: #f59e0b;
    --ikun-amber-600: #d97706;
    --ikun-amber-700: #b45309;
    --ikun-amber-800: #92400e;
    --ikun-amber-900: #78350f;
    --ikun-amber-950: #451a03;
    --ikun-orange-50: #fff7ed;
    --ikun-orange-100: #ffedd5;
    --ikun-orange-200: #fed7aa;
    --ikun-orange-300: #fdba74;
    --ikun-orange-400: #fb923c;
    --ikun-orange-500: #f97316;
    --ikun-orange-600: #ea580c;
    --ikun-orange-700: #c2410c;
    --ikun-orange-800: #9a3412;
    --ikun-orange-900: #7c2d12;
    --ikun-orange-950: #431407;
    --ikun-red-50: #fef2f2;
    --ikun-red-100: #fee2e2;
    --ikun-red-200: #fecaca;
    --ikun-red-300: #fca5a5;
    --ikun-red-400: #f87171;
    --ikun-red-500: #ef4444;
    --ikun-red-600: #dc2626;
    --ikun-red-700: #b91c1c;
    --ikun-red-800: #991b1b;
    --ikun-red-900: #7f1d1d;
    --ikun-red-950: #450a0a;
    --ikun-gray-50: #f9fafb;
    --ikun-gray-100: #f3f4f6;
    --ikun-gray-200: #e5e7eb;
    --ikun-gray-300: #d1d5db;
    --ikun-gray-400: #9ca3af;
    --ikun-gray-500: #6b7280;
    --ikun-gray-600: #4b5563;
    --ikun-gray-700: #374151;
    --ikun-gray-800: #1f2937;
    --ikun-gray-900: #111827;
    --ikun-gray-950: #030712;
    --ikun-slate-50: #f8fafc;
    --ikun-slate-100: #f1f5f9;
    --ikun-slate-200: #e2e8f0;
    --ikun-slate-300: #cbd5e1;
    --ikun-slate-400: #94a3b8;
    --ikun-slate-500: #64748b;
    --ikun-slate-600: #475569;
    --ikun-slate-700: #334155;
    --ikun-slate-800: #1e293b;
    --ikun-slate-900: #0f172a;
    --ikun-slate-950: #020617;
    --ikun-zinc-50: #fafafa;
    --ikun-zinc-100: #f4f4f5;
    --ikun-zinc-200: #e4e4e7;
    --ikun-zinc-300: #d4d4d8;
    --ikun-zinc-400: #a1a1aa;
    --ikun-zinc-500: #71717a;
    --ikun-zinc-600: #52525b;
    --ikun-zinc-700: #3f3f46;
    --ikun-zinc-800: #27272a;
    --ikun-zinc-900: #18181b;
    --ikun-zinc-950: #09090b;
    --ikun-neutral-50: #fafafa;
    --ikun-neutral-100: #f5f5f5;
    --ikun-neutral-200: #e5e5e5;
    --ikun-neutral-300: #d4d4d4;
    --ikun-neutral-400: #a3a3a3;
    --ikun-neutral-500: #737373;
    --ikun-neutral-600: #525252;
    --ikun-neutral-700: #404040;
    --ikun-neutral-800: #262626;
    --ikun-neutral-900: #171717;
    --ikun-neutral-950: #0a0a0a;
    --ikun-stone-50: #fafaf9;
    --ikun-stone-100: #f5f5f4;
    --ikun-stone-200: #e7e5e4;
    --ikun-stone-300: #d6d3d1;
    --ikun-stone-400: #a8a29e;
    --ikun-stone-500: #78716c;
    --ikun-stone-600: #57534e;
    --ikun-stone-700: #44403c;
    --ikun-stone-800: #292524;
    --ikun-stone-900: #1c1917;
    --ikun-stone-950: #0c0a09;
    --ikun-light-50: #fdfdfd;
    --ikun-light-100: #fcfcfc;
    --ikun-light-200: #fafafa;
    --ikun-light-300: #f8f9fa;
    --ikun-light-400: #f6f6f6;
    --ikun-light-500: #f2f2f2;
    --ikun-light-600: #f1f3f5;
    --ikun-light-700: #e9ecef;
    --ikun-light-800: #dee2e6;
    --ikun-light-900: #dde1e3;
    --ikun-light-950: #d8dcdf;
    --ikun-dark-50: #4a4a4a;
    --ikun-dark-100: #3c3c3c;
    --ikun-dark-200: #323232;
    --ikun-dark-300: #2d2d2d;
    --ikun-dark-400: #222222;
    --ikun-dark-500: #1f1f1f;
    --ikun-dark-600: #1c1c1e;
    --ikun-dark-700: #1b1b1b;
    --ikun-dark-800: #181818;
    --ikun-dark-900: #0f0f0f;
    --ikun-dark-950: #080808
}

button,select,input,option {
    outline: none;
    -webkit-appearance: none
}

.visible,[visible=""] {
    visibility: visible
}

.absolute,[absolute=""] {
    position: absolute
}

.fixed {
    position: fixed
}

.relative {
    position: relative
}

.sticky {
    position: sticky
}

.grid-cols-11 {
    grid-template-columns: repeat(11,minmax(0,1fr))
}

.grid-cols-2 {
    grid-template-columns: repeat(2,minmax(0,1fr))
}

.m-1 {
    margin: .25rem
}

.m-2 {
    margin: .5rem
}

.\!my-2 {
    margin-top: .5rem!important;
    margin-bottom: .5rem!important
}

.mx-1 {
    margin-left: .25rem;
    margin-right: .25rem
}

.mx-10px,[mx-10px=""] {
    margin-left: 10px;
    margin-right: 10px
}

.mx-2 {
    margin-left: .5rem;
    margin-right: .5rem
}

.mx-4,.mx4 {
    margin-left: 1rem;
    margin-right: 1rem
}

.mx-8px {
    margin-left: 8px;
    margin-right: 8px
}

.mx-auto {
    margin-left: auto;
    margin-right: auto
}

.my,.my-4 {
    margin-top: 1rem;
    margin-bottom: 1rem
}

.my-0 {
    margin-top: 0;
    margin-bottom: 0
}

.my-1 {
    margin-top: .25rem;
    margin-bottom: .25rem
}

.my-10px {
    margin-top: 10px;
    margin-bottom: 10px
}

.my-12px {
    margin-top: 12px;
    margin-bottom: 12px
}

.my-2 {
    margin-top: .5rem;
    margin-bottom: .5rem
}

.my-20px {
    margin-top: 20px;
    margin-bottom: 20px
}

.my-4px,[my-4px=""] {
    margin-top: 4px;
    margin-bottom: 4px
}

.my-6 {
    margin-top: 1.5rem;
    margin-bottom: 1.5rem
}

[mx-10px~="default:"]:default {
    margin-left: 10px;
    margin-right: 10px
}

.\!ml-0 {
    margin-left: 0!important
}

.mb-2 {
    margin-bottom: .5rem
}

.mb-4 {
    margin-bottom: 1rem
}

.mb-6px {
    margin-bottom: 6px
}

.me {
    margin-inline-end:1rem}

.ml-\[16px\] {
    margin-left: 16px
}

.ml-1 {
    margin-left: .25rem
}

.ml-10px,[ml-10px=""] {
    margin-left: 10px
}

.ml-2,.ml2 {
    margin-left: .5rem
}

.ml-20px {
    margin-left: 20px
}

.ml-2px {
    margin-left: 2px
}

.ml-4 {
    margin-left: 1rem
}

.ml-4px {
    margin-left: 4px
}

.mr-\[16px\] {
    margin-right: 16px
}

.mr-10px,[mr-10px=""] {
    margin-right: 10px
}

.mr-2 {
    margin-right: .5rem
}

.mr-20px {
    margin-right: 20px
}

.mr-2px {
    margin-right: 2px
}

.mr-3 {
    margin-right: .75rem
}

.mr-40px {
    margin-right: 40px
}

.mr-8px {
    margin-right: 8px
}

.mr4 {
    margin-right: 1rem
}

.ms {
    margin-inline-start:1rem}

.mt-2 {
    margin-top: .5rem
}

.mt-3 {
    margin-top: .75rem
}

.mt-4 {
    margin-top: 1rem
}

.mt-6 {
    margin-top: 1.5rem
}

.box-border {
    box-sizing: border-box
}

.inline {
    display: inline
}

.\!block {
    display: block!important
}

.block,[block=""] {
    display: block
}

.inline-block {
    display: inline-block
}

.contents {
    display: contents
}

.hidden,.k-col-0 {
    display: none
}

[size~=lg] {
    width: 32rem;
    height: 32rem
}

[size~=md] {
    width: 28rem;
    height: 28rem
}

[size~=sm] {
    width: 24rem;
    height: 24rem
}

.h-100 {
    height: 25rem
}

.h-100px {
    height: 100px
}

.h-150px {
    height: 150px
}

.h-200px {
    height: 200px
}

.h-300px {
    height: 300px
}

.h-30px {
    height: 30px
}

.h-30vh {
    height: 30vh
}

.h-32px {
    height: 32px
}

.h-36px {
    height: 36px
}

.h-4,.h4 {
    height: 1rem
}

.h-50 {
    height: 12.5rem
}

.h-600px {
    height: 600px
}

.h-65px {
    height: 65px
}

.h-8 {
    height: 2rem
}

.h-full {
    height: 100%
}

.h1,[h1=""] {
    height: .25rem
}

.h2 {
    height: .5rem
}

.h3 {
    height: .75rem
}

.h5 {
    height: 1.25rem
}

.h6 {
    height: 1.5rem
}

.ha {
    height: auto
}

.min-w-240px {
    min-width: 240px
}

.w-1\/4 {
    width: 25%
}

.w-100px {
    width: 100px
}

.w-120px {
    width: 120px
}

.w-200px {
    width: 200px
}

.w-240px {
    width: 240px
}

.w-300px {
    width: 300px
}

.w-4 {
    width: 1rem
}

.w-50 {
    width: 12.5rem
}

.w-50px {
    width: 50px
}

.w-full {
    width: 100%
}

.w-max {
    width: max-content
}

.flex,[flex=""] {
    display: flex
}

.inline-flex {
    display: inline-flex
}

[flex~="$$invalidate(0,"] {
    flex: var(--\$invalidate\(0)
}

[flex~="$$invalidate(1,"] {
    flex: var(--\$invalidate\(1)
}

[flex~="$$invalidate(10,"] {
    flex: var(--\$invalidate\(10)
}

[flex~="$$invalidate(11,"] {
    flex: var(--\$invalidate\(11)
}

[flex~="$$invalidate(12,"] {
    flex: var(--\$invalidate\(12)
}

[flex~="$$invalidate(2,"] {
    flex: var(--\$invalidate\(2)
}

[flex~="$$invalidate(28,"] {
    flex: var(--\$invalidate\(28)
}

[flex~="$$invalidate(4,"] {
    flex: var(--\$invalidate\(4)
}

[flex~="$$invalidate(5,"] {
    flex: var(--\$invalidate\(5)
}

[flex~="$$invalidate(6,"] {
    flex: var(--\$invalidate\(6)
}

[flex~="$$invalidate(7,"] {
    flex: var(--\$invalidate\(7)
}

[flex~="$$invalidate(8,"] {
    flex: var(--\$invalidate\(8)
}

[flex~="$$invalidate(9,"] {
    flex: var(--\$invalidate\(9)
}

[flex~="$$invalidate)"] {
    flex: var(--\$invalidate\))
}

[flex~="$$new_props"] {
    flex: var(--\$new_props)
}

[flex~="$$new_props.$$scope)"] {
    flex: var(--\$new_props\.\$\$scope\))
}

[flex~="$$new_props.align)"] {
    flex: var(--\$new_props\.align\))
}

[flex~="$$new_props.attrs)"] {
    flex: var(--\$new_props\.attrs\))
}

[flex~="$$new_props.cls)"] {
    flex: var(--\$new_props\.cls\))
}

[flex~="$$new_props.elm)"] {
    flex: var(--\$new_props\.elm\))
}

[flex~="$$new_props.flex)"] {
    flex: var(--\$new_props\.flex\))
}

[flex~="$$new_props.gap)"] {
    flex: var(--\$new_props\.gap\))
}

[flex~="$$new_props.justify)"] {
    flex: var(--\$new_props\.justify\))
}

[flex~="$$new_props.vertical)"] {
    flex: var(--\$new_props\.vertical\))
}

[flex~="$$new_props.wrap)"] {
    flex: var(--\$new_props\.wrap\))
}

[flex~="$$new_props)"] {
    flex: var(--\$new_props\))
}

[flex~="$$props"],[flex~="$$props,"] {
    flex: var(--\$props)
}

[flex~="$$props),"] {
    flex: var(--\$props\))
}

[flex~="$$restProps"] {
    flex: var(--\$restProps)
}

[flex~="$$scope"] {
    flex: var(--\$scope)
}

[flex~="$$self.$$.update"] {
    flex: var(--\$self\.\$\$\.update)
}

[flex~="$$self.$$set"] {
    flex: var(--\$self\.\$\$set)
}

.flex-1 {
    flex: 1 1 0%
}

.flex-auto {
    flex: 1 1 auto
}

.flex-shrink {
    flex-shrink: 1
}

.flex-grow,.grow,[grow~=","] {
    flex-grow: 1
}

.flex-col {
    flex-direction: column
}

.flex-wrap,[flex~=wrap] {
    flex-wrap: wrap
}

.table,[table=""] {
    display: table
}

.border-collapse {
    border-collapse: collapse
}

.-rotate-90 {
    --un-rotate-x: 0;
    --un-rotate-y: 0;
    --un-rotate-z: 0;
    --un-rotate: -90deg;
    transform: translate(var(--un-translate-x)) translateY(var(--un-translate-y)) translateZ(var(--un-translate-z)) rotate(var(--un-rotate)) rotateX(var(--un-rotate-x)) rotateY(var(--un-rotate-y)) rotate(var(--un-rotate-z)) skew(var(--un-skew-x)) skewY(var(--un-skew-y)) scaleX(var(--un-scale-x)) scaleY(var(--un-scale-y)) scaleZ(var(--un-scale-z))
}

.rotate-180 {
    --un-rotate-x: 0;
    --un-rotate-y: 0;
    --un-rotate-z: 0;
    --un-rotate: 180deg;
    transform: translate(var(--un-translate-x)) translateY(var(--un-translate-y)) translateZ(var(--un-translate-z)) rotate(var(--un-rotate)) rotateX(var(--un-rotate-x)) rotateY(var(--un-rotate-y)) rotate(var(--un-rotate-z)) skew(var(--un-skew-x)) skewY(var(--un-skew-y)) scaleX(var(--un-scale-x)) scaleY(var(--un-scale-y)) scaleZ(var(--un-scale-z))
}

.rotate-90 {
    --un-rotate-x: 0;
    --un-rotate-y: 0;
    --un-rotate-z: 0;
    --un-rotate: 90deg;
    transform: translate(var(--un-translate-x)) translateY(var(--un-translate-y)) translateZ(var(--un-translate-z)) rotate(var(--un-rotate)) rotateX(var(--un-rotate-x)) rotateY(var(--un-rotate-y)) rotate(var(--un-rotate-z)) skew(var(--un-skew-x)) skewY(var(--un-skew-y)) scaleX(var(--un-scale-x)) scaleY(var(--un-scale-y)) scaleZ(var(--un-scale-z))
}

.hover\:scale-110:hover {
    --un-scale-x: 1.1;
    --un-scale-y: 1.1;
    transform: translate(var(--un-translate-x)) translateY(var(--un-translate-y)) translateZ(var(--un-translate-z)) rotate(var(--un-rotate)) rotateX(var(--un-rotate-x)) rotateY(var(--un-rotate-y)) rotate(var(--un-rotate-z)) skew(var(--un-skew-x)) skewY(var(--un-skew-y)) scaleX(var(--un-scale-x)) scaleY(var(--un-scale-y)) scaleZ(var(--un-scale-z))
}

.transform {
    transform: translate(var(--un-translate-x)) translateY(var(--un-translate-y)) translateZ(var(--un-translate-z)) rotate(var(--un-rotate)) rotateX(var(--un-rotate-x)) rotateY(var(--un-rotate-y)) rotate(var(--un-rotate-z)) skew(var(--un-skew-x)) skewY(var(--un-skew-y)) scaleX(var(--un-scale-x)) scaleY(var(--un-scale-y)) scaleZ(var(--un-scale-z))
}

@keyframes ikun-checking {
    0% {
        box-shadow: 0 0 0 2px #f8a15366
    }

    60% {
        box-shadow: 0 0 0 4px #f8a15333
    }

    80% {
        box-shadow: 0 0 0 6px #f8a1531a
    }

    to {
        box-shadow: 0 0 0 8px #f8a1530d
    }
}

.animate-ikun-checking {
    animation: ikun-checking .3s linear 1
}

@keyframes ikun-clicking--error {
    0% {
        box-shadow: 0 0 0 2px #fb718566
    }

    60% {
        box-shadow: 0 0 0 4px #fb718533
    }

    80% {
        box-shadow: 0 0 0 6px #fb71851a
    }

    to {
        box-shadow: 0 0 0 10px #fb71850d
    }
}

@keyframes ikun-clicking--info {
    0% {
        box-shadow: 0 0 0 2px #94a3b866
    }

    60% {
        box-shadow: 0 0 0 4px #94a3b833
    }

    80% {
        box-shadow: 0 0 0 6px #94a3b81a
    }

    to {
        box-shadow: 0 0 0 10px #94a3b80d
    }
}

@keyframes ikun-clicking--success {
    0% {
        box-shadow: 0 0 0 2px #4ade8066
    }

    60% {
        box-shadow: 0 0 0 4px #4ade8033
    }

    80% {
        box-shadow: 0 0 0 6px #4ade801a
    }

    to {
        box-shadow: 0 0 0 10px #4ade800d
    }
}

@keyframes ikun-clicking--warning {
    0% {
        box-shadow: 0 0 0 2px #fbbf2466
    }

    60% {
        box-shadow: 0 0 0 4px #fbbf2433
    }

    80% {
        box-shadow: 0 0 0 6px #fbbf241a
    }

    to {
        box-shadow: 0 0 0 10px #fbbf240d
    }
}

@keyframes ikun-checking-main {
    0% {
        box-shadow: 0 0 0 2px #f8a15366
    }

    60% {
        box-shadow: 0 0 0 4px #f8a15333
    }

    80% {
        box-shadow: 0 0 0 6px #f8a1531a
    }

    to {
        box-shadow: 0 0 0 8px #f8a1530d
    }
}

@keyframes ikun-clicking--primary {
    0% {
        box-shadow: 0 0 0 2px #2dd4bf66
    }

    60% {
        box-shadow: 0 0 0 4px #2dd4bf33
    }

    80% {
        box-shadow: 0 0 0 6px #2dd4bf1a
    }

    to {
        box-shadow: 0 0 0 10px #2dd4bf0d
    }
}

@keyframes ikun-skeleton-loading {
    0% {
        background-position: 100% 50%
    }

    to {
        background-position: 0 50%
    }
}

@keyframes spin {
    0% {
        transform: rotate(0)
    }

    to {
        transform: rotate(360deg)
    }
}

@keyframes bounce {
    0%,to {
        transform: translateY(-25%);
        animation-timing-function: cubic-bezier(.8,0,1,1)
    }

    50% {
        transform: translateY(0);
        animation-timing-function: cubic-bezier(0,0,.2,1)
    }
}

@keyframes ikun-switching {
    0% {
        box-shadow: 0 0 0 2px #f8a15366
    }

    60% {
        box-shadow: 0 0 0 4px #f8a15333
    }

    80% {
        box-shadow: 0 0 0 6px #f8a1531a
    }

    to {
        box-shadow: 0 0 0 8px #f8a1530d
    }
}

.cursor-pointer {
    cursor: pointer
}

.resize {
    resize: both
}

.items-center,[items-center=""] {
    align-items: center
}

.justify-start {
    justify-content: flex-start
}

.justify-end,[justify~=end] {
    justify-content: flex-end
}

.justify-center,[justify~=center] {
    justify-content: center
}

.justify-between,[justify-between=""],[justify~=between] {
    justify-content: space-between
}

.justify-around,[justify~=around] {
    justify-content: space-around
}

[justify~=evenly] {
    justify-content: space-evenly
}

.gap-4 {
    gap: 1rem
}

.gap-6px,[gap-6px=""] {
    gap: 6px
}

.gap\[1\] {
    gap: 1
}

[gap~=sm] {
    gap: .875rem
}

.overflow-auto {
    overflow: auto
}

.overflow-y-auto {
    overflow-y: auto
}

.\!border,[\!border=""] {
    border-width: 1px!important
}

.b,.border,.border-1,[border=""] {
    border-width: 1px
}

[-border=""] {
    border-width: -1px
}

[border~="default:"]:default {
    border-width: 1px
}

.border-t-1px {
    border-top-width: 1px
}

.b-blue {
    --un-border-opacity: 1;
    border-color: rgb(96 165 250 / var(--un-border-opacity))
}

.b-green {
    --un-border-opacity: 1;
    border-color: rgb(74 222 128 / var(--un-border-opacity))
}

.b-ikun-bd-base {
    border-color: var(--ikun-zinc-300)
}

.b-pink {
    --un-border-opacity: 1;
    border-color: rgb(244 114 182 / var(--un-border-opacity))
}

.b-red {
    --un-border-opacity: 1;
    border-color: rgb(248 113 113 / var(--un-border-opacity))
}

.border-ikun-main,[border-ikun-main=""] {
    --un-border-opacity: 1;
    border-color: rgb(248 161 83 / var(--un-border-opacity))
}

.border-slate-200 {
    --un-border-opacity: 1;
    border-color: rgb(226 232 240 / var(--un-border-opacity))
}

[border-color~="!current"] {
    border-color: currentColor!important
}

[border-color~=current] {
    border-color: currentColor
}

[border~="[create_default_slot]"] {
    border-color: create default slot
}

[border~="$$invalidate(14,"] {
    border-color: var(--\$invalidate\(14)
}

[border~="$$invalidate(15,"] {
    border-color: var(--\$invalidate\(15)
}

[border~="$$invalidate(16,"] {
    border-color: var(--\$invalidate\(16)
}

[border~="$$invalidate(19,"] {
    border-color: var(--\$invalidate\(19)
}

[border~="$$invalidate(4,"] {
    border-color: var(--\$invalidate\(4)
}

[border~="$$invalidate(9,"] {
    border-color: var(--\$invalidate\(9)
}

.rounded,[rounded=""] {
    border-radius: .25rem
}

.rounded-full {
    border-radius: 9999px
}

.border-solid {
    border-style: solid
}

.border-t-solid {
    border-top-style: solid
}

.bg-blue {
    --un-bg-opacity: 1;
    background-color: rgb(96 165 250 / var(--un-bg-opacity))
}

.bg-green-500 {
    --un-bg-opacity: 1;
    background-color: rgb(34 197 94 / var(--un-bg-opacity))
}

.bg-ikun-main,[bg-ikun-main=""] {
    --un-bg-opacity: 1;
    background-color: rgb(248 161 83 / var(--un-bg-opacity))
}

.bg-ikun-white {
    background-color: var(--ikun-white)
}

.bg-orange-100 {
    --un-bg-opacity: 1;
    background-color: rgb(255 237 213 / var(--un-bg-opacity))
}

.bg-orange-200 {
    --un-bg-opacity: 1;
    background-color: rgb(254 215 170 / var(--un-bg-opacity))
}

.bg-orange-300 {
    --un-bg-opacity: 1;
    background-color: rgb(253 186 116 / var(--un-bg-opacity))
}

.bg-sky-500 {
    --un-bg-opacity: 1;
    background-color: rgb(14 165 233 / var(--un-bg-opacity))
}

.dark .dark\:bg-ikun-dark-500 {
    background-color: var(--ikun-dark-500)
}

.dark .dark\:bg-ikun-stone-400 {
    background-color: var(--ikun-stone-400)
}

.hover\:bg-ikun-main:hover {
    --un-bg-opacity: 1;
    background-color: rgb(248 161 83 / var(--un-bg-opacity))
}

.p-2,.p2 {
    padding: .5rem
}

.p0 {
    padding: 0
}

.p1 {
    padding: .25rem
}

.p3 {
    padding: .75rem
}

.px,[px=""] {
    padding-left: 1rem;
    padding-right: 1rem
}

.px-0,[px~="0"] {
    padding-left: 0;
    padding-right: 0
}

.px-1 {
    padding-left: .25rem;
    padding-right: .25rem
}

.px-10px {
    padding-left: 10px;
    padding-right: 10px
}

.px-2 {
    padding-left: .5rem;
    padding-right: .5rem
}

.py-1 {
    padding-top: .25rem;
    padding-bottom: .25rem
}

.py-2 {
    padding-top: .5rem;
    padding-bottom: .5rem
}

.py-30px {
    padding-top: 30px;
    padding-bottom: 30px
}

.py-4 {
    padding-top: 1rem;
    padding-bottom: 1rem
}

[px~="[create_default_slot]"] {
    padding-left: create default slot;
    padding-right: create default slot
}

[px~="$$invalidate(0,"] {
    padding-left: var(--\$invalidate\(0);
    padding-right:var(--\$invalidate\(0)}

[px~="$$invalidate(22,"] {
    padding-left: var(--\$invalidate\(22);
    padding-right:var(--\$invalidate\(22)}

[px~="$$invalidate(3,"] {
    padding-left: var(--\$invalidate\(3);
    padding-right:var(--\$invalidate\(3)}

[px~="$$invalidate(4,"] {
    padding-left: var(--\$invalidate\(4);
    padding-right:var(--\$invalidate\(4)}

[px~="$$invalidate)"] {
    padding-left: var(--\$invalidate\));
    padding-right: var(--\$invalidate\))
}

[px~="$$props"],[px~="$$props,"] {
    padding-left: var(--\$props);
    padding-right: var(--\$props)
}

[px~="1024"] {
    padding-left: 256rem;
    padding-right: 256rem
}

[px~="128"] {
    padding-left: 32rem;
    padding-right: 32rem
}

[px~="16"] {
    padding-left: 4rem;
    padding-right: 4rem
}

[px~="32"] {
    padding-left: 8rem;
    padding-right: 8rem
}

[px~="64"] {
    padding-left: 16rem;
    padding-right: 16rem
}

[px~="8"] {
    padding-left: 2rem;
    padding-right: 2rem
}

[px~="default:"]:default {
    padding-left: 1rem;
    padding-right: 1rem
}

.pl-12px {
    padding-left: 12px
}

.pt-2 {
    padding-top: .5rem
}

[p~=t] {
    padding-top: 1rem
}

.text-center,[text~=center] {
    text-align: center
}

[align~=start] {
    vertical-align: top
}

.text-\[12px\],.text-12px {
    font-size: 12px
}

.text-13px {
    font-size: 13px
}

.text-6 {
    font-size: 1.5rem
}

.text-lg {
    font-size: 1.125rem;
    line-height: 1.75rem
}

.text-xs {
    font-size: .75rem;
    line-height: 1rem
}

[text~="3"] {
    font-size: .75rem
}

.\!text-white {
    --un-text-opacity: 1 !important;
    color: rgb(255 255 255 / var(--un-text-opacity))!important
}

.dark .dark\:text-white,.text-white,[text-white=""],[text-white~="{"],[text-white~="}"],[text-white~="="],[text-white~="$$props"],[text-white~=bgCheckColor],[text-white~=const],[text-white~="getPrefixCls("],[text-white~=let],[text-white~=prefixCls] {
    --un-text-opacity: 1;
    color: rgb(255 255 255 / var(--un-text-opacity))
}

.text-black {
    --un-text-opacity: 1;
    color: rgb(0 0 0 / var(--un-text-opacity))
}

.color-blue,.text-blue {
    --un-text-opacity: 1;
    color: rgb(96 165 250 / var(--un-text-opacity))
}

.text-green {
    --un-text-opacity: 1;
    color: rgb(74 222 128 / var(--un-text-opacity))
}

.text-green-500 {
    --un-text-opacity: 1;
    color: rgb(34 197 94 / var(--un-text-opacity))
}

.text-ikun-dark-300 {
    color: var(--ikun-dark-300)
}

.text-ikun-error {
    color: var(--ikun-rose-400)
}

.text-ikun-info {
    color: var(--ikun-gray-400)
}

.text-ikun-main,[color~="#f8a153"],[text-ikun-main=""] {
    --un-text-opacity: 1;
    color: rgb(248 161 83 / var(--un-text-opacity))
}

.text-ikun-primary {
    color: var(--ikun-teal-400)
}

.text-ikun-success {
    color: var(--ikun-green-400)
}

.text-ikun-tx-base {
    color: var(--ikun-slate-900)
}

.text-ikun-tx-gr {
    color: var(--ikun-zinc-400)
}

.text-ikun-warning {
    color: var(--ikun-amber-400)
}

.color-red,.text-red {
    --un-text-opacity: 1;
    color: rgb(248 113 113 / var(--un-text-opacity))
}

.text-red-500 {
    --un-text-opacity: 1;
    color: rgb(239 68 68 / var(--un-text-opacity))
}

[text~="$$props"] {
    color: var(--\$props)
}

.hover\:text-ikun-main:hover {
    --un-text-opacity: 1;
    color: rgb(248 161 83 / var(--un-text-opacity))
}

.hover\:text-white:hover {
    --un-text-opacity: 1;
    color: rgb(255 255 255 / var(--un-text-opacity))
}

.color-\#909399 {
    --un-text-opacity: 1;
    color: rgb(144 147 153 / var(--un-text-opacity))
}

[color~="#29b8ce"] {
    --un-text-opacity: 1;
    color: rgb(41 184 206 / var(--un-text-opacity))
}

.font-600 {
    font-weight: 600
}

.leading-160px {
    line-height: 160px
}

.leading-300px {
    line-height: 300px
}

.leading-30px {
    line-height: 30px
}

.leading-60px {
    line-height: 60px
}

.leading-8 {
    line-height: 2rem
}

.\!underline,[\!underline=""] {
    text-decoration-line: underline!important
}

.underline,[underline=""] {
    text-decoration-line: underline
}

[default~=underline]:default {
    text-decoration-line: underline
}

[underline~="0"] {
    text-decoration-thickness: 0px
}

[underline~="$$props"] {
    -webkit-text-decoration-color: var(--\$props);
    text-decoration-color: var(--\$props)
}

[underline~="$$restProps"] {
    -webkit-text-decoration-color: var(--\$restProps);
    text-decoration-color: var(--\$restProps)
}

[underline~="$$scope"] {
    -webkit-text-decoration-color: var(--\$scope);
    text-decoration-color: var(--\$scope)
}

[underline~="$$slots"] {
    -webkit-text-decoration-color: var(--\$slots);
    text-decoration-color: var(--\$slots)
}

.tab,[tab=""] {
    -moz-tab-size: 4;
    -o-tab-size: 4;
    tab-size: 4
}

.op50 {
    opacity: .5
}

.dark .dark\:shadow-ikun-main {
    --un-shadow-opacity: 1;
    --un-shadow-color: rgb(248 161 83 / var(--un-shadow-opacity))
}

.shadow,[shadow=""] {
    --un-shadow: var(--un-shadow-inset) 0 1px 3px 0 var(--un-shadow-color, rgb(0 0 0 / .1)),var(--un-shadow-inset) 0 1px 2px -1px var(--un-shadow-color, rgb(0 0 0 / .1));
    box-shadow: var(--un-ring-offset-shadow),var(--un-ring-shadow),var(--un-shadow)
}

.outline {
    outline-style: solid
}

.blur {
    --un-blur: blur(8px);
    filter: var(--un-blur) var(--un-brightness) var(--un-contrast) var(--un-drop-shadow) var(--un-grayscale) var(--un-hue-rotate) var(--un-invert) var(--un-saturate) var(--un-sepia)
}

.filter {
    filter: var(--un-blur) var(--un-brightness) var(--un-contrast) var(--un-drop-shadow) var(--un-grayscale) var(--un-hue-rotate) var(--un-invert) var(--un-saturate) var(--un-sepia)
}

.-transition,[-transition=""] {
    transition-property: color,background-color,border-color,outline-color,text-decoration-color,fill,stroke,opacity,box-shadow,transform,filter,backdrop-filter;
    transition-timing-function: cubic-bezier(.4,0,.2,1);
    transition-duration: -.15s
}

.transition,[transition=""] {
    transition-property: color,background-color,border-color,outline-color,text-decoration-color,fill,stroke,opacity,box-shadow,transform,filter,backdrop-filter;
    transition-timing-function: cubic-bezier(.4,0,.2,1);
    transition-duration: .15s
}

.duration-200,[duration~="200"] {
    transition-duration: .2s
}

[duration~="$$props"] {
    transition-duration: var(--\$props)
}

[duration~="$$restProps"] {
    transition-duration: var(--\$restProps)
}

[duration~="$$scope"] {
    transition-duration: var(--\$scope)
}

[duration~="0"] {
    transition-duration: 0s
}

[duration~="40"] {
    transition-duration: 40ms
}

.ease,[ease=""] {
    transition-timing-function: cubic-bezier(.4,0,.2,1)
}

.ease-in {
    transition-timing-function: cubic-bezier(.4,0,1,1)
}

.ease-out {
    transition-timing-function: cubic-bezier(0,0,.2,1)
}

.k-input-shadow {
    box-shadow: 0 0 0 2px #f8a1534d
}

.k-btn-shadow--success {
    box-shadow: 0 0 0 2px #4ade8080
}

.k-btn-shadow--error {
    box-shadow: 0 0 0 2px #fb718580
}

.k-btn-shadow--warning {
    box-shadow: 0 0 0 2px #fbbf2480
}

.k-btn-shadow--info {
    box-shadow: 0 0 0 2px #94a3b880
}

.k-btn-shadow--primary {
    box-shadow: 0 0 0 2px #2dd4bf80
}

.k-icon-transition {
    transition: all .3s linear
}

.k-notify-transition {
    transition: top .3s linear
}

.k-switch-transition {
    transition: right .1s linear
}

.k-col-push-1 {
    left: 4.1667%;
    position: relative
}

.k-col-pull-1 {
    right: 4.1667%;
    position: relative
}

.k-col-offset-1 {
    margin-left: 4.1667%
}

.k-col-1 {
    max-width: 4.166666666666666%;
    flex: 0 0 4.1667%
}

.k-col-push-2 {
    left: 8.3333%;
    position: relative
}

.k-col-pull-2 {
    right: 8.3333%;
    position: relative
}

.k-col-offset-2 {
    margin-left: 8.3333%
}

.k-col-2 {
    max-width: 8.333333333333332%;
    flex: 0 0 8.3333%
}

.k-col-push-3 {
    left: 12.5%;
    position: relative
}

.k-col-pull-3 {
    right: 12.5%;
    position: relative
}

.k-col-offset-3 {
    margin-left: 12.5%
}

.k-col-3 {
    max-width: 12.5%;
    flex: 0 0 12.5%
}

.k-col-push-4 {
    left: 16.6667%;
    position: relative
}

.k-col-pull-4 {
    right: 16.6667%;
    position: relative
}

.k-col-offset-4 {
    margin-left: 16.6667%
}

.k-col-4 {
    max-width: 16.666666666666664%;
    flex: 0 0 16.6667%
}

.k-col-push-5 {
    left: 20.8333%;
    position: relative
}

.k-col-pull-5 {
    right: 20.8333%;
    position: relative
}

.k-col-offset-5 {
    margin-left: 20.8333%
}

.k-col-5 {
    max-width: 20.833333333333332%;
    flex: 0 0 20.8333%
}

.k-col-push-6 {
    left: 25%;
    position: relative
}

.k-col-pull-6 {
    right: 25%;
    position: relative
}

.k-col-offset-6 {
    margin-left: 25%
}

.k-col-6 {
    max-width: 25%;
    flex: 0 0 25%
}

.k-col-push-7 {
    left: 29.1667%;
    position: relative
}

.k-col-pull-7 {
    right: 29.1667%;
    position: relative
}

.k-col-offset-7 {
    margin-left: 29.1667%
}

.k-col-7 {
    max-width: 29.166666666666664%;
    flex: 0 0 29.1667%
}

.k-col-push-8 {
    left: 33.3333%;
    position: relative
}

.k-col-pull-8 {
    right: 33.3333%;
    position: relative
}

.k-col-offset-8 {
    margin-left: 33.3333%
}

.k-col-8 {
    max-width: 33.33333333333333%;
    flex: 0 0 33.3333%
}

.k-col-push-9 {
    left: 37.5%;
    position: relative
}

.k-col-pull-9 {
    right: 37.5%;
    position: relative
}

.k-col-offset-9 {
    margin-left: 37.5%
}

.k-col-9 {
    max-width: 37.5%;
    flex: 0 0 37.5%
}

.k-col-push-10 {
    left: 41.6667%;
    position: relative
}

.k-col-pull-10 {
    right: 41.6667%;
    position: relative
}

.k-col-offset-10 {
    margin-left: 41.6667%
}

.k-col-10 {
    max-width: 41.666666666666664%;
    flex: 0 0 41.6667%
}

.k-col-push-11 {
    left: 45.8333%;
    position: relative
}

.k-col-pull-11 {
    right: 45.8333%;
    position: relative
}

.k-col-offset-11 {
    margin-left: 45.8333%
}

.k-col-11 {
    max-width: 45.83333333333333%;
    flex: 0 0 45.8333%
}

.k-col-push-12 {
    left: 50%;
    position: relative
}

.k-col-pull-12 {
    right: 50%;
    position: relative
}

.k-col-offset-12 {
    margin-left: 50%
}

.k-col-12 {
    max-width: 50%;
    flex: 0 0 50%
}

.k-col-push-13 {
    left: 54.1667%;
    position: relative
}

.k-col-pull-13 {
    right: 54.1667%;
    position: relative
}

.k-col-offset-13 {
    margin-left: 54.1667%
}

.k-col-13 {
    max-width: 54.166666666666664%;
    flex: 0 0 54.1667%
}

.k-col-push-14 {
    left: 58.3333%;
    position: relative
}

.k-col-pull-14 {
    right: 58.3333%;
    position: relative
}

.k-col-offset-14 {
    margin-left: 58.3333%
}

.k-col-14 {
    max-width: 58.33333333333333%;
    flex: 0 0 58.3333%
}

.k-col-push-15 {
    left: 62.5%;
    position: relative
}

.k-col-pull-15 {
    right: 62.5%;
    position: relative
}

.k-col-offset-15 {
    margin-left: 62.5%
}

.k-col-15 {
    max-width: 62.5%;
    flex: 0 0 62.5%
}

.k-col-push-16 {
    left: 66.6667%;
    position: relative
}

.k-col-pull-16 {
    right: 66.6667%;
    position: relative
}

.k-col-offset-16 {
    margin-left: 66.6667%
}

.k-col-16 {
    max-width: 66.66666666666666%;
    flex: 0 0 66.6667%
}

.k-col-push-17 {
    left: 70.8333%;
    position: relative
}

.k-col-pull-17 {
    right: 70.8333%;
    position: relative
}

.k-col-offset-17 {
    margin-left: 70.8333%
}

.k-col-17 {
    max-width: 70.83333333333333%;
    flex: 0 0 70.8333%
}

.k-col-push-18 {
    left: 75%;
    position: relative
}

.k-col-pull-18 {
    right: 75%;
    position: relative
}

.k-col-offset-18 {
    margin-left: 75%
}

.k-col-18 {
    max-width: 75%;
    flex: 0 0 75%
}

.k-col-push-19 {
    left: 79.1667%;
    position: relative
}

.k-col-pull-19 {
    right: 79.1667%;
    position: relative
}

.k-col-offset-19 {
    margin-left: 79.1667%
}

.k-col-19 {
    max-width: 79.16666666666666%;
    flex: 0 0 79.1667%
}

.k-col-push-20 {
    left: 83.3333%;
    position: relative
}

.k-col-pull-20 {
    right: 83.3333%;
    position: relative
}

.k-col-offset-20 {
    margin-left: 83.3333%
}

.k-col-20 {
    max-width: 83.33333333333333%;
    flex: 0 0 83.3333%
}

.k-col-push-21 {
    left: 87.5%;
    position: relative
}

.k-col-pull-21 {
    right: 87.5%;
    position: relative
}

.k-col-offset-21 {
    margin-left: 87.5%
}

.k-col-21 {
    max-width: 87.5%;
    flex: 0 0 87.5%
}

.k-col-push-22 {
    left: 91.6667%;
    position: relative
}

.k-col-pull-22 {
    right: 91.6667%;
    position: relative
}

.k-col-offset-22 {
    margin-left: 91.6667%
}

.k-col-22 {
    max-width: 91.66666666666666%;
    flex: 0 0 91.6667%
}

.k-col-push-23 {
    left: 95.8333%;
    position: relative
}

.k-col-pull-23 {
    right: 95.8333%;
    position: relative
}

.k-col-offset-23 {
    margin-left: 95.8333%
}

.k-col-23 {
    max-width: 95.83333333333333%;
    flex: 0 0 95.8333%
}

.k-col-push-24 {
    left: 100%;
    position: relative
}

.k-col-pull-24 {
    right: 100%;
    position: relative
}

.k-col-offset-24 {
    margin-left: 100%
}

.k-col-24 {
    max-width: 100%;
    flex: 0 0 100%
}

.k-descriptions--cols-1 {
    grid: auto-flow / repeat(1,auto)
}

.k-descriptions--cols-2 {
    grid: auto-flow / repeat(2,auto)
}

.k-descriptions--cols-3 {
    grid: auto-flow / repeat(3,auto)
}

.k-descriptions--cols-4 {
    grid: auto-flow / repeat(4,auto)
}

.k-descriptions--cols-5 {
    grid: auto-flow / repeat(5,auto)
}

.k-descriptions--cols-6 {
    grid: auto-flow / repeat(6,auto)
}

.k-descriptions--cols-7 {
    grid: auto-flow / repeat(7,auto)
}

.k-descriptions--cols-8 {
    grid: auto-flow / repeat(8,auto)
}

.k-descriptions--cols-9 {
    grid: auto-flow / repeat(9,auto)
}

.k-descriptions--cols-10 {
    grid: auto-flow / repeat(10,auto)
}

.k-descriptions--cols-11 {
    grid: auto-flow / repeat(11,auto)
}

.k-descriptions--cols-12 {
    grid: auto-flow / repeat(12,auto)
}

.k-descriptions--cols-13 {
    grid: auto-flow / repeat(13,auto)
}

.k-descriptions--cols-14 {
    grid: auto-flow / repeat(14,auto)
}

.k-descriptions--cols-15 {
    grid: auto-flow / repeat(15,auto)
}

.k-descriptions--cols-16 {
    grid: auto-flow / repeat(16,auto)
}

.k-descriptions--cols-17 {
    grid: auto-flow / repeat(17,auto)
}

.k-descriptions--cols-18 {
    grid: auto-flow / repeat(18,auto)
}

.k-descriptions--cols-19 {
    grid: auto-flow / repeat(19,auto)
}

.k-descriptions--cols-20 {
    grid: auto-flow / repeat(20,auto)
}

.k-descriptions--cols-21 {
    grid: auto-flow / repeat(21,auto)
}

.k-descriptions--cols-22 {
    grid: auto-flow / repeat(22,auto)
}

.k-descriptions--cols-23 {
    grid: auto-flow / repeat(23,auto)
}

.k-descriptions--cols-24 {
    grid: auto-flow / repeat(24,auto)
}

.k-descriptions-item--col-1 {
    grid-column-start: 1;
    grid-column-end: -1
}

.ikun-last\:k-descriptions-item--col-1 {
    --at-apply: last:k-descriptions-item--col-1
}

.k-descriptions-item--col-2 {
    grid-column-start: 2;
    grid-column-end: -1
}

.ikun-last\:k-descriptions-item--col-2 {
    --at-apply: last:k-descriptions-item--col-2
}

.k-descriptions-item--col-3 {
    grid-column-start: 3;
    grid-column-end: -1
}

.ikun-last\:k-descriptions-item--col-3 {
    --at-apply: last:k-descriptions-item--col-3
}

.k-descriptions-item--col-4 {
    grid-column-start: 4;
    grid-column-end: -1
}

.ikun-last\:k-descriptions-item--col-4 {
    --at-apply: last:k-descriptions-item--col-4
}

.k-descriptions-item--col-5 {
    grid-column-start: 5;
    grid-column-end: -1
}

.ikun-last\:k-descriptions-item--col-5 {
    --at-apply: last:k-descriptions-item--col-5
}

.k-descriptions-item--col-6 {
    grid-column-start: 6;
    grid-column-end: -1
}

.ikun-last\:k-descriptions-item--col-6 {
    --at-apply: last:k-descriptions-item--col-6
}

.k-descriptions-item--col-7 {
    grid-column-start: 7;
    grid-column-end: -1
}

.ikun-last\:k-descriptions-item--col-7 {
    --at-apply: last:k-descriptions-item--col-7
}

.k-descriptions-item--col-8 {
    grid-column-start: 8;
    grid-column-end: -1
}

.ikun-last\:k-descriptions-item--col-8 {
    --at-apply: last:k-descriptions-item--col-8
}

.k-descriptions-item--col-9 {
    grid-column-start: 9;
    grid-column-end: -1
}

.ikun-last\:k-descriptions-item--col-9 {
    --at-apply: last:k-descriptions-item--col-9
}

.k-descriptions-item--col-10 {
    grid-column-start: 10;
    grid-column-end: -1
}

.ikun-last\:k-descriptions-item--col-10 {
    --at-apply: last:k-descriptions-item--col-10
}

.k-descriptions-item--col-11 {
    grid-column-start: 11;
    grid-column-end: -1
}

.ikun-last\:k-descriptions-item--col-11 {
    --at-apply: last:k-descriptions-item--col-11
}

.k-descriptions-item--col-12 {
    grid-column-start: 12;
    grid-column-end: -1
}

.ikun-last\:k-descriptions-item--col-12 {
    --at-apply: last:k-descriptions-item--col-12
}

.k-descriptions-item--col-13 {
    grid-column-start: 13;
    grid-column-end: -1
}

.ikun-last\:k-descriptions-item--col-13 {
    --at-apply: last:k-descriptions-item--col-13
}

.k-descriptions-item--col-14 {
    grid-column-start: 14;
    grid-column-end: -1
}

.ikun-last\:k-descriptions-item--col-14 {
    --at-apply: last:k-descriptions-item--col-14
}

.k-descriptions-item--col-15 {
    grid-column-start: 15;
    grid-column-end: -1
}

.ikun-last\:k-descriptions-item--col-15 {
    --at-apply: last:k-descriptions-item--col-15
}

.k-descriptions-item--col-16 {
    grid-column-start: 16;
    grid-column-end: -1
}

.ikun-last\:k-descriptions-item--col-16 {
    --at-apply: last:k-descriptions-item--col-16
}

.k-descriptions-item--col-17 {
    grid-column-start: 17;
    grid-column-end: -1
}

.ikun-last\:k-descriptions-item--col-17 {
    --at-apply: last:k-descriptions-item--col-17
}

.k-descriptions-item--col-18 {
    grid-column-start: 18;
    grid-column-end: -1
}

.ikun-last\:k-descriptions-item--col-18 {
    --at-apply: last:k-descriptions-item--col-18
}

.k-descriptions-item--col-19 {
    grid-column-start: 19;
    grid-column-end: -1
}

.ikun-last\:k-descriptions-item--col-19 {
    --at-apply: last:k-descriptions-item--col-19
}

.k-descriptions-item--col-20 {
    grid-column-start: 20;
    grid-column-end: -1
}

.ikun-last\:k-descriptions-item--col-20 {
    --at-apply: last:k-descriptions-item--col-20
}

.k-descriptions-item--col-21 {
    grid-column-start: 21;
    grid-column-end: -1
}

.ikun-last\:k-descriptions-item--col-21 {
    --at-apply: last:k-descriptions-item--col-21
}

.k-descriptions-item--col-22 {
    grid-column-start: 22;
    grid-column-end: -1
}

.ikun-last\:k-descriptions-item--col-22 {
    --at-apply: last:k-descriptions-item--col-22
}

.k-descriptions-item--col-23 {
    grid-column-start: 23;
    grid-column-end: -1
}

.ikun-last\:k-descriptions-item--col-23 {
    --at-apply: last:k-descriptions-item--col-23
}

.k-descriptions-item--col-24 {
    grid-column-start: 24;
    grid-column-end: -1
}

.ikun-last\:k-descriptions-item--col-24 {
    --at-apply: last:k-descriptions-item--col-24
}

.ikun\:50\:bg-ikun-main {
    --ikun-context-background-color: rgba(248,161,83,.5);
    background-color: var(--ikun-context-background-color)
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-0.is-guttered {
        display:none
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-0 {
        max-width:0%;
        flex: 0 0 0%
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-1 {
        max-width:4.166666666666666%;
        flex: 0 0 4.1667%;
        display: block
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-10 {
        max-width:41.666666666666664%;
        flex: 0 0 41.6667%;
        display: block
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-11 {
        max-width:45.83333333333333%;
        flex: 0 0 45.8333%;
        display: block
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-12 {
        max-width:50%;
        flex: 0 0 50%;
        display: block
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-13 {
        max-width:54.166666666666664%;
        flex: 0 0 54.1667%;
        display: block
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-14 {
        max-width:58.33333333333333%;
        flex: 0 0 58.3333%;
        display: block
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-15 {
        max-width:62.5%;
        flex: 0 0 62.5%;
        display: block
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-16 {
        max-width:66.66666666666666%;
        flex: 0 0 66.6667%;
        display: block
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-17 {
        max-width:70.83333333333333%;
        flex: 0 0 70.8333%;
        display: block
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-18 {
        max-width:75%;
        flex: 0 0 75%;
        display: block
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-19 {
        max-width:79.16666666666666%;
        flex: 0 0 79.1667%;
        display: block
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-2 {
        max-width:8.333333333333332%;
        flex: 0 0 8.3333%;
        display: block
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-20 {
        max-width:83.33333333333333%;
        flex: 0 0 83.3333%;
        display: block
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-21 {
        max-width:87.5%;
        flex: 0 0 87.5%;
        display: block
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-22 {
        max-width:91.66666666666666%;
        flex: 0 0 91.6667%;
        display: block
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-23 {
        max-width:95.83333333333333%;
        flex: 0 0 95.8333%;
        display: block
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-24 {
        max-width:100%;
        flex: 0 0 100%;
        display: block
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-3 {
        max-width:12.5%;
        flex: 0 0 12.5%;
        display: block
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-4 {
        max-width:16.666666666666664%;
        flex: 0 0 16.6667%;
        display: block
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-5 {
        max-width:20.833333333333332%;
        flex: 0 0 20.8333%;
        display: block
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-6 {
        max-width:25%;
        flex: 0 0 25%;
        display: block
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-7 {
        max-width:29.166666666666664%;
        flex: 0 0 29.1667%;
        display: block
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-8 {
        max-width:33.33333333333333%;
        flex: 0 0 33.3333%;
        display: block
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-9 {
        max-width:37.5%;
        flex: 0 0 37.5%;
        display: block
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-offset-0 {
        margin-left:0%
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-offset-1 {
        margin-left:4.1667%
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-offset-10 {
        margin-left:41.6667%
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-offset-11 {
        margin-left:45.8333%
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-offset-12 {
        margin-left:50%
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-offset-13 {
        margin-left:54.1667%
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-offset-14 {
        margin-left:58.3333%
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-offset-15 {
        margin-left:62.5%
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-offset-16 {
        margin-left:66.6667%
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-offset-17 {
        margin-left:70.8333%
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-offset-18 {
        margin-left:75%
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-offset-19 {
        margin-left:79.1667%
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-offset-2 {
        margin-left:8.3333%
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-offset-20 {
        margin-left:83.3333%
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-offset-21 {
        margin-left:87.5%
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-offset-22 {
        margin-left:91.6667%
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-offset-23 {
        margin-left:95.8333%
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-offset-24 {
        margin-left:100%
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-offset-3 {
        margin-left:12.5%
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-offset-4 {
        margin-left:16.6667%
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-offset-5 {
        margin-left:20.8333%
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-offset-6 {
        margin-left:25%
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-offset-7 {
        margin-left:29.1667%
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-offset-8 {
        margin-left:33.3333%
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-offset-9 {
        margin-left:37.5%
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-pull-0 {
        right:0%;
        position: relative
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-pull-1 {
        right:4.1667%;
        position: relative
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-pull-10 {
        right:41.6667%;
        position: relative
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-pull-11 {
        right:45.8333%;
        position: relative
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-pull-12 {
        right:50%;
        position: relative
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-pull-13 {
        right:54.1667%;
        position: relative
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-pull-14 {
        right:58.3333%;
        position: relative
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-pull-15 {
        right:62.5%;
        position: relative
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-pull-16 {
        right:66.6667%;
        position: relative
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-pull-17 {
        right:70.8333%;
        position: relative
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-pull-18 {
        right:75%;
        position: relative
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-pull-19 {
        right:79.1667%;
        position: relative
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-pull-2 {
        right:8.3333%;
        position: relative
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-pull-20 {
        right:83.3333%;
        position: relative
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-pull-21 {
        right:87.5%;
        position: relative
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-pull-22 {
        right:91.6667%;
        position: relative
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-pull-23 {
        right:95.8333%;
        position: relative
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-pull-24 {
        right:100%;
        position: relative
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-pull-3 {
        right:12.5%;
        position: relative
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-pull-4 {
        right:16.6667%;
        position: relative
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-pull-5 {
        right:20.8333%;
        position: relative
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-pull-6 {
        right:25%;
        position: relative
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-pull-7 {
        right:29.1667%;
        position: relative
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-pull-8 {
        right:33.3333%;
        position: relative
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-pull-9 {
        right:37.5%;
        position: relative
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-push-0 {
        left:0%;
        position: relative
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-push-1 {
        left:4.1667%;
        position: relative
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-push-10 {
        left:41.6667%;
        position: relative
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-push-11 {
        left:45.8333%;
        position: relative
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-push-12 {
        left:50%;
        position: relative
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-push-13 {
        left:54.1667%;
        position: relative
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-push-14 {
        left:58.3333%;
        position: relative
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-push-15 {
        left:62.5%;
        position: relative
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-push-16 {
        left:66.6667%;
        position: relative
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-push-17 {
        left:70.8333%;
        position: relative
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-push-18 {
        left:75%;
        position: relative
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-push-19 {
        left:79.1667%;
        position: relative
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-push-2 {
        left:8.3333%;
        position: relative
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-push-20 {
        left:83.3333%;
        position: relative
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-push-21 {
        left:87.5%;
        position: relative
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-push-22 {
        left:91.6667%;
        position: relative
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-push-23 {
        left:95.8333%;
        position: relative
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-push-24 {
        left:100%;
        position: relative
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-push-3 {
        left:12.5%;
        position: relative
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-push-4 {
        left:16.6667%;
        position: relative
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-push-5 {
        left:20.8333%;
        position: relative
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-push-6 {
        left:25%;
        position: relative
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-push-7 {
        left:29.1667%;
        position: relative
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-push-8 {
        left:33.3333%;
        position: relative
    }
}

@media only screen and (max-width: 768px) {
    .ikun-xs\:k-col-xs-push-9 {
        left:37.5%;
        position: relative
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-0.is-guttered {
        display:none
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-0 {
        max-width:0%;
        flex: 0 0 0%
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-1 {
        max-width:4.166666666666666%;
        flex: 0 0 4.1667%;
        display: block
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-10 {
        max-width:41.666666666666664%;
        flex: 0 0 41.6667%;
        display: block
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-11 {
        max-width:45.83333333333333%;
        flex: 0 0 45.8333%;
        display: block
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-12 {
        max-width:50%;
        flex: 0 0 50%;
        display: block
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-13 {
        max-width:54.166666666666664%;
        flex: 0 0 54.1667%;
        display: block
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-14 {
        max-width:58.33333333333333%;
        flex: 0 0 58.3333%;
        display: block
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-15 {
        max-width:62.5%;
        flex: 0 0 62.5%;
        display: block
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-16 {
        max-width:66.66666666666666%;
        flex: 0 0 66.6667%;
        display: block
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-17 {
        max-width:70.83333333333333%;
        flex: 0 0 70.8333%;
        display: block
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-18 {
        max-width:75%;
        flex: 0 0 75%;
        display: block
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-19 {
        max-width:79.16666666666666%;
        flex: 0 0 79.1667%;
        display: block
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-2 {
        max-width:8.333333333333332%;
        flex: 0 0 8.3333%;
        display: block
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-20 {
        max-width:83.33333333333333%;
        flex: 0 0 83.3333%;
        display: block
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-21 {
        max-width:87.5%;
        flex: 0 0 87.5%;
        display: block
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-22 {
        max-width:91.66666666666666%;
        flex: 0 0 91.6667%;
        display: block
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-23 {
        max-width:95.83333333333333%;
        flex: 0 0 95.8333%;
        display: block
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-24 {
        max-width:100%;
        flex: 0 0 100%;
        display: block
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-3 {
        max-width:12.5%;
        flex: 0 0 12.5%;
        display: block
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-4 {
        max-width:16.666666666666664%;
        flex: 0 0 16.6667%;
        display: block
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-5 {
        max-width:20.833333333333332%;
        flex: 0 0 20.8333%;
        display: block
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-6 {
        max-width:25%;
        flex: 0 0 25%;
        display: block
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-7 {
        max-width:29.166666666666664%;
        flex: 0 0 29.1667%;
        display: block
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-8 {
        max-width:33.33333333333333%;
        flex: 0 0 33.3333%;
        display: block
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-9 {
        max-width:37.5%;
        flex: 0 0 37.5%;
        display: block
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-offset-0 {
        margin-left:0%
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-offset-1 {
        margin-left:4.1667%
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-offset-10 {
        margin-left:41.6667%
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-offset-11 {
        margin-left:45.8333%
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-offset-12 {
        margin-left:50%
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-offset-13 {
        margin-left:54.1667%
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-offset-14 {
        margin-left:58.3333%
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-offset-15 {
        margin-left:62.5%
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-offset-16 {
        margin-left:66.6667%
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-offset-17 {
        margin-left:70.8333%
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-offset-18 {
        margin-left:75%
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-offset-19 {
        margin-left:79.1667%
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-offset-2 {
        margin-left:8.3333%
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-offset-20 {
        margin-left:83.3333%
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-offset-21 {
        margin-left:87.5%
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-offset-22 {
        margin-left:91.6667%
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-offset-23 {
        margin-left:95.8333%
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-offset-24 {
        margin-left:100%
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-offset-3 {
        margin-left:12.5%
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-offset-4 {
        margin-left:16.6667%
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-offset-5 {
        margin-left:20.8333%
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-offset-6 {
        margin-left:25%
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-offset-7 {
        margin-left:29.1667%
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-offset-8 {
        margin-left:33.3333%
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-offset-9 {
        margin-left:37.5%
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-pull-0 {
        right:0%;
        position: relative
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-pull-1 {
        right:4.1667%;
        position: relative
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-pull-10 {
        right:41.6667%;
        position: relative
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-pull-11 {
        right:45.8333%;
        position: relative
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-pull-12 {
        right:50%;
        position: relative
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-pull-13 {
        right:54.1667%;
        position: relative
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-pull-14 {
        right:58.3333%;
        position: relative
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-pull-15 {
        right:62.5%;
        position: relative
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-pull-16 {
        right:66.6667%;
        position: relative
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-pull-17 {
        right:70.8333%;
        position: relative
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-pull-18 {
        right:75%;
        position: relative
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-pull-19 {
        right:79.1667%;
        position: relative
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-pull-2 {
        right:8.3333%;
        position: relative
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-pull-20 {
        right:83.3333%;
        position: relative
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-pull-21 {
        right:87.5%;
        position: relative
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-pull-22 {
        right:91.6667%;
        position: relative
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-pull-23 {
        right:95.8333%;
        position: relative
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-pull-24 {
        right:100%;
        position: relative
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-pull-3 {
        right:12.5%;
        position: relative
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-pull-4 {
        right:16.6667%;
        position: relative
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-pull-5 {
        right:20.8333%;
        position: relative
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-pull-6 {
        right:25%;
        position: relative
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-pull-7 {
        right:29.1667%;
        position: relative
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-pull-8 {
        right:33.3333%;
        position: relative
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-pull-9 {
        right:37.5%;
        position: relative
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-push-0 {
        left:0%;
        position: relative
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-push-1 {
        left:4.1667%;
        position: relative
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-push-10 {
        left:41.6667%;
        position: relative
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-push-11 {
        left:45.8333%;
        position: relative
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-push-12 {
        left:50%;
        position: relative
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-push-13 {
        left:54.1667%;
        position: relative
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-push-14 {
        left:58.3333%;
        position: relative
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-push-15 {
        left:62.5%;
        position: relative
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-push-16 {
        left:66.6667%;
        position: relative
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-push-17 {
        left:70.8333%;
        position: relative
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-push-18 {
        left:75%;
        position: relative
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-push-19 {
        left:79.1667%;
        position: relative
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-push-2 {
        left:8.3333%;
        position: relative
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-push-20 {
        left:83.3333%;
        position: relative
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-push-21 {
        left:87.5%;
        position: relative
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-push-22 {
        left:91.6667%;
        position: relative
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-push-23 {
        left:95.8333%;
        position: relative
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-push-24 {
        left:100%;
        position: relative
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-push-3 {
        left:12.5%;
        position: relative
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-push-4 {
        left:16.6667%;
        position: relative
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-push-5 {
        left:20.8333%;
        position: relative
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-push-6 {
        left:25%;
        position: relative
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-push-7 {
        left:29.1667%;
        position: relative
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-push-8 {
        left:33.3333%;
        position: relative
    }
}

@media only screen and (min-width: 1200px) {
    .ikun-lg\:k-col-lg-push-9 {
        left:37.5%;
        position: relative
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-0.is-guttered {
        display:none
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-0 {
        max-width:0%;
        flex: 0 0 0%
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-1 {
        max-width:4.166666666666666%;
        flex: 0 0 4.1667%;
        display: block
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-10 {
        max-width:41.666666666666664%;
        flex: 0 0 41.6667%;
        display: block
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-11 {
        max-width:45.83333333333333%;
        flex: 0 0 45.8333%;
        display: block
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-12 {
        max-width:50%;
        flex: 0 0 50%;
        display: block
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-13 {
        max-width:54.166666666666664%;
        flex: 0 0 54.1667%;
        display: block
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-14 {
        max-width:58.33333333333333%;
        flex: 0 0 58.3333%;
        display: block
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-15 {
        max-width:62.5%;
        flex: 0 0 62.5%;
        display: block
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-16 {
        max-width:66.66666666666666%;
        flex: 0 0 66.6667%;
        display: block
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-17 {
        max-width:70.83333333333333%;
        flex: 0 0 70.8333%;
        display: block
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-18 {
        max-width:75%;
        flex: 0 0 75%;
        display: block
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-19 {
        max-width:79.16666666666666%;
        flex: 0 0 79.1667%;
        display: block
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-2 {
        max-width:8.333333333333332%;
        flex: 0 0 8.3333%;
        display: block
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-20 {
        max-width:83.33333333333333%;
        flex: 0 0 83.3333%;
        display: block
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-21 {
        max-width:87.5%;
        flex: 0 0 87.5%;
        display: block
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-22 {
        max-width:91.66666666666666%;
        flex: 0 0 91.6667%;
        display: block
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-23 {
        max-width:95.83333333333333%;
        flex: 0 0 95.8333%;
        display: block
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-24 {
        max-width:100%;
        flex: 0 0 100%;
        display: block
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-3 {
        max-width:12.5%;
        flex: 0 0 12.5%;
        display: block
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-4 {
        max-width:16.666666666666664%;
        flex: 0 0 16.6667%;
        display: block
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-5 {
        max-width:20.833333333333332%;
        flex: 0 0 20.8333%;
        display: block
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-6 {
        max-width:25%;
        flex: 0 0 25%;
        display: block
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-7 {
        max-width:29.166666666666664%;
        flex: 0 0 29.1667%;
        display: block
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-8 {
        max-width:33.33333333333333%;
        flex: 0 0 33.3333%;
        display: block
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-9 {
        max-width:37.5%;
        flex: 0 0 37.5%;
        display: block
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-offset-0 {
        margin-left:0%
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-offset-1 {
        margin-left:4.1667%
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-offset-10 {
        margin-left:41.6667%
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-offset-11 {
        margin-left:45.8333%
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-offset-12 {
        margin-left:50%
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-offset-13 {
        margin-left:54.1667%
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-offset-14 {
        margin-left:58.3333%
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-offset-15 {
        margin-left:62.5%
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-offset-16 {
        margin-left:66.6667%
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-offset-17 {
        margin-left:70.8333%
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-offset-18 {
        margin-left:75%
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-offset-19 {
        margin-left:79.1667%
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-offset-2 {
        margin-left:8.3333%
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-offset-20 {
        margin-left:83.3333%
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-offset-21 {
        margin-left:87.5%
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-offset-22 {
        margin-left:91.6667%
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-offset-23 {
        margin-left:95.8333%
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-offset-24 {
        margin-left:100%
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-offset-3 {
        margin-left:12.5%
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-offset-4 {
        margin-left:16.6667%
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-offset-5 {
        margin-left:20.8333%
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-offset-6 {
        margin-left:25%
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-offset-7 {
        margin-left:29.1667%
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-offset-8 {
        margin-left:33.3333%
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-offset-9 {
        margin-left:37.5%
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-pull-0 {
        right:0%;
        position: relative
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-pull-1 {
        right:4.1667%;
        position: relative
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-pull-10 {
        right:41.6667%;
        position: relative
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-pull-11 {
        right:45.8333%;
        position: relative
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-pull-12 {
        right:50%;
        position: relative
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-pull-13 {
        right:54.1667%;
        position: relative
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-pull-14 {
        right:58.3333%;
        position: relative
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-pull-15 {
        right:62.5%;
        position: relative
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-pull-16 {
        right:66.6667%;
        position: relative
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-pull-17 {
        right:70.8333%;
        position: relative
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-pull-18 {
        right:75%;
        position: relative
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-pull-19 {
        right:79.1667%;
        position: relative
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-pull-2 {
        right:8.3333%;
        position: relative
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-pull-20 {
        right:83.3333%;
        position: relative
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-pull-21 {
        right:87.5%;
        position: relative
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-pull-22 {
        right:91.6667%;
        position: relative
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-pull-23 {
        right:95.8333%;
        position: relative
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-pull-24 {
        right:100%;
        position: relative
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-pull-3 {
        right:12.5%;
        position: relative
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-pull-4 {
        right:16.6667%;
        position: relative
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-pull-5 {
        right:20.8333%;
        position: relative
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-pull-6 {
        right:25%;
        position: relative
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-pull-7 {
        right:29.1667%;
        position: relative
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-pull-8 {
        right:33.3333%;
        position: relative
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-pull-9 {
        right:37.5%;
        position: relative
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-push-0 {
        left:0%;
        position: relative
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-push-1 {
        left:4.1667%;
        position: relative
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-push-10 {
        left:41.6667%;
        position: relative
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-push-11 {
        left:45.8333%;
        position: relative
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-push-12 {
        left:50%;
        position: relative
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-push-13 {
        left:54.1667%;
        position: relative
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-push-14 {
        left:58.3333%;
        position: relative
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-push-15 {
        left:62.5%;
        position: relative
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-push-16 {
        left:66.6667%;
        position: relative
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-push-17 {
        left:70.8333%;
        position: relative
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-push-18 {
        left:75%;
        position: relative
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-push-19 {
        left:79.1667%;
        position: relative
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-push-2 {
        left:8.3333%;
        position: relative
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-push-20 {
        left:83.3333%;
        position: relative
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-push-21 {
        left:87.5%;
        position: relative
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-push-22 {
        left:91.6667%;
        position: relative
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-push-23 {
        left:95.8333%;
        position: relative
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-push-24 {
        left:100%;
        position: relative
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-push-3 {
        left:12.5%;
        position: relative
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-push-4 {
        left:16.6667%;
        position: relative
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-push-5 {
        left:20.8333%;
        position: relative
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-push-6 {
        left:25%;
        position: relative
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-push-7 {
        left:29.1667%;
        position: relative
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-push-8 {
        left:33.3333%;
        position: relative
    }
}

@media only screen and (min-width: 1920px) {
    .ikun-xl\:k-col-xl-push-9 {
        left:37.5%;
        position: relative
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-0.is-guttered {
        display:none
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-0 {
        max-width:0%;
        flex: 0 0 0%
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-1 {
        max-width:4.166666666666666%;
        flex: 0 0 4.1667%;
        display: block
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-10 {
        max-width:41.666666666666664%;
        flex: 0 0 41.6667%;
        display: block
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-11 {
        max-width:45.83333333333333%;
        flex: 0 0 45.8333%;
        display: block
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-12 {
        max-width:50%;
        flex: 0 0 50%;
        display: block
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-13 {
        max-width:54.166666666666664%;
        flex: 0 0 54.1667%;
        display: block
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-14 {
        max-width:58.33333333333333%;
        flex: 0 0 58.3333%;
        display: block
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-15 {
        max-width:62.5%;
        flex: 0 0 62.5%;
        display: block
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-16 {
        max-width:66.66666666666666%;
        flex: 0 0 66.6667%;
        display: block
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-17 {
        max-width:70.83333333333333%;
        flex: 0 0 70.8333%;
        display: block
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-18 {
        max-width:75%;
        flex: 0 0 75%;
        display: block
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-19 {
        max-width:79.16666666666666%;
        flex: 0 0 79.1667%;
        display: block
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-2 {
        max-width:8.333333333333332%;
        flex: 0 0 8.3333%;
        display: block
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-20 {
        max-width:83.33333333333333%;
        flex: 0 0 83.3333%;
        display: block
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-21 {
        max-width:87.5%;
        flex: 0 0 87.5%;
        display: block
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-22 {
        max-width:91.66666666666666%;
        flex: 0 0 91.6667%;
        display: block
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-23 {
        max-width:95.83333333333333%;
        flex: 0 0 95.8333%;
        display: block
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-24 {
        max-width:100%;
        flex: 0 0 100%;
        display: block
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-3 {
        max-width:12.5%;
        flex: 0 0 12.5%;
        display: block
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-4 {
        max-width:16.666666666666664%;
        flex: 0 0 16.6667%;
        display: block
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-5 {
        max-width:20.833333333333332%;
        flex: 0 0 20.8333%;
        display: block
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-6 {
        max-width:25%;
        flex: 0 0 25%;
        display: block
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-7 {
        max-width:29.166666666666664%;
        flex: 0 0 29.1667%;
        display: block
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-8 {
        max-width:33.33333333333333%;
        flex: 0 0 33.3333%;
        display: block
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-9 {
        max-width:37.5%;
        flex: 0 0 37.5%;
        display: block
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-offset-0 {
        margin-left:0%
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-offset-1 {
        margin-left:4.1667%
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-offset-10 {
        margin-left:41.6667%
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-offset-11 {
        margin-left:45.8333%
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-offset-12 {
        margin-left:50%
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-offset-13 {
        margin-left:54.1667%
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-offset-14 {
        margin-left:58.3333%
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-offset-15 {
        margin-left:62.5%
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-offset-16 {
        margin-left:66.6667%
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-offset-17 {
        margin-left:70.8333%
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-offset-18 {
        margin-left:75%
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-offset-19 {
        margin-left:79.1667%
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-offset-2 {
        margin-left:8.3333%
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-offset-20 {
        margin-left:83.3333%
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-offset-21 {
        margin-left:87.5%
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-offset-22 {
        margin-left:91.6667%
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-offset-23 {
        margin-left:95.8333%
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-offset-24 {
        margin-left:100%
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-offset-3 {
        margin-left:12.5%
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-offset-4 {
        margin-left:16.6667%
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-offset-5 {
        margin-left:20.8333%
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-offset-6 {
        margin-left:25%
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-offset-7 {
        margin-left:29.1667%
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-offset-8 {
        margin-left:33.3333%
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-offset-9 {
        margin-left:37.5%
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-pull-0 {
        right:0%;
        position: relative
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-pull-1 {
        right:4.1667%;
        position: relative
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-pull-10 {
        right:41.6667%;
        position: relative
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-pull-11 {
        right:45.8333%;
        position: relative
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-pull-12 {
        right:50%;
        position: relative
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-pull-13 {
        right:54.1667%;
        position: relative
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-pull-14 {
        right:58.3333%;
        position: relative
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-pull-15 {
        right:62.5%;
        position: relative
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-pull-16 {
        right:66.6667%;
        position: relative
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-pull-17 {
        right:70.8333%;
        position: relative
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-pull-18 {
        right:75%;
        position: relative
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-pull-19 {
        right:79.1667%;
        position: relative
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-pull-2 {
        right:8.3333%;
        position: relative
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-pull-20 {
        right:83.3333%;
        position: relative
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-pull-21 {
        right:87.5%;
        position: relative
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-pull-22 {
        right:91.6667%;
        position: relative
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-pull-23 {
        right:95.8333%;
        position: relative
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-pull-24 {
        right:100%;
        position: relative
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-pull-3 {
        right:12.5%;
        position: relative
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-pull-4 {
        right:16.6667%;
        position: relative
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-pull-5 {
        right:20.8333%;
        position: relative
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-pull-6 {
        right:25%;
        position: relative
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-pull-7 {
        right:29.1667%;
        position: relative
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-pull-8 {
        right:33.3333%;
        position: relative
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-pull-9 {
        right:37.5%;
        position: relative
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-push-0 {
        left:0%;
        position: relative
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-push-1 {
        left:4.1667%;
        position: relative
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-push-10 {
        left:41.6667%;
        position: relative
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-push-11 {
        left:45.8333%;
        position: relative
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-push-12 {
        left:50%;
        position: relative
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-push-13 {
        left:54.1667%;
        position: relative
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-push-14 {
        left:58.3333%;
        position: relative
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-push-15 {
        left:62.5%;
        position: relative
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-push-16 {
        left:66.6667%;
        position: relative
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-push-17 {
        left:70.8333%;
        position: relative
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-push-18 {
        left:75%;
        position: relative
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-push-19 {
        left:79.1667%;
        position: relative
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-push-2 {
        left:8.3333%;
        position: relative
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-push-20 {
        left:83.3333%;
        position: relative
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-push-21 {
        left:87.5%;
        position: relative
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-push-22 {
        left:91.6667%;
        position: relative
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-push-23 {
        left:95.8333%;
        position: relative
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-push-24 {
        left:100%;
        position: relative
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-push-3 {
        left:12.5%;
        position: relative
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-push-4 {
        left:16.6667%;
        position: relative
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-push-5 {
        left:20.8333%;
        position: relative
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-push-6 {
        left:25%;
        position: relative
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-push-7 {
        left:29.1667%;
        position: relative
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-push-8 {
        left:33.3333%;
        position: relative
    }
}

@media only screen and (min-width: 768px) {
    .ikun-sm\:k-col-sm-push-9 {
        left:37.5%;
        position: relative
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-0.is-guttered {
        display:none
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-0 {
        max-width:0%;
        flex: 0 0 0%
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-1 {
        max-width:4.166666666666666%;
        flex: 0 0 4.1667%;
        display: block
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-10 {
        max-width:41.666666666666664%;
        flex: 0 0 41.6667%;
        display: block
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-11 {
        max-width:45.83333333333333%;
        flex: 0 0 45.8333%;
        display: block
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-12 {
        max-width:50%;
        flex: 0 0 50%;
        display: block
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-13 {
        max-width:54.166666666666664%;
        flex: 0 0 54.1667%;
        display: block
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-14 {
        max-width:58.33333333333333%;
        flex: 0 0 58.3333%;
        display: block
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-15 {
        max-width:62.5%;
        flex: 0 0 62.5%;
        display: block
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-16 {
        max-width:66.66666666666666%;
        flex: 0 0 66.6667%;
        display: block
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-17 {
        max-width:70.83333333333333%;
        flex: 0 0 70.8333%;
        display: block
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-18 {
        max-width:75%;
        flex: 0 0 75%;
        display: block
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-19 {
        max-width:79.16666666666666%;
        flex: 0 0 79.1667%;
        display: block
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-2 {
        max-width:8.333333333333332%;
        flex: 0 0 8.3333%;
        display: block
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-20 {
        max-width:83.33333333333333%;
        flex: 0 0 83.3333%;
        display: block
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-21 {
        max-width:87.5%;
        flex: 0 0 87.5%;
        display: block
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-22 {
        max-width:91.66666666666666%;
        flex: 0 0 91.6667%;
        display: block
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-23 {
        max-width:95.83333333333333%;
        flex: 0 0 95.8333%;
        display: block
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-24 {
        max-width:100%;
        flex: 0 0 100%;
        display: block
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-3 {
        max-width:12.5%;
        flex: 0 0 12.5%;
        display: block
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-4 {
        max-width:16.666666666666664%;
        flex: 0 0 16.6667%;
        display: block
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-5 {
        max-width:20.833333333333332%;
        flex: 0 0 20.8333%;
        display: block
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-6 {
        max-width:25%;
        flex: 0 0 25%;
        display: block
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-7 {
        max-width:29.166666666666664%;
        flex: 0 0 29.1667%;
        display: block
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-8 {
        max-width:33.33333333333333%;
        flex: 0 0 33.3333%;
        display: block
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-9 {
        max-width:37.5%;
        flex: 0 0 37.5%;
        display: block
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-offset-0 {
        margin-left:0%
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-offset-1 {
        margin-left:4.1667%
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-offset-10 {
        margin-left:41.6667%
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-offset-11 {
        margin-left:45.8333%
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-offset-12 {
        margin-left:50%
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-offset-13 {
        margin-left:54.1667%
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-offset-14 {
        margin-left:58.3333%
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-offset-15 {
        margin-left:62.5%
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-offset-16 {
        margin-left:66.6667%
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-offset-17 {
        margin-left:70.8333%
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-offset-18 {
        margin-left:75%
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-offset-19 {
        margin-left:79.1667%
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-offset-2 {
        margin-left:8.3333%
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-offset-20 {
        margin-left:83.3333%
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-offset-21 {
        margin-left:87.5%
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-offset-22 {
        margin-left:91.6667%
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-offset-23 {
        margin-left:95.8333%
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-offset-24 {
        margin-left:100%
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-offset-3 {
        margin-left:12.5%
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-offset-4 {
        margin-left:16.6667%
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-offset-5 {
        margin-left:20.8333%
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-offset-6 {
        margin-left:25%
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-offset-7 {
        margin-left:29.1667%
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-offset-8 {
        margin-left:33.3333%
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-offset-9 {
        margin-left:37.5%
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-pull-0 {
        right:0%;
        position: relative
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-pull-1 {
        right:4.1667%;
        position: relative
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-pull-10 {
        right:41.6667%;
        position: relative
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-pull-11 {
        right:45.8333%;
        position: relative
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-pull-12 {
        right:50%;
        position: relative
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-pull-13 {
        right:54.1667%;
        position: relative
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-pull-14 {
        right:58.3333%;
        position: relative
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-pull-15 {
        right:62.5%;
        position: relative
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-pull-16 {
        right:66.6667%;
        position: relative
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-pull-17 {
        right:70.8333%;
        position: relative
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-pull-18 {
        right:75%;
        position: relative
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-pull-19 {
        right:79.1667%;
        position: relative
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-pull-2 {
        right:8.3333%;
        position: relative
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-pull-20 {
        right:83.3333%;
        position: relative
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-pull-21 {
        right:87.5%;
        position: relative
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-pull-22 {
        right:91.6667%;
        position: relative
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-pull-23 {
        right:95.8333%;
        position: relative
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-pull-24 {
        right:100%;
        position: relative
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-pull-3 {
        right:12.5%;
        position: relative
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-pull-4 {
        right:16.6667%;
        position: relative
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-pull-5 {
        right:20.8333%;
        position: relative
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-pull-6 {
        right:25%;
        position: relative
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-pull-7 {
        right:29.1667%;
        position: relative
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-pull-8 {
        right:33.3333%;
        position: relative
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-pull-9 {
        right:37.5%;
        position: relative
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-push-0 {
        left:0%;
        position: relative
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-push-1 {
        left:4.1667%;
        position: relative
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-push-10 {
        left:41.6667%;
        position: relative
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-push-11 {
        left:45.8333%;
        position: relative
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-push-12 {
        left:50%;
        position: relative
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-push-13 {
        left:54.1667%;
        position: relative
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-push-14 {
        left:58.3333%;
        position: relative
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-push-15 {
        left:62.5%;
        position: relative
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-push-16 {
        left:66.6667%;
        position: relative
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-push-17 {
        left:70.8333%;
        position: relative
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-push-18 {
        left:75%;
        position: relative
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-push-19 {
        left:79.1667%;
        position: relative
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-push-2 {
        left:8.3333%;
        position: relative
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-push-20 {
        left:83.3333%;
        position: relative
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-push-21 {
        left:87.5%;
        position: relative
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-push-22 {
        left:91.6667%;
        position: relative
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-push-23 {
        left:95.8333%;
        position: relative
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-push-24 {
        left:100%;
        position: relative
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-push-3 {
        left:12.5%;
        position: relative
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-push-4 {
        left:16.6667%;
        position: relative
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-push-5 {
        left:20.8333%;
        position: relative
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-push-6 {
        left:25%;
        position: relative
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-push-7 {
        left:29.1667%;
        position: relative
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-push-8 {
        left:33.3333%;
        position: relative
    }
}

@media only screen and (min-width: 992px) {
    .ikun-md\:k-col-md-push-9 {
        left:37.5%;
        position: relative
    }
}

@media (min-width: 768px) {
    [md~=block] {
        display:block
    }

    [md~=border] {
        border-width: 1px
    }
}

[k-popover-arrow].svelte-13arsd0:after {
    content: " ";
    width: 8px;
    height: 8px;
    transform: rotate(45deg);
    background-color: var(--ikun-white);
    top: 0;
    position: absolute;
    left: 0
}

.dark [k-popover-arrow]:after {
    background-color: var(--ikun-dark-300)
}

[data-popper-arrow-top].svelte-13arsd0 {
    bottom: 4px;
    position: absolute;
    left: calc(50% - 4px)
}

.dark [data-popper-arrow-top]:after {
    box-shadow: 4px 4px 8px #f8a153cc
}

[data-popper-arrow-bottom].svelte-13arsd0 {
    top: -4px;
    position: absolute;
    left: calc(50% - 4px)
}

.dark [data-popper-arrow-bottom]:after {
    box-shadow: -4px -4px 8px #f8a153cc
}

[data-popper-arrow-right].svelte-13arsd0 {
    top: calc(50% - 4px);
    position: absolute;
    left: -4px
}

.dark [data-popper-arrow-right]:after {
    box-shadow: -4px 4px 8px #f8a153cc
}

[data-popper-arrow-left].svelte-13arsd0 {
    top: calc(50% - 4px);
    position: absolute;
    right: 4px
}

.dark [data-popper-arrow-left]:after {
    box-shadow: 4px -4px 8px #f8a153cc
}

.k-scrollbar::-webkit-scrollbar-track-piece {
    background: var(--k-scrollbar--track);
    border-radius: var(--k-scrollbar--track__radius)
}

.k-scrollbar::-webkit-scrollbar {
    width: var(--k-scrollbar__w);
    height: var(--k-scrollbar__h)
}

.k-scrollbar::-webkit-scrollbar-thumb {
    background: var(--k-scrollbar--thumb);
    border-radius: var(--k-scrollbar--thumb__radius)
}

.k-button--base+.k-button--base {
    margin-left: .5rem
}

.k-button-group .k-button--base+.k-button--base {
    margin-left: 0
}

.k-button--primary__fill {
    color: #ccfbf1!important
}

.demo-indicators {
    bottom: -2px
}

.demo-carousel-item.svelte-1c5n2gd {
    margin-left: 2px;
    margin-right: 2px;
    width: 26px;
    height: 8px;
    cursor: pointer;
    border-radius: .25rem;
    --un-bg-opacity: 1;
    background-color: rgb(251 146 60 / var(--un-bg-opacity))
}

.demo-carousel-item--active.svelte-1c5n2gd {
    --un-bg-opacity: 1;
    background-color: rgb(234 88 12 / var(--un-bg-opacity))
}

.k-input--inner.svelte-1ibt20v::-webkit-inner-spin-button,.k-input--inner.svelte-1ibt20v::-webkit-outer-spin-button {
    -webkit-appearance: none;
    margin: 0
}

.countdown-footer {
    font-size: 14px;
    margin: 4px auto 0
}

.demo-image.svelte-1ep430a .block.svelte-1ep430a {
    padding: 30px 0;
    text-align: center;
    border-right: solid 1px rgb(226 232 240);
    display: inline-block;
    width: 20%;
    box-sizing: border-box;
    vertical-align: top
}

.demo-image.svelte-1ep430a .block.svelte-1ep430a:last-child {
    border-right: none
}

.demo-image.svelte-1ep430a .demonstration.svelte-1ep430a {
    display: block;
    color: var(--vp-c-text-1);
    font-size: 14px;
    margin-bottom: 20px
}

.demo-image__error.svelte-54i4sh .block.svelte-54i4sh {
    padding: 30px 0;
    text-align: center;
    display: inline-block;
    width: 49%;
    box-sizing: border-box;
    vertical-align: top
}

.demo-image__error.svelte-54i4sh .demonstration.svelte-54i4sh {
    display: block;
    color: var(--vp-c-text-1);
    font-size: 14px;
    margin-bottom: 20px
}

.demo-image__error .k-image {
    padding: 0 5px;
    max-width: 300px;
    max-height: 200px;
    width: 100%;
    height: 200px
}

.demo-image__error.svelte-54i4sh .image-slot.svelte-54i4sh {
    display: flex;
    justify-content: center;
    align-items: center;
    width: 100%;
    height: 100%;
    background: #f3f4f6;
    color: var(--vp-c-text-1);
    font-size: 30px
}

.demo-image__lazy.svelte-rc5e0r {
    height: 400px;
    overflow-y: auto
}

.demo-image__lazy .k-image {
    display: block;
    min-height: 200px;
    margin-bottom: 10px
}

.demo-image__lazy .k-image:last-child {
    margin-bottom: 0
}

.demo-image__placeholder.svelte-1d07oqs .block.svelte-1d07oqs {
    padding: 30px 0;
    text-align: center;
    display: inline-block;
    width: 49%;
    box-sizing: border-box;
    vertical-align: top
}

.demo-image__placeholder.svelte-1d07oqs .demonstration.svelte-1d07oqs {
    display: block;
    color: var(--vp-c-text-1);
    font-size: 14px;
    margin-bottom: 20px
}

.demo-image__placeholder .k-image {
    padding: 0 5px;
    max-width: 300px;
    max-height: 200px
}

.demo-image__placeholder.image-slot {
    display: flex;
    justify-content: center;
    align-items: center;
    width: 100%;
    height: 100%;
    background: #909399;
    color: var(--vp-c-text-1);
    font-size: 14px
}

.demo-image__placeholder.svelte-1d07oqs .dot.svelte-1d07oqs {
    animation: dot 2s infinite steps(3,start);
    overflow: hidden
}

.demo-image__preview.svelte-1yc3cl1 {
    height: 100px;
    width: 100px
}

.custom-segmented-item.svelte-1lybzi {
    z-index: 1;
    padding-left: 12px;
    padding-right: 12px
}

.custom-icon.svelte-a5uo5u {
    width: 32px;
    height: 32px;
    display: flex;
    align-items: center;
    justify-content: center
}

.custom-title.svelte-a5uo5u,.custom-sub-title.svelte-a5uo5u {
    display: inline
}

.k-tabs__nav::-webkit-scrollbar-track-piece {
    background: transparent
}

.k-tabs__nav::-webkit-scrollbar {
    width: 0;
    height: 0
}

.k-tabs__header:after {
    content: "";
    position: absolute;
    left: 0;
    bottom: 0;
    width: 100%;
    height: 2px;
    background-color: var(--ikun-zinc-300)
}

.k-tabs__header--card:after,.k-tabs__header--border:after {
    content: "";
    position: absolute;
    left: 0;
    bottom: 0;
    width: 100%;
    border-left-width: 0px;
    border-top-width: 0px;
    border-bottom-width: 1px;
    border-right-width: 0px;
    border-color: var(--ikun-zinc-300);
    border-style: solid;
    background-color: var(--ikun-zinc-300)
}

.k-tabs>.k-tabs__header--card .k-tabs__nav-item:first-child {
    border-left: none
}

.k-tabs>.k-tabs__header--border .k-tabs__nav-item:first-child {
    border-left: none;
    border-top-left-radius: .25rem;
    border-top-right-radius: .25rem
}
